/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.OS;

import tango.stdc.string;

import dwt.dwthelper.utils;
import dwt.internal.C;
import dwt.internal.Library;
import dwt.internal.Platform;

static import Gestalt = dwt.internal.c.carboncore.Gestalt;
import dwt.internal.c.carboncore.MacTypes;
static import Processes = dwt.internal.c.hiservices.Processes;
static import dwt.internal.c.qd.Quickdraw;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSString;
static import NSAccessibility = dwt.internal.objc.appkit.NSAccessibility;
static import NSAttributedString = dwt.internal.objc.appkit.NSAttributedString;
static import NSGraphics = dwt.internal.objc.appkit.NSGraphics;
static import NSScreen = dwt.internal.objc.appkit.NSScreen;
static import CGRemoteOperation = dwt.internal.objc.coregraphics.CGRemoteOperation;
static import NSGeometry = dwt.internal.objc.foundation.NSGeometry;
static import NSHFSFileTypes = dwt.internal.objc.foundation.NSHFSFileTypes;
static import NSRunLoop = dwt.internal.objc.foundation.NSRunLoop;
static import dwt.internal.objc.runtime;

private alias dwt.internal.objc.runtime.objc_object objc_object;

struct ClassData
{
    dwt.internal.objc.runtime.id* var;
    String arg;
}

struct SelectorData
{
    String* var;
    String arg;
}

public class OS : C
{    
    private alias dwt.internal.objc.runtime.id id;
    /*static this ()
    {
        Library.loadLibrary("swt-pi"); //$NON-NLS-1$
    }*/

    public static const int VERSION;

    static this ()
    {
        int[1] response;
        OS.Gestalt(OS.gestaltSystemVersion, response);
        VERSION = response[0] & 0xffff;
        
        OS.sel_sendSelection = OS.sel_registerName("sendSelection");
        OS.sel_sendDoubleSelection = OS.sel_registerName("sendDoubleSelection");
        OS.sel_sendArrowSelection = OS.sel_registerName("sendArrowSelection");
        OS.sel_sendVerticalSelection = OS.sel_registerName("sendVerticalSelection");
        OS.sel_sendHorizontalSelection = OS.sel_registerName("sendHorizontalSelection");
        OS.sel_drawAtPoint_ = OS.sel_registerName("drawAtPoint:");
        OS.sel_timerProc_1 = OS.sel_registerName("timerProc:");

        foreach (data ; classesData)
            *data.var = objc_getClass(data.arg);
            
        foreach (data ; selectorData)
            *data.var = sel_registerName(data.arg);
    }
    
    //TODO - don't hard code
    public static const size_t PTR_SIZEOF = (void*).sizeof;
    
    public static const uint gestaltSystemVersion = ('s'<<24) + ('y'<<16) + ('s'<<8) + 'v';
    public static const short noErr = 0;
    alias Processes.kProcessTransformToForegroundApplication kProcessTransformToForegroundApplication;
    public static const int kAlertCautionIcon = ('c'<<24) + ('a'<<16) + ('u'<<8) + 't';
    public static const int kAlertNoteIcon = ('n'<<24) + ('o'<<16) + ('t'<<8) + 'e';
    public static const int kAlertStopIcon = ('s'<<24) + ('t'<<16) + ('o'<<8) + 'p';

    public static const String sel_sendSelection;
    public static const String sel_sendDoubleSelection;
    public static const String sel_sendArrowSelection;
    public static const String sel_sendVerticalSelection;
    public static const String sel_sendHorizontalSelection;
    public static const String sel_drawAtPoint_;
    public static const String sel_timerProc_1;
    
    Object JNIGetObject(NSInteger globalRef)
    {
        return cast(Object) globalRef;
    }
    
    alias Gestalt.Gestalt Gestalt;
    alias Processes.GetCurrentProcess GetCurrentProcess;
    alias Processes.SetFrontProcess SetFrontProcess;
    alias Processes.TransformProcessType TransformProcessType;
    alias NSGeometry.NSIntersectionRect NSIntersectionRect;
    alias CGRemoteOperation.CGWarpMouseCursorPosition CGWarpMouseCursorPosition;
    
    /** QuickDraw calls */
    alias dwt.internal.c.qd.Quickdraw.RegionToRectsProcPtr RegionToRectsProcPtr;
    alias dwt.internal.c.qd.Quickdraw.RegionToRectsUPP RegionToRectsUPP;
    alias dwt.internal.c.qd.Quickdraw.NewRgn NewRgn;
    alias dwt.internal.c.qd.Quickdraw.OpenRgn OpenRgn;
    alias dwt.internal.c.qd.Quickdraw.MoveTo MoveTo;
    alias dwt.internal.c.qd.Quickdraw.LineTo LineTo;
    alias dwt.internal.c.qd.Quickdraw.UnionRgn UnionRgn;
    alias dwt.internal.c.qd.Quickdraw.CloseRgn CloseRgn;
    alias dwt.internal.c.qd.Quickdraw.DisposeRgn DisposeRgn;
    alias dwt.internal.c.qd.Quickdraw.PtInRgn PtInRgn;
    alias dwt.internal.c.qd.Quickdraw.GetRegioinBounds GetRegioinBounds;
    alias dwt.internal.c.qd.Quickdraw.SectRgn SectRgn;
    alias dwt.internal.c.qd.Quickdraw.EmptyRgn EmptyRgn;
    alias dwt.internal.c.qd.Quickdraw.DiffRgn DiffRgn;
    alias dwt.internal.c.qd.Quickdraw.RectInRgn RectInRgn;
    alias dwt.internal.c.qd.Quickdraw.QDRegionToRects QDRegionToRects;
    alias dwt.internal.c.qd.Quickdraw.CopyRgn CopyRgn;
    alias dwt.internal.c.qd.Quickdraw.SetRect SetRect;
    
    public static const int kQDParseRegionFromTop = (1 << 0);
    public static const int kQDParseRegionFromBottom = (1 << 1);
    public static const int kQDParseRegionFromLeft = (1 << 2);
    public static const int kQDParseRegionFromRight = (1 << 3);
    public static const int kQDParseRegionFromTopLeft = kQDParseRegionFromTop | kQDParseRegionFromLeft;
    public static const int kQDRegionToRectsMsgParse = 2;
    
    /** objc runtime */
    static alias dwt.internal.objc.runtime.objc_registerClassPair objc_registerClassPair;
    alias dwt.internal.objc.runtime.class_addMethod class_addMethod;
    alias dwt.internal.objc.runtime.objc_allocateClassPair objc_allocateClassPair;
    alias dwt.internal.objc.runtime.objc_getClass objc_getClass;
    alias dwt.internal.objc.runtime.objc_lookUpClass objc_lookUpClass;
    alias dwt.internal.objc.runtime.object_getClassName object_getClassName;
    alias dwt.internal.objc.runtime.object_getInstanceVariable object_getInstanceVariable;
    alias dwt.internal.objc.runtime.object_setInstanceVariable object_setInstanceVariable;
    alias dwt.internal.objc.runtime.sel_registerName sel_registerName;
    alias dwt.internal.objc.runtime.objc_msgSend objc_msgSend;
    alias dwt.internal.objc.runtime.objc_msgSend_struct objc_msgSend_struct;
    alias dwt.internal.objc.runtime.objc_msgSend_stret objc_msgSend_stret;
    alias dwt.internal.objc.runtime.objc_msgSendSuper objc_msgSendSuper;
    
    version (X86)
        alias dwt.internal.objc.runtime.objc_msgSend_fpret objc_msgSend_fpret;
        
    alias dwt.internal.objc.runtime.drawRect_1CALLBACK drawRect_1CALLBACK;

    /** Classes */
    public static /*const*/ id class_NSScanner;
    public static /*const*/ id class_NSCIImageRep;
    public static /*const*/ id class_NSPathControl;
    public static /*const*/ id class_NSTreeController;
    public static /*const*/ id class_NSPDFImageRep;
    public static /*const*/ id class_NSPageLayout;
    public static /*const*/ id class_NSMetadataQueryAttributeValueTuple;
    public static /*const*/ id class_NSAppleScript;
    public static /*const*/ id class_NSGradient;
    public static /*const*/ id class_NSColorPanel;
    public static /*const*/ id class_NSPrinter;
    public static /*const*/ id class_NSCachedURLResponse;
    public static /*const*/ id class_NSLevelIndicatorCell;
    public static /*const*/ id class_NSScriptClassDescription;
    public static /*const*/ id class_NSDistantObjectRequest;
    public static /*const*/ id class_NSOpenPanel;
    public static /*const*/ id class_NSOperationQueue;
    public static /*const*/ id class_NSOpenGLPixelBuffer;
    public static /*const*/ id class_NSRelativeSpecifier;
    public static /*const*/ id class_NSTextStorage;
    public static /*const*/ id class_NSPopUpButtonCell;
    public static /*const*/ id class_NSTextContainer;
    public static /*const*/ id class_NSStepperCell;
    public static /*const*/ id class_NSTextTable;
    public static /*const*/ id class_NSInvocationOperation;
    public static /*const*/ id class_NSDeleteCommand;
    public static /*const*/ id class_NSImageView;
    public static /*const*/ id class_NSMovieView;
    public static /*const*/ id class_NSLock;
    public static /*const*/ id class_NSCoder;
    public static /*const*/ id class_NSXMLElement;
    public static /*const*/ id class_NSLayoutManager;
    public static /*const*/ id class_NSTabView;
    public static /*const*/ id class_NSSpeechRecognizer;
    public static /*const*/ id class_NSAttributedString;
    public static /*const*/ id class_NSProcessInfo;
    public static /*const*/ id class_NSTextFieldCell;
    public static /*const*/ id class_NSDate;
    public static /*const*/ id class_NSMachBootstrapServer;
    public static /*const*/ id class_NSData;
    public static /*const*/ id class_NSNumberFormatter;
    public static /*const*/ id class_NSPositionalSpecifier;
    public static /*const*/ id class_NSSegmentedControl;
    public static /*const*/ id class_NSMatrix;
    public static /*const*/ id class_NSPanel;
    public static /*const*/ id class_NSPrintInfo;
    public static /*const*/ id class_NSResponder;
    public static /*const*/ id class_NSNull;
    public static /*const*/ id class_NSRunLoop;
    public static /*const*/ id class_NSMutableAttributedString;
    public static /*const*/ id class_NSImageCell;
    public static /*const*/ id class_CIColor;
    public static /*const*/ id class_NSSegmentedCell;
    public static /*const*/ id class_NSDocument;
    public static /*const*/ id class_NSTextTab;
    public static /*const*/ id class_NSWhoseSpecifier;
    public static /*const*/ id class_NSMenu;
    public static /*const*/ id class_NSPopUpButton;
    public static /*const*/ id class_NSInvocation;
    public static /*const*/ id class_NSDatePicker;
    public static /*const*/ id class_NSSliderCell;
    public static /*const*/ id class_NSURLCache;
    public static /*const*/ id class_NSSpeechSynthesizer;
    public static /*const*/ id class_NSBezierPath;
    public static /*const*/ id class_NSSavePanel;
    public static /*const*/ id class_NSMetadataQuery;
    public static /*const*/ id class_NSLogicalTest;
    public static /*const*/ id class_NSAffineTransform;
    public static /*const*/ id class_NSTreeNode;
    public static /*const*/ id class_NSControl;
    public static /*const*/ id class_NSWindowController;
    public static /*const*/ id class_NSURLResponse;
    public static /*const*/ id class_NSFormatter;
    public static /*const*/ id class_NSAssertionHandler;
    public static /*const*/ id class_NSPort;
    public static /*const*/ id class_NSURLProtectionSpace;
    public static /*const*/ id class_NSPredicate;
    public static /*const*/ id class_NSIndexSpecifier;
    public static /*const*/ id class_NSPortMessage;
    public static /*const*/ id class_NSTypesetter;
    public static /*const*/ id class_NSCompoundPredicate;
    public static /*const*/ id class_NSBundle;
    public static /*const*/ id class_NSSortDescriptor;
    public static /*const*/ id class_NSFontManager;
    public static /*const*/ id class_NSProxy;
    public static /*const*/ id class_NSTextView;
    public static /*const*/ id class_NSMutableSet;
    public static /*const*/ id class_NSDatePickerCell;
    public static /*const*/ id class_NSStatusItem;
    public static /*const*/ id class_NSDirectoryEnumerator;
    public static /*const*/ id class_NSPropertyListSerialization;
    public static /*const*/ id class_NSHost;
    public static /*const*/ id class_NSPipe;
    public static /*const*/ id class_NSNibConnector;
    public static /*const*/ id class_NSDecimalNumber;
    public static /*const*/ id class_NSMenuView;
    public static /*const*/ id class_NSMenuItem;
    public static /*const*/ id class_NSPICTImageRep;
    public static /*const*/ id class_NSPasteboard;
    public static /*const*/ id class_NSScriptExecutionContext;
    public static /*const*/ id class_NSNotificationQueue;
    public static /*const*/ id class_NSError;
    public static /*const*/ id class_NSNib;
    public static /*const*/ id class_NSAppleEventManager;
    public static /*const*/ id class_NSCondition;
    public static /*const*/ id class_NSBrowser;
    public static /*const*/ id class_NSDocumentController;
    public static /*const*/ id class_NSMethodSignature;
    public static /*const*/ id class_NSTextList;
    public static /*const*/ id class_NSURLCredentialStorage;
    public static /*const*/ id class_NSEvent;
    public static /*const*/ id class_NSScreen;
    public static /*const*/ id class_NSMutableCharacterSet;
    public static /*const*/ id class_NSSecureTextFieldCell;
    public static /*const*/ id class_NSOpenGLPixelFormat;
    public static /*const*/ id class_NSInputServer;
    public static /*const*/ id class_NSNotification;
    public static /*const*/ id class_NSSpecifierTest;
    public static /*const*/ id class_NSCustomImageRep;
    public static /*const*/ id class_NSParagraphStyle;
    public static /*const*/ id class_NSTableView;
    public static /*const*/ id class_NSFileWrapper;
    public static /*const*/ id class_NSNotificationCenter;
    public static /*const*/ id class_NSMutableString;
    public static /*const*/ id class_NSFontPanel;
    public static /*const*/ id class_NSAppleEventDescriptor;
    public static /*const*/ id class_NSConnection;
    public static /*const*/ id class_NSURLDownload;
    public static /*const*/ id class_NSKeyedUnarchiver;
    public static /*const*/ id class_NSCountedSet;
    public static /*const*/ id class_NSSlider;
    public static /*const*/ id class_NSCharacterSet;
    public static /*const*/ id class_NSDictionary;
    public static /*const*/ id class_NSOpenGLContext;
    public static /*const*/ id class_NSCachedImageRep;
    public static /*const*/ id class_NSURL;
    public static /*const*/ id class_NSInputStream;
    public static /*const*/ id class_NSMutableURLRequest;
    public static /*const*/ id class_NSURLConnection;
    public static /*const*/ id class_NSPersistentDocument;
    public static /*const*/ id class_NSClipView;
    public static /*const*/ id class_NSScriptSuiteRegistry;
    public static /*const*/ id class_NSStepper;
    public static /*const*/ id class_NSXMLNode;
    public static /*const*/ id class_NSHTTPCookie;
    public static /*const*/ id class_NSMetadataQueryResultGroup;
    public static /*const*/ id class_NSURLCredential;
    public static /*const*/ id class_NSHashTable;
    public static /*const*/ id class_NSColor;
    public static /*const*/ id class_NSPathComponentCell;
    public static /*const*/ id class_NSToolbar;
    public static /*const*/ id class_NSUndoManager;
    public static /*const*/ id class_NSNibControlConnector;
    public static /*const*/ id class_NSFontDescriptor;
    public static /*const*/ id class_NSSpellChecker;
    public static /*const*/ id class_NSTableColumn;
    public static /*const*/ id class_NSSpellServer;
    public static /*const*/ id class_NSAutoreleasePool;
    public static /*const*/ id class_NSUnarchiver;
    public static /*const*/ id class_NSColorSpace;
    public static /*const*/ id class_NSQuickDrawView;
    public static /*const*/ id class_NSDrawer;
    public static /*const*/ id class_NSFileHandle;
    public static /*const*/ id class_NSCalendarDate;
    public static /*const*/ id class_NSThread;
    public static /*const*/ id class_NSProtocolChecker;
    public static /*const*/ id class_NSDateComponents;
    public static /*const*/ id class_NSAnimationContext;
    public static /*const*/ id class_NSURLRequest;
    public static /*const*/ id class_NSViewAnimation;
    public static /*const*/ id class_NSScriptObjectSpecifier;
    public static /*const*/ id class_NSCell;
    public static /*const*/ id class_NSTableHeaderCell;
    public static /*const*/ id class_NSATSTypesetter;
    public static /*const*/ id class_NSNetService;
    public static /*const*/ id class_NSMutableParagraphStyle;
    public static /*const*/ id class_NSButton;
    public static /*const*/ id class_NSAnimation;
    public static /*const*/ id class_NSText;
    public static /*const*/ id class_NSMapTable;
    public static /*const*/ id class_NSDictionaryController;
    public static /*const*/ id class_NSTrackingArea;
    public static /*const*/ id class_NSURLProtocol;
    public static /*const*/ id class_NSGlyphInfo;
    public static /*const*/ id class_NSSocketPortNameServer;
    public static /*const*/ id class_NSQuitCommand;
    public static /*const*/ id class_NSDistributedNotificationCenter;
    public static /*const*/ id class_NSCloseCommand;
    public static /*const*/ id class_NSPrintOperation;
    public static /*const*/ id class_NSGraphicsContext;
    public static /*const*/ id class_NSNumber;
    public static /*const*/ id class_NSPortCoder;
    public static /*const*/ id class_NSTextTableBlock;
    public static /*const*/ id class_NSNibOutletConnector;
    public static /*const*/ id class_NSLocale;
    public static /*const*/ id class_NSTableHeaderView;
    public static /*const*/ id class_NSScriptWhoseTest;
    public static /*const*/ id class_NSNetServiceBrowser;
    public static /*const*/ id class_NSConditionLock;
    public static /*const*/ id class_NSTimeZone;
    public static /*const*/ id class_NSComparisonPredicate;
    public static /*const*/ id class_NSScriptCoercionHandler;
    public static /*const*/ id class_NSFileManager;
    public static /*const*/ id class_NSPredicateEditorRowTemplate;
    public static /*const*/ id class_NSString;
    public static /*const*/ id class_NSToolbarItem;
    public static /*const*/ id class_NSPointerArray;
    public static /*const*/ id class_NSURLAuthenticationChallenge;
    public static /*const*/ id class_NSStatusBar;
    public static /*const*/ id class_NSTextField;
    public static /*const*/ id class_NSSecureTextField;
    public static /*const*/ id class_NSOutputStream;
    public static /*const*/ id class_NSComboBoxCell;
    public static /*const*/ id class_NSXMLDTDNode;
    public static /*const*/ id class_NSMessagePortNameServer;
    public static /*const*/ id class_NSHTTPCookieStorage;
    public static /*const*/ id class_NSActionCell;
    public static /*const*/ id class_NSXMLDocument;
    public static /*const*/ id class_NSBitmapImageRep;
    public static /*const*/ id class_NSHTTPURLResponse;
    public static /*const*/ id class_NSImage;
    public static /*const*/ id class_NSIndexSet;
    public static /*const*/ id class_NSRangeSpecifier;
    public static /*const*/ id class_NSGlyphGenerator;
    public static /*const*/ id class_NSFormCell;
    public static /*const*/ id class_NSScroller;
    public static /*const*/ id class_NSMetadataItem;
    public static /*const*/ id class_NSStream;
    public static /*const*/ id class_NSClassDescription;
    public static /*const*/ id class_NSMutableIndexSet;
    public static /*const*/ id class_NSView;
    public static /*const*/ id class_NSUserDefaults;
    public static /*const*/ id class_NSSetCommand;
    public static /*const*/ id class_NSPathCell;
    public static /*const*/ id class_NSMoveCommand;
    public static /*const*/ id class_NSSplitView;
    public static /*const*/ id class_NSTextBlock;
    public static /*const*/ id class_NSTabViewItem;
    public static /*const*/ id class_NSCollectionViewItem;
    public static /*const*/ id class_NSValue;
    public static /*const*/ id class_NSHelpManager;
    public static /*const*/ id class_NSEnumerator;
    public static /*const*/ id class_NSDistantObject;
    public static /*const*/ id class_NSGarbageCollector;
    public static /*const*/ id class_NSXMLParser;
    public static /*const*/ id class_NSFont;
    public static /*const*/ id class_NSAlert;
    public static /*const*/ id class_NSUniqueIDSpecifier;
    public static /*const*/ id class_NSOutlineView;
    public static /*const*/ id class_NSProgressIndicator;
    public static /*const*/ id class_NSController;
    public static /*const*/ id class_NSComboBox;
    public static /*const*/ id class_NSArrayController;
    public static /*const*/ id class_NSKeyedArchiver;
    public static /*const*/ id class_NSDecimalNumberHandler;
    public static /*const*/ id class_NSObject;
    public static /*const*/ id class_NSNameSpecifier;
    public static /*const*/ id class_NSUserDefaultsController;
    public static /*const*/ id class_NSLevelIndicator;
    public static /*const*/ id class_NSDistributedLock;
    public static /*const*/ id class_NSTokenFieldCell;
    public static /*const*/ id class_NSSet;
    public static /*const*/ id class_NSMutableData;
    public static /*const*/ id class_NSArray;
    public static /*const*/ id class_NSExpression;
    public static /*const*/ id class_NSMenuItemCell;
    public static /*const*/ id class_NSColorPicker;
    public static /*const*/ id class_NSForm;
    public static /*const*/ id class_NSApplication;
    public static /*const*/ id class_NSInputManager;
    public static /*const*/ id class_NSPointerFunctions;
    public static /*const*/ id class_NSRecursiveLock;
    public static /*const*/ id class_NSBox;
    public static /*const*/ id class_NSDockTile;
    public static /*const*/ id class_NSTextAttachment;
    public static /*const*/ id class_NSIndexPath;
    public static /*const*/ id class_NSEPSImageRep;
    public static /*const*/ id class_NSBrowserCell;
    public static /*const*/ id class_NSValueTransformer;
    public static /*const*/ id class_CIImage;
    public static /*const*/ id class_NSMovie;
    public static /*const*/ id class_NSTimer;
    public static /*const*/ id class_NSMachPort;
    public static /*const*/ id class_NSCreateCommand;
    public static /*const*/ id class_NSPortNameServer;
    public static /*const*/ id class_NSRulerMarker;
    public static /*const*/ id class_NSImageRep;
    public static /*const*/ id class_NSWindow;
    public static /*const*/ id class_NSColorWell;
    public static /*const*/ id class_NSSound;
    public static /*const*/ id class_NSToolbarItemGroup;
    public static /*const*/ id class_NSRulerView;
    public static /*const*/ id class_NSWorkspace;
    public static /*const*/ id class_NSSearchFieldCell;
    public static /*const*/ id class_NSMutableArray;
    public static /*const*/ id class_NSRuleEditor;
    public static /*const*/ id class_NSScriptCommandDescription;
    public static /*const*/ id class_NSViewController;
    public static /*const*/ id class_NSPredicateEditor;
    public static /*const*/ id class_NSCloneCommand;
    public static /*const*/ id class_NSOpenGLView;
    public static /*const*/ id class_NSCursor;
    public static /*const*/ id class_NSSearchField;
    public static /*const*/ id class_NSXMLDTD;
    public static /*const*/ id class_NSSocketPort;
    public static /*const*/ id class_NSObjectController;
    public static /*const*/ id class_NSScriptCommand;
    public static /*const*/ id class_NSShadow;
    public static /*const*/ id class_NSScrollView;
    public static /*const*/ id class_NSPrintPanel;
    public static /*const*/ id class_NSURLHandle;
    public static /*const*/ id class_NSOperation;
    public static /*const*/ id class_NSMutableDictionary;
    public static /*const*/ id class_NSException;
    public static /*const*/ id class_NSButtonCell;
    public static /*const*/ id class_NSTask;
    public static /*const*/ id class_NSArchiver;
    public static /*const*/ id class_NSDateFormatter;
    public static /*const*/ id class_NSCalendar;
    public static /*const*/ id class_NSTokenField;
    public static /*const*/ id class_NSCollectionView;
    public static /*const*/ id class_NSColorList;
    public static /*const*/ id class_DOMEvent;
    public static /*const*/ id class_DOMWheelEvent;
    public static /*const*/ id class_WebView;
    public static /*const*/ id class_WebPreferences;
    public static /*const*/ id class_WebFrameView;
    
    private static const ClassData[] classesData = [
        { &class_NSScanner, "NSScanner" },
        { &class_NSCIImageRep, "NSCIImageRep" },
        { &class_NSPathControl, "NSPathControl" },
        { &class_NSTreeController, "NSTreeController" },
        { &class_NSPDFImageRep, "NSPDFImageRep" },
        { &class_NSPageLayout, "NSPageLayout" },
        { &class_NSMetadataQueryAttributeValueTuple, "NSMetadataQueryAttributeValueTuple" },
        { &class_NSAppleScript, "NSAppleScript" },
        { &class_NSGradient, "NSGradient" },
        { &class_NSColorPanel, "NSColorPanel" },
        { &class_NSPrinter, "NSPrinter" },
        { &class_NSCachedURLResponse, "NSCachedURLResponse" },
        { &class_NSLevelIndicatorCell, "NSLevelIndicatorCell" },
        { &class_NSScriptClassDescription, "NSScriptClassDescription" },
        { &class_NSDistantObjectRequest, "NSDistantObjectRequest" },
        { &class_NSOpenPanel, "NSOpenPanel" },
        { &class_NSOperationQueue, "NSOperationQueue" },
        { &class_NSOpenGLPixelBuffer, "NSOpenGLPixelBuffer" },
        { &class_NSRelativeSpecifier, "NSRelativeSpecifier" },
        { &class_NSTextStorage, "NSTextStorage" },
        { &class_NSPopUpButtonCell, "NSPopUpButtonCell" },
        { &class_NSTextContainer, "NSTextContainer" },
        { &class_NSStepperCell, "NSStepperCell" },
        { &class_NSTextTable, "NSTextTable" },
        { &class_NSInvocationOperation, "NSInvocationOperation" },
        { &class_NSDeleteCommand, "NSDeleteCommand" },
        { &class_NSImageView, "NSImageView" },
        { &class_NSMovieView, "NSMovieView" },
        { &class_NSLock, "NSLock" },
        { &class_NSCoder, "NSCoder" },
        { &class_NSXMLElement, "NSXMLElement" },
        { &class_NSLayoutManager, "NSLayoutManager" },
        { &class_NSTabView, "NSTabView" },
        { &class_NSSpeechRecognizer, "NSSpeechRecognizer" },
        { &class_NSAttributedString, "NSAttributedString" },
        { &class_NSProcessInfo, "NSProcessInfo" },
        { &class_NSTextFieldCell, "NSTextFieldCell" },
        { &class_NSDate, "NSDate" },
        { &class_NSMachBootstrapServer, "NSMachBootstrapServer" },
        { &class_NSData, "NSData" },
        { &class_NSNumberFormatter, "NSNumberFormatter" },
        { &class_NSPositionalSpecifier, "NSPositionalSpecifier" },
        { &class_NSSegmentedControl, "NSSegmentedControl" },
        { &class_NSMatrix, "NSMatrix" },
        { &class_NSPanel, "NSPanel" },
        { &class_NSPrintInfo, "NSPrintInfo" },
        { &class_NSResponder, "NSResponder" },
        { &class_NSNull, "NSNull" },
        { &class_NSRunLoop, "NSRunLoop" },
        { &class_NSMutableAttributedString, "NSMutableAttributedString" },
        { &class_NSImageCell, "NSImageCell" },
        { &class_CIColor, "CIColor" },
        { &class_NSSegmentedCell, "NSSegmentedCell" },
        { &class_NSDocument, "NSDocument" },
        { &class_NSTextTab, "NSTextTab" },
        { &class_NSWhoseSpecifier, "NSWhoseSpecifier" },
        { &class_NSMenu, "NSMenu" },
        { &class_NSPopUpButton, "NSPopUpButton" },
        { &class_NSInvocation, "NSInvocation" },
        { &class_NSDatePicker, "NSDatePicker" },
        { &class_NSSliderCell, "NSSliderCell" },
        { &class_NSURLCache, "NSURLCache" },
        { &class_NSSpeechSynthesizer, "NSSpeechSynthesizer" },
        { &class_NSBezierPath, "NSBezierPath" },
        { &class_NSSavePanel, "NSSavePanel" },
        { &class_NSMetadataQuery, "NSMetadataQuery" },
        { &class_NSLogicalTest, "NSLogicalTest" },
        { &class_NSAffineTransform, "NSAffineTransform" },
        { &class_NSTreeNode, "NSTreeNode" },
        { &class_NSControl, "NSControl" },
        { &class_NSWindowController, "NSWindowController" },
        { &class_NSURLResponse, "NSURLResponse" },
        { &class_NSFormatter, "NSFormatter" },
        { &class_NSAssertionHandler, "NSAssertionHandler" },
        { &class_NSPort, "NSPort" },
        { &class_NSURLProtectionSpace, "NSURLProtectionSpace" },
        { &class_NSPredicate, "NSPredicate" },
        { &class_NSIndexSpecifier, "NSIndexSpecifier" },
        { &class_NSPortMessage, "NSPortMessage" },
        { &class_NSTypesetter, "NSTypesetter" },
        { &class_NSCompoundPredicate, "NSCompoundPredicate" },
        { &class_NSBundle, "NSBundle" },
        { &class_NSSortDescriptor, "NSSortDescriptor" },
        { &class_NSFontManager, "NSFontManager" },
        { &class_NSProxy, "NSProxy" },
        { &class_NSTextView, "NSTextView" },
        { &class_NSMutableSet, "NSMutableSet" },
        { &class_NSDatePickerCell, "NSDatePickerCell" },
        { &class_NSStatusItem, "NSStatusItem" },
        { &class_NSDirectoryEnumerator, "NSDirectoryEnumerator" },
        { &class_NSPropertyListSerialization, "NSPropertyListSerialization" },
        { &class_NSHost, "NSHost" },
        { &class_NSPipe, "NSPipe" },
        { &class_NSNibConnector, "NSNibConnector" },
        { &class_NSDecimalNumber, "NSDecimalNumber" },
        { &class_NSMenuView, "NSMenuView" },
        { &class_NSMenuItem, "NSMenuItem" },
        { &class_NSPICTImageRep, "NSPICTImageRep" },
        { &class_NSPasteboard, "NSPasteboard" },
        { &class_NSScriptExecutionContext, "NSScriptExecutionContext" },
        { &class_NSNotificationQueue, "NSNotificationQueue" },
        { &class_NSError, "NSError" },
        { &class_NSNib, "NSNib" },
        { &class_NSAppleEventManager, "NSAppleEventManager" },
        { &class_NSCondition, "NSCondition" },
        { &class_NSBrowser, "NSBrowser" },
        { &class_NSDocumentController, "NSDocumentController" },
        { &class_NSMethodSignature, "NSMethodSignature" },
        { &class_NSTextList, "NSTextList" },
        { &class_NSURLCredentialStorage, "NSURLCredentialStorage" },
        { &class_NSEvent, "NSEvent" },
        { &class_NSScreen, "NSScreen" },
        { &class_NSMutableCharacterSet, "NSMutableCharacterSet" },
        { &class_NSSecureTextFieldCell, "NSSecureTextFieldCell" },
        { &class_NSOpenGLPixelFormat, "NSOpenGLPixelFormat" },
        { &class_NSInputServer, "NSInputServer" },
        { &class_NSNotification, "NSNotification" },
        { &class_NSSpecifierTest, "NSSpecifierTest" },
        { &class_NSCustomImageRep, "NSCustomImageRep" },
        { &class_NSParagraphStyle, "NSParagraphStyle" },
        { &class_NSTableView, "NSTableView" },
        { &class_NSFileWrapper, "NSFileWrapper" },
        { &class_NSNotificationCenter, "NSNotificationCenter" },
        { &class_NSMutableString, "NSMutableString" },
        { &class_NSFontPanel, "NSFontPanel" },
        { &class_NSAppleEventDescriptor, "NSAppleEventDescriptor" },
        { &class_NSConnection, "NSConnection" },
        { &class_NSURLDownload, "NSURLDownload" },
        { &class_NSKeyedUnarchiver, "NSKeyedUnarchiver" },
        { &class_NSCountedSet, "NSCountedSet" },
        { &class_NSSlider, "NSSlider" },
        { &class_NSCharacterSet, "NSCharacterSet" },
        { &class_NSDictionary, "NSDictionary" },
        { &class_NSOpenGLContext, "NSOpenGLContext" },
        { &class_NSCachedImageRep, "NSCachedImageRep" },
        { &class_NSURL, "NSURL" },
        { &class_NSInputStream, "NSInputStream" },
        { &class_NSMutableURLRequest, "NSMutableURLRequest" },
        { &class_NSURLConnection, "NSURLConnection" },
        { &class_NSPersistentDocument, "NSPersistentDocument" },
        { &class_NSClipView, "NSClipView" },
        { &class_NSScriptSuiteRegistry, "NSScriptSuiteRegistry" },
        { &class_NSStepper, "NSStepper" },
        { &class_NSXMLNode, "NSXMLNode" },
        { &class_NSHTTPCookie, "NSHTTPCookie" },
        { &class_NSMetadataQueryResultGroup, "NSMetadataQueryResultGroup" },
        { &class_NSURLCredential, "NSURLCredential" },
        { &class_NSHashTable, "NSHashTable" },
        { &class_NSColor, "NSColor" },
        { &class_NSPathComponentCell, "NSPathComponentCell" },
        { &class_NSToolbar, "NSToolbar" },
        { &class_NSUndoManager, "NSUndoManager" },
        { &class_NSNibControlConnector, "NSNibControlConnector" },
        { &class_NSFontDescriptor, "NSFontDescriptor" },
        { &class_NSSpellChecker, "NSSpellChecker" },
        { &class_NSTableColumn, "NSTableColumn" },
        { &class_NSSpellServer, "NSSpellServer" },
        { &class_NSAutoreleasePool, "NSAutoreleasePool" },
        { &class_NSUnarchiver, "NSUnarchiver" },
        { &class_NSColorSpace, "NSColorSpace" },
        { &class_NSQuickDrawView, "NSQuickDrawView" },
        { &class_NSDrawer, "NSDrawer" },
        { &class_NSFileHandle, "NSFileHandle" },
        { &class_NSCalendarDate, "NSCalendarDate" },
        { &class_NSThread, "NSThread" },
        { &class_NSProtocolChecker, "NSProtocolChecker" },
        { &class_NSDateComponents, "NSDateComponents" },
        { &class_NSAnimationContext, "NSAnimationContext" },
        { &class_NSURLRequest, "NSURLRequest" },
        { &class_NSViewAnimation, "NSViewAnimation" },
        { &class_NSScriptObjectSpecifier, "NSScriptObjectSpecifier" },
        { &class_NSCell, "NSCell" },
        { &class_NSTableHeaderCell, "NSTableHeaderCell" },
        { &class_NSATSTypesetter, "NSATSTypesetter" },
        { &class_NSNetService, "NSNetService" },
        { &class_NSMutableParagraphStyle, "NSMutableParagraphStyle" },
        { &class_NSButton, "NSButton" },
        { &class_NSAnimation, "NSAnimation" },
        { &class_NSText, "NSText" },
        { &class_NSMapTable, "NSMapTable" },
        { &class_NSDictionaryController, "NSDictionaryController" },
        { &class_NSTrackingArea, "NSTrackingArea" },
        { &class_NSURLProtocol, "NSURLProtocol" },
        { &class_NSGlyphInfo, "NSGlyphInfo" },
        { &class_NSSocketPortNameServer, "NSSocketPortNameServer" },
        { &class_NSQuitCommand, "NSQuitCommand" },
        { &class_NSDistributedNotificationCenter, "NSDistributedNotificationCenter" },
        { &class_NSCloseCommand, "NSCloseCommand" },
        { &class_NSPrintOperation, "NSPrintOperation" },
        { &class_NSGraphicsContext, "NSGraphicsContext" },
        { &class_NSNumber, "NSNumber" },
        { &class_NSPortCoder, "NSPortCoder" },
        { &class_NSTextTableBlock, "NSTextTableBlock" },
        { &class_NSNibOutletConnector, "NSNibOutletConnector" },
        { &class_NSLocale, "NSLocale" },
        { &class_NSTableHeaderView, "NSTableHeaderView" },
        { &class_NSScriptWhoseTest, "NSScriptWhoseTest" },
        { &class_NSNetServiceBrowser, "NSNetServiceBrowser" },
        { &class_NSConditionLock, "NSConditionLock" },
        { &class_NSTimeZone, "NSTimeZone" },
        { &class_NSComparisonPredicate, "NSComparisonPredicate" },
        { &class_NSScriptCoercionHandler, "NSScriptCoercionHandler" },
        { &class_NSFileManager, "NSFileManager" },
        { &class_NSPredicateEditorRowTemplate, "NSPredicateEditorRowTemplate" },
        { &class_NSString, "NSString" },
        { &class_NSToolbarItem, "NSToolbarItem" },
        { &class_NSPointerArray, "NSPointerArray" },
        { &class_NSURLAuthenticationChallenge, "NSURLAuthenticationChallenge" },
        { &class_NSStatusBar, "NSStatusBar" },
        { &class_NSTextField, "NSTextField" },
        { &class_NSSecureTextField, "NSSecureTextField" },
        { &class_NSOutputStream, "NSOutputStream" },
        { &class_NSComboBoxCell, "NSComboBoxCell" },
        { &class_NSXMLDTDNode, "NSXMLDTDNode" },
        { &class_NSMessagePortNameServer, "NSMessagePortNameServer" },
        { &class_NSHTTPCookieStorage, "NSHTTPCookieStorage" },
        { &class_NSActionCell, "NSActionCell" },
        { &class_NSXMLDocument, "NSXMLDocument" },
        { &class_NSBitmapImageRep, "NSBitmapImageRep" },
        { &class_NSHTTPURLResponse, "NSHTTPURLResponse" },
        { &class_NSImage, "NSImage" },
        { &class_NSIndexSet, "NSIndexSet" },
        { &class_NSRangeSpecifier, "NSRangeSpecifier" },
        { &class_NSGlyphGenerator, "NSGlyphGenerator" },
        { &class_NSFormCell, "NSFormCell" },
        { &class_NSScroller, "NSScroller" },
        { &class_NSMetadataItem, "NSMetadataItem" },
        { &class_NSStream, "NSStream" },
        { &class_NSClassDescription, "NSClassDescription" },
        { &class_NSMutableIndexSet, "NSMutableIndexSet" },
        { &class_NSView, "NSView" },
        { &class_NSUserDefaults, "NSUserDefaults" },
        { &class_NSSetCommand, "NSSetCommand" },
        { &class_NSPathCell, "NSPathCell" },
        { &class_NSMoveCommand, "NSMoveCommand" },
        { &class_NSSplitView, "NSSplitView" },
        { &class_NSTextBlock, "NSTextBlock" },
        { &class_NSTabViewItem, "NSTabViewItem" },
        { &class_NSCollectionViewItem, "NSCollectionViewItem" },
        { &class_NSValue, "NSValue" },
        { &class_NSHelpManager, "NSHelpManager" },
        { &class_NSEnumerator, "NSEnumerator" },
        { &class_NSDistantObject, "NSDistantObject" },
        { &class_NSGarbageCollector, "NSGarbageCollector" },
        { &class_NSXMLParser, "NSXMLParser" },
        { &class_NSFont, "NSFont" },
        { &class_NSAlert, "NSAlert" },
        { &class_NSUniqueIDSpecifier, "NSUniqueIDSpecifier" },
        { &class_NSOutlineView, "NSOutlineView" },
        { &class_NSProgressIndicator, "NSProgressIndicator" },
        { &class_NSController, "NSController" },
        { &class_NSComboBox, "NSComboBox" },
        { &class_NSArrayController, "NSArrayController" },
        { &class_NSKeyedArchiver, "NSKeyedArchiver" },
        { &class_NSDecimalNumberHandler, "NSDecimalNumberHandler" },
        { &class_NSObject, "NSObject" },
        { &class_NSNameSpecifier, "NSNameSpecifier" },
        { &class_NSUserDefaultsController, "NSUserDefaultsController" },
        { &class_NSLevelIndicator, "NSLevelIndicator" },
        { &class_NSDistributedLock, "NSDistributedLock" },
        { &class_NSTokenFieldCell, "NSTokenFieldCell" },
        { &class_NSSet, "NSSet" },
        { &class_NSMutableData, "NSMutableData" },
        { &class_NSArray, "NSArray" },
        { &class_NSExpression, "NSExpression" },
        { &class_NSMenuItemCell, "NSMenuItemCell" },
        { &class_NSColorPicker, "NSColorPicker" },
        { &class_NSForm, "NSForm" },
        { &class_NSApplication, "NSApplication" },
        { &class_NSInputManager, "NSInputManager" },
        { &class_NSPointerFunctions, "NSPointerFunctions" },
        { &class_NSRecursiveLock, "NSRecursiveLock" },
        { &class_NSBox, "NSBox" },
        { &class_NSDockTile, "NSDockTile" },
        { &class_NSTextAttachment, "NSTextAttachment" },
        { &class_NSIndexPath, "NSIndexPath" },
        { &class_NSEPSImageRep, "NSEPSImageRep" },
        { &class_NSBrowserCell, "NSBrowserCell" },
        { &class_NSValueTransformer, "NSValueTransformer" },
        { &class_CIImage, "CIImage" },
        { &class_NSMovie, "NSMovie" },
        { &class_NSTimer, "NSTimer" },
        { &class_NSMachPort, "NSMachPort" },
        { &class_NSCreateCommand, "NSCreateCommand" },
        { &class_NSPortNameServer, "NSPortNameServer" },
        { &class_NSRulerMarker, "NSRulerMarker" },
        { &class_NSImageRep, "NSImageRep" },
        { &class_NSWindow, "NSWindow" },
        { &class_NSColorWell, "NSColorWell" },
        { &class_NSSound, "NSSound" },
        { &class_NSToolbarItemGroup, "NSToolbarItemGroup" },
        { &class_NSRulerView, "NSRulerView" },
        { &class_NSWorkspace, "NSWorkspace" },
        { &class_NSSearchFieldCell, "NSSearchFieldCell" },
        { &class_NSMutableArray, "NSMutableArray" },
        { &class_NSRuleEditor, "NSRuleEditor" },
        { &class_NSScriptCommandDescription, "NSScriptCommandDescription" },
        { &class_NSViewController, "NSViewController" },
        { &class_NSPredicateEditor, "NSPredicateEditor" },
        { &class_NSCloneCommand, "NSCloneCommand" },
        { &class_NSOpenGLView, "NSOpenGLView" },
        { &class_NSCursor, "NSCursor" },
        { &class_NSSearchField, "NSSearchField" },
        { &class_NSXMLDTD, "NSXMLDTD" },
        { &class_NSSocketPort, "NSSocketPort" },
        { &class_NSObjectController, "NSObjectController" },
        { &class_NSScriptCommand, "NSScriptCommand" },
        { &class_NSShadow, "NSShadow" },
        { &class_NSScrollView, "NSScrollView" },
        { &class_NSPrintPanel, "NSPrintPanel" },
        { &class_NSURLHandle, "NSURLHandle" },
        { &class_NSOperation, "NSOperation" },
        { &class_NSMutableDictionary, "NSMutableDictionary" },
        { &class_NSException, "NSException" },
        { &class_NSButtonCell, "NSButtonCell" },
        { &class_NSTask, "NSTask" },
        { &class_NSArchiver, "NSArchiver" },
        { &class_NSDateFormatter, "NSDateFormatter" },
        { &class_NSCalendar, "NSCalendar" },
        { &class_NSTokenField, "NSTokenField" },
        { &class_NSCollectionView, "NSCollectionView" },
        { &class_NSColorList, "NSColorList" },
        { &class_DOMEvent, "DOMEvent" },
        { &class_DOMWheelEvent, "DOMWheelEvent" },
        { &class_WebView, "WebView" },
        { &class_WebPreferences, "WebPreferences" },
        { &class_WebFrameView, "WebFrameView" },
    ];

    /** Selectors */
    public static /*const*/ String sel_inputClientEnabled_1;
    public static /*const*/ String sel_setVerticalPagination_1;
    public static /*const*/ String sel_isEqualToHost_1;
    public static /*const*/ String sel_compare_1;
    public static /*const*/ String sel_printPanel;
    public static /*const*/ String sel_unregisterImageRepClass_1;
    public static /*const*/ String sel_dataWithLength_1;
    public static /*const*/ String sel_dismissPopUp;
    public static /*const*/ String sel_substituteFontForFont_1;
    public static /*const*/ String sel_sendAction_1to_1;
    public static /*const*/ String sel_rangeOfCharacterFromSet_1options_1range_1;
    public static /*const*/ String sel_autoupdatingCurrentCalendar;
    public static /*const*/ String sel_nextDaylightSavingTimeTransitionAfterDate_1;
    public static /*const*/ String sel_attachmentSizeForGlyphAtIndex_1;
    public static /*const*/ String sel_shouldCollapseAutoExpandedItemsForDeposited_1;
    public static /*const*/ String sel_decimalNumberByRoundingAccordingToBehavior_1;
    public static /*const*/ String sel_scanHexFloat_1;
    public static /*const*/ String sel_rangesForUserTextChange;
    public static /*const*/ String sel_indexOfItemWithObjectValue_1;
    public static /*const*/ String sel_sendsSearchStringImmediately;
    public static /*const*/ String sel_isTransparent;
    public static /*const*/ String sel_widthOfColumn_1;
    public static /*const*/ String sel_calendarFormat;
    public static /*const*/ String sel_lineBreakByHyphenatingBeforeIndex_1withinRange_1;
    public static /*const*/ String sel_parentNode;
    public static /*const*/ String sel_setDrawsOutsideLineFragment_1forGlyphRange_1;
    public static /*const*/ String sel_negativeSuffix;
    public static /*const*/ String sel_setFlatness_1;
    public static /*const*/ String sel_ignoresAlpha;
    public static /*const*/ String sel_setValue_1type_1forDimension_1;
    public static /*const*/ String sel_setLayer_1;
    public static /*const*/ String sel_setActionName_1;
    public static /*const*/ String sel_setIcon_1;
    public static /*const*/ String sel_tokenFieldCell_1readFromPasteboard_1;
    public static /*const*/ String sel_setPropertyList_1forType_1;
    public static /*const*/ String sel_endModalSession_1;
    public static /*const*/ String sel_sharedColorPanel;
    public static /*const*/ String sel_contentSizeForFrameSize_1hasHorizontalScroller_1hasVerticalScroller_1borderType_1;
    public static /*const*/ String sel_layoutRectForTextBlock_1glyphRange_1;
    public static /*const*/ String sel_scrollRowToVisible_1;
    public static /*const*/ String sel_attributedStringForZero;
    public static /*const*/ String sel_showsInvisibleCharacters;
    public static /*const*/ String sel_adjustPageWidthNew_1left_1right_1limit_1;
    public static /*const*/ String sel_client;
    public static /*const*/ String sel_initWithKey_1ascending_1selector_1;
    public static /*const*/ String sel_completedString_1;
    public static /*const*/ String sel_bundleForClass_1;
    public static /*const*/ String sel_pathControl_1acceptDrop_1;
    public static /*const*/ String sel_imageRepsWithPasteboard_1;
    public static /*const*/ String sel_toolTipForSegment_1;
    public static /*const*/ String sel_suspended;
    public static /*const*/ String sel_encodeDouble_1forKey_1;
    public static /*const*/ String sel_setNextState;
    public static /*const*/ String sel_ignoreWord_1inSpellDocumentWithTag_1;
    public static /*const*/ String sel_stopMonitoring;
    public static /*const*/ String sel_initWithTitle_1action_1keyEquivalent_1;
    public static /*const*/ String sel_setDropRow_1dropOperation_1;
    public static /*const*/ String sel_contentView;
    public static /*const*/ String sel_setNilSymbol_1;
    public static /*const*/ String sel_removePropertyForKey_1inRequest_1;
    public static /*const*/ String sel_setMarkerLocation_1;
    public static /*const*/ String sel_resolvedKeyDictionary;
    public static /*const*/ String sel_enumeratorAtPath_1;
    public static /*const*/ String sel_decodeObjectForKey_1;
    public static /*const*/ String sel_loadInForeground;
    public static /*const*/ String sel_baseSpecifier;
    public static /*const*/ String sel_isMemberOfClass_1;
    public static /*const*/ String sel_setMaxVisibleColumns_1;
    public static /*const*/ String sel_unmountAndEjectDeviceAtPath_1;
    public static /*const*/ String sel_openTempFile_1;
    public static /*const*/ String sel_isRowSelected_1;
    public static /*const*/ String sel_insertItemWithItemIdentifier_1atIndex_1;
    public static /*const*/ String sel_parserDidEndDocument_1;
    public static /*const*/ String sel_reverseTransformedValue_1;
    public static /*const*/ String sel_setTimeStyle_1;
    public static /*const*/ String sel_initWithContentsOfFile_1usedEncoding_1error_1;
    public static /*const*/ String sel_endGrouping;
    public static /*const*/ String sel_initWithProxyHost_1port_1type_1realm_1authenticationMethod_1;
    public static /*const*/ String sel_tableView_1dataCellForTableColumn_1row_1;
    public static /*const*/ String sel_convertPoint_1toView_1;
    public static /*const*/ String sel_setFrame_1display_1animate_1;
    public static /*const*/ String sel_exceptionDuringOperation_1error_1leftOperand_1rightOperand_1;
    public static /*const*/ String sel_applicationOpenUntitledFile_1;
    public static /*const*/ String sel_initWithRootElement_1;
    public static /*const*/ String sel_setHorizontalScroller_1;
    public static /*const*/ String sel_finalWritePrintInfo;
    public static /*const*/ String sel_addItemWithTitle_1;
    public static /*const*/ String sel_setColor_1;
    public static /*const*/ String sel_isHostCacheEnabled;
    public static /*const*/ String sel_controlTextDidChange_1;
    public static /*const*/ String sel_headerLevel;
    public static /*const*/ String sel_loadInBackground;
    public static /*const*/ String sel_setNeedsDisplayForItemAtIndex_1;
    public static /*const*/ String sel_setCellPrototype_1;
    public static /*const*/ String sel_enqueueNotification_1postingStyle_1coalesceMask_1forModes_1;
    public static /*const*/ String sel_minColumnWidth;
    public static /*const*/ String sel_tableView_1shouldTypeSelectForEvent_1withCurrentSearchString_1;
    public static /*const*/ String sel_validateValue_1forKey_1error_1;
    public static /*const*/ String sel_canBeConvertedToEncoding_1;
    public static /*const*/ String sel_numberOfItems;
    public static /*const*/ String sel_bestRepresentationForDevice_1;
    public static /*const*/ String sel_setBorderColor_1forEdge_1;
    public static /*const*/ String sel_setHorizontalLineScroll_1;
    public static /*const*/ String sel_sharedHTTPCookieStorage;
    public static /*const*/ String sel_cachesBezierPath;
    public static /*const*/ String sel_strokeLineFromPoint_1toPoint_1;
    public static /*const*/ String sel_preferredBackingLocation;
    public static /*const*/ String sel_removeRowAtIndex_1;
    public static /*const*/ String sel_setCurrentTime_1;
    public static /*const*/ String sel_String;
    public static /*const*/ String sel_hasVerticalScroller;
    public static /*const*/ String sel_initWithTimeInterval_1sinceDate_1;
    public static /*const*/ String sel_showsProgressPanel;
    public static /*const*/ String sel_setDirectParameter_1;
    public static /*const*/ String sel_storeCachedResponse_1forRequest_1;
    public static /*const*/ String sel_textUnfilteredPasteboardTypes;
    public static /*const*/ String sel_isDragging;
    public static /*const*/ String sel_tableView_1shouldTrackCell_1forTableColumn_1row_1;
    public static /*const*/ String sel_dictionaryRepresentation;
    public static /*const*/ String sel_attributesForExtraLineFragment;
    public static /*const*/ String sel_getCharacters_1range_1;
    public static /*const*/ String sel_nibName;
    public static /*const*/ String sel_initWithURL_1options_1documentAttributes_1error_1;
    public static /*const*/ String sel_initWithFrame_1mode_1cellClass_1numberOfRows_1numberOfColumns_1;
    public static /*const*/ String sel_reflectScrolledClipView_1;
    public static /*const*/ String sel_StringWithContentsOfURL_1usedEncoding_1error_1;
    public static /*const*/ String sel_displayIfNeededIgnoringOpacity;
    public static /*const*/ String sel_archiverWillFinish_1;
    public static /*const*/ String sel_initWithOptions_1;
    public static /*const*/ String sel_ruleEditor_1numberOfChildrenForCriterion_1withRowType_1;
    public static /*const*/ String sel_removeColorWithKey_1;
    public static /*const*/ String sel_setObjectValue_1;
    public static /*const*/ String sel_graphicsContextWithGraphicsPort_1flipped_1;
    public static /*const*/ String sel_setMarkedText_1selectedRange_1replacementRange_1;
    public static /*const*/ String sel_outlineView_1numberOfChildrenOfItem_1;
    public static /*const*/ String sel_cellFrameAtRow_1column_1;
    public static /*const*/ String sel_blueColor;
    public static /*const*/ String sel_selectedTextBackgroundColor;
    public static /*const*/ String sel_initWithFormat_1locale_1;
    public static /*const*/ String sel_propertyListForType_1;
    public static /*const*/ String sel_setConfigurationFromDictionary_1;
    public static /*const*/ String sel_registerClassDescription_1forClass_1;
    public static /*const*/ String sel_removeAllItems;
    public static /*const*/ String sel_setFontPanelFactory_1;
    public static /*const*/ String sel_didChangeValueForKey_1withSetMutation_1usingObjects_1;
    public static /*const*/ String sel_CGEvent;
    public static /*const*/ String sel_disable;
    public static /*const*/ String sel_setColumnAutoresizingStyle_1;
    public static /*const*/ String sel_absoluteZ;
    public static /*const*/ String sel_intForKey_1inTable_1;
    public static /*const*/ String sel_minFrameWidthWithTitle_1styleMask_1;
    public static /*const*/ String sel_highlightColor;
    public static /*const*/ String sel_setRoundingMode_1;
    public static /*const*/ String sel_didChangeValueForKey_1;
    public static /*const*/ String sel_setMenuZone_1;
    public static /*const*/ String sel_updateFromPrintInfo;
    public static /*const*/ String sel_setSelectedItemIdentifier_1;
    public static /*const*/ String sel_setReplyTimeout_1;
    public static /*const*/ String sel_showsFirstResponder;
    public static /*const*/ String sel_loadNibNamed_1owner_1;
    public static /*const*/ String sel_setDocument_1;
    public static /*const*/ String sel_filePosixPermissions;
    public static /*const*/ String sel_collapseItem_1collapseChildren_1;
    public static /*const*/ String sel_setCell_1;
    public static /*const*/ String sel_setHTTPBodyStream_1;
    public static /*const*/ String sel_updateAttachmentsFromPath_1;
    public static /*const*/ String sel_updateFontPanel;
    public static /*const*/ String sel_animationDidStop_1;
    public static /*const*/ String sel_URL_1resourceDidFailLoadingWithReason_1;
    public static /*const*/ String sel_defaultBaselineOffsetForFont_1;
    public static /*const*/ String sel_browser_1shouldShowCellExpansionForRow_1column_1;
    public static /*const*/ String sel_draggingEnded_1;
    public static /*const*/ String sel_openURL_1;
    public static /*const*/ String sel_longLongValue;
    public static /*const*/ String sel_colorPanel;
    public static /*const*/ String sel_encodeFloat_1forKey_1;
    public static /*const*/ String sel_shouldBreakLineByHyphenatingBeforeCharacterAtIndex_1;
    public static /*const*/ String sel_performSelectorInBackground_1withObject_1;
    public static /*const*/ String sel_initTextCell_1;
    public static /*const*/ String sel_classDescription;
    public static /*const*/ String sel_menuFontOfSize_1;
    public static /*const*/ String sel_window_1willPositionSheet_1usingRect_1;
    public static /*const*/ String sel_allowsTypeSelect;
    public static /*const*/ String sel_attributeWithName_1URI_1StringValue_1;
    public static /*const*/ String sel_setLinkTextAttributes_1;
    public static /*const*/ String sel_StringWithFormat_1;
    public static /*const*/ String sel_initWithTable_1startingRow_1rowSpan_1startingColumn_1columnSpan_1;
    public static /*const*/ String sel_setShouldProcessNamespaces_1;
    public static /*const*/ String sel_orderFrontRegardless;
    public static /*const*/ String sel_setProtocolForProxy_1;
    public static /*const*/ String sel_bundlePath;
    public static /*const*/ String sel_isAutoscroll;
    public static /*const*/ String sel_addConnection_1toRunLoop_1forMode_1;
    public static /*const*/ String sel_moveWordBackwardAndModifySelection_1;
    public static /*const*/ String sel_textContainerChangedGeometry_1;
    public static /*const*/ String sel_conversation;
    public static /*const*/ String sel_showWindow_1;
    public static /*const*/ String sel_showGuessPanel_1;
    public static /*const*/ String sel_setBorderWidth_1;
    public static /*const*/ String sel_buttons;
    public static /*const*/ String sel_bitmapRepresentation;
    public static /*const*/ String sel_nextObject;
    public static /*const*/ String sel_predicate;
    public static /*const*/ String sel_verticalPagination;
    public static /*const*/ String sel_readInBackgroundAndNotify;
    public static /*const*/ String sel_pixelBufferMipMapLevel;
    public static /*const*/ String sel_getValue_1;
    public static /*const*/ String sel_eventID;
    public static /*const*/ String sel_sortDescriptors;
    public static /*const*/ String sel_removeObjectAtArrangedObjectIndexPath_1;
    public static /*const*/ String sel_decodeBytesWithReturnedLength_1;
    public static /*const*/ String sel_textView_1shouldChangeTextInRange_1replacementString_1;
    public static /*const*/ String sel_removeCursorRect_1cursor_1;
    public static /*const*/ String sel_hasPassword;
    public static /*const*/ String sel_updateWindows;
    public static /*const*/ String sel_pasteboardWithName_1;
    public static /*const*/ String sel_writeSelectionToPasteboard_1types_1;
    public static /*const*/ String sel_setFlipped_1;
    public static /*const*/ String sel_glyphWithName_1;
    public static /*const*/ String sel_launchApplication_1showIcon_1autolaunch_1;
    public static /*const*/ String sel_indexPath;
    public static /*const*/ String sel_setAttributeDescriptor_1forKeyword_1;
    public static /*const*/ String sel_removeAllActions;
    public static /*const*/ String sel_defaultAttachmentScaling;
    public static /*const*/ String sel_localizedStringWithFormat_1;
    public static /*const*/ String sel_setAutoscroll_1;
    public static /*const*/ String sel_heightAdjustLimit;
    public static /*const*/ String sel_moveUpAndModifySelection_1;
    public static /*const*/ String sel_visibilityPriority;
    public static /*const*/ String sel_textView_1clickedOnCell_1inRect_1atIndex_1;
    public static /*const*/ String sel_archivedDataWithRootObject_1;
    public static /*const*/ String sel_parser_1foundCDATA_1;
    public static /*const*/ String sel_setWidth_1ofColumn_1;
    public static /*const*/ String sel_setHighlightedTableColumn_1;
    public static /*const*/ String sel_toggle_1;
    public static /*const*/ String sel_parent;
    public static /*const*/ String sel_tableView_1shouldSelectRow_1;
    public static /*const*/ String sel_setWithObject_1;
    public static /*const*/ String sel_attribute_1atIndex_1effectiveRange_1;
    public static /*const*/ String sel_columnsInRect_1;
    public static /*const*/ String sel_setSearchScopes_1;
    public static /*const*/ String sel_setByAddingObjectsFromArray_1;
    public static /*const*/ String sel_textViewDidChangeTypingAttributes_1;
    public static /*const*/ String sel_frameRate;
    public static /*const*/ String sel_browser_1writeRowsWithIndexes_1inColumn_1toPasteboard_1;
    public static /*const*/ String sel_errorWithDomain_1code_1userInfo_1;
    public static /*const*/ String sel_setAlternate_1;
    public static /*const*/ String sel_currentValue;
    public static /*const*/ String sel_download_1decideDestinationWithSuggestedFilename_1;
    public static /*const*/ String sel_setBoxType_1;
    public static /*const*/ String sel_fileNamesFromRunningOpenPanel;
    public static /*const*/ String sel_valueWithPointer_1;
    public static /*const*/ String sel_metadataQuery_1replacementObjectForResultObject_1;
    public static /*const*/ String sel_editedColumn;
    public static /*const*/ String sel_cachedResponseForRequest_1;
    public static /*const*/ String sel_failureReason;
    public static /*const*/ String sel_constantValue;
    public static /*const*/ String sel_commandClassName;
    public static /*const*/ String sel_fileWrapper;
    public static /*const*/ String sel_setUsesUserKeyEquivalents_1;
    public static /*const*/ String sel_prototype;
    public static /*const*/ String sel_clearStartAnimation;
    public static /*const*/ String sel_setMovableByWindowBackground_1;
    public static /*const*/ String sel_setDateFormat_1;
    public static /*const*/ String sel_StringWithContentsOfFile_1usedEncoding_1error_1;
    public static /*const*/ String sel_toggleAutomaticLinkDetection_1;
    public static /*const*/ String sel_statusForTable_1;
    public static /*const*/ String sel_setAllowsColumnSelection_1;
    public static /*const*/ String sel_lowercaseWord_1;
    public static /*const*/ String sel_setResolvesAliases_1;
    public static /*const*/ String sel_appendFormat_1;
    public static /*const*/ String sel_isAnimating;
    public static /*const*/ String sel_dateFormat;
    public static /*const*/ String sel_setMuted_1;
    public static /*const*/ String sel_drawWithExpansionFrame_1inView_1;
    public static /*const*/ String sel_copyPath_1toPath_1handler_1;
    public static /*const*/ String sel_isExplicitlyIncluded;
    public static /*const*/ String sel_isExtensionHidden;
    public static /*const*/ String sel_showPackedGlyphs_1length_1glyphRange_1atPoint_1font_1color_1printingAdjustment_1;
    public static /*const*/ String sel_rulerView_1didRemoveMarker_1;
    public static /*const*/ String sel_setControlTint_1;
    public static /*const*/ String sel_isSelectable;
    public static /*const*/ String sel_initWithMachPort_1;
    public static /*const*/ String sel_fill;
    public static /*const*/ String sel_isEnteringProximity;
    public static /*const*/ String sel_drawingRectForBounds_1;
    public static /*const*/ String sel_decodeInt32ForKey_1;
    public static /*const*/ String sel_deltaY;
    public static /*const*/ String sel_displaysLinkToolTips;
    public static /*const*/ String sel_moveToEndOfDocument_1;
    public static /*const*/ String sel_isFirstResponder;
    public static /*const*/ String sel_receiversSpecifier;
    public static /*const*/ String sel_canInitWithURL_1;
    public static /*const*/ String sel_parameterString;
    public static /*const*/ String sel_isMovable;
    public static /*const*/ String sel_setAvoidsEmptySelection_1;
    public static /*const*/ String sel_lockFocusIfCanDrawInContext_1;
    public static /*const*/ String sel_updateChangeCount_1;
    public static /*const*/ String sel_rootDocument;
    public static /*const*/ String sel_superview;
    public static /*const*/ String sel_resolveNamespaceForName_1;
    public static /*const*/ String sel_maxNumberOfColumns;
    public static /*const*/ String sel_setMaxSize_1;
    public static /*const*/ String sel_completePathIntoString_1caseSensitive_1matchesIntoArray_1filterTypes_1;
    public static /*const*/ String sel_updateCell_1;
    public static /*const*/ String sel_setWeek_1;
    public static /*const*/ String sel_titleRectForBounds_1;
    public static /*const*/ String sel_rulerView_1willAddMarker_1atLocation_1;
    public static /*const*/ String sel_message;
    public static /*const*/ String sel_setContentSize_1;
    public static /*const*/ String sel_broadcast;
    public static /*const*/ String sel_isNativeType_1;
    public static /*const*/ String sel_contentBorderThicknessForEdge_1;
    public static /*const*/ String sel_keyEquivalentOffset;
    public static /*const*/ String sel_makeUntitledDocumentOfType_1;
    public static /*const*/ String sel_windowFrameTextColor;
    public static /*const*/ String sel_addItemsWithTitles_1;
    public static /*const*/ String sel_levelForRow_1;
    public static /*const*/ String sel_dissolveToPoint_1fromRect_1fraction_1;
    public static /*const*/ String sel_discardCachedImage;
    public static /*const*/ String sel_rootProxyForConnectionWithRegisteredName_1host_1usingNameServer_1;
    public static /*const*/ String sel_mouseExited_1;
    public static /*const*/ String sel_StringWithCString_1;
    public static /*const*/ String sel_standardUserDefaults;
    public static /*const*/ String sel_archiver_1didEncodeObject_1;
    public static /*const*/ String sel_canDraw;
    public static /*const*/ String sel_shouldDelayWindowOrderingForEvent_1;
    public static /*const*/ String sel_selectedMenuItemTextColor;
    public static /*const*/ String sel_attachSubmenuForItemAtIndex_1;
    public static /*const*/ String sel_condition;
    public static /*const*/ String sel_setReservedThicknessForAccessoryView_1;
    public static /*const*/ String sel_replaceObjectsInRange_1withObjectsFromArray_1;
    public static /*const*/ String sel_placeholderString;
    public static /*const*/ String sel_setPMSymbol_1;
    public static /*const*/ String sel_localizedNameOfStringEncoding_1;
    public static /*const*/ String sel_outlineViewItemWillCollapse_1;
    public static /*const*/ String sel_localizedKey;
    public static /*const*/ String sel_whiteColor;
    public static /*const*/ String sel_viewBoundsChanged_1;
    public static /*const*/ String sel_vendorDefined;
    public static /*const*/ String sel_classNameDecodedForArchiveClassName_1;
    public static /*const*/ String sel_lockDate;
    public static /*const*/ String sel_twoDigitStartDate;
    public static /*const*/ String sel_rectOfRow_1;
    public static /*const*/ String sel_receivePort;
    public static /*const*/ String sel_decimalNumberByMultiplyingByPowerOf10_1withBehavior_1;
    public static /*const*/ String sel_isAnyApplicationSpeaking;
    public static /*const*/ String sel_aeDesc;
    public static /*const*/ String sel_windowWillBeginSheet_1;
    public static /*const*/ String sel_accessibilityFocusedUIElement;
    public static /*const*/ String sel_orderBack_1;
    public static /*const*/ String sel_scanDecimal_1;
    public static /*const*/ String sel_transformStruct;
    public static /*const*/ String sel_fileAttributesToWriteToFile_1ofType_1saveOperation_1;
    public static /*const*/ String sel_controlCharacterSet;
    public static /*const*/ String sel_setNextResponder_1;
    public static /*const*/ String sel_pasteboardChangedOwner_1;
    public static /*const*/ String sel_canSelectHiddenExtension;
    public static /*const*/ String sel_attribute_1atIndex_1longestEffectiveRange_1inRange_1;
    public static /*const*/ String sel_setAutovalidates_1;
    public static /*const*/ String sel_setAllowsFloats_1;
    public static /*const*/ String sel_sortDescriptorPrototype;
    public static /*const*/ String sel_trackKnob_1;
    public static /*const*/ String sel_comboBox_1indexOfItemWithStringValue_1;
    public static /*const*/ String sel_setSource_1;
    public static /*const*/ String sel_contentFilters;
    public static /*const*/ String sel_dictionaryWithContentsOfFile_1;
    public static /*const*/ String sel_drawArrow_1highlight_1;
    public static /*const*/ String sel_handleSaveScriptCommand_1;
    public static /*const*/ String sel_rangeOfString_1options_1;
    public static /*const*/ String sel_setPickerMode_1;
    public static /*const*/ String sel_setStandaloneQuarterSymbols_1;
    public static /*const*/ String sel_setSize_1;
    public static /*const*/ String sel_setAllowsUndo_1;
    public static /*const*/ String sel_edge;
    public static /*const*/ String sel_stopLoading;
    public static /*const*/ String sel_fileURLWithPath_1isDirectory_1;
    public static /*const*/ String sel_userInfo;
    public static /*const*/ String sel_components_1fromDate_1;
    public static /*const*/ String sel_dictionary;
    public static /*const*/ String sel_connection_1didCancelAuthenticationChallenge_1;
    public static /*const*/ String sel_selectParagraph_1;
    public static /*const*/ String sel_initWithCapacity_1;
    public static /*const*/ String sel_initWithObjectSpecifier_1comparisonOperator_1testObject_1;
    public static /*const*/ String sel_nestingMode;
    public static /*const*/ String sel_paragraphSpacingBefore;
    public static /*const*/ String sel_itemChanged_1;
    public static /*const*/ String sel_setSelectionIndexes_1;
    public static /*const*/ String sel_open;
    public static /*const*/ String sel_sendActionOn_1;
    public static /*const*/ String sel_initWithFireDate_1interval_1target_1selector_1userInfo_1repeats_1;
    public static /*const*/ String sel_formatterBehavior;
    public static /*const*/ String sel_fillRect_1;
    public static /*const*/ String sel_animationCurve;
    public static /*const*/ String sel_remoteObjects;
    public static /*const*/ String sel_setSelectionIndexPath_1;
    public static /*const*/ String sel_availableFontNamesWithTraits_1;
    public static /*const*/ String sel_convertFont_1toFamily_1;
    public static /*const*/ String sel_splitView_1resizeSubviewsWithOldSize_1;
    public static /*const*/ String sel_setSmartInsertDeleteEnabled_1;
    public static /*const*/ String sel_shouldChangePrintInfo_1;
    public static /*const*/ String sel_objectBeingTested;
    public static /*const*/ String sel_selectItemWithObjectValue_1;
    public static /*const*/ String sel_rightExpressions;
    public static /*const*/ String sel_unableToSetNilForKey_1;
    public static /*const*/ String sel_visibleItems;
    public static /*const*/ String sel_items;
    public static /*const*/ String sel_templatesWithAttributeKeyPaths_1inEntityDescription_1;
    public static /*const*/ String sel_setMaximumIntegerDigits_1;
    public static /*const*/ String sel_scrollRectToVisible_1;
    public static /*const*/ String sel_disableKeyEquivalentForDefaultButtonCell;
    public static /*const*/ String sel_objectsForXQuery_1error_1;
    public static /*const*/ String sel_readToEndOfFileInBackgroundAndNotifyForModes_1;
    public static /*const*/ String sel_scanHexLongLong_1;
    public static /*const*/ String sel_ascender;
    public static /*const*/ String sel_arrangeObjects_1;
    public static /*const*/ String sel_setNegativeSuffix_1;
    public static /*const*/ String sel_initWithString_1;
    public static /*const*/ String sel_initWithName_1data_1;
    public static /*const*/ String sel_data;
    public static /*const*/ String sel_encodePortObject_1;
    public static /*const*/ String sel_becomeFirstResponder;
    public static /*const*/ String sel_setImage_1forSegment_1;
    public static /*const*/ String sel_copyRuler_1;
    public static /*const*/ String sel_appendBezierPathWithGlyphs_1count_1inFont_1;
    public static /*const*/ String sel_playsSelectionOnly;
    public static /*const*/ String sel_boundsRectForTextBlock_1glyphRange_1;
    public static /*const*/ String sel_makeObjectsPerformSelector_1withObject_1;
    public static /*const*/ String sel_StringByTrimmingCharactersInSet_1;
    public static /*const*/ String sel_timerWithTimeInterval_1invocation_1repeats_1;
    public static /*const*/ String sel_viewDidMoveToSuperview;
    public static /*const*/ String sel_pathCell_1willDisplayOpenPanel_1;
    public static /*const*/ String sel_pathSeparator;
    public static /*const*/ String sel_generatesCalendarDates;
    public static /*const*/ String sel_pressure;
    public static /*const*/ String sel_sendPort;
    public static /*const*/ String sel_argumentsRetained;
    public static /*const*/ String sel_setContainerSpecifier_1;
    public static /*const*/ String sel_decodeNXColor;
    public static /*const*/ String sel_orientation;
    public static /*const*/ String sel_setScriptErrorString_1;
    public static /*const*/ String sel_makeDocumentWithContentsOfFile_1ofType_1;
    public static /*const*/ String sel_reason;
    public static /*const*/ String sel_currentEvent;
    public static /*const*/ String sel_setOffScreen_1width_1height_1rowbytes_1;
    public static /*const*/ String sel_invalidateAttributesInRange_1;
    public static /*const*/ String sel_descriptorWithDescriptorType_1bytes_1length_1;
    public static /*const*/ String sel_setCredential_1forProtectionSpace_1;
    public static /*const*/ String sel_fileGroupOwnerAccountName;
    public static /*const*/ String sel_setColor_1forKey_1;
    public static /*const*/ String sel_setAutohidesScrollers_1;
    public static /*const*/ String sel_noteNumberOfRowsChanged;
    public static /*const*/ String sel_disableCursorRects;
    public static /*const*/ String sel_setLenient_1;
    public static /*const*/ String sel_registerUnitWithName_1abbreviation_1unitToPointsConversionFactor_1stepUpCycle_1stepDownCycle_1;
    public static /*const*/ String sel_standardWindowButton_1;
    public static /*const*/ String sel_objectForProperty_1error_1;
    public static /*const*/ String sel_imageRepWithData_1;
    public static /*const*/ String sel_flushGraphics;
    public static /*const*/ String sel_setCacheDepthMatchesImageDepth_1;
    public static /*const*/ String sel_highlightColorInView_1;
    public static /*const*/ String sel_setBaseSpecifier_1;
    public static /*const*/ String sel_performFileOperation_1source_1destination_1files_1tag_1;
    public static /*const*/ String sel_outlineView_1itemForPersistentObject_1;
    public static /*const*/ String sel_propertyListFromData_1mutabilityOption_1format_1errorDescription_1;
    public static /*const*/ String sel_setDocumentView_1;
    public static /*const*/ String sel_drawsOutsideLineFragmentForGlyphAtIndex_1;
    public static /*const*/ String sel_dragImageForSelectionWithEvent_1origin_1;
    public static /*const*/ String sel_buttonNumber;
    public static /*const*/ String sel_advancementForGlyph_1;
    public static /*const*/ String sel_parser_1validationErrorOccurred_1;
    public static /*const*/ String sel_reusesColumns;
    public static /*const*/ String sel_minute;
    public static /*const*/ String sel_setCanChooseFiles_1;
    public static /*const*/ String sel_groupingSize;
    public static /*const*/ String sel_containsAttachments;
    public static /*const*/ String sel_selectedControlTextColor;
    public static /*const*/ String sel_initWithMantissa_1exponent_1isNegative_1;
    public static /*const*/ String sel_initWithVoice_1;
    public static /*const*/ String sel_setResizingMask_1;
    public static /*const*/ String sel_setOnMouseExited_1;
    public static /*const*/ String sel_toggleContinuousSpellChecking_1;
    public static /*const*/ String sel_allowsCutCopyPaste;
    public static /*const*/ String sel_endSheet_1;
    public static /*const*/ String sel_allowsBranchSelection;
    public static /*const*/ String sel_initWithRequest_1delegate_1;
    public static /*const*/ String sel_isAtEnd;
    public static /*const*/ String sel_relativeString;
    public static /*const*/ String sel_tableView_1willDisplayCell_1forTableColumn_1row_1;
    public static /*const*/ String sel_resizeSubviewsWithOldSize_1;
    public static /*const*/ String sel_compoundPredicateType;
    public static /*const*/ String sel_accessoryControllers;
    public static /*const*/ String sel_shouldDrawColor;
    public static /*const*/ String sel_applicationShouldTerminate_1;
    public static /*const*/ String sel_setTextContainer_1;
    public static /*const*/ String sel_discardCursorRects;
    public static /*const*/ String sel_deviceCMYKColorSpace;
    public static /*const*/ String sel_setDefaultPlaceholder_1forMarker_1withBinding_1;
    public static /*const*/ String sel_setIsZoomed_1;
    public static /*const*/ String sel_blueComponent;
    public static /*const*/ String sel_portWithMachPort_1options_1;
    public static /*const*/ String sel_restoreGraphicsState;
    public static /*const*/ String sel_isTemplate;
    public static /*const*/ String sel_setScanLocation_1;
    public static /*const*/ String sel_initWithBool_1;
    public static /*const*/ String sel_initWithSet_1copyItems_1;
    public static /*const*/ String sel_setPositivePrefix_1;
    public static /*const*/ String sel_propertyForKeyIfAvailable_1;
    public static /*const*/ String sel_fileOwnerAccountID;
    public static /*const*/ String sel_initForIncrementalLoad;
    public static /*const*/ String sel_cellAttribute_1;
    public static /*const*/ String sel_baselineLocation;
    public static /*const*/ String sel_initWithAttributedString_1;
    public static /*const*/ String sel_showWindows;
    public static /*const*/ String sel_writeToFile_1atomically_1updateFilenames_1;
    public static /*const*/ String sel_setCookies_1forURL_1mainDocumentURL_1;
    public static /*const*/ String sel_unarchiver_1cannotDecodeObjectOfClassName_1originalClasses_1;
    public static /*const*/ String sel_selectRow_1inColumn_1;
    public static /*const*/ String sel_dissolveToPoint_1fraction_1;
    public static /*const*/ String sel_wantsToTrackMouseForEvent_1inRect_1ofView_1atCharacterIndex_1;
    public static /*const*/ String sel_openURLs_1withAppBundleIdentifier_1options_1additionalEventParamDescriptor_1launchIdentifiers_1;
    public static /*const*/ String sel_checkForRemovableMedia;
    public static /*const*/ String sel_setImage_1;
    public static /*const*/ String sel_isFixedPitch;
    public static /*const*/ String sel_protocolFamily;
    public static /*const*/ String sel_protocolCheckerWithTarget_1protocol_1;
    public static /*const*/ String sel_streamError;
    public static /*const*/ String sel_replaceBytesInRange_1withBytes_1length_1;
    public static /*const*/ String sel_canChooseDirectories;
    public static /*const*/ String sel_classForPortCoder;
    public static /*const*/ String sel_mainRunLoop;
    public static /*const*/ String sel_setItemPrototype_1;
    public static /*const*/ String sel_controlShadowColor;
    public static /*const*/ String sel_level;
    public static /*const*/ String sel_setContextHelpModeActive_1;
    public static /*const*/ String sel_levelForItem_1;
    public static /*const*/ String sel_setHeightTracksTextView_1;
    public static /*const*/ String sel_applicationWillTerminate_1;
    public static /*const*/ String sel_wantsPeriodicDraggingUpdates;
    public static /*const*/ String sel_createCommandInstance;
    public static /*const*/ String sel_parser_1foundElementDeclarationWithName_1model_1;
    public static /*const*/ String sel_window_1shouldPopUpDocumentPathMenu_1;
    public static /*const*/ String sel_setRepresentedURL_1;
    public static /*const*/ String sel_outlineView_1didDragTableColumn_1;
    public static /*const*/ String sel_appendTransform_1;
    public static /*const*/ String sel_setMIMEType_1;
    public static /*const*/ String sel_setHeadIndent_1;
    public static /*const*/ String sel_setConstrainedFrameSize_1;
    public static /*const*/ String sel_setUsesDataSource_1;
    public static /*const*/ String sel_replaceBytesInRange_1withBytes_1;
    public static /*const*/ String sel_rowTypeKeyPath;
    public static /*const*/ String sel_undoManager;
    public static /*const*/ String sel_frameCenterRotation;
    public static /*const*/ String sel_setTextView_1;
    public static /*const*/ String sel_executeAppleEvent_1error_1;
    public static /*const*/ String sel_setFormatter_1;
    public static /*const*/ String sel_scanLocation;
    public static /*const*/ String sel_scrollsDynamically;
    public static /*const*/ String sel_setIndentationLevel_1;
    public static /*const*/ String sel_minimumRangeOfUnit_1;
    public static /*const*/ String sel_textViewForBeginningOfSelection;
    public static /*const*/ String sel_tokenFieldCell_1displayStringForRepresentedObject_1;
    public static /*const*/ String sel_constrainFrameRect_1toScreen_1;
    public static /*const*/ String sel_getObjectValue_1forString_1range_1error_1;
    public static /*const*/ String sel_writeFileContents_1;
    public static /*const*/ String sel_setProgressMarks_1;
    public static /*const*/ String sel_lastComponentOfFileName;
    public static /*const*/ String sel_preventWindowOrdering;
    public static /*const*/ String sel_setDefaultDate_1;
    public static /*const*/ String sel_submenu;
    public static /*const*/ String sel_setTXTRecordData_1;
    public static /*const*/ String sel_bytesPerRow;
    public static /*const*/ String sel_outlineView_1toolTipForCell_1rect_1tableColumn_1item_1mouseLocation_1;
    public static /*const*/ String sel_outlineView_1shouldEditTableColumn_1item_1;
    public static /*const*/ String sel_initWithContainerSize_1;
    public static /*const*/ String sel_setEvaluationErrorNumber_1;
    public static /*const*/ String sel_setTopLevelObject_1;
    public static /*const*/ String sel_dataOfType_1error_1;
    public static /*const*/ String sel_isSupersetOfSet_1;
    public static /*const*/ String sel_initWithURL_1cachePolicy_1timeoutInterval_1;
    public static /*const*/ String sel_setAutosaveExpandedItems_1;
    public static /*const*/ String sel_rangeValue;
    public static /*const*/ String sel_indexPathByAddingIndex_1;
    public static /*const*/ String sel_deleteToMark_1;
    public static /*const*/ String sel_appleEventCodeForSuite_1;
    public static /*const*/ String sel_getBytes_1;
    public static /*const*/ String sel_setMinimumDaysInFirstWeek_1;
    public static /*const*/ String sel_refusesFirstResponder;
    public static /*const*/ String sel_setMaxItemSize_1;
    public static /*const*/ String sel_localizedStringForKey_1value_1table_1;
    public static /*const*/ String sel_mapTableWithKeyOptions_1valueOptions_1;
    public static /*const*/ String sel_test;
    public static /*const*/ String sel_trackScrollButtons_1;
    public static /*const*/ String sel_PDFRepresentation;
    public static /*const*/ String sel_setImageFrameStyle_1;
    public static /*const*/ String sel_encodeClassName_1intoClassName_1;
    public static /*const*/ String sel_beginPageInRect_1atPlacement_1;
    public static /*const*/ String sel_setAllowsOtherFileTypes_1;
    public static /*const*/ String sel_isWordInUserDictionaries_1caseSensitive_1;
    public static /*const*/ String sel_dispatchRawAppleEvent_1withRawReply_1handlerRefCon_1;
    public static /*const*/ String sel_isScrollable;
    public static /*const*/ String sel_numberOfColorStops;
    public static /*const*/ String sel_unhideAllApplications_1;
    public static /*const*/ String sel_retainCount;
    public static /*const*/ String sel_runModalPrintOperation_1delegate_1didRunSelector_1contextInfo_1;
    public static /*const*/ String sel_update;
    public static /*const*/ String sel_isRotatedOrScaledFromBase;
    public static /*const*/ String sel_initWithWindowNibPath_1owner_1;
    public static /*const*/ String sel_entryType;
    public static /*const*/ String sel_dictionaryFromTXTRecordData_1;
    public static /*const*/ String sel_setLineCapStyle_1;
    public static /*const*/ String sel_setValues_1forParameter_1;
    public static /*const*/ String sel_numberStyle;
    public static /*const*/ String sel_disableCollectorForPointer_1;
    public static /*const*/ String sel_initWithPointerFunctions_1capacity_1;
    public static /*const*/ String sel_sendEvent_1;
    public static /*const*/ String sel_removeSelectedObjects_1;
    public static /*const*/ String sel_serviceConnectionWithName_1rootObject_1usingNameServer_1;
    public static /*const*/ String sel_decimalNumberByMultiplyingBy_1;
    public static /*const*/ String sel_shouldChangeTextInRanges_1replacementStrings_1;
    public static /*const*/ String sel_setResizeIncrements_1;
    public static /*const*/ String sel_alignLeft_1;
    public static /*const*/ String sel_launch;
    public static /*const*/ String sel_executeCommand;
    public static /*const*/ String sel_setPixelBuffer_1cubeMapFace_1mipMapLevel_1currentVirtualScreen_1;
    public static /*const*/ String sel_isCachedSeparately;
    public static /*const*/ String sel_setUsesSignificantDigits_1;
    public static /*const*/ String sel_countKeyPathForNode_1;
    public static /*const*/ String sel_setContainerIsRangeContainerObject_1;
    public static /*const*/ String sel_showsStateColumn;
    public static /*const*/ String sel_uppercaseString;
    public static /*const*/ String sel_directoryContentsAtPath_1;
    public static /*const*/ String sel_titleFont;
    public static /*const*/ String sel_comparisonPredicateModifier;
    public static /*const*/ String sel_isMultiThreaded;
    public static /*const*/ String sel_setGroupingAttributes_1;
    public static /*const*/ String sel_selectedRowIndexesInColumn_1;
    public static /*const*/ String sel_isFlushWindowDisabled;
    public static /*const*/ String sel_setReusesColumns_1;
    public static /*const*/ String sel_getCString_1maxLength_1;
    public static /*const*/ String sel_setIndicatorImage_1inTableColumn_1;
    public static /*const*/ String sel_keyEquivalent;
    public static /*const*/ String sel_skipDescendents;
    public static /*const*/ String sel_waitUntilExit;
    public static /*const*/ String sel_initWithWindowNibName_1owner_1;
    public static /*const*/ String sel_objectClass;
    public static /*const*/ String sel_allFrameworks;
    public static /*const*/ String sel_cellWithTag_1;
    public static /*const*/ String sel_representationUsingType_1properties_1;
    public static /*const*/ String sel_textPasteboardTypes;
    public static /*const*/ String sel_contentViewMargins;
    public static /*const*/ String sel_canUndo;
    public static /*const*/ String sel_initWithFormat_1locale_1arguments_1;
    public static /*const*/ String sel_usableParts;
    public static /*const*/ String sel_comboBoxSelectionIsChanging_1;
    public static /*const*/ String sel_raise_1format_1arguments_1;
    public static /*const*/ String sel_isWindowLoaded;
    public static /*const*/ String sel_levelIndicatorStyle;
    public static /*const*/ String sel_localizedFailureReason;
    public static /*const*/ String sel_characterRangeForGlyphRange_1actualGlyphRange_1;
    public static /*const*/ String sel_lineNumber;
    public static /*const*/ String sel_HTTPBody;
    public static /*const*/ String sel_lineBreakMode;
    public static /*const*/ String sel_isStopped;
    public static /*const*/ String sel_canResumeDownloadDecodedWithEncodingMIMEType_1;
    public static /*const*/ String sel_removeObjectsAtArrangedObjectIndexPaths_1;
    public static /*const*/ String sel_isHidden;
    public static /*const*/ String sel_otherMouseDragged_1;
    public static /*const*/ String sel_headerRectOfColumn_1;
    public static /*const*/ String sel_hasVerticalRuler;
    public static /*const*/ String sel_setBottomMargin_1;
    public static /*const*/ String sel_initWithNotificationCenter_1;
    public static /*const*/ String sel_addSpeechDictionary_1;
    public static /*const*/ String sel_setPositiveFormat_1;
    public static /*const*/ String sel_application_1openTempFile_1;
    public static /*const*/ String sel_setEntityName_1;
    public static /*const*/ String sel_setForegroundColor_1;
    public static /*const*/ String sel_initWithUnsignedLong_1;
    public static /*const*/ String sel_setWindowsMenu_1;
    public static /*const*/ String sel_applicationDidUnhide_1;
    public static /*const*/ String sel_availableData;
    public static /*const*/ String sel_setVertical_1;
    public static /*const*/ String sel_disableUpdates;
    public static /*const*/ String sel_compileAndReturnError_1;
    public static /*const*/ String sel_containsIndex_1;
    public static /*const*/ String sel_canSelectPrevious;
    public static /*const*/ String sel_initWithBytes_1length_1encoding_1;
    public static /*const*/ String sel_setTextColor_1;
    public static /*const*/ String sel_stream_1handleEvent_1;
    public static /*const*/ String sel_setWeekdaySymbols_1;
    public static /*const*/ String sel_setHiddenUntilMouseMoves_1;
    public static /*const*/ String sel_orderFrontStandardAboutPanelWithOptions_1;
    public static /*const*/ String sel_setAttributesAsDictionary_1;
    public static /*const*/ String sel_rowTypeForRow_1;
    public static /*const*/ String sel_setRequestTimeout_1;
    public static /*const*/ String sel_XMLDataWithOptions_1;
    public static /*const*/ String sel_closedHandCursor;
    public static /*const*/ String sel_nextSibling;
    public static /*const*/ String sel_controlTextColor;
    public static /*const*/ String sel_abbreviationDictionary;
    public static /*const*/ String sel_archiverDidFinish_1;
    public static /*const*/ String sel_valueTypeForDimension_1;
    public static /*const*/ String sel_setCriteriaKeyPath_1;
    public static /*const*/ String sel_isLessThan_1;
    public static /*const*/ String sel_processName;
    public static /*const*/ String sel_frameOfOutlineCellAtRow_1;
    public static /*const*/ String sel_removeObjectsInArray_1;
    public static /*const*/ String sel_leftExpression;
    public static /*const*/ String sel_removeToolTip_1;
    public static /*const*/ String sel_mutableCopy;
    public static /*const*/ String sel_directParameter;
    public static /*const*/ String sel_name;
    public static /*const*/ String sel_bitsPerPixel;
    public static /*const*/ String sel_weekday;
    public static /*const*/ String sel_descendantNodeAtIndexPath_1;
    public static /*const*/ String sel_setPercentSymbol_1;
    public static /*const*/ String sel_selectedCell;
    public static /*const*/ String sel_windowWillClose_1;
    public static /*const*/ String sel_setDatePickerStyle_1;
    public static /*const*/ String sel_initWithObjects_1;
    public static /*const*/ String sel_numberWithInt_1;
    public static /*const*/ String sel_collection;
    public static /*const*/ String sel_initWithTarget_1selector_1object_1;
    public static /*const*/ String sel_insertText_1replacementRange_1;
    public static /*const*/ String sel_initWithAEDescNoCopy_1;
    public static /*const*/ String sel_usesGroupingSeparator;
    public static /*const*/ String sel_pathControl_1shouldDragPathComponentCell_1withPasteboard_1;
    public static /*const*/ String sel_decimalNumberByAdding_1withBehavior_1;
    public static /*const*/ String sel_setTextContainer_1forGlyphRange_1;
    public static /*const*/ String sel_needsToDrawRect_1;
    public static /*const*/ String sel_activeConversationChanged_1toNewConversation_1;
    public static /*const*/ String sel_italicAngle;
    public static /*const*/ String sel_aeteResource_1;
    public static /*const*/ String sel_noteNewRecentDocumentURL_1;
    public static /*const*/ String sel_setPageScroll_1;
    public static /*const*/ String sel_speechSynthesizer_1didFinishSpeaking_1;
    public static /*const*/ String sel_convertSizeToBase_1;
    public static /*const*/ String sel_pointerFunctionsWithOptions_1;
    public static /*const*/ String sel_setHTTPBody_1;
    public static /*const*/ String sel_itemWithTag_1;
    public static /*const*/ String sel_spellServer_1checkGrammarInString_1language_1details_1;
    public static /*const*/ String sel_vendorPointingDeviceType;
    public static /*const*/ String sel_firstRectForCharacterRange_1;
    public static /*const*/ String sel_classDescriptionsInSuite_1;
    public static /*const*/ String sel_setAttachmentSize_1forGlyphRange_1;
    public static /*const*/ String sel_isEmpty;
    public static /*const*/ String sel_soundNamed_1;
    public static /*const*/ String sel_preparedCellAtColumn_1row_1;
    public static /*const*/ String sel_setLeafKeyPath_1;
    public static /*const*/ String sel_initWithUnsignedInteger_1;
    public static /*const*/ String sel_fractionOfDistanceThroughGlyphForPoint_1inTextContainer_1;
    public static /*const*/ String sel_isFloatingPanel;
    public static /*const*/ String sel_replaceObjectsAtIndexes_1withObjects_1;
    public static /*const*/ String sel_getComponents_1;
    public static /*const*/ String sel_fileType;
    public static /*const*/ String sel_setShowsBaselineSeparator_1;
    public static /*const*/ String sel_removeCredential_1forProtectionSpace_1;
    public static /*const*/ String sel_imageRepWithContentsOfFile_1;
    public static /*const*/ String sel_predicateWithFormat_1argumentArray_1;
    public static /*const*/ String sel_positiveSuffix;
    public static /*const*/ String sel_formatter;
    public static /*const*/ String sel_setAnimationDelay_1;
    public static /*const*/ String sel_maxConcurrentOperationCount;
    public static /*const*/ String sel_childSpecifier;
    public static /*const*/ String sel_cacheMode;
    public static /*const*/ String sel_registerForServices;
    public static /*const*/ String sel_setFirstWeekday_1;
    public static /*const*/ String sel_rulerViewClass;
    public static /*const*/ String sel_initialValue;
    public static /*const*/ String sel_redColor;
    public static /*const*/ String sel_addDependency_1;
    public static /*const*/ String sel_pathExtension;
    public static /*const*/ String sel_fastestEncoding;
    public static /*const*/ String sel_socketType;
    public static /*const*/ String sel_setRuleThickness_1;
    public static /*const*/ String sel_setDTDKind_1;
    public static /*const*/ String sel_setClass_1forClassName_1;
    public static /*const*/ String sel_setDocumentCursor_1;
    public static /*const*/ String sel_extraLineFragmentRect;
    public static /*const*/ String sel_attributeForName_1;
    public static /*const*/ String sel_defaultCredentialForProtectionSpace_1;
    public static /*const*/ String sel_indexOfItemWithTag_1;
    public static /*const*/ String sel_fontManager_1willIncludeFont_1;
    public static /*const*/ String sel_scrollRangeToVisible_1;
    public static /*const*/ String sel_fileTypeFromLastRunSavePanel;
    public static /*const*/ String sel_collectionView;
    public static /*const*/ String sel_tabView;
    public static /*const*/ String sel_commonISOCurrencyCodes;
    public static /*const*/ String sel_removeFontTrait_1;
    public static /*const*/ String sel_drawKnob_1;
    public static /*const*/ String sel_tokenField_1menuForRepresentedObject_1;
    public static /*const*/ String sel_setFrameUsingName_1;
    public static /*const*/ String sel_classNameEncodedForTrueClassName_1;
    public static /*const*/ String sel_windowFrameAutosaveName;
    public static /*const*/ String sel_characterAtIndex_1;
    public static /*const*/ String sel_smartInsertAfterStringForString_1replacingRange_1;
    public static /*const*/ String sel_version;
    public static /*const*/ String sel_objectsAtIndexes_1;
    public static /*const*/ String sel_requestIsCacheEquivalent_1toRequest_1;
    public static /*const*/ String sel_columnOfMatrix_1;
    public static /*const*/ String sel_isBezeled;
    public static /*const*/ String sel_setAutosaveName_1;
    public static /*const*/ String sel_becomeMainWindow;
    public static /*const*/ String sel_pasteAsRichText_1;
    public static /*const*/ String sel_isSpeaking;
    public static /*const*/ String sel_format;
    public static /*const*/ String sel_volume;
    public static /*const*/ String sel_setMenu_1;
    public static /*const*/ String sel_setEra_1;
    public static /*const*/ String sel_textContainerOrigin;
    public static /*const*/ String sel_setLocalizesFormat_1;
    public static /*const*/ String sel_removeIndex_1;
    public static /*const*/ String sel_gotoPosterFrame_1;
    public static /*const*/ String sel_validateValue_1forKeyPath_1error_1;
    public static /*const*/ String sel_initWithCharactersNoCopy_1length_1freeWhenDone_1;
    public static /*const*/ String sel_initWithLength_1;
    public static /*const*/ String sel_setAllowsMultipleSelection_1;
    public static /*const*/ String sel_isRotatedFromBase;
    public static /*const*/ String sel_beginDocument;
    public static /*const*/ String sel_initWithContentsOfURL_1usedEncoding_1error_1;
    public static /*const*/ String sel_showsSuppressionButton;
    public static /*const*/ String sel_tearOffMenuRepresentation;
    public static /*const*/ String sel_otherEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1subtype_1data1_1data2_1;
    public static /*const*/ String sel_imageUnfilteredFileTypes;
    public static /*const*/ String sel_isGathering;
    public static /*const*/ String sel_slideImage_1from_1to_1;
    public static /*const*/ String sel_initWithTCPPort_1;
    public static /*const*/ String sel_StringByFoldingWithOptions_1locale_1;
    public static /*const*/ String sel_viewDidUnhide;
    public static /*const*/ String sel_controlSize;
    public static /*const*/ String sel_resourceDataUsingCache_1;
    public static /*const*/ String sel_startWhenAnimation_1reachesProgress_1;
    public static /*const*/ String sel_registerURLHandleClass_1;
    public static /*const*/ String sel_indicatorImageInTableColumn_1;
    public static /*const*/ String sel_decimalNumberByMultiplyingByPowerOf10_1;
    public static /*const*/ String sel_scrollPoint_1;
    public static /*const*/ String sel_setValue_1forKeyPath_1;
    public static /*const*/ String sel_fontDescriptorWithMatrix_1;
    public static /*const*/ String sel_parser_1foundProcessingInstructionWithTarget_1data_1;
    public static /*const*/ String sel_interfaceStyle;
    public static /*const*/ String sel_comboBox_1objectValueForItemAtIndex_1;
    public static /*const*/ String sel_applicationDidFinishLaunching_1;
    public static /*const*/ String sel_currentMemoryUsage;
    public static /*const*/ String sel_altersStateOfSelectedItem;
    public static /*const*/ String sel_selectedColumn;
    public static /*const*/ String sel_convertBaseToScreen_1;
    public static /*const*/ String sel_lineHeightMultiple;
    public static /*const*/ String sel_CGColorSpace;
    public static /*const*/ String sel_descriptionInStringsFileFormat;
    public static /*const*/ String sel_isOutputStackInReverseOrder;
    public static /*const*/ String sel_takeValue_1forKey_1;
    public static /*const*/ String sel_StringWithContentsOfFile_1;
    public static /*const*/ String sel_addItem_1;
    public static /*const*/ String sel_viewWillMoveToWindow_1;
    public static /*const*/ String sel_changeFileAttributes_1atPath_1;
    public static /*const*/ String sel_userFixedPitchFontOfSize_1;
    public static /*const*/ String sel_selectRowIndexes_1inColumn_1;
    public static /*const*/ String sel_defaultLineCapStyle;
    public static /*const*/ String sel_attributedAlternateTitle;
    public static /*const*/ String sel_fileExistsAtPath_1;
    public static /*const*/ String sel_textView_1clickedOnLink_1atIndex_1;
    public static /*const*/ String sel_drawers;
    public static /*const*/ String sel_outlineView_1shouldSelectTableColumn_1;
    public static /*const*/ String sel_pointValue;
    public static /*const*/ String sel_integerValue;
    public static /*const*/ String sel_modifyFontViaPanel_1;
    public static /*const*/ String sel_windowTitleForDocumentDisplayName_1;
    public static /*const*/ String sel_shortWeekdaySymbols;
    public static /*const*/ String sel_titleOfSelectedItem;
    public static /*const*/ String sel_setWindowsNeedUpdate_1;
    public static /*const*/ String sel_StringWithUTF8String_1;
    public static /*const*/ String sel_transformedValueClass;
    public static /*const*/ String sel_initWithColorsAndLocations_1;
    public static /*const*/ String sel_acceptsMouseMovedEvents;
    public static /*const*/ String sel_toolTipsFontOfSize_1;
    public static /*const*/ String sel_setTextAttributesForPositiveValues_1;
    public static /*const*/ String sel_setAlwaysShowsDecimalSeparator_1;
    public static /*const*/ String sel_setNumberOfColumns_1;
    public static /*const*/ String sel_moveRightAndModifySelection_1;
    public static /*const*/ String sel_indexOfItem_1;
    public static /*const*/ String sel_moveWordRight_1;
    public static /*const*/ String sel_numberWithUnsignedLongLong_1;
    public static /*const*/ String sel_initWithAuthenticationChallenge_1sender_1;
    public static /*const*/ String sel_panelConvertFont_1;
    public static /*const*/ String sel_temporaryAttribute_1atCharacterIndex_1effectiveRange_1;
    public static /*const*/ String sel_intersectHashTable_1;
    public static /*const*/ String sel_positionOfGlyph_1precededByGlyph_1isNominal_1;
    public static /*const*/ String sel_setLocalizedKeyTable_1;
    public static /*const*/ String sel_fileManager_1shouldLinkItemAtPath_1toPath_1;
    public static /*const*/ String sel_setScriptErrorNumber_1;
    public static /*const*/ String sel_initWithLocaleIdentifier_1;
    public static /*const*/ String sel_toolTip;
    public static /*const*/ String sel_alternateMnemonic;
    public static /*const*/ String sel_setChannelMapping_1;
    public static /*const*/ String sel_setLocalizedKey_1;
    public static /*const*/ String sel_selector;
    public static /*const*/ String sel_setCurrencyGroupingSeparator_1;
    public static /*const*/ String sel_initWithKeyOptions_1valueOptions_1capacity_1;
    public static /*const*/ String sel_setStandaloneMonthSymbols_1;
    public static /*const*/ String sel_physicalMemory;
    public static /*const*/ String sel_parse;
    public static /*const*/ String sel_defaultTypesetterBehavior;
    public static /*const*/ String sel_setRulerVisible_1;
    public static /*const*/ String sel_resizeDownCursor;
    public static /*const*/ String sel_getBoundingRects_1forGlyphs_1count_1;
    public static /*const*/ String sel_openPanel;
    public static /*const*/ String sel_setEntryWidth_1;
    public static /*const*/ String sel_insertChildren_1atIndex_1;
    public static /*const*/ String sel_selectNext_1;
    public static /*const*/ String sel_paragraphGlyphRange;
    public static /*const*/ String sel_animations;
    public static /*const*/ String sel_setMarkers_1;
    public static /*const*/ String sel_raise;
    public static /*const*/ String sel_menuZone;
    public static /*const*/ String sel_weekdaySymbols;
    public static /*const*/ String sel_setHTTPMethod_1;
    public static /*const*/ String sel_placeholderAttributedString;
    public static /*const*/ String sel_filenameExtension_1isValidForType_1;
    public static /*const*/ String sel_initWithReceivePort_1sendPort_1;
    public static /*const*/ String sel_setContextHelp_1forObject_1;
    public static /*const*/ String sel_archiveRootObject_1toFile_1;
    public static /*const*/ String sel_setAnimations_1;
    public static /*const*/ String sel_locationOfPrintRect_1;
    public static /*const*/ String sel_setInterfaceStyle_1;
    public static /*const*/ String sel_startMonitoring;
    public static /*const*/ String sel_presentError_1modalForWindow_1delegate_1didPresentSelector_1contextInfo_1;
    public static /*const*/ String sel_windowFrameColor;
    public static /*const*/ String sel_paragraphSpacing;
    public static /*const*/ String sel_fileAttributes;
    public static /*const*/ String sel_setDisplayedCommandsTitle_1;
    public static /*const*/ String sel_preflightAndReturnError_1;
    public static /*const*/ String sel_setObservationInfo_1;
    public static /*const*/ String sel_currentCommand;
    public static /*const*/ String sel_processInfo;
    public static /*const*/ String sel_appendString_1;
    public static /*const*/ String sel_setShowsHelp_1;
    public static /*const*/ String sel_datePickerStyle;
    public static /*const*/ String sel_addFileWrapper_1;
    public static /*const*/ String sel_bitmapImageRepForCachingDisplayInRect_1;
    public static /*const*/ String sel_initWithFileAtPath_1;
    public static /*const*/ String sel_cellClass;
    public static /*const*/ String sel_imageRepsWithContentsOfFile_1;
    public static /*const*/ String sel_localizedScannerWithString_1;
    public static /*const*/ String sel_isExpandable_1;
    public static /*const*/ String sel_isLoaded;
    public static /*const*/ String sel_browser_1acceptDrop_1atRow_1column_1dropOperation_1;
    public static /*const*/ String sel_panel_1directoryDidChange_1;
    public static /*const*/ String sel_publicID;
    public static /*const*/ String sel_contentMaxSize;
    public static /*const*/ String sel_menuDidClose_1;
    public static /*const*/ String sel_setPrinter_1;
    public static /*const*/ String sel_keywordForDescriptorAtIndex_1;
    public static /*const*/ String sel_notANumberSymbol;
    public static /*const*/ String sel_minimumLineHeight;
    public static /*const*/ String sel_setContentBorderThickness_1forEdge_1;
    public static /*const*/ String sel_titleFrameOfColumn_1;
    public static /*const*/ String sel_dateValue;
    public static /*const*/ String sel_numberOfRows;
    public static /*const*/ String sel_isReadableFileAtPath_1;
    public static /*const*/ String sel_canInsertChild;
    public static /*const*/ String sel_StringByReplacingOccurrencesOfString_1withString_1options_1range_1;
    public static /*const*/ String sel_ok_1;
    public static /*const*/ String sel_hourOfDay;
    public static /*const*/ String sel_paragraphRangeForRange_1;
    public static /*const*/ String sel_focusStack;
    public static /*const*/ String sel_setUsesThreadedAnimation_1;
    public static /*const*/ String sel_dataForType_1;
    public static /*const*/ String sel_isByref;
    public static /*const*/ String sel_initWithResponse_1data_1userInfo_1storagePolicy_1;
    public static /*const*/ String sel_initWithSerializedRepresentation_1;
    public static /*const*/ String sel_openDocument_1;
    public static /*const*/ String sel_translateRectsNeedingDisplayInRect_1by_1;
    public static /*const*/ String sel_highlightsBy;
    public static /*const*/ String sel_openHandCursor;
    public static /*const*/ String sel_lineFragmentRectForProposedRect_1remainingRect_1;
    public static /*const*/ String sel_selectedNodes;
    public static /*const*/ String sel_replaceObjectAtIndex_1withObject_1;
    public static /*const*/ String sel_indexOfItemAtPoint_1;
    public static /*const*/ String sel_setCriteria_1andDisplayValues_1forRowAtIndex_1;
    public static /*const*/ String sel_textStorage_1edited_1range_1changeInLength_1invalidatedRange_1;
    public static /*const*/ String sel_synchronizeWindowTitleWithDocumentName;
    public static /*const*/ String sel_fileHandleWithNullDevice;
    public static /*const*/ String sel_descriptorWithTypeCode_1;
    public static /*const*/ String sel_initWithDocFormat_1documentAttributes_1;
    public static /*const*/ String sel_setAutoresizingMask_1;
    public static /*const*/ String sel_methodReturnLength;
    public static /*const*/ String sel_recentDocumentURLs;
    public static /*const*/ String sel_setCurrentDirectoryPath_1;
    public static /*const*/ String sel_characterSetWithRange_1;
    public static /*const*/ String sel_resizeUpCursor;
    public static /*const*/ String sel_rect;
    public static /*const*/ String sel_removeCharactersInRange_1;
    public static /*const*/ String sel_performSelectorOnMainThread_1withObject_1waitUntilDone_1;
    public static /*const*/ String sel_elementAtIndex_1associatedPoints_1;
    public static /*const*/ String sel_dataForKey_1;
    public static /*const*/ String sel_defaultDepthLimit;
    public static /*const*/ String sel_rulersVisible;
    public static /*const*/ String sel_generalPasteboard;
    public static /*const*/ String sel_setAllowsTickMarkValuesOnly_1;
    public static /*const*/ String sel_stateImageOffset;
    public static /*const*/ String sel_isBordered;
    public static /*const*/ String sel_insertPointer_1atIndex_1;
    public static /*const*/ String sel_keyForFileWrapper_1;
    public static /*const*/ String sel_renewGState;
    public static /*const*/ String sel_autovalidates;
    public static /*const*/ String sel_localizedNameForFamily_1face_1;
    public static /*const*/ String sel_setAltIncrementValue_1;
    public static /*const*/ String sel_sortUsingFunction_1context_1;
    public static /*const*/ String sel_fileNameExtensionWasHiddenInLastRunSavePanel;
    public static /*const*/ String sel_endSheet_1returnCode_1;
    public static /*const*/ String sel_insertObjects_1atIndexes_1;
    public static /*const*/ String sel_standaloneMonthSymbols;
    public static /*const*/ String sel_prefersAllColumnUserResizing;
    public static /*const*/ String sel_separatesColumns;
    public static /*const*/ String sel_moveToBeginningOfDocument_1;
    public static /*const*/ String sel_objectZone;
    public static /*const*/ String sel_initWithURL_1MIMEType_1expectedContentLength_1textEncodingName_1;
    public static /*const*/ String sel_gotoEnd_1;
    public static /*const*/ String sel_superscriptRange_1;
    public static /*const*/ String sel_readInBackgroundAndNotifyForModes_1;
    public static /*const*/ String sel_initWithObjects_1forKeys_1;
    public static /*const*/ String sel_cancel;
    public static /*const*/ String sel_suiteName;
    public static /*const*/ String sel_sortedArrayUsingFunction_1context_1hint_1;
    public static /*const*/ String sel_countWordsInString_1language_1;
    public static /*const*/ String sel_prepareWithInvocationTarget_1;
    public static /*const*/ String sel_statusItemWithLength_1;
    public static /*const*/ String sel_tableView_1shouldEditTableColumn_1row_1;
    public static /*const*/ String sel_appendBezierPathWithRect_1;
    public static /*const*/ String sel_scrollColumnsRightBy_1;
    public static /*const*/ String sel_negativeInfinitySymbol;
    public static /*const*/ String sel_firstLineHeadIndent;
    public static /*const*/ String sel_generateGlyphsForGlyphStorage_1desiredNumberOfCharacters_1glyphIndex_1characterIndex_1;
    public static /*const*/ String sel_dateWithTimeIntervalSinceReferenceDate_1;
    public static /*const*/ String sel_menu_1updateItem_1atIndex_1shouldCancel_1;
    public static /*const*/ String sel_connection_1willSendRequest_1redirectResponse_1;
    public static /*const*/ String sel_attemptRecoveryFromError_1optionIndex_1delegate_1didRecoverSelector_1contextInfo_1;
    public static /*const*/ String sel_cursorUpdate_1;
    public static /*const*/ String sel_initWithMachPort_1options_1;
    public static /*const*/ String sel_applyFontTraits_1range_1;
    public static /*const*/ String sel_noteHeightOfRowsWithIndexesChanged_1;
    public static /*const*/ String sel_orderFrontTablePanel_1;
    public static /*const*/ String sel_arrayWithObjects_1;
    public static /*const*/ String sel_enableFlushWindow;
    public static /*const*/ String sel_minimum;
    public static /*const*/ String sel_stopListening;
    public static /*const*/ String sel_endParagraph;
    public static /*const*/ String sel_sharingType;
    public static /*const*/ String sel_backgroundLayoutEnabled;
    public static /*const*/ String sel_yellowColor;
    public static /*const*/ String sel_columnIndexesInRect_1;
    public static /*const*/ String sel_compositingOperation;
    public static /*const*/ String sel_stopModalWithCode_1;
    public static /*const*/ String sel_smallSystemFontSize;
    public static /*const*/ String sel_nonretainedObjectValue;
    public static /*const*/ String sel_encodeBytes_1length_1forKey_1;
    public static /*const*/ String sel_objectValues;
    public static /*const*/ String sel_destroyContext;
    public static /*const*/ String sel_setFileModificationDate_1;
    public static /*const*/ String sel_rightMouseDragged_1;
    public static /*const*/ String sel_systemStatusBar;
    public static /*const*/ String sel_executableArchitectures;
    public static /*const*/ String sel_recentSearches;
    public static /*const*/ String sel_getWhite_1alpha_1;
    public static /*const*/ String sel_readDataToEndOfFile;
    public static /*const*/ String sel_setHour_1;
    public static /*const*/ String sel_titleBarFontOfSize_1;
    public static /*const*/ String sel_canDragRowsWithIndexes_1atPoint_1;
    public static /*const*/ String sel_acceptsArrowKeys;
    public static /*const*/ String sel_availableColorLists;
    public static /*const*/ String sel_setUsesLazyFetching_1;
    public static /*const*/ String sel_convertAttributes_1;
    public static /*const*/ String sel_isWritableFileAtPath_1;
    public static /*const*/ String sel_timerWithTimeInterval_1target_1selector_1userInfo_1repeats_1;
    public static /*const*/ String sel_windowDidChangeScreen_1;
    public static /*const*/ String sel_insertTextContainer_1atIndex_1;
    public static /*const*/ String sel_weightOfFont_1;
    public static /*const*/ String sel_temporaryAttributesAtCharacterIndex_1longestEffectiveRange_1inRange_1;
    public static /*const*/ String sel_trackWithEvent_1;
    public static /*const*/ String sel_selectRowIndexes_1byExtendingSelection_1;
    public static /*const*/ String sel_charactersToBeSkipped;
    public static /*const*/ String sel_names;
    public static /*const*/ String sel_setAllowsCutCopyPaste_1;
    public static /*const*/ String sel_setDuration_1;
    public static /*const*/ String sel_sleepForTimeInterval_1;
    public static /*const*/ String sel_removeChildAtIndex_1;
    public static /*const*/ String sel_tokenFieldCell_1writeRepresentedObjects_1toPasteboard_1;
    public static /*const*/ String sel_backgroundStyle;
    public static /*const*/ String sel_open_1;
    public static /*const*/ String sel_indexGreaterThanOrEqualToIndex_1;
    public static /*const*/ String sel_isAbsolutePath;
    public static /*const*/ String sel_paletteLabel;
    public static /*const*/ String sel_setQuarterSymbols_1;
    public static /*const*/ String sel_suppressionButton;
    public static /*const*/ String sel_undo;
    public static /*const*/ String sel_rangeOfString_1options_1range_1locale_1;
    public static /*const*/ String sel_localizedName_1locale_1;
    public static /*const*/ String sel_setTableView_1;
    public static /*const*/ String sel_isExecutableFileAtPath_1;
    public static /*const*/ String sel_standaloneQuarterSymbols;
    public static /*const*/ String sel_textView_1shouldSetSpellingState_1range_1;
    public static /*const*/ String sel_newObject;
    public static /*const*/ String sel_setDocumentEdited_1;
    public static /*const*/ String sel_setRelativePosition_1;
    public static /*const*/ String sel_allConnections;
    public static /*const*/ String sel_isLessThanOrEqualTo_1;
    public static /*const*/ String sel_attributeWithName_1StringValue_1;
    public static /*const*/ String sel_floatForKey_1;
    public static /*const*/ String sel_initWithDomain_1type_1name_1port_1;
    public static /*const*/ String sel_setShadowOffset_1;
    public static /*const*/ String sel_tabViewItems;
    public static /*const*/ String sel_appleEventCodeForReturnType;
    public static /*const*/ String sel_createFileAtPath_1contents_1attributes_1;
    public static /*const*/ String sel_ruleEditor_1predicatePartsForCriterion_1withDisplayValue_1inRow_1;
    public static /*const*/ String sel_evaluateWithObject_1;
    public static /*const*/ String sel_pathComponents;
    public static /*const*/ String sel_setTarget_1;
    public static /*const*/ String sel_fileCreationDate;
    public static /*const*/ String sel_port;
    public static /*const*/ String sel_publish;
    public static /*const*/ String sel_downloadDidFinish_1;
    public static /*const*/ String sel_endEditing_1;
    public static /*const*/ String sel_expectedResourceDataSize;
    public static /*const*/ String sel_paddingCharacter;
    public static /*const*/ String sel_convertPoint_1fromView_1;
    public static /*const*/ String sel_setIntValue_1;
    public static /*const*/ String sel_appendBezierPathWithArcFromPoint_1toPoint_1radius_1;
    public static /*const*/ String sel_currentFontAction;
    public static /*const*/ String sel_expressionForFunction_1arguments_1;
    public static /*const*/ String sel_minimumDaysInFirstWeek;
    public static /*const*/ String sel_setDeletesFileUponFailure_1;
    public static /*const*/ String sel_pageCount;
    public static /*const*/ String sel_imageAlignment;
    public static /*const*/ String sel_URLProtocol_1didCancelAuthenticationChallenge_1;
    public static /*const*/ String sel_localizedPaperName;
    public static /*const*/ String sel_setAllowsBranchSelection_1;
    public static /*const*/ String sel_symbolicLinkDestination;
    public static /*const*/ String sel_prepareSavePanel_1;
    public static /*const*/ String sel_enableMultipleThreads;
    public static /*const*/ String sel_configurePersistentStoreCoordinatorForURL_1ofType_1modelConfiguration_1storeOptions_1error_1;
    public static /*const*/ String sel_backgroundLoadDidFailWithReason_1;
    public static /*const*/ String sel_copyAttributesFromContext_1withMask_1;
    public static /*const*/ String sel_isVertical;
    public static /*const*/ String sel_wait;
    public static /*const*/ String sel_firstObjectCommonWithArray_1;
    public static /*const*/ String sel_hideOtherApplications_1;
    public static /*const*/ String sel_startSpeakingString_1;
    public static /*const*/ String sel_makeKeyAndOrderFront_1;
    public static /*const*/ String sel_drawCellAtIndex_1;
    public static /*const*/ String sel_headerToolTip;
    public static /*const*/ String sel_readRTFDFromFile_1;
    public static /*const*/ String sel_knownTimeZoneNames;
    public static /*const*/ String sel_toOneRelationshipKeys;
    public static /*const*/ String sel_replyTimeout;
    public static /*const*/ String sel_setDelegate_1;
    public static /*const*/ String sel_initWithTarget_1protocol_1;
    public static /*const*/ String sel_setShowsPrintPanel_1;
    public static /*const*/ String sel_trackingNumber;
    public static /*const*/ String sel_initWithDecimal_1;
    public static /*const*/ String sel_proxyWithTarget_1connection_1;
    public static /*const*/ String sel_setCompositingFilter_1;
    public static /*const*/ String sel_systemFontSizeForControlSize_1;
    public static /*const*/ String sel_registerDefaults_1;
    public static /*const*/ String sel_veryShortStandaloneMonthSymbols;
    public static /*const*/ String sel_setPlusSign_1;
    public static /*const*/ String sel_colorRenderingIntent;
    public static /*const*/ String sel_thicknessRequiredInRuler;
    public static /*const*/ String sel_setAlertStyle_1;
    public static /*const*/ String sel_searchScopes;
    public static /*const*/ String sel_tag;
    public static /*const*/ String sel_autosavingDelay;
    public static /*const*/ String sel_setDateStyle_1;
    public static /*const*/ String sel_setIcon_1forFile_1options_1;
    public static /*const*/ String sel_internationalCurrencySymbol;
    public static /*const*/ String sel_netService_1didUpdateTXTRecordData_1;
    public static /*const*/ String sel_setOnMouseEntered_1;
    public static /*const*/ String sel_setTextBaseWritingDirection_1;
    public static /*const*/ String sel_startSpecifier;
    public static /*const*/ String sel_setExcludedFromWindowsMenu_1;
    public static /*const*/ String sel_operatingSystemName;
    public static /*const*/ String sel_isConcurrent;
    public static /*const*/ String sel_enableRelease_1;
    public static /*const*/ String sel_getValues_1forAttribute_1forVirtualScreen_1;
    public static /*const*/ String sel_interrupt;
    public static /*const*/ String sel_whiteComponent;
    public static /*const*/ String sel_keyEquivalentRectForBounds_1;
    public static /*const*/ String sel_numberOfVisibleColumns;
    public static /*const*/ String sel_windowNibName;
    public static /*const*/ String sel_parser_1foundIgnorableWhitespace_1;
    public static /*const*/ String sel_menuItemCellForItemAtIndex_1;
    public static /*const*/ String sel_addTrackingArea_1;
    public static /*const*/ String sel_arrangedObjects;
    public static /*const*/ String sel_timeStyle;
    public static /*const*/ String sel_indexPathWithIndexes_1length_1;
    public static /*const*/ String sel_addNamespace_1;
    public static /*const*/ String sel_setDisplayValuesKeyPath_1;
    public static /*const*/ String sel_notificationBatchingInterval;
    public static /*const*/ String sel_MIMEType;
    public static /*const*/ String sel_drawerWillClose_1;
    public static /*const*/ String sel_sortedArrayHint;
    public static /*const*/ String sel_shortQuarterSymbols;
    public static /*const*/ String sel_usesAlternatingRowBackgroundColors;
    public static /*const*/ String sel_colorWithKey_1;
    public static /*const*/ String sel_rangeForUserCompletion;
    public static /*const*/ String sel_boolValue;
    public static /*const*/ String sel_autosaveName;
    public static /*const*/ String sel_childWindows;
    public static /*const*/ String sel_mapTableWithStrongToWeakObjects;
    public static /*const*/ String sel_unhide;
    public static /*const*/ String sel_setRowClass_1;
    public static /*const*/ String sel_endSubelementIndex;
    public static /*const*/ String sel_preferredLocalizations;
    public static /*const*/ String sel_fileSystemChanged;
    public static /*const*/ String sel_secondOfMinute;
    public static /*const*/ String sel_scrollWheel_1;
    public static /*const*/ String sel_characterIndexForGlyphAtIndex_1;
    public static /*const*/ String sel_drawRepresentation_1inRect_1;
    public static /*const*/ String sel_setByAddingObject_1;
    public static /*const*/ String sel_rotateByAngle_1;
    public static /*const*/ String sel_allValues;
    public static /*const*/ String sel_addItemWithObjectValue_1;
    public static /*const*/ String sel_tabViewItemAtIndex_1;
    public static /*const*/ String sel_servicePortWithName_1;
    public static /*const*/ String sel_multiplier;
    public static /*const*/ String sel_setSelectionGranularity_1;
    public static /*const*/ String sel_setViewsNeedDisplay_1;
    public static /*const*/ String sel_object;
    public static /*const*/ String sel_writeFileWrapper_1;
    public static /*const*/ String sel_authenticationMethod;
    public static /*const*/ String sel_frameLength;
    public static /*const*/ String sel_nextNode;
    public static /*const*/ String sel_characterSetWithCharactersInString_1;
    public static /*const*/ String sel_messageText;
    public static /*const*/ String sel_setArguments_1;
    public static /*const*/ String sel_getBytes_1length_1;
    public static /*const*/ String sel_setDropItem_1dropChildIndex_1;
    public static /*const*/ String sel_expressionForVariable_1;
    public static /*const*/ String sel_rectPreservedDuringLiveResize;
    public static /*const*/ String sel_isMuted;
    public static /*const*/ String sel_allowsColumnResizing;
    public static /*const*/ String sel_readFileWrapper;
    public static /*const*/ String sel_undoNestedGroup;
    public static /*const*/ String sel_setIncludedKeys_1;
    public static /*const*/ String sel_textWithStringValue_1;
    public static /*const*/ String sel_ruleEditorRowsDidChange_1;
    public static /*const*/ String sel_handleMouseEvent_1;
    public static /*const*/ String sel_browser_1canDragRowsWithIndexes_1inColumn_1withEvent_1;
    public static /*const*/ String sel_drawPageBorderWithSize_1;
    public static /*const*/ String sel_valueWithBytes_1objCType_1;
    public static /*const*/ String sel_subpathsAtPath_1;
    public static /*const*/ String sel_mnemonicLocation;
    public static /*const*/ String sel_dockTile;
    public static /*const*/ String sel_setFirstLineHeadIndent_1;
    public static /*const*/ String sel_isAutomaticQuoteSubstitutionEnabled;
    public static /*const*/ String sel_allowsReverseTransformation;
    public static /*const*/ String sel_moveNodes_1toIndexPath_1;
    public static /*const*/ String sel_seekToFileOffset_1;
    public static /*const*/ String sel_scriptingBeginsWith_1;
    public static /*const*/ String sel_setInformativeText_1;
    public static /*const*/ String sel_initWithIndexSet_1;
    public static /*const*/ String sel_write_1maxLength_1;
    public static /*const*/ String sel_canInitWithRequest_1;
    public static /*const*/ String sel_enqueueNotification_1postingStyle_1;
    public static /*const*/ String sel_setShouldResolveExternalEntities_1;
    public static /*const*/ String sel_usesFindPanel;
    public static /*const*/ String sel_perMillSymbol;
    public static /*const*/ String sel_setClearsFilterPredicateOnInsertion_1;
    public static /*const*/ String sel_currentLocale;
    public static /*const*/ String sel_pasteboardByFilteringData_1ofType_1;
    public static /*const*/ String sel_isSheet;
    public static /*const*/ String sel_hasWritablePropertyForKey_1;
    public static /*const*/ String sel_drawDividerInRect_1;
    public static /*const*/ String sel_sharedUserDefaultsController;
    public static /*const*/ String sel_preferredFontNames;
    public static /*const*/ String sel_menuBarFontOfSize_1;
    public static /*const*/ String sel_sharedColorPanelExists;
    public static /*const*/ String sel_reshape;
    public static /*const*/ String sel_initWithLong_1;
    public static /*const*/ String sel_reservedThicknessForAccessoryView;
    public static /*const*/ String sel_setTitleCell_1;
    public static /*const*/ String sel_sharedSpellCheckerExists;
    public static /*const*/ String sel_locationForSubmenu_1;
    public static /*const*/ String sel_nodesForXPath_1error_1;
    public static /*const*/ String sel_setHasVerticalRuler_1;
    public static /*const*/ String sel_controlHighlightColor;
    public static /*const*/ String sel_rowSpan;
    public static /*const*/ String sel_decodeObject;
    public static /*const*/ String sel_fileHandleForReadingAtPath_1;
    public static /*const*/ String sel_didLoadBytes_1loadComplete_1;
    public static /*const*/ String sel_renewRows_1columns_1;
    public static /*const*/ String sel_performKeyEquivalent_1;
    public static /*const*/ String sel_windowDidResignKey_1;
    public static /*const*/ String sel_typeForKey_1;
    public static /*const*/ String sel_selectedObjects;
    public static /*const*/ String sel_defaultPrinter;
    public static /*const*/ String sel_colorWithPatternImage_1;
    public static /*const*/ String sel_setAttributedAlternateTitle_1;
    public static /*const*/ String sel_setValue_1forKey_1;
    public static /*const*/ String sel_drawInteriorWithFrame_1inView_1;
    public static /*const*/ String sel_copy_1;
    public static /*const*/ String sel_scanString_1intoString_1;
    public static /*const*/ String sel_fileManager_1shouldProceedAfterError_1;
    public static /*const*/ String sel_fileManager_1shouldRemoveItemAtPath_1;
    public static /*const*/ String sel_removeSavedColumnsWithAutosaveName_1;
    public static /*const*/ String sel_numberWithUnsignedInteger_1;
    public static /*const*/ String sel_rulerMarkersForTextView_1paragraphStyle_1ruler_1;
    public static /*const*/ String sel_layoutRectForTextBlock_1atIndex_1effectiveRange_1;
    public static /*const*/ String sel_maxPossiblePositionOfDividerAtIndex_1;
    public static /*const*/ String sel_removePort_1forMode_1;
    public static /*const*/ String sel_drawHashMarksAndLabelsInRect_1;
    public static /*const*/ String sel_control_1textView_1doCommandBySelector_1;
    public static /*const*/ String sel_getLineFragmentRect_1usedRect_1remainingRect_1forStartingGlyphAtIndex_1proposedRect_1lineSpacing_1paragraphSpacingBefore_1paragraphSpacingAfter_1;
    public static /*const*/ String sel_textContainerInset;
    public static /*const*/ String sel_positionsForCompositeSequence_1numberOfGlyphs_1pointArray_1;
    public static /*const*/ String sel_StringByAppendingPathComponent_1;
    public static /*const*/ String sel_application_1printFiles_1;
    public static /*const*/ String sel_scanInt_1;
    public static /*const*/ String sel_operators;
    public static /*const*/ String sel_fireDate;
    public static /*const*/ String sel_isExternal;
    public static /*const*/ String sel_setImagePosition_1;
    public static /*const*/ String sel_predicateWithFormat_1arguments_1;
    public static /*const*/ String sel_stopSpeaking;
    public static /*const*/ String sel_contentWidthValueType;
    public static /*const*/ String sel_paddingPosition;
    public static /*const*/ String sel_removeLastObject;
    public static /*const*/ String sel_StringByReplacingCharactersInRange_1withString_1;
    public static /*const*/ String sel_pointerValue;
    public static /*const*/ String sel_setTruncatesLastVisibleLine_1;
    public static /*const*/ String sel_URLHandleResourceDidBeginLoading_1;
    public static /*const*/ String sel_valueForKeyPath_1;
    public static /*const*/ String sel_setPeriodicDelay_1interval_1;
    public static /*const*/ String sel_imageRepWithCIImage_1;
    public static /*const*/ String sel_wantsNotificationForMarkedText;
    public static /*const*/ String sel_rectForPart_1;
    public static /*const*/ String sel_setWeekday_1;
    public static /*const*/ String sel_streamStatus;
    public static /*const*/ String sel_containsPoint_1;
    public static /*const*/ String sel_underlineThickness;
    public static /*const*/ String sel_allObjects;
    public static /*const*/ String sel_characters;
    public static /*const*/ String sel_outlineViewSelectionIsChanging_1;
    public static /*const*/ String sel_netServiceBrowser_1didNotSearch_1;
    public static /*const*/ String sel_poolCountHighWaterMark;
    public static /*const*/ String sel_setColorSpaceName_1;
    public static /*const*/ String sel_graphicsPort;
    public static /*const*/ String sel_fontDescriptorWithName_1matrix_1;
    public static /*const*/ String sel_setSelectable_1;
    public static /*const*/ String sel_scriptErrorOffendingObjectDescriptor;
    public static /*const*/ String sel_resizingMask;
    public static /*const*/ String sel_canHandleRequest_1;
    public static /*const*/ String sel_imageRepWithPasteboard_1;
    public static /*const*/ String sel_stopQuery;
    public static /*const*/ String sel_dataWithBytes_1length_1;
    public static /*const*/ String sel_setCachesBezierPath_1;
    public static /*const*/ String sel_arrayForKey_1;
    public static /*const*/ String sel_cell;
    public static /*const*/ String sel_dealloc;
    public static /*const*/ String sel_constrainScrollPoint_1;
    public static /*const*/ String sel_printSettings;
    public static /*const*/ String sel_autoresizesOutlineColumn;
    public static /*const*/ String sel_setFont_1range_1;
    public static /*const*/ String sel_limitDateForMode_1;
    public static /*const*/ String sel_stroke;
    public static /*const*/ String sel_parser_1parseErrorOccurred_1;
    public static /*const*/ String sel_sendsActionOnEndEditing;
    public static /*const*/ String sel_toggleGrammarChecking_1;
    public static /*const*/ String sel_acceptsBinary;
    public static /*const*/ String sel_indexLessThanIndex_1;
    public static /*const*/ String sel_setCollapsesBorders_1;
    public static /*const*/ String sel_setTimeoutInterval_1;
    public static /*const*/ String sel_setNeedsDisplayInRect_1avoidAdditionalLayout_1;
    public static /*const*/ String sel_encodeWithCoder_1;
    public static /*const*/ String sel_compositeToPoint_1operation_1;
    public static /*const*/ String sel_textView_1doubleClickedOnCell_1inRect_1atIndex_1;
    public static /*const*/ String sel_setAlternateTitleWithMnemonic_1;
    public static /*const*/ String sel_minimumSignificantDigits;
    public static /*const*/ String sel_stackSize;
    public static /*const*/ String sel_setLayoutManager_1;
    public static /*const*/ String sel_image_1didLoadRepresentationHeader_1;
    public static /*const*/ String sel_depth;
    public static /*const*/ String sel_setTypesetter_1;
    public static /*const*/ String sel_isSessionOnly;
    public static /*const*/ String sel_performFindPanelAction_1;
    public static /*const*/ String sel_fileManager_1shouldProceedAfterError_1removingItemAtPath_1;
    public static /*const*/ String sel_paperSize;
    public static /*const*/ String sel_changeColor_1;
    public static /*const*/ String sel_unarchiverDidFinish_1;
    public static /*const*/ String sel_initWithObjectsAndKeys_1;
    public static /*const*/ String sel_notationDeclarationForName_1;
    public static /*const*/ String sel_maximumSignificantDigits;
    public static /*const*/ String sel_receivesCredentialSecurely;
    public static /*const*/ String sel_setObjectBeingTested_1;
    public static /*const*/ String sel_cacheDepthMatchesImageDepth;
    public static /*const*/ String sel_hasPropertyForKey_1;
    public static /*const*/ String sel_draggingDestinationWindow;
    public static /*const*/ String sel_typeCodeValue;
    public static /*const*/ String sel_portForName_1;
    public static /*const*/ String sel_getCString_1maxLength_1encoding_1;
    public static /*const*/ String sel_attributedString;
    public static /*const*/ String sel_fileExistsAtPath_1isDirectory_1;
    public static /*const*/ String sel_updateRuler;
    public static /*const*/ String sel_print_1;
    public static /*const*/ String sel_setFrameSize_1;
    public static /*const*/ String sel_dataFromPropertyList_1format_1errorDescription_1;
    public static /*const*/ String sel_initWithContentsOfURL_1ofType_1;
    public static /*const*/ String sel_replaceValueAtIndex_1inPropertyWithKey_1withValue_1;
    public static /*const*/ String sel_formIntersectionWithCharacterSet_1;
    public static /*const*/ String sel_renderingMode;
    public static /*const*/ String sel_viewsNeedDisplay;
    public static /*const*/ String sel_lineFragmentRectForProposedRect_1sweepDirection_1movementDirection_1remainingRect_1;
    public static /*const*/ String sel_rulerAccessoryViewForTextView_1paragraphStyle_1ruler_1enabled_1;
    public static /*const*/ String sel_initWithArray_1copyItems_1;
    public static /*const*/ String sel_ensureLayoutForGlyphRange_1;
    public static /*const*/ String sel_availableLocaleIdentifiers;
    public static /*const*/ String sel_viewDidHide;
    public static /*const*/ String sel_setShouldReportNamespacePrefixes_1;
    public static /*const*/ String sel_runToolbarCustomizationPalette_1;
    public static /*const*/ String sel_roundingBehavior;
    public static /*const*/ String sel_expressionForEvaluatedObject;
    public static /*const*/ String sel_rulerView_1handleMouseDown_1;
    public static /*const*/ String sel_scanCharactersFromSet_1intoString_1;
    public static /*const*/ String sel_applicationDidChangeScreenParameters_1;
    public static /*const*/ String sel_textView_1clickedOnCell_1inRect_1;
    public static /*const*/ String sel_decodeDoubleForKey_1;
    public static /*const*/ String sel_URLHandle_1resourceDidFailLoadingWithReason_1;
    public static /*const*/ String sel_setCountKeyPath_1;
    public static /*const*/ String sel_showContextHelpForObject_1locationHint_1;
    public static /*const*/ String sel_setData_1forType_1;
    public static /*const*/ String sel_setPixel_1atX_1y_1;
    public static /*const*/ String sel_setReceiversSpecifier_1;
    public static /*const*/ String sel_postNotificationName_1object_1userInfo_1;
    public static /*const*/ String sel_rowForItem_1;
    public static /*const*/ String sel_fetch_1;
    public static /*const*/ String sel_propertyList_1isValidForFormat_1;
    public static /*const*/ String sel_configureAsServer;
    public static /*const*/ String sel_setAllowsColumnReordering_1;
    public static /*const*/ String sel_charValue;
    public static /*const*/ String sel_setInsertionClassDescription_1;
    public static /*const*/ String sel_cyanColor;
    public static /*const*/ String sel_lockWhenCondition_1;
    public static /*const*/ String sel_cacheImageInRect_1;
    public static /*const*/ String sel_keyboardFocusIndicatorColor;
    public static /*const*/ String sel_hasUndoManager;
    public static /*const*/ String sel_drawInBezierPath_1relativeCenterPosition_1;
    public static /*const*/ String sel_decimalNumberByAdding_1;
    public static /*const*/ String sel_initWithDescriptorType_1data_1;
    public static /*const*/ String sel_isUndoing;
    public static /*const*/ String sel_boolForKey_1;
    public static /*const*/ String sel_localizedCatalogNameComponent;
    public static /*const*/ String sel_representations;
    public static /*const*/ String sel_expressionValueWithObject_1context_1;
    public static /*const*/ String sel_viewWillMoveToSuperview_1;
    public static /*const*/ String sel_alphaValue;
    public static /*const*/ String sel_learnWord_1;
    public static /*const*/ String sel_releaseGlobally;
    public static /*const*/ String sel_defaultCompletionDelay;
    public static /*const*/ String sel_control_1textShouldEndEditing_1;
    public static /*const*/ String sel_alertWithMessageText_1defaultButton_1alternateButton_1otherButton_1informativeTextWithFormat_1;
    public static /*const*/ String sel_control_1textShouldBeginEditing_1;
    public static /*const*/ String sel_sizeMode;
    public static /*const*/ String sel_representedURL;
    public static /*const*/ String sel_fileHFSCreatorCode;
    public static /*const*/ String sel_removeDependency_1;
    public static /*const*/ String sel_parentForItem_1;
    public static /*const*/ String sel_adjustPageHeightNew_1top_1bottom_1limit_1;
    public static /*const*/ String sel_showPanels;
    public static /*const*/ String sel_alwaysUsesMultipleValuesMarker;
    public static /*const*/ String sel_setUpFieldEditorAttributes_1;
    public static /*const*/ String sel_comboBoxCell_1completedString_1;
    public static /*const*/ String sel_null;
    public static /*const*/ String sel_setTextAttributesForNil_1;
    public static /*const*/ String sel_currencyGroupingSeparator;
    public static /*const*/ String sel_toolbarSelectableItemIdentifiers_1;
    public static /*const*/ String sel_size;
    public static /*const*/ String sel_fileModificationDate;
    public static /*const*/ String sel_timestamp;
    public static /*const*/ String sel_canonicalRequestForRequest_1;
    public static /*const*/ String sel_moveBackwardAndModifySelection_1;
    public static /*const*/ String sel_frameOfColumn_1;
    public static /*const*/ String sel_setRefusesFirstResponder_1;
    public static /*const*/ String sel_hasDynamicDepthLimit;
    public static /*const*/ String sel_decodeIntForKey_1;
    public static /*const*/ String sel_autoupdatingCurrentLocale;
    public static /*const*/ String sel_transformBezierPath_1;
    public static /*const*/ String sel_registerPort_1name_1nameServerPortNumber_1;
    public static /*const*/ String sel_contentWidth;
    public static /*const*/ String sel_noteUserDefaultsChanged;
    public static /*const*/ String sel_orangeColor;
    public static /*const*/ String sel_lastItem;
    public static /*const*/ String sel_setButtonType_1;
    public static /*const*/ String sel_initWithContentsOfURL_1ofType_1error_1;
    public static /*const*/ String sel_rowTemplates;
    public static /*const*/ String sel_setEnabled_1forSegment_1;
    public static /*const*/ String sel_avoidsEmptySelection;
    public static /*const*/ String sel_encodeInt_1forKey_1;
    public static /*const*/ String sel_dictionaryWithValuesForKeys_1;
    public static /*const*/ String sel_start_1;
    public static /*const*/ String sel_sortUsingDescriptors_1;
    public static /*const*/ String sel_currentParagraphStyle;
    public static /*const*/ String sel_treeNodeWithRepresentedObject_1;
    public static /*const*/ String sel_tableColumnWithIdentifier_1;
    public static /*const*/ String sel_attributedTitle;
    public static /*const*/ String sel_setEntryType_1;
    public static /*const*/ String sel_pixelFormat;
    public static /*const*/ String sel_temporaryAttribute_1atCharacterIndex_1longestEffectiveRange_1inRange_1;
    public static /*const*/ String sel_treatsFilePackagesAsDirectories;
    public static /*const*/ String sel_glyphAtIndex_1;
    public static /*const*/ String sel_titleWidth_1;
    public static /*const*/ String sel_setWords_1;
    public static /*const*/ String sel_glyphIndexForPoint_1inTextContainer_1;
    public static /*const*/ String sel_alternateSelectedControlColor;
    public static /*const*/ String sel_sizeToCells;
    public static /*const*/ String sel_flushWindow;
    public static /*const*/ String sel_URLAtIndex_1effectiveRange_1;
    public static /*const*/ String sel_isSimpleRectangularTextContainer;
    public static /*const*/ String sel_dragImageForRowsWithIndexes_1tableColumns_1event_1offset_1;
    public static /*const*/ String sel_takeDoubleValueFrom_1;
    public static /*const*/ String sel_selectItem_1;
    public static /*const*/ String sel_isMultiple;
    public static /*const*/ String sel_arrangeInFront_1;
    public static /*const*/ String sel_defaultFocusRingType;
    public static /*const*/ String sel_componentsSeparatedByString_1;
    public static /*const*/ String sel_calendar;
    public static /*const*/ String sel_openFile_1withApplication_1;
    public static /*const*/ String sel_moveWordBackward_1;
    public static /*const*/ String sel_getCharacters_1;
    public static /*const*/ String sel_initWithInt_1;
    public static /*const*/ String sel_initWithReceivePort_1sendPort_1components_1;
    public static /*const*/ String sel_setBool_1forKey_1;
    public static /*const*/ String sel_keyPathsForValuesAffectingValueForKey_1;
    public static /*const*/ String sel_saveDocumentTo_1;
    public static /*const*/ String sel_knobRectFlipped_1;
    public static /*const*/ String sel_isEqualToAttributedString_1;
    public static /*const*/ String sel_indexOfResult_1;
    public static /*const*/ String sel_attributesForVoice_1;
    public static /*const*/ String sel_encodeConditionalObject_1;
    public static /*const*/ String sel_pixelBufferCubeMapFace;
    public static /*const*/ String sel_index;
    public static /*const*/ String sel_transactionID;
    public static /*const*/ String sel_displayRectIgnoringOpacity_1;
    public static /*const*/ String sel_setKeyboardFocusRingNeedsDisplayInRect_1;
    public static /*const*/ String sel_invalidateLayoutForCharacterRange_1isSoft_1actualCharacterRange_1;
    public static /*const*/ String sel_contentsEqualAtPath_1andPath_1;
    public static /*const*/ String sel_cancelOperation_1;
    public static /*const*/ String sel_accessibilityAttributeValue_1;
    public static /*const*/ String sel_windowNibPath;
    public static /*const*/ String sel_saveToFile_1saveOperation_1delegate_1didSaveSelector_1contextInfo_1;
    public static /*const*/ String sel_setMixedStateImage_1;
    public static /*const*/ String sel_predicateWithFormat_1;
    public static /*const*/ String sel_initWithSendPort_1receivePort_1components_1;
    public static /*const*/ String sel_setRecentsAutosaveName_1;
    public static /*const*/ String sel_autosavesConfiguration;
    public static /*const*/ String sel_setSubitems_1;
    public static /*const*/ String sel_setPathStyle_1;
    public static /*const*/ String sel_startAnimation_1;
    public static /*const*/ String sel_bezierPath;
    public static /*const*/ String sel_archiver_1willEncodeObject_1;
    public static /*const*/ String sel_acceptInputForMode_1beforeDate_1;
    public static /*const*/ String sel_setTearOffMenuRepresentation_1;
    public static /*const*/ String sel_writableTypes;
    public static /*const*/ String sel_domain;
    public static /*const*/ String sel_removeDocument_1;
    public static /*const*/ String sel_showsBaselineSeparator;
    public static /*const*/ String sel_dragImageForRows_1event_1dragImageOffset_1;
    public static /*const*/ String sel_table;
    public static /*const*/ String sel_initRegularFileWithContents_1;
    public static /*const*/ String sel_add_1;
    public static /*const*/ String sel_stateImageWidth;
    public static /*const*/ String sel_URLProtocol_1didReceiveAuthenticationChallenge_1;
    public static /*const*/ String sel_imageAndTitleWidth;
    public static /*const*/ String sel_trackingAreas;
    public static /*const*/ String sel_initRecordDescriptor;
    public static /*const*/ String sel_itemIdentifier;
    public static /*const*/ String sel_doubleClickAtIndex_1;
    public static /*const*/ String sel_fixesAttributesLazily;
    public static /*const*/ String sel_netServiceBrowserWillSearch_1;
    public static /*const*/ String sel_textureInternalFormat;
    public static /*const*/ String sel_valueWithSize_1;
    public static /*const*/ String sel_setVerticalScroller_1;
    public static /*const*/ String sel_absolutePathForAppBundleWithIdentifier_1;
    public static /*const*/ String sel_contentMinSize;
    public static /*const*/ String sel_persistentDomainForName_1;
    public static /*const*/ String sel_cellAtIndex_1;
    public static /*const*/ String sel_setWithArray_1;
    public static /*const*/ String sel_resetCursorRects;
    public static /*const*/ String sel_imageRepClassForFileType_1;
    public static /*const*/ String sel_setContainerIsObjectBeingTested_1;
    public static /*const*/ String sel_removeProgressMark_1;
    public static /*const*/ String sel_hitTestForEvent_1inRect_1ofView_1;
    public static /*const*/ String sel_listDescriptor;
    public static /*const*/ String sel_rangeOfUnit_1startDate_1interval_1forDate_1;
    public static /*const*/ String sel_checkSpaceForParts;
    public static /*const*/ String sel_availableVoices;
    public static /*const*/ String sel_PMPrintSettings;
    public static /*const*/ String sel_nonBaseCharacterSet;
    public static /*const*/ String sel_launchedTaskWithLaunchPath_1arguments_1;
    public static /*const*/ String sel_clearCurrentContext;
    public static /*const*/ String sel_applicationWillUpdate_1;
    public static /*const*/ String sel_addFontTrait_1;
    public static /*const*/ String sel_arrayByAddingObjectsFromArray_1;
    public static /*const*/ String sel_abortParsing;
    public static /*const*/ String sel_subviews;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1uniqueID_1;
    public static /*const*/ String sel_acceptableDragTypes;
    public static /*const*/ String sel_managedObjectContext;
    public static /*const*/ String sel_resizeWithMagnification_1;
    public static /*const*/ String sel_setUsesFindPanel_1;
    public static /*const*/ String sel_application_1printFiles_1withSettings_1showPrintPanels_1;
    public static /*const*/ String sel_loadAndReturnError_1;
    public static /*const*/ String sel_initWithLeftExpressions_1rightExpressions_1modifier_1operators_1options_1;
    public static /*const*/ String sel_addSelectionIndexes_1;
    public static /*const*/ String sel_initWithBitmapDataPlanes_1pixelsWide_1pixelsHigh_1bitsPerSample_1samplesPerPixel_1hasAlpha_1isPlanar_1colorSpaceName_1bitmapFormat_1bytesPerRow_1bitsPerPixel_1;
    public static /*const*/ String sel_initToFileAtPath_1append_1;
    public static /*const*/ String sel_currencyDecimalSeparator;
    public static /*const*/ String sel_expansionFrameWithFrame_1inView_1;
    public static /*const*/ String sel_HTTPShouldHandleCookies;
    public static /*const*/ String sel_rearrangeObjects;
    public static /*const*/ String sel_graphicsContextWithWindow_1;
    public static /*const*/ String sel_StringWithCapacity_1;
    public static /*const*/ String sel_results;
    public static /*const*/ String sel_loadFileWrapperRepresentation_1ofType_1;
    public static /*const*/ String sel_secondsFromGMTForDate_1;
    public static /*const*/ String sel_clearStopAnimation;
    public static /*const*/ String sel_numberWithShort_1;
    public static /*const*/ String sel_setHorizontallyCentered_1;
    public static /*const*/ String sel_setNeedsDisplayInRect_1;
    public static /*const*/ String sel_objectDidBeginEditing_1;
    public static /*const*/ String sel_rightMouseDown_1;
    public static /*const*/ String sel_data2;
    public static /*const*/ String sel_initWithCalendarIdentifier_1;
    public static /*const*/ String sel_containsValueForKey_1;
    public static /*const*/ String sel_result;
    public static /*const*/ String sel_printDocument_1;
    public static /*const*/ String sel_addSuiteNamed_1;
    public static /*const*/ String sel_deleteCookie_1;
    public static /*const*/ String sel_isLocationRequiredToCreateForKey_1;
    public static /*const*/ String sel_saveGraphicsState;
    public static /*const*/ String sel_getInfoForFile_1application_1type_1;
    public static /*const*/ String sel_HTTPBodyStream;
    public static /*const*/ String sel_accessibilityParameterizedAttributeNames;
    public static /*const*/ String sel_objectForKey_1;
    public static /*const*/ String sel_classForArchiver;
    public static /*const*/ String sel_allBundles;
    public static /*const*/ String sel_rangeOfComposedCharacterSequenceAtIndex_1;
    public static /*const*/ String sel_allowsDuplicatesInToolbar;
    public static /*const*/ String sel_speechSynthesizer_1didEncounterSyncMessage_1;
    public static /*const*/ String sel_performSelector_1withObject_1afterDelay_1inModes_1;
    public static /*const*/ String sel_setScalesWhenResized_1;
    public static /*const*/ String sel_fileWrappers;
    public static /*const*/ String sel_setSubmenu_1;
    public static /*const*/ String sel_setSendsSearchStringImmediately_1;
    public static /*const*/ String sel_movieUnfilteredPasteboardTypes;
    public static /*const*/ String sel_browser_1willDisplayCell_1atRow_1column_1;
    public static /*const*/ String sel_valueOfAttribute_1forResultAtIndex_1;
    public static /*const*/ String sel_rightExpression;
    public static /*const*/ String sel_moveNode_1toIndexPath_1;
    public static /*const*/ String sel_insertionKey;
    public static /*const*/ String sel_columnsAutosaveName;
    public static /*const*/ String sel_connection_1didReceiveResponse_1;
    public static /*const*/ String sel_delegate;
    public static /*const*/ String sel_valueForHTTPHeaderField_1;
    public static /*const*/ String sel_requiredThickness;
    public static /*const*/ String sel_selectedCells;
    public static /*const*/ String sel_setResizable_1;
    public static /*const*/ String sel_resizeRightCursor;
    public static /*const*/ String sel_arrayWithContentsOfURL_1;
    public static /*const*/ String sel_setEchosBullets_1;
    public static /*const*/ String sel_outlineViewItemDidCollapse_1;
    public static /*const*/ String sel_mutableSetValueForKey_1;
    public static /*const*/ String sel_initWithObjects_1forKeys_1count_1;
    public static /*const*/ String sel_canBeDisabled;
    public static /*const*/ String sel_selectTabViewItemWithIdentifier_1;
    public static /*const*/ String sel_setLongEraSymbols_1;
    public static /*const*/ String sel_displayRect_1;
    public static /*const*/ String sel_initRemoteWithProtocolFamily_1socketType_1protocol_1address_1;
    public static /*const*/ String sel_setQueuePriority_1;
    public static /*const*/ String sel_initWithFileDescriptor_1closeOnDealloc_1;
    public static /*const*/ String sel_comboBoxWillDismiss_1;
    public static /*const*/ String sel_setMatchesOnMultipleResolution_1;
    public static /*const*/ String sel_connection;
    public static /*const*/ String sel_includedKeys;
    public static /*const*/ String sel_writeToURL_1options_1error_1;
    public static /*const*/ String sel_activeProcessorCount;
    public static /*const*/ String sel_countByEnumeratingWithState_1objects_1count_1;
    public static /*const*/ String sel_setTransformStruct_1;
    public static /*const*/ String sel_setVeryShortWeekdaySymbols_1;
    public static /*const*/ String sel_markerLocation;
    public static /*const*/ String sel_widthForLayer_1edge_1;
    public static /*const*/ String sel_transform;
    public static /*const*/ String sel_addSelectionIndexPaths_1;
    public static /*const*/ String sel_removeRequestMode_1;
    public static /*const*/ String sel_indexOfObject_1inRange_1;
    public static /*const*/ String sel_awakeAfterUsingCoder_1;
    public static /*const*/ String sel_setKnobProportion_1;
    public static /*const*/ String sel_setAllowsUserCustomization_1;
    public static /*const*/ String sel_setCurrentOperation_1;
    public static /*const*/ String sel_outlineView_1isGroupItem_1;
    public static /*const*/ String sel_deleteGlyphsInRange_1;
    public static /*const*/ String sel_setSelectedObjects_1;
    public static /*const*/ String sel_pathComponentCellAtPoint_1withFrame_1inView_1;
    public static /*const*/ String sel_outlineView_1acceptDrop_1item_1childIndex_1;
    public static /*const*/ String sel_setBackgroundColor_1;
    public static /*const*/ String sel_canSelectNext;
    public static /*const*/ String sel_encodeRect_1forKey_1;
    public static /*const*/ String sel_resetCursorRect_1inView_1;
    public static /*const*/ String sel_resumeData;
    public static /*const*/ String sel_levelsOfUndo;
    public static /*const*/ String sel_objectIsForcedForKey_1;
    public static /*const*/ String sel_minSize;
    public static /*const*/ String sel_indentationPerLevel;
    public static /*const*/ String sel_browserColumnConfigurationDidChange_1;
    public static /*const*/ String sel_startAnimation;
    public static /*const*/ String sel_outlineView_1namesOfPromisedFilesDroppedAtDestination_1forDraggedItems_1;
    public static /*const*/ String sel_setAlignment_1range_1;
    public static /*const*/ String sel_zeroSymbol;
    public static /*const*/ String sel_draggedImage_1beganAt_1;
    public static /*const*/ String sel_buttonMask;
    public static /*const*/ String sel_frame;
    public static /*const*/ String sel_markers;
    public static /*const*/ String sel_initWithObjects_1count_1;
    public static /*const*/ String sel_unload;
    public static /*const*/ String sel_initForReadingWithData_1;
    public static /*const*/ String sel_year;
    public static /*const*/ String sel_ruleEditor_1child_1forCriterion_1withRowType_1;
    public static /*const*/ String sel_dayOfMonth;
    public static /*const*/ String sel_colorUsingColorSpaceName_1;
    public static /*const*/ String sel_registerCoercer_1selector_1toConvertFromClass_1toClass_1;
    public static /*const*/ String sel_removeObject_1inRange_1;
    public static /*const*/ String sel_setFrameFromString_1;
    public static /*const*/ String sel_canAdd;
    public static /*const*/ String sel_era;
    public static /*const*/ String sel_expressionForSubquery_1usingIteratorVariable_1predicate_1;
    public static /*const*/ String sel_setAMSymbol_1;
    public static /*const*/ String sel_groupedResults;
    public static /*const*/ String sel_attributedStringValue;
    public static /*const*/ String sel_enclosingScrollView;
    public static /*const*/ String sel_isEqualToNumber_1;
    public static /*const*/ String sel_mainBundle;
    public static /*const*/ String sel_textContainerForGlyphAtIndex_1effectiveRange_1;
    public static /*const*/ String sel_setUsesGroupingSeparator_1;
    public static /*const*/ String sel_pointerAtIndex_1;
    public static /*const*/ String sel_arrowsPosition;
    public static /*const*/ String sel_panel_1compareFilename_1with_1caseSensitive_1;
    public static /*const*/ String sel_drawSeparatorItemWithFrame_1inView_1;
    public static /*const*/ String sel_objectsByEvaluatingWithContainers_1;
    public static /*const*/ String sel_textTabForGlyphLocation_1writingDirection_1maxLocation_1;
    public static /*const*/ String sel_fontDescriptor;
    public static /*const*/ String sel_validAttributesForMarkedText;
    public static /*const*/ String sel_scriptingEndsWith_1;
    public static /*const*/ String sel_scrollViaScroller_1;
    public static /*const*/ String sel_setAlwaysUsesMultipleValuesMarker_1;
    public static /*const*/ String sel_attributeKeys;
    public static /*const*/ String sel_darkGrayColor;
    public static /*const*/ String sel_setExtensionHidden_1;
    public static /*const*/ String sel_drawInRect_1withAttributes_1;
    public static /*const*/ String sel_selectTabViewItemAtIndex_1;
    public static /*const*/ String sel_contentRectForFrameRect_1;
    public static /*const*/ String sel_setParagraphSpacingBefore_1;
    public static /*const*/ String sel_minDate;
    public static /*const*/ String sel_isARepeat;
    public static /*const*/ String sel_selectedTabViewItem;
    public static /*const*/ String sel_minusHashTable_1;
    public static /*const*/ String sel_preferredLocalizationsFromArray_1forPreferences_1;
    public static /*const*/ String sel_setTextBlocks_1;
    public static /*const*/ String sel_writePrintInfo;
    public static /*const*/ String sel_paperName;
    public static /*const*/ String sel_pauseSpeakingAtBoundary_1;
    public static /*const*/ String sel_markedTextAbandoned_1;
    public static /*const*/ String sel_setTitled_1;
    public static /*const*/ String sel_hidesOnDeactivate;
    public static /*const*/ String sel_selectedRange;
    public static /*const*/ String sel_reportException_1;
    public static /*const*/ String sel_drawBezelWithFrame_1inView_1;
    public static /*const*/ String sel_relativeMoveToPoint_1;
    public static /*const*/ String sel_printingAdjustmentInLayoutManager_1forNominallySpacedGlyphRange_1packedGlyphs_1count_1;
    public static /*const*/ String sel_longValue;
    public static /*const*/ String sel_setMaxNumberOfColumns_1;
    public static /*const*/ String sel_textView_1draggedCell_1inRect_1event_1atIndex_1;
    public static /*const*/ String sel_isRemovable;
    public static /*const*/ String sel_handleCloseScriptCommand_1;
    public static /*const*/ String sel_layoutManager_1shouldUseTemporaryAttributes_1forDrawingToScreen_1atCharacterIndex_1effectiveRange_1;
    public static /*const*/ String sel_expressionForKeyPath_1;
    public static /*const*/ String sel_bezierPathWithOvalInRect_1;
    public static /*const*/ String sel_deselectSelectedCell;
    public static /*const*/ String sel_defaultSubcontainerAttributeKey;
    public static /*const*/ String sel_yank_1;
    public static /*const*/ String sel_changeSpelling_1;
    public static /*const*/ String sel_totalAutoreleasedObjects;
    public static /*const*/ String sel_loops;
    public static /*const*/ String sel_boundsRectForTextBlock_1atIndex_1effectiveRange_1;
    public static /*const*/ String sel_resignMainWindow;
    public static /*const*/ String sel_availableLanguages;
    public static /*const*/ String sel_initWithMarkerFormat_1options_1;
    public static /*const*/ String sel_runInNewThread;
    public static /*const*/ String sel_tableView_1selectionIndexesForProposedSelection_1;
    public static /*const*/ String sel_fetchWithRequest_1merge_1error_1;
    public static /*const*/ String sel_endSubelementIdentifier;
    public static /*const*/ String sel_implementationClassName;
    public static /*const*/ String sel_eventNumber;
    public static /*const*/ String sel_requestTimeout;
    public static /*const*/ String sel_boldSystemFontOfSize_1;
    public static /*const*/ String sel_setPixelsWide_1;
    public static /*const*/ String sel_labelForSegment_1;
    public static /*const*/ String sel_setAlternateTitle_1;
    public static /*const*/ String sel_shouldBreakLineByWordBeforeCharacterAtIndex_1;
    public static /*const*/ String sel_lockFocusIfCanDraw;
    public static /*const*/ String sel_setFormat_1;
    public static /*const*/ String sel_setSegmentCount_1;
    public static /*const*/ String sel_accessInstanceVariablesDirectly;
    public static /*const*/ String sel_comboBox_1completedString_1;
    public static /*const*/ String sel_moveToBeginningOfParagraph_1;
    public static /*const*/ String sel_defaultParagraphStyle;
    public static /*const*/ String sel_availableTypeFromArray_1;
    public static /*const*/ String sel_setGregorianStartDate_1;
    public static /*const*/ String sel_dateWithTimeIntervalSince1970_1;
    public static /*const*/ String sel_imagePasteboardTypes;
    public static /*const*/ String sel_laterDate_1;
    public static /*const*/ String sel_setBounds_1;
    public static /*const*/ String sel_HTTPMethod;
    public static /*const*/ String sel_getGlyphsInRange_1glyphs_1characterIndexes_1glyphInscriptions_1elasticBits_1bidiLevels_1;
    public static /*const*/ String sel_rectArrayForCharacterRange_1withinSelectedCharacterRange_1inTextContainer_1rectCount_1;
    public static /*const*/ String sel_drawGridInClipRect_1;
    public static /*const*/ String sel_isStarted;
    public static /*const*/ String sel_descriptorType;
    public static /*const*/ String sel_ISOCurrencyCodes;
    public static /*const*/ String sel_resetCancelButtonCell;
    public static /*const*/ String sel_positiveInfinitySymbol;
    public static /*const*/ String sel_sendsActionOnArrowKeys;
    public static /*const*/ String sel_delete_1;
    public static /*const*/ String sel_toolbarWillAddItem_1;
    public static /*const*/ String sel_updateCellInside_1;
    public static /*const*/ String sel_inputClientResignActive_1;
    public static /*const*/ String sel_initWithEventClass_1eventID_1targetDescriptor_1returnID_1transactionID_1;
    public static /*const*/ String sel_decimalNumberByDividingBy_1withBehavior_1;
    public static /*const*/ String sel_spellServer_1suggestCompletionsForPartialWordRange_1inString_1language_1;
    public static /*const*/ String sel_arrayWithObjects_1count_1;
    public static /*const*/ String sel_connectionWithRegisteredName_1host_1;
    public static /*const*/ String sel_initWithFormat_1;
    public static /*const*/ String sel_sharedURLCache;
    public static /*const*/ String sel_edited_1range_1changeInLength_1;
    public static /*const*/ String sel_prepareContent;
    public static /*const*/ String sel_StringWithCString_1encoding_1;
    public static /*const*/ String sel_postNotificationName_1object_1userInfo_1deliverImmediately_1;
    public static /*const*/ String sel_coerceToDescriptorType_1;
    public static /*const*/ String sel_selectionIndex;
    public static /*const*/ String sel_setContentMaxSize_1;
    public static /*const*/ String sel_setColor_1atX_1y_1;
    public static /*const*/ String sel_graphicsContext;
    public static /*const*/ String sel_hostWithName_1;
    public static /*const*/ String sel_toggleRuler_1;
    public static /*const*/ String sel_glyphInfoWithGlyph_1forFont_1baseString_1;
    public static /*const*/ String sel_panel_1willExpand_1;
    public static /*const*/ String sel_selectText_1;
    public static /*const*/ String sel_setShortMonthSymbols_1;
    public static /*const*/ String sel_setBorderType_1;
    public static /*const*/ String sel_rangeOfString_1;
    public static /*const*/ String sel_invalidateGlyphsOnLayoutInvalidationForGlyphRange_1;
    public static /*const*/ String sel_availableMembersOfFontFamily_1;
    public static /*const*/ String sel_XPath;
    public static /*const*/ String sel_contentsOfDirectoryAtPath_1error_1;
    public static /*const*/ String sel_newItemForRepresentedObject_1;
    public static /*const*/ String sel_setMatrixClass_1;
    public static /*const*/ String sel_compositeToPoint_1operation_1fraction_1;
    public static /*const*/ String sel_setHorizontallyResizable_1;
    public static /*const*/ String sel_mapTableWithStrongToStrongObjects;
    public static /*const*/ String sel_colorSpaceModel;
    public static /*const*/ String sel_setCriticalValue_1;
    public static /*const*/ String sel_allowsToolTipsWhenApplicationIsInactive;
    public static /*const*/ String sel_transformUsingAffineTransform_1;
    public static /*const*/ String sel_initWithInvocation_1;
    public static /*const*/ String sel_containerClassDescription;
    public static /*const*/ String sel_parser_1resolveExternalEntityName_1systemID_1;
    public static /*const*/ String sel_mouseLocationOutsideOfEventStream;
    public static /*const*/ String sel_detach;
    public static /*const*/ String sel_setPickerMask_1;
    public static /*const*/ String sel_tokenStyle;
    public static /*const*/ String sel_setOptions_1;
    public static /*const*/ String sel_PDFOperationWithView_1insideRect_1toPath_1printInfo_1;
    public static /*const*/ String sel_parser_1didStartElement_1namespaceURI_1qualifiedName_1attributes_1;
    public static /*const*/ String sel_availableFontNamesMatchingFontDescriptor_1;
    public static /*const*/ String sel_relativePath;
    public static /*const*/ String sel_moveWordForwardAndModifySelection_1;
    public static /*const*/ String sel_currentTime;
    public static /*const*/ String sel_slideDraggedImageTo_1;
    public static /*const*/ String sel_application_1printFile_1;
    public static /*const*/ String sel_punctuationCharacterSet;
    public static /*const*/ String sel_allKeysForObject_1;
    public static /*const*/ String sel_pathStyle;
    public static /*const*/ String sel_allowsEditingTextAttributes;
    public static /*const*/ String sel_lineSpacingAfterGlyphAtIndex_1withProposedLineFragmentRect_1;
    public static /*const*/ String sel_initWithContentsOfMappedFile_1;
    public static /*const*/ String sel_initWithFrame_1pullsDown_1;
    public static /*const*/ String sel_setView_1;
    public static /*const*/ String sel_outlineViewSelectionDidChange_1;
    public static /*const*/ String sel_widthValueTypeForLayer_1edge_1;
    public static /*const*/ String sel_dateWithTimeIntervalSinceNow_1;
    public static /*const*/ String sel_display;
    public static /*const*/ String sel_setRoundingBehavior_1;
    public static /*const*/ String sel_valueWithPoint_1;
    public static /*const*/ String sel_tickMarkValueAtIndex_1;
    public static /*const*/ String sel_addColumnWithCells_1;
    public static /*const*/ String sel_exposeBinding_1;
    public static /*const*/ String sel_weekdayOrdinal;
    public static /*const*/ String sel_canAddChild;
    public static /*const*/ String sel_hitTest_1;
    public static /*const*/ String sel_nibBundle;
    public static /*const*/ String sel_resumeExecutionWithResult_1;
    public static /*const*/ String sel_setMonthSymbols_1;
    public static /*const*/ String sel_hitPart;
    public static /*const*/ String sel_download_1didCancelAuthenticationChallenge_1;
    public static /*const*/ String sel_descriptionWithCalendarFormat_1;
    public static /*const*/ String sel_setProtocolSpecificInformation_1;
    public static /*const*/ String sel_tokenField_1shouldAddObjects_1atIndex_1;
    public static /*const*/ String sel_popUpContextMenu_1withEvent_1forView_1;
    public static /*const*/ String sel_stopPeriodicEvents;
    public static /*const*/ String sel_setDTD_1;
    public static /*const*/ String sel_glyphAtIndex_1isValidIndex_1;
    public static /*const*/ String sel_encodeSize_1;
    public static /*const*/ String sel_windowForSheet;
    public static /*const*/ String sel_displayMode;
    public static /*const*/ String sel_revertDocumentToSaved_1;
    public static /*const*/ String sel_tableView_1objectValueForTableColumn_1row_1;
    public static /*const*/ String sel_setBackingType_1;
    public static /*const*/ String sel_scanUpToCharactersFromSet_1intoString_1;
    public static /*const*/ String sel_nextValidKeyView;
    public static /*const*/ String sel_arrayWithObject_1;
    public static /*const*/ String sel_flushBuffer;
    public static /*const*/ String sel_hasValidObjectValue;
    public static /*const*/ String sel_numberWithUnsignedLong_1;
    public static /*const*/ String sel_collectExhaustively;
    public static /*const*/ String sel_setImageInterpolation_1;
    public static /*const*/ String sel_setSystemID_1;
    public static /*const*/ String sel_setCornerView_1;
    public static /*const*/ String sel_initWithDouble_1;
    public static /*const*/ String sel_sortedArrayUsingDescriptors_1;
    public static /*const*/ String sel_removeTextContainerAtIndex_1;
    public static /*const*/ String sel_whitespaceCharacterSet;
    public static /*const*/ String sel_classDescriptionForClass_1;
    public static /*const*/ String sel_setAttributedString_1;
    public static /*const*/ String sel_setPixelsHigh_1;
    public static /*const*/ String sel_setDynamicDepthLimit_1;
    public static /*const*/ String sel_sharedApplication;
    public static /*const*/ String sel_sound_1didFinishPlaying_1;
    public static /*const*/ String sel_defaultBehavior;
    public static /*const*/ String sel_beginSheetForDirectory_1file_1types_1modalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1;
    public static /*const*/ String sel_orderFrontFontPanel_1;
    public static /*const*/ String sel_searchForBrowsableDomains;
    public static /*const*/ String sel_toggleAutomaticQuoteSubstitution_1;
    public static /*const*/ String sel_textView_1willChangeSelectionFromCharacterRanges_1toCharacterRanges_1;
    public static /*const*/ String sel_alignRight_1;
    public static /*const*/ String sel_getBytes_1maxLength_1usedLength_1encoding_1options_1range_1remainingRange_1;
    public static /*const*/ String sel_keyPointerFunctions;
    public static /*const*/ String sel_mouseDownFlags;
    public static /*const*/ String sel_expandItem_1;
    public static /*const*/ String sel_bezierPathWithRect_1;
    public static /*const*/ String sel_setGradientType_1;
    public static /*const*/ String sel_alphanumericCharacterSet;
    public static /*const*/ String sel_deleteWordForward_1;
    public static /*const*/ String sel_cStringUsingEncoding_1;
    public static /*const*/ String sel_storedValueForKey_1;
    public static /*const*/ String sel_fileSize;
    public static /*const*/ String sel_elementWithName_1URI_1;
    public static /*const*/ String sel_pointSize;
    public static /*const*/ String sel_veryShortMonthSymbols;
    public static /*const*/ String sel_transformSize_1;
    public static /*const*/ String sel_titleWidth;
    public static /*const*/ String sel_setTextContainerInset_1;
    public static /*const*/ String sel_supportedWindowDepths;
    public static /*const*/ String sel_appleEvent;
    public static /*const*/ String sel_valueClassForBinding_1;
    public static /*const*/ String sel_setFullScreen;
    public static /*const*/ String sel_encodeObject_1forKey_1;
    public static /*const*/ String sel_setSpellingState_1range_1;
    public static /*const*/ String sel_greenComponent;
    public static /*const*/ String sel_textBackgroundColor;
    public static /*const*/ String sel_currentEditor;
    public static /*const*/ String sel_attachedSheet;
    public static /*const*/ String sel_new;
    public static /*const*/ String sel_setChildren_1;
    public static /*const*/ String sel_options;
    public static /*const*/ String sel_setObjectClass_1;
    public static /*const*/ String sel_borderWidth;
    public static /*const*/ String sel_secondarySelectedControlColor;
    public static /*const*/ String sel_scrollItemAtIndexToVisible_1;
    public static /*const*/ String sel_wantsLayer;
    public static /*const*/ String sel_setPath_1;
    public static /*const*/ String sel_setKeys_1triggerChangeNotificationsForDependentKey_1;
    public static /*const*/ String sel_verticalAlignment;
    public static /*const*/ String sel_selectionGranularity;
    public static /*const*/ String sel_minimumIntegerDigits;
    public static /*const*/ String sel_canCreateDirectories;
    public static /*const*/ String sel_fixAttributesInRange_1;
    public static /*const*/ String sel_URLWithString_1;
    public static /*const*/ String sel_setFrameFromContentFrame_1;
    public static /*const*/ String sel_setFillColor_1;
    public static /*const*/ String sel_dictionaryWithCapacity_1;
    public static /*const*/ String sel_updateFromPath_1;
    public static /*const*/ String sel_netServiceDidResolveAddress_1;
    public static /*const*/ String sel_usesLazyFetching;
    public static /*const*/ String sel_setMenuBarVisible_1;
    public static /*const*/ String sel_windowDidBecomeKey_1;
    public static /*const*/ String sel_menuChanged_1;
    public static /*const*/ String sel_itemObjectValueAtIndex_1;
    public static /*const*/ String sel_setClassName_1forClass_1;
    public static /*const*/ String sel_setShowsToolbarButton_1;
    public static /*const*/ String sel_plusSign;
    public static /*const*/ String sel_sharedSpellChecker;
    public static /*const*/ String sel_getNumberOfRows_1columns_1;
    public static /*const*/ String sel_valueTransformerNames;
    public static /*const*/ String sel_interpolatedColorAtLocation_1;
    public static /*const*/ String sel_updateSpellingPanelWithMisspelledWord_1;
    public static /*const*/ String sel_yellowComponent;
    public static /*const*/ String sel_acceptsFirstResponder;
    public static /*const*/ String sel_valueWithRect_1;
    public static /*const*/ String sel_frameOfCellAtColumn_1row_1;
    public static /*const*/ String sel_makeWindowsPerform_1inOrder_1;
    public static /*const*/ String sel_lastIndex;
    public static /*const*/ String sel_initWithCharacters_1length_1;
    public static /*const*/ String sel_initWithIdentifier_1;
    public static /*const*/ String sel_proxyWithLocal_1connection_1;
    public static /*const*/ String sel_scrollColumnToVisible_1;
    public static /*const*/ String sel_descriptor;
    public static /*const*/ String sel_ISOCountryCodes;
    public static /*const*/ String sel_setStandardInput_1;
    public static /*const*/ String sel_getAdvancements_1forGlyphs_1count_1;
    public static /*const*/ String sel_displayColumn_1;
    public static /*const*/ String sel_setAltersStateOfSelectedItem_1;
    public static /*const*/ String sel_setFrameRotation_1;
    public static /*const*/ String sel_clickedOnLink_1atIndex_1;
    public static /*const*/ String sel_addAttribute_1;
    public static /*const*/ String sel_readPrintInfo;
    public static /*const*/ String sel_setCurrentContext_1;
    public static /*const*/ String sel_setVerticalLineScroll_1;
    public static /*const*/ String sel_commands;
    public static /*const*/ String sel_setNamespaces_1;
    public static /*const*/ String sel_removeEntryAtIndex_1;
    public static /*const*/ String sel_setAllowsColumnResizing_1;
    public static /*const*/ String sel_colorWithDeviceCyan_1magenta_1yellow_1black_1alpha_1;
    public static /*const*/ String sel_textView_1shouldChangeTypingAttributes_1toAttributes_1;
    public static /*const*/ String sel_usesFeedbackWindow;
    public static /*const*/ String sel_setCookie_1;
    public static /*const*/ String sel_keyWindow;
    public static /*const*/ String sel_headIndent;
    public static /*const*/ String sel_removeObjectIdenticalTo_1inRange_1;
    public static /*const*/ String sel_applicationWillUnhide_1;
    public static /*const*/ String sel_currentPage;
    public static /*const*/ String sel_setOffStateImage_1;
    public static /*const*/ String sel_addRowWithCells_1;
    public static /*const*/ String sel_setInterlineSpacing_1;
    public static /*const*/ String sel_imageFileTypes;
    public static /*const*/ String sel_setArray_1;
    public static /*const*/ String sel_addLayoutManager_1;
    public static /*const*/ String sel_outputStreamToFileAtPath_1append_1;
    public static /*const*/ String sel_registeredDraggedTypes;
    public static /*const*/ String sel_colorWithCalibratedRed_1green_1blue_1alpha_1;
    public static /*const*/ String sel_invalidateClassDescriptionCache;
    public static /*const*/ String sel_URLProtocolDidFinishLoading_1;
    public static /*const*/ String sel_didChangeArrangementCriteria;
    public static /*const*/ String sel_ICCProfileData;
    public static /*const*/ String sel_availableResourceData;
    public static /*const*/ String sel_glyphIndexForPoint_1inTextContainer_1fractionOfDistanceThroughGlyph_1;
    public static /*const*/ String sel_moveToEndOfParagraph_1;
    public static /*const*/ String sel_enterFullScreenMode_1withOptions_1;
    public static /*const*/ String sel_fieldEditor_1forObject_1;
    public static /*const*/ String sel_setTreatsFilePackagesAsDirectories_1;
    public static /*const*/ String sel_setLevelIndicatorStyle_1;
    public static /*const*/ String sel_minimumDecimalNumber;
    public static /*const*/ String sel_hasSpaceAvailable;
    public static /*const*/ String sel_widthOfString_1;
    public static /*const*/ String sel_setLocale_1;
    public static /*const*/ String sel_setPreferredEdge_1;
    public static /*const*/ String sel_setRichText_1;
    public static /*const*/ String sel_rangesForUserCharacterAttributeChange;
    public static /*const*/ String sel_rectForPage_1;
    public static /*const*/ String sel_rowHeight;
    public static /*const*/ String sel_windowDidChangeScreenProfile_1;
    public static /*const*/ String sel_setCachePolicy_1;
    public static /*const*/ String sel_parser_1didEndMappingPrefix_1;
    public static /*const*/ String sel_cleanUpAfterDragOperation;
    public static /*const*/ String sel_browser_1typeSelectStringForRow_1inColumn_1;
    public static /*const*/ String sel_canInitWithPasteboard_1;
    public static /*const*/ String sel_startListening;
    public static /*const*/ String sel_setExcludedKeys_1;
    public static /*const*/ String sel_readFromFile_1ofType_1;
    public static /*const*/ String sel_setReservedThicknessForMarkers_1;
    public static /*const*/ String sel_windowRef;
    public static /*const*/ String sel_browser_1selectRow_1inColumn_1;
    public static /*const*/ String sel_isOpaque;
    public static /*const*/ String sel_fontDescriptorWithFamily_1;
    public static /*const*/ String sel_itemTitleAtIndex_1;
    public static /*const*/ String sel_boundingBox;
    public static /*const*/ String sel_moveColumn_1toColumn_1;
    public static /*const*/ String sel_badgeLabel;
    public static /*const*/ String sel_outline_1;
    public static /*const*/ String sel_characterIndexForInsertionAtPoint_1;
    public static /*const*/ String sel_URLHandleClassForURL_1;
    public static /*const*/ String sel_selectKeyViewFollowingView_1;
    public static /*const*/ String sel_fullPathForApplication_1;
    public static /*const*/ String sel_outlineView_1willDisplayOutlineCell_1forTableColumn_1item_1;
    public static /*const*/ String sel_encodePropertyList_1;
    public static /*const*/ String sel_generatesDecimalNumbers;
    public static /*const*/ String sel_appendAttributedString_1;
    public static /*const*/ String sel_persistentDomainNames;
    public static /*const*/ String sel_setUserFont_1;
    public static /*const*/ String sel_initWithProperties_1;
    public static /*const*/ String sel_loadResourceDataNotifyingClient_1usingCache_1;
    public static /*const*/ String sel_closeFile;
    public static /*const*/ String sel_allHeaderFields;
    public static /*const*/ String sel_unlearnWord_1;
    public static /*const*/ String sel_drawsCellBackground;
    public static /*const*/ String sel_PICTRepresentation;
    public static /*const*/ String sel_imageScaling;
    public static /*const*/ String sel_scanUpToString_1intoString_1;
    public static /*const*/ String sel_scrollBarColor;
    public static /*const*/ String sel_initWithDelegate_1name_1;
    public static /*const*/ String sel_setDateValue_1;
    public static /*const*/ String sel_dividerStyle;
    public static /*const*/ String sel_scrollPageDown_1;
    public static /*const*/ String sel_removeLayoutManager_1;
    public static /*const*/ String sel_textAttributesForNegativeValues;
    public static /*const*/ String sel_attachment;
    public static /*const*/ String sel_reset;
    public static /*const*/ String sel_initWithAttributes_1;
    public static /*const*/ String sel_allowsMixedState;
    public static /*const*/ String sel_addPort_1forMode_1;
    public static /*const*/ String sel_windowDidDeminiaturize_1;
    public static /*const*/ String sel_setRowHeight_1;
    public static /*const*/ String sel_setGraphicsState_1;
    public static /*const*/ String sel_replaceCharactersInRange_1withAttributedString_1;
    public static /*const*/ String sel_setAttributedStringValue_1;
    public static /*const*/ String sel_criteriaKeyPath;
    public static /*const*/ String sel_standardInput;
    public static /*const*/ String sel_isFontAvailable_1;
    public static /*const*/ String sel_setAllowsTypeSelect_1;
    public static /*const*/ String sel_portWithMachPort_1;
    public static /*const*/ String sel_panel_1isValidFilename_1;
    public static /*const*/ String sel_imageablePageBounds;
    public static /*const*/ String sel_notificationWithName_1object_1;
    public static /*const*/ String sel_sharedFontPanelExists;
    public static /*const*/ String sel_blackColor;
    public static /*const*/ String sel_removeDescriptorAtIndex_1;
    public static /*const*/ String sel_dataUsingEncoding_1allowLossyConversion_1;
    public static /*const*/ String sel_propertyForKey_1inRequest_1;
    public static /*const*/ String sel_setHeaderLevel_1;
    public static /*const*/ String sel_jobTitle;
    public static /*const*/ String sel_removePersistentDomainForName_1;
    public static /*const*/ String sel_contentResizeIncrements;
    public static /*const*/ String sel_textFileTypes;
    public static /*const*/ String sel_setAction_1;
    public static /*const*/ String sel_knobProportion;
    public static /*const*/ String sel_numberOfArguments;
    public static /*const*/ String sel_setScrollsDynamically_1;
    public static /*const*/ String sel_setTextColor_1range_1;
    public static /*const*/ String sel_setBoundsSize_1;
    public static /*const*/ String sel_setVolume_1;
    public static /*const*/ String sel_windowControllers;
    public static /*const*/ String sel_insertAttributedString_1atIndex_1;
    public static /*const*/ String sel_eventWithEventRef_1;
    public static /*const*/ String sel_initByReferencingFile_1;
    public static /*const*/ String sel_fire;
    public static /*const*/ String sel_writeToPasteboard_1;
    public static /*const*/ String sel_connectionForProxy;
    public static /*const*/ String sel_outlineView_1mouseDownInHeaderOfTableColumn_1;
    public static /*const*/ String sel_mutableArrayValueForKeyPath_1;
    public static /*const*/ String sel_validRequestorForSendType_1returnType_1;
    public static /*const*/ String sel_isRichText;
    public static /*const*/ String sel_moveWordLeft_1;
    public static /*const*/ String sel_indexSetWithIndex_1;
    public static /*const*/ String sel_setContextMenuRepresentation_1;
    public static /*const*/ String sel_updateTrackingAreas;
    public static /*const*/ String sel_defaultCollector;
    public static /*const*/ String sel_orderedIndex;
    public static /*const*/ String sel_relativeCurveToPoint_1controlPoint1_1controlPoint2_1;
    public static /*const*/ String sel_setShowsApplicationBadge_1;
    public static /*const*/ String sel_setValue_1;
    public static /*const*/ String sel_attributeDeclarationForName_1elementName_1;
    public static /*const*/ String sel_setWidth_1type_1forLayer_1;
    public static /*const*/ String sel_decodePoint;
    public static /*const*/ String sel_makeWindowControllers;
    public static /*const*/ String sel_userFontOfSize_1;
    public static /*const*/ String sel_dependencies;
    public static /*const*/ String sel_setAttributes_1;
    public static /*const*/ String sel_setFrameCenterRotation_1;
    public static /*const*/ String sel_nilSymbol;
    public static /*const*/ String sel_scalesWhenResized;
    public static /*const*/ String sel_setMinusSign_1;
    public static /*const*/ String sel_predicateOperatorType;
    public static /*const*/ String sel_replyWithException_1;
    public static /*const*/ String sel_fileName;
    public static /*const*/ String sel_indexPathByRemovingLastIndex;
    public static /*const*/ String sel_openHelpAnchor_1inBook_1;
    public static /*const*/ String sel_initWithBytes_1objCType_1;
    public static /*const*/ String sel_removeObject_1;
    public static /*const*/ String sel_colorNameComponent;
    public static /*const*/ String sel_setCellBackgroundColor_1;
    public static /*const*/ String sel_getLineDash_1count_1phase_1;
    public static /*const*/ String sel_scriptingContains_1;
    public static /*const*/ String sel_setDefaultWindingRule_1;
    public static /*const*/ String sel_outputStreamToBuffer_1capacity_1;
    public static /*const*/ String sel_defaultButtonTitle;
    public static /*const*/ String sel_draggingSourceOperationMask;
    public static /*const*/ String sel_textDidChange_1;
    public static /*const*/ String sel_drawSheetBorderWithSize_1;
    public static /*const*/ String sel_integerForKey_1;
    public static /*const*/ String sel_setDefaultNameServerPortNumber_1;
    public static /*const*/ String sel_previousNode;
    public static /*const*/ String sel_trackingArea;
    public static /*const*/ String sel_highlightWithLevel_1;
    public static /*const*/ String sel_trackMouse_1inRect_1ofView_1atCharacterIndex_1untilMouseUp_1;
    public static /*const*/ String sel_signatureWithObjCTypes_1;
    public static /*const*/ String sel_saveToURL_1ofType_1forSaveOperation_1error_1;
    public static /*const*/ String sel_dataWithBytesNoCopy_1length_1freeWhenDone_1;
    public static /*const*/ String sel_encodeInteger_1forKey_1;
    public static /*const*/ String sel_removeFromSuperview;
    public static /*const*/ String sel_dataWithBytesNoCopy_1length_1;
    public static /*const*/ String sel_initWithIndexesInRange_1;
    public static /*const*/ String sel_initWithKeyPointerFunctions_1valuePointerFunctions_1capacity_1;
    public static /*const*/ String sel_tilt;
    public static /*const*/ String sel_setHidden_1;
    public static /*const*/ String sel_setMenuFormRepresentation_1;
    public static /*const*/ String sel_setCanChooseDirectories_1;
    public static /*const*/ String sel_usedRectForTextContainer_1;
    public static /*const*/ String sel_allowsColumnSelection;
    public static /*const*/ String sel_orderOut_1;
    public static /*const*/ String sel_filterUsingPredicate_1;
    public static /*const*/ String sel_setTest_1;
    public static /*const*/ String sel_setAllowedTypes_1;
    public static /*const*/ String sel_registerForDraggedTypes_1;
    public static /*const*/ String sel_objectEnumerator;
    public static /*const*/ String sel_setWindowController_1;
    public static /*const*/ String sel_setDestination_1;
    public static /*const*/ String sel_addRepresentation_1;
    public static /*const*/ String sel_isEqual_1;
    public static /*const*/ String sel_glyphRangeForTextContainer_1;
    public static /*const*/ String sel_setStandaloneWeekdaySymbols_1;
    public static /*const*/ String sel_setIgnoresAlpha_1;
    public static /*const*/ String sel_drawBarInside_1flipped_1;
    public static /*const*/ String sel_doesNotRecognizeSelector_1;
    public static /*const*/ String sel_windowDidResignMain_1;
    public static /*const*/ String sel_scrollItemAtIndexToTop_1;
    public static /*const*/ String sel_makePreviousSegmentKey;
    public static /*const*/ String sel_download_1shouldDecodeSourceDataOfMIMEType_1;
    public static /*const*/ String sel_compareObject_1toObject_1;
    public static /*const*/ String sel_widthTracksTextView;
    public static /*const*/ String sel_subpredicates;
    public static /*const*/ String sel_relativeLineToPoint_1;
    public static /*const*/ String sel_gridStyleMask;
    public static /*const*/ String sel_initWithCString_1;
    public static /*const*/ String sel_imageScalingForSegment_1;
    public static /*const*/ String sel_editWithFrame_1inView_1editor_1delegate_1event_1;
    public static /*const*/ String sel_glyphPacking;
    public static /*const*/ String sel_resolveWithTimeout_1;
    public static /*const*/ String sel_hasEditedDocuments;
    public static /*const*/ String sel_getLineFragmentRect_1usedRect_1forParagraphSeparatorGlyphRange_1atProposedOrigin_1;
    public static /*const*/ String sel_autosaveDocumentWithDelegate_1didAutosaveSelector_1contextInfo_1;
    public static /*const*/ String sel_readSelectionFromPasteboard_1type_1;
    public static /*const*/ String sel_spellServer_1suggestGuessesForWord_1inLanguage_1;
    public static /*const*/ String sel_initWithTimeIntervalSinceNow_1;
    public static /*const*/ String sel_setMaxWidth_1;
    public static /*const*/ String sel_userDefaultsChanged;
    public static /*const*/ String sel_setWidth_1;
    public static /*const*/ String sel_setPrintPanel_1;
    public static /*const*/ String sel_setCurrentPage_1;
    public static /*const*/ String sel_resizeIncrements;
    public static /*const*/ String sel_selectWithFrame_1inView_1editor_1delegate_1start_1length_1;
    public static /*const*/ String sel_sRGBColorSpace;
    public static /*const*/ String sel_scriptErrorExpectedTypeDescriptor;
    public static /*const*/ String sel_setHasHorizontalRuler_1;
    public static /*const*/ String sel_initialFirstResponder;
    public static /*const*/ String sel_StringForObjectValue_1;
    public static /*const*/ String sel_pageRange;
    public static /*const*/ String sel_printOperationWithView_1;
    public static /*const*/ String sel_initWithFrame_1pixelFormat_1;
    public static /*const*/ String sel_fileWrapperOfType_1error_1;
    public static /*const*/ String sel_doesContain_1;
    public static /*const*/ String sel_mutableSetValueForKeyPath_1;
    public static /*const*/ String sel_initWithURL_1cached_1;
    public static /*const*/ String sel_controlAlternatingRowBackgroundColors;
    public static /*const*/ String sel_pathComponentCellClass;
    public static /*const*/ String sel_arrayWithCapacity_1;
    public static /*const*/ String sel_types;
    public static /*const*/ String sel_setPrintInfo_1;
    public static /*const*/ String sel_indexOfTabViewItemWithIdentifier_1;
    public static /*const*/ String sel_isEnabled;
    public static /*const*/ String sel_setHeaderView_1;
    public static /*const*/ String sel_accessibilityHitTest_1;
    public static /*const*/ String sel_removeMarker_1;
    public static /*const*/ String sel_showContextHelp_1;
    public static /*const*/ String sel_selectsInsertedObjects;
    public static /*const*/ String sel_selectedRowInColumn_1;
    public static /*const*/ String sel_noteNewRecentDocument_1;
    public static /*const*/ String sel_setAttachment_1;
    public static /*const*/ String sel_localeIdentifier;
    public static /*const*/ String sel_scrollLineUp_1;
    public static /*const*/ String sel_setCalendarFormat_1;
    public static /*const*/ String sel_setAssociatedPoints_1atIndex_1;
    public static /*const*/ String sel_resourceData;
    public static /*const*/ String sel_setVeryShortStandaloneMonthSymbols_1;
    public static /*const*/ String sel_windowDidUpdate_1;
    public static /*const*/ String sel_moveLeft_1;
    public static /*const*/ String sel_showsBorderOnlyWhileMouseInside;
    public static /*const*/ String sel_valueForKey_1;
    public static /*const*/ String sel_setContentResizeIncrements_1;
    public static /*const*/ String sel_drain;
    public static /*const*/ String sel_concat;
    public static /*const*/ String sel_scrollerWidthForControlSize_1;
    public static /*const*/ String sel_insertItemWithTitle_1action_1keyEquivalent_1atIndex_1;
    public static /*const*/ String sel_doubleValue;
    public static /*const*/ String sel_dividerThickness;
    public static /*const*/ String sel_rowAtPoint_1;
    public static /*const*/ String sel_updateWindowsItem_1;
    public static /*const*/ String sel_calendarDate;
    public static /*const*/ String sel_fixAttachmentAttributeInRange_1;
    public static /*const*/ String sel_mapTableWithWeakToWeakObjects;
    public static /*const*/ String sel_setClip;
    public static /*const*/ String sel_evaluationErrorNumber;
    public static /*const*/ String sel_revertToSavedFromURL_1ofType_1;
    public static /*const*/ String sel_autorecalculatesContentBorderThicknessForEdge_1;
    public static /*const*/ String sel_lineToPoint_1;
    public static /*const*/ String sel_insertionReplaces;
    public static /*const*/ String sel_smallestEncoding;
    public static /*const*/ String sel_elementAtIndex_1;
    public static /*const*/ String sel_getReturnValue_1;
    public static /*const*/ String sel_regularFileContents;
    public static /*const*/ String sel_recache;
    public static /*const*/ String sel_setTextAttributesForNegativeInfinity_1;
    public static /*const*/ String sel_horizontalRulerView;
    public static /*const*/ String sel_initToMemory;
    public static /*const*/ String sel_shouldCreateUI;
    public static /*const*/ String sel_scheme;
    public static /*const*/ String sel_raiseBaseline_1;
    public static /*const*/ String sel_initWithArray_1;
    public static /*const*/ String sel_displayNameForKey_1value_1;
    public static /*const*/ String sel_centerScanRect_1;
    public static /*const*/ String sel_memoryCapacity;
    public static /*const*/ String sel_setBackgroundLayoutEnabled_1;
    public static /*const*/ String sel_machPort;
    public static /*const*/ String sel_selectedFont;
    public static /*const*/ String sel_tableColumns;
    public static /*const*/ String sel_removeObjectAtIndex_1;
    public static /*const*/ String sel_insertNewButtonImage_1in_1;
    public static /*const*/ String sel_StringWithContentsOfURL_1encoding_1error_1;
    public static /*const*/ String sel_menuChangedMessagesEnabled;
    public static /*const*/ String sel_initWithShort_1;
    public static /*const*/ String sel_setColorRenderingIntent_1;
    public static /*const*/ String sel_descriptionWithCalendarFormat_1locale_1;
    public static /*const*/ String sel_resourceSpecifier;
    public static /*const*/ String sel_pasteboardByFilteringFile_1;
    public static /*const*/ String sel_dragColor_1withEvent_1fromView_1;
    public static /*const*/ String sel_setStroke;
    public static /*const*/ String sel_isControllerVisible;
    public static /*const*/ String sel_putCell_1atRow_1column_1;
    public static /*const*/ String sel_firstIndex;
    public static /*const*/ String sel_setFontManagerFactory_1;
    public static /*const*/ String sel_exponentSymbol;
    public static /*const*/ String sel_StringValue;
    public static /*const*/ String sel_getObjects_1range_1;
    public static /*const*/ String sel_scriptingProperties;
    public static /*const*/ String sel_query;
    public static /*const*/ String sel_eventClass;
    public static /*const*/ String sel_dateWithNaturalLanguageString_1;
    public static /*const*/ String sel_datePickerMode;
    public static /*const*/ String sel_setAlternateMnemonicLocation_1;
    public static /*const*/ String sel_StringByDeletingLastPathComponent;
    public static /*const*/ String sel_encodeObject_1;
    public static /*const*/ String sel_unarchiveObjectWithData_1;
    public static /*const*/ String sel_destination;
    public static /*const*/ String sel_ensureLayoutForCharacterRange_1;
    public static /*const*/ String sel_tabView_1didSelectTabViewItem_1;
    public static /*const*/ String sel_removeContextHelpForObject_1;
    public static /*const*/ String sel_ensureGlyphsForCharacterRange_1;
    public static /*const*/ String sel_setMinimumFractionDigits_1;
    public static /*const*/ String sel_boundsRotation;
    public static /*const*/ String sel_invalidateDisplayForGlyphRange_1;
    public static /*const*/ String sel_rectForBlock_1layoutAtPoint_1inRect_1textContainer_1characterRange_1;
    public static /*const*/ String sel_pasteFont_1;
    public static /*const*/ String sel_backgroundColor;
    public static /*const*/ String sel_StringFromNumber_1;
    public static /*const*/ String sel_expiresDate;
    public static /*const*/ String sel_initWithWindowRef_1;
    public static /*const*/ String sel_toggleToolbarShown_1;
    public static /*const*/ String sel_outlineViewItemDidExpand_1;
    public static /*const*/ String sel_TIFFRepresentationOfImageRepsInArray_1usingCompression_1factor_1;
    public static /*const*/ String sel_variable;
    public static /*const*/ String sel_objectsForKeys_1notFoundMarker_1;
    public static /*const*/ String sel_controlColor;
    public static /*const*/ String sel_unarchiverWillFinish_1;
    public static /*const*/ String sel_proposedCredential;
    public static /*const*/ String sel_isPaneSplitter;
    public static /*const*/ String sel_endUndoGrouping;
    public static /*const*/ String sel_setFrameRate_1;
    public static /*const*/ String sel_completionDelay;
    public static /*const*/ String sel_setUserFixedPitchFont_1;
    public static /*const*/ String sel_isIndeterminate;
    public static /*const*/ String sel_menuItem;
    public static /*const*/ String sel_setNumberStyle_1;
    public static /*const*/ String sel_takeIntegerValueFrom_1;
    public static /*const*/ String sel_setIndentationMarkerFollowsCell_1;
    public static /*const*/ String sel_tile;
    public static /*const*/ String sel_cancelButtonRectForBounds_1;
    public static /*const*/ String sel_deselectRow_1;
    public static /*const*/ String sel_setMouseCoalescingEnabled_1;
    public static /*const*/ String sel_removeWindowController_1;
    public static /*const*/ String sel_warningValue;
    public static /*const*/ String sel_isVerticallyResizable;
    public static /*const*/ String sel_defaultFetchRequest;
    public static /*const*/ String sel_netServiceWillResolve_1;
    public static /*const*/ String sel_addProgressMark_1;
    public static /*const*/ String sel_recentsAutosaveName;
    public static /*const*/ String sel_commitEditing;
    public static /*const*/ String sel_attributesOfItemAtPath_1error_1;
    public static /*const*/ String sel_download_1willSendRequest_1redirectResponse_1;
    public static /*const*/ String sel_canBeCompressedUsing_1;
    public static /*const*/ String sel_strokeRect_1;
    public static /*const*/ String sel_descriptionWithLocale_1indent_1;
    public static /*const*/ String sel_applicationDockMenu_1;
    public static /*const*/ String sel_initWithCString_1length_1;
    public static /*const*/ String sel_runPageLayout_1;
    public static /*const*/ String sel_toolbar_1itemForItemIdentifier_1willBeInsertedIntoToolbar_1;
    public static /*const*/ String sel_setSelectsInsertedObjects_1;
    public static /*const*/ String sel_alternateSelectedControlTextColor;
    public static /*const*/ String sel_isValidGlyphIndex_1;
    public static /*const*/ String sel_StringForKey_1inTable_1;
    public static /*const*/ String sel_cellSizeForBounds_1;
    public static /*const*/ String sel_beginSheetForDirectory_1file_1modalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1;
    public static /*const*/ String sel_invalidateLayoutForCharacterRange_1actualCharacterRange_1;
    public static /*const*/ String sel_initAsTearOff;
    public static /*const*/ String sel_allowsOtherFileTypes;
    public static /*const*/ String sel_mouseMoved_1;
    public static /*const*/ String sel_deleteCharactersInRange_1;
    public static /*const*/ String sel_setTitleFont_1;
    public static /*const*/ String sel_showsApplicationBadge;
    public static /*const*/ String sel_initWithLeftExpression_1rightExpression_1modifier_1type_1options_1;
    public static /*const*/ String sel_distantPast;
    public static /*const*/ String sel_isReady;
    public static /*const*/ String sel_draggedImage_1movedTo_1;
    public static /*const*/ String sel_resetTotalAutoreleasedObjects;
    public static /*const*/ String sel_setGlyphGenerator_1;
    public static /*const*/ String sel_groupsByEvent;
    public static /*const*/ String sel_shortMonthSymbols;
    public static /*const*/ String sel_setDescriptor_1forKeyword_1;
    public static /*const*/ String sel_description;
    public static /*const*/ String sel_replaceOccurrencesOfString_1withString_1options_1range_1;
    public static /*const*/ String sel_boundsRectForContentRect_1inRect_1textContainer_1characterRange_1;
    public static /*const*/ String sel_authenticationDataForComponents_1;
    public static /*const*/ String sel_isExecuting;
    public static /*const*/ String sel_branchImage;
    public static /*const*/ String sel_decodeRectForKey_1;
    public static /*const*/ String sel_rectValue;
    public static /*const*/ String sel_setFrameTopLeftPoint_1;
    public static /*const*/ String sel_initWithFileDescriptor_1;
    public static /*const*/ String sel_removePointerAtIndex_1;
    public static /*const*/ String sel_executeAndReturnError_1;
    public static /*const*/ String sel_changeCaseOfLetter_1;
    public static /*const*/ String sel_appendBezierPathWithArcWithCenter_1radius_1startAngle_1endAngle_1clockwise_1;
    public static /*const*/ String sel_insertNewlineIgnoringFieldEditor_1;
    public static /*const*/ String sel_attributeDescriptorForKeyword_1;
    public static /*const*/ String sel_decimalNumberWithMantissa_1exponent_1isNegative_1;
    public static /*const*/ String sel_activeConversationWillChange_1fromOldConversation_1;
    public static /*const*/ String sel_layoutAlgorithm;
    public static /*const*/ String sel_itemNumberInTextList_1atIndex_1;
    public static /*const*/ String sel_initWithImage_1hotSpot_1;
    public static /*const*/ String sel_setStackSize_1;
    public static /*const*/ String sel_matrixInColumn_1;
    public static /*const*/ String sel_performSelector_1withObject_1;
    public static /*const*/ String sel_setSound_1;
    public static /*const*/ String sel_accessibilityPerformAction_1;
    public static /*const*/ String sel_comment;
    public static /*const*/ String sel_rangeOfNominallySpacedGlyphsContainingIndex_1;
    public static /*const*/ String sel_showAttachmentCell_1inRect_1characterIndex_1;
    public static /*const*/ String sel_isDisplayedWhenStopped;
    public static /*const*/ String sel_addCollection_1options_1;
    public static /*const*/ String sel_drawInRect_1angle_1;
    public static /*const*/ String sel_initWithFrame_1mode_1prototype_1numberOfRows_1numberOfColumns_1;
    public static /*const*/ String sel_sharedCredentialStorage;
    public static /*const*/ String sel_colorWithDeviceWhite_1alpha_1;
    public static /*const*/ String sel_setMainDocumentURL_1;
    public static /*const*/ String sel_interpretKeyEvents_1;
    public static /*const*/ String sel_readFromData_1ofType_1error_1;
    public static /*const*/ String sel_tokenFieldCell_1menuForRepresentedObject_1;
    public static /*const*/ String sel_setEventHandler_1andSelector_1forEventClass_1andEventID_1;
    public static /*const*/ String sel_addAttribute_1value_1range_1;
    public static /*const*/ String sel_outlineView_1writeItems_1toPasteboard_1;
    public static /*const*/ String sel_initWithCString_1encoding_1;
    public static /*const*/ String sel_setTypesetterBehavior_1;
    public static /*const*/ String sel_removeObjectAtArrangedObjectIndex_1;
    public static /*const*/ String sel_redo;
    public static /*const*/ String sel_addMarker_1;
    public static /*const*/ String sel_backgroundColors;
    public static /*const*/ String sel_leafKeyPath;
    public static /*const*/ String sel_setMinimumIntegerDigits_1;
    public static /*const*/ String sel_waitForDataInBackgroundAndNotify;
    public static /*const*/ String sel_setPreservesContentDuringLiveResize_1;
    public static /*const*/ String sel_setRootElement_1;
    public static /*const*/ String sel_dataWithEPSInsideRect_1;
    public static /*const*/ String sel_valuesForKeys_1;
    public static /*const*/ String sel_imageOrigin;
    public static /*const*/ String sel_writePDFInsideRect_1toPasteboard_1;
    public static /*const*/ String sel_sortIndicatorRectForBounds_1;
    public static /*const*/ String sel_predefinedNamespaceForPrefix_1;
    public static /*const*/ String sel_viewWillStartLiveResize;
    public static /*const*/ String sel_becomeKeyWindow;
    public static /*const*/ String sel_isHighlighted;
    public static /*const*/ String sel_initWithPickerMask_1colorPanel_1;
    public static /*const*/ String sel_systemFontOfSize_1;
    public static /*const*/ String sel_decimalNumberBySubtracting_1withBehavior_1;
    public static /*const*/ String sel_hide_1;
    public static /*const*/ String sel_resetSearchButtonCell;
    public static /*const*/ String sel_runModalForDirectory_1file_1types_1;
    public static /*const*/ String sel_pathForImageResource_1;
    public static /*const*/ String sel_setFilterPredicate_1;
    public static /*const*/ String sel_validateEditing;
    public static /*const*/ String sel_makeDocumentForURL_1withContentsOfURL_1ofType_1error_1;
    public static /*const*/ String sel_localizedCompare_1;
    public static /*const*/ String sel_sharedWorkspace;
    public static /*const*/ String sel_deliverResult;
    public static /*const*/ String sel_aspectRatio;
    public static /*const*/ String sel_keyEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1characters_1charactersIgnoringModifiers_1isARepeat_1keyCode_1;
    public static /*const*/ String sel_soundUnfilteredPasteboardTypes;
    public static /*const*/ String sel_dateByAddingComponents_1toDate_1options_1;
    public static /*const*/ String sel_indentationMarkerFollowsCell;
    public static /*const*/ String sel_typesetter;
    public static /*const*/ String sel_childCount;
    public static /*const*/ String sel_borderRect;
    public static /*const*/ String sel_setPageOrder_1;
    public static /*const*/ String sel_currentThread;
    public static /*const*/ String sel_textViewDidChangeSelection_1;
    public static /*const*/ String sel_setBaseWritingDirection_1;
    public static /*const*/ String sel_attributedSubStringForProposedRange_1actualRange_1;
    public static /*const*/ String sel_pop;
    public static /*const*/ String sel_animator;
    public static /*const*/ String sel_allowsEmptySelection;
    public static /*const*/ String sel_scriptingIsGreaterThanOrEqualTo_1;
    public static /*const*/ String sel_numberOfSelectedRows;
    public static /*const*/ String sel_imageDidNotDraw_1inRect_1;
    public static /*const*/ String sel_topLevelObject;
    public static /*const*/ String sel_openDocumentWithContentsOfURL_1display_1;
    public static /*const*/ String sel_valueListAttributes;
    public static /*const*/ String sel_enableFreedObjectCheck_1;
    public static /*const*/ String sel_moveForward_1;
    public static /*const*/ String sel_setSendsActionOnArrowKeys_1;
    public static /*const*/ String sel_versionForClassName_1;
    public static /*const*/ String sel_coerceValue_1forKey_1;
    public static /*const*/ String sel_operatingSystem;
    public static /*const*/ String sel_characterEncoding;
    public static /*const*/ String sel_blendedColorWithFraction_1ofColor_1;
    public static /*const*/ String sel_panel_1userEnteredFilename_1confirmed_1;
    public static /*const*/ String sel_addSelectedObjects_1;
    public static /*const*/ String sel_pointingDeviceID;
    public static /*const*/ String sel_children;
    public static /*const*/ String sel_takeObjectValueFrom_1;
    public static /*const*/ String sel_indexSet;
    public static /*const*/ String sel_setMovie_1;
    public static /*const*/ String sel_setKeyEquivalentModifierMask_1;
    public static /*const*/ String sel_allowsKeyedCoding;
    public static /*const*/ String sel_rotateByDegrees_1;
    public static /*const*/ String sel_compoundTypes;
    public static /*const*/ String sel_setShortStandaloneWeekdaySymbols_1;
    public static /*const*/ String sel_removeWindowsItem_1;
    public static /*const*/ String sel_StringArrayForKey_1;
    public static /*const*/ String sel_outlineView_1typeSelectStringForTableColumn_1item_1;
    public static /*const*/ String sel_initWithWindow_1;
    public static /*const*/ String sel_accessibilityIsAttributeSettable_1;
    public static /*const*/ String sel_rangeForUserCharacterAttributeChange;
    public static /*const*/ String sel_setCalendar_1;
    public static /*const*/ String sel_beginEditing;
    public static /*const*/ String sel_enableUpdates;
    public static /*const*/ String sel_setPrefersAllColumnUserResizing_1;
    public static /*const*/ String sel_isTornOff;
    public static /*const*/ String sel_checkSpellingOfString_1startingAt_1;
    public static /*const*/ String sel_drawPackedGlyphs_1atPoint_1;
    public static /*const*/ String sel_graphicsContextWithAttributes_1;
    public static /*const*/ String sel_textView_1completions_1forPartialWordRange_1indexOfSelectedItem_1;
    public static /*const*/ String sel_outlineView_1shouldExpandItem_1;
    public static /*const*/ String sel_isInFullScreenMode;
    public static /*const*/ String sel_userKeyEquivalent;
    public static /*const*/ String sel_menuBarHeight;
    public static /*const*/ String sel_initWithSize_1depth_1separate_1alpha_1;
    public static /*const*/ String sel_criticalValue;
    public static /*const*/ String sel_tableView_1didClickTableColumn_1;
    public static /*const*/ String sel_addChildWindow_1ordered_1;
    public static /*const*/ String sel_autoscroll_1;
    public static /*const*/ String sel_infoDictionary;
    public static /*const*/ String sel_printOperationWithSettings_1error_1;
    public static /*const*/ String sel_translateOriginToPoint_1;
    public static /*const*/ String sel_takeStoredValue_1forKey_1;
    public static /*const*/ String sel_mouseUp_1;
    public static /*const*/ String sel_setNotationName_1;
    public static /*const*/ String sel_setArgument_1atIndex_1;
    public static /*const*/ String sel_setSelectedAttributes_1isMultiple_1;
    public static /*const*/ String sel_dayOfCommonEra;
    public static /*const*/ String sel_greenColor;
    public static /*const*/ String sel_initWithProtocolFamily_1socketType_1protocol_1address_1;
    public static /*const*/ String sel_setAttachmentCell_1;
    public static /*const*/ String sel_previousFailureCount;
    public static /*const*/ String sel_currentOperation;
    public static /*const*/ String sel_tokenField_1completionsForSubString_1indexOfToken_1indexOfSelectedItem_1;
    public static /*const*/ String sel_positionOfGlyph_1struckOverGlyph_1metricsExist_1;
    public static /*const*/ String sel_setMarkedTextAttributes_1;
    public static /*const*/ String sel_validateToolbarItem_1;
    public static /*const*/ String sel_startingColumn;
    public static /*const*/ String sel_setSelectedRanges_1;
    public static /*const*/ String sel_addItemWithTitle_1action_1keyEquivalent_1;
    public static /*const*/ String sel_postNotificationName_1object_1;
    public static /*const*/ String sel_replacementObjectForKeyedArchiver_1;
    public static /*const*/ String sel_deletesFileUponFailure;
    public static /*const*/ String sel_speechRecognizer_1didRecognizeCommand_1;
    public static /*const*/ String sel_columnSpan;
    public static /*const*/ String sel_animationBlockingMode;
    public static /*const*/ String sel_drawParts;
    public static /*const*/ String sel_style;
    public static /*const*/ String sel_makeUntitledDocumentOfType_1error_1;
    public static /*const*/ String sel_filteredArrayUsingPredicate_1;
    public static /*const*/ String sel_wantsDefaultClipping;
    public static /*const*/ String sel_one;
    public static /*const*/ String sel_persistentStoreTypeForFileType_1;
    public static /*const*/ String sel_pixelsHigh;
    public static /*const*/ String sel_rulerView_1shouldMoveMarker_1;
    public static /*const*/ String sel_sizeWithAttributes_1;
    public static /*const*/ String sel_drawTitleOfColumn_1inRect_1;
    public static /*const*/ String sel_setLevelsOfUndo_1;
    public static /*const*/ String sel_invoke;
    public static /*const*/ String sel_keyEnumerator;
    public static /*const*/ String sel_convertFont_1toSize_1;
    public static /*const*/ String sel_mouseExited_1withFrame_1inView_1;
    public static /*const*/ String sel_widthAdjustLimit;
    public static /*const*/ String sel_animationResizeTime_1;
    public static /*const*/ String sel_ensureLayoutForBoundingRect_1inTextContainer_1;
    public static /*const*/ String sel_initWithExpressionType_1;
    public static /*const*/ String sel_numberWithUnsignedChar_1;
    public static /*const*/ String sel_directory;
    public static /*const*/ String sel_address;
    public static /*const*/ String sel_defaultPixelFormat;
    public static /*const*/ String sel_deleteBackwardByDecomposingPreviousCharacter_1;
    public static /*const*/ String sel_clickCount;
    public static /*const*/ String sel_trackMarker_1withMouseEvent_1;
    public static /*const*/ String sel_URL_1resourceDataDidBecomeAvailable_1;
    public static /*const*/ String sel_outlineView_1setObjectValue_1forTableColumn_1byItem_1;
    public static /*const*/ String sel_insert_1;
    public static /*const*/ String sel_methodForSelector_1;
    public static /*const*/ String sel_insertGlyph_1atGlyphIndex_1characterIndex_1;
    public static /*const*/ String sel_readFromFileWrapper_1ofType_1error_1;
    public static /*const*/ String sel_selectedControlColor;
    public static /*const*/ String sel_selectedRow;
    public static /*const*/ String sel_control_1isValidObject_1;
    public static /*const*/ String sel_setUniqueID_1;
    public static /*const*/ String sel_initWithName_1fromFile_1;
    public static /*const*/ String sel_sizeOfLabel_1;
    public static /*const*/ String sel_credentialsForProtectionSpace_1;
    public static /*const*/ String sel_anyObject;
    public static /*const*/ String sel_runLoopModesForAnimating;
    public static /*const*/ String sel_setSortDescriptors_1;
    public static /*const*/ String sel_convertSize_1toView_1;
    public static /*const*/ String sel_setLineFragmentRect_1forGlyphRange_1usedRect_1;
    public static /*const*/ String sel_discardEditing;
    public static /*const*/ String sel_isAutodisplay;
    public static /*const*/ String sel_matchesOnMultipleResolution;
    public static /*const*/ String sel_multipleThreadsEnabled;
    public static /*const*/ String sel_positionOfGlyph_1forCharacter_1struckOverRect_1;
    public static /*const*/ String sel_boundsRectForBlock_1contentRect_1inRect_1textContainer_1characterRange_1;
    public static /*const*/ String sel_outlineView_1objectValueForTableColumn_1byItem_1;
    public static /*const*/ String sel_transformPoint_1;
    public static /*const*/ String sel_createClassDescription;
    public static /*const*/ String sel_inputStreamWithFileAtPath_1;
    public static /*const*/ String sel_menuForEvent_1inRect_1ofView_1;
    public static /*const*/ String sel_setRowTypeKeyPath_1;
    public static /*const*/ String sel_infoForBinding_1;
    public static /*const*/ String sel_setDataRetained_1;
    public static /*const*/ String sel_revertToContentsOfURL_1ofType_1error_1;
    public static /*const*/ String sel_currentControlTint;
    public static /*const*/ String sel_selection;
    public static /*const*/ String sel_array;
    public static /*const*/ String sel_setStyle_1;
    public static /*const*/ String sel_setPredicate_1;
    public static /*const*/ String sel_endEditing;
    public static /*const*/ String sel_doClick_1;
    public static /*const*/ String sel_toManyRelationshipKeys;
    public static /*const*/ String sel_selectedKnobColor;
    public static /*const*/ String sel_setOrderedIndex_1;
    public static /*const*/ String sel_initWithSet_1;
    public static /*const*/ String sel_drawSelector;
    public static /*const*/ String sel_requestWithURL_1;
    public static /*const*/ String sel_imageNamed_1;
    public static /*const*/ String sel_hyphenationFactorForGlyphAtIndex_1;
    public static /*const*/ String sel_miniwindowTitle;
    public static /*const*/ String sel_isFileURL;
    public static /*const*/ String sel_selectedSegment;
    public static /*const*/ String sel_applicationDidResignActive_1;
    public static /*const*/ String sel_initWithString_1calendarFormat_1;
    public static /*const*/ String sel_initWithProtectionSpace_1proposedCredential_1previousFailureCount_1failureResponse_1error_1sender_1;
    public static /*const*/ String sel_menuHasKeyEquivalent_1forEvent_1target_1action_1;
    public static /*const*/ String sel_minPossiblePositionOfDividerAtIndex_1;
    public static /*const*/ String sel_abbreviationForDate_1;
    public static /*const*/ String sel_absoluteX;
    public static /*const*/ String sel_scriptErrorNumber;
    public static /*const*/ String sel_previousValidKeyView;
    public static /*const*/ String sel_valueWithRange_1;
    public static /*const*/ String sel_initWithDefaults_1initialValues_1;
    public static /*const*/ String sel_initNotTestWithTest_1;
    public static /*const*/ String sel_abortModal;
    public static /*const*/ String sel_isSuspended;
    public static /*const*/ String sel_isFilePackageAtPath_1;
    public static /*const*/ String sel_useCredential_1forAuthenticationChallenge_1;
    public static /*const*/ String sel_draggingSequenceNumber;
    public static /*const*/ String sel_lastColumn;
    public static /*const*/ String sel_distantFuture;
    public static /*const*/ String sel_download_1didReceiveResponse_1;
    public static /*const*/ String sel_textTransform;
    public static /*const*/ String sel_hasHorizontalScroller;
    public static /*const*/ String sel_shadowBlurRadius;
    public static /*const*/ String sel_pointingDeviceType;
    public static /*const*/ String sel_setMenuView_1;
    public static /*const*/ String sel_setWindingRule_1;
    public static /*const*/ String sel_imageForSegment_1;
    public static /*const*/ String sel_bytes;
    public static /*const*/ String sel_propertyListFromStringsFileFormat;
    public static /*const*/ String sel_setParagraphStyle_1;
    public static /*const*/ String sel_highlightMode;
    public static /*const*/ String sel_voice;
    public static /*const*/ String sel_hostName;
    public static /*const*/ String sel_removeAccessoryController_1;
    public static /*const*/ String sel_rowsInRect_1;
    public static /*const*/ String sel_registerImageRepClass_1;
    public static /*const*/ String sel_value_1withObjCType_1;
    public static /*const*/ String sel_enclosingMenuItem;
    public static /*const*/ String sel_exposedBindings;
    public static /*const*/ String sel_setSharedScriptSuiteRegistry_1;
    public static /*const*/ String sel_readablePasteboardTypes;
    public static /*const*/ String sel_drawViewBackgroundInRect_1;
    public static /*const*/ String sel_setDataCell_1;
    public static /*const*/ String sel_dataRepresentationOfType_1;
    public static /*const*/ String sel_setOrientation_1;
    public static /*const*/ String sel_setFileWrapper_1;
    public static /*const*/ String sel_runModalOpenPanel_1forTypes_1;
    public static /*const*/ String sel_adjustSubviews;
    public static /*const*/ String sel_setCurrencyDecimalSeparator_1;
    public static /*const*/ String sel_needsDisplay;
    public static /*const*/ String sel_insertValue_1atIndex_1inPropertyWithKey_1;
    public static /*const*/ String sel_setTextStorage_1;
    public static /*const*/ String sel_isAlternate;
    public static /*const*/ String sel_setOutputFormat_1;
    public static /*const*/ String sel_comboBoxWillPopUp_1;
    public static /*const*/ String sel_insertChild_1;
    public static /*const*/ String sel_initWithCommandDescription_1;
    public static /*const*/ String sel_setLineDash_1count_1phase_1;
    public static /*const*/ String sel_setHardInvalidation_1forGlyphRange_1;
    public static /*const*/ String sel_setAllowsToolTipsWhenApplicationIsInactive_1;
    public static /*const*/ String sel_tableView_1namesOfPromisedFilesDroppedAtDestination_1forDraggedRowsWithIndexes_1;
    public static /*const*/ String sel_highlightedItemIndex;
    public static /*const*/ String sel_trailingOffset;
    public static /*const*/ String sel_layer;
    public static /*const*/ String sel_isDeletableFileAtPath_1;
    public static /*const*/ String sel_textUnfilteredTypes;
    public static /*const*/ String sel_gregorianStartDate;
    public static /*const*/ String sel_isDocumentEdited;
    public static /*const*/ String sel_colorWithCalibratedWhite_1alpha_1;
    public static /*const*/ String sel_shouldRunSavePanelWithAccessoryView;
    public static /*const*/ String sel_finishEncoding;
    public static /*const*/ String sel_setKeyCell_1;
    public static /*const*/ String sel_isPartialStringValid_1newEditingString_1errorDescription_1;
    public static /*const*/ String sel_setRangeContainerObject_1;
    public static /*const*/ String sel_typeOfFile_1error_1;
    public static /*const*/ String sel_disappearingItemCursor;
    public static /*const*/ String sel_textureMaxMipMapLevel;
    public static /*const*/ String sel_setEraSymbols_1;
    public static /*const*/ String sel_setBordered_1;
    public static /*const*/ String sel_precomposedStringWithCanonicalMapping;
    public static /*const*/ String sel_setEnabled_1;
    public static /*const*/ String sel_setChildrenKeyPath_1;
    public static /*const*/ String sel_applicationDidBecomeActive_1;
    public static /*const*/ String sel_setCancelButtonCell_1;
    public static /*const*/ String sel_backgroundFilters;
    public static /*const*/ String sel_indexOfCellWithTag_1;
    public static /*const*/ String sel_UTF8String;
    public static /*const*/ String sel_horizontalPagination;
    public static /*const*/ String sel_allowedInputSourceLocales;
    public static /*const*/ String sel_toolbar;
    public static /*const*/ String sel_setGeneratesDecimalNumbers_1;
    public static /*const*/ String sel_highlight_1withFrame_1inView_1;
    public static /*const*/ String sel_rotation;
    public static /*const*/ String sel_colorForControlTint_1;
    public static /*const*/ String sel_mutableString;
    public static /*const*/ String sel_shadowWithLevel_1;
    public static /*const*/ String sel_frameRectForContentRect_1styleMask_1;
    public static /*const*/ String sel_numberOfColorComponents;
    public static /*const*/ String sel_alternateImage;
    public static /*const*/ String sel_initWithString_1relativeToURL_1;
    public static /*const*/ String sel_pageOrder;
    public static /*const*/ String sel_cancel_1;
    public static /*const*/ String sel_declareTypes_1owner_1;
    public static /*const*/ String sel_lastObject;
    public static /*const*/ String sel_type_1conformsToType_1;
    public static /*const*/ String sel_mutableArrayValueForKey_1;
    public static /*const*/ String sel_initWithName_1host_1;
    public static /*const*/ String sel_keyEquivalentWidth;
    public static /*const*/ String sel_modifier;
    public static /*const*/ String sel_setPerMillSymbol_1;
    public static /*const*/ String sel_setToolbar_1;
    public static /*const*/ String sel_changeAttributes_1;
    public static /*const*/ String sel_removeItemWithTitle_1;
    public static /*const*/ String sel_setAspectRatio_1;
    public static /*const*/ String sel_undoManagerForTextView_1;
    public static /*const*/ String sel_clickedPathComponentCell;
    public static /*const*/ String sel_commentWithStringValue_1;
    public static /*const*/ String sel_initWithContainerSpecifier_1key_1;
    public static /*const*/ String sel_windowWillReturnUndoManager_1;
    public static /*const*/ String sel_imageAndTitleOffset;
    public static /*const*/ String sel_initialize;
    public static /*const*/ String sel_truncatesLastVisibleLine;
    public static /*const*/ String sel_setExponentSymbol_1;
    public static /*const*/ String sel_setCurrentProgress_1;
    public static /*const*/ String sel_initWithContentsOfFile_1options_1error_1;
    public static /*const*/ String sel_titleCell;
    public static /*const*/ String sel_setCurrencySymbol_1;
    public static /*const*/ String sel_usesScreenFonts;
    public static /*const*/ String sel_propertyList;
    public static /*const*/ String sel_subgroups;
    public static /*const*/ String sel_setFloatValue_1knobProportion_1;
    public static /*const*/ String sel_componentsJoinedByString_1;
    public static /*const*/ String sel_initWithICCProfileData_1;
    public static /*const*/ String sel_setNextKeyView_1;
    public static /*const*/ String sel_setAnimationCurve_1;
    public static /*const*/ String sel_tokenFieldCell_1completionsForSubString_1indexOfToken_1indexOfSelectedItem_1;
    public static /*const*/ String sel_takeValuesFromDictionary_1;
    public static /*const*/ String sel_imageRepClassForPasteboardType_1;
    public static /*const*/ String sel_setPlaybackDeviceIdentifier_1;
    public static /*const*/ String sel_globallyUniqueString;
    public static /*const*/ String sel_setLineWidth_1;
    public static /*const*/ String sel_selectedColumnIndexes;
    public static /*const*/ String sel_addWindowsItem_1title_1filename_1;
    public static /*const*/ String sel_truncateFileAtOffset_1;
    public static /*const*/ String sel_setStandardOutput_1;
    public static /*const*/ String sel_encodeInt32_1forKey_1;
    public static /*const*/ String sel_baselineDeltaForCharacterAtIndex_1;
    public static /*const*/ String sel_setValueWraps_1;
    public static /*const*/ String sel_addOperation_1;
    public static /*const*/ String sel_resignKeyWindow;
    public static /*const*/ String sel_insertNewline_1;
    public static /*const*/ String sel_saveFrameUsingName_1;
    public static /*const*/ String sel_setWithObjects_1;
    public static /*const*/ String sel_indexOfItemWithTarget_1andAction_1;
    public static /*const*/ String sel_processEditing;
    public static /*const*/ String sel_removeValueAtIndex_1fromPropertyWithKey_1;
    public static /*const*/ String sel_setShouldCascadeWindows_1;
    public static /*const*/ String sel_stepBack_1;
    public static /*const*/ String sel_lockWhenCondition_1beforeDate_1;
    public static /*const*/ String sel_realm;
    public static /*const*/ String sel_appendBezierPathWithPackedGlyphs_1;
    public static /*const*/ String sel_inputStreamWithData_1;
    public static /*const*/ String sel_clickedRow;
    public static /*const*/ String sel_animationShouldStart_1;
    public static /*const*/ String sel_appleEventCodeForKey_1;
    public static /*const*/ String sel_sendAction_1to_1forAllCells_1;
    public static /*const*/ String sel_writableTypesForSaveOperation_1;
    public static /*const*/ String sel_drawWellInside_1;
    public static /*const*/ String sel_intersectsSet_1;
    public static /*const*/ String sel_runOperationModalForWindow_1delegate_1didRunSelector_1contextInfo_1;
    public static /*const*/ String sel_setAllowsEmptySelection_1;
    public static /*const*/ String sel_tighteningFactorForTruncation;
    public static /*const*/ String sel_insertDescriptor_1atIndex_1;
    public static /*const*/ String sel_setDefaultBehavior_1;
    public static /*const*/ String sel_allowsFloats;
    public static /*const*/ String sel_representedObject;
    public static /*const*/ String sel_isFlipped;
    public static /*const*/ String sel_rectOfColumn_1;
    public static /*const*/ String sel_setFrame_1display_1;
    public static /*const*/ String sel_setTextAttributesForPositiveInfinity_1;
    public static /*const*/ String sel_textUnfilteredFileTypes;
    public static /*const*/ String sel_bezierPathByFlatteningPath;
    public static /*const*/ String sel_week;
    public static /*const*/ String sel_takeIntValueFrom_1;
    public static /*const*/ String sel_setWantsNotificationForMarkedText_1;
    public static /*const*/ String sel_StringByPaddingToLength_1withString_1startingAtIndex_1;
    public static /*const*/ String sel_stopModal;
    public static /*const*/ String sel_veryShortWeekdaySymbols;
    public static /*const*/ String sel_user;
    public static /*const*/ String sel_animation_1didReachProgressMark_1;
    public static /*const*/ String sel_fontWithName_1size_1;
    public static /*const*/ String sel_selectWord_1;
    public static /*const*/ String sel_initWithDuration_1animationCurve_1;
    public static /*const*/ String sel_afmDictionary;
    public static /*const*/ String sel_canChooseFiles;
    public static /*const*/ String sel_defaultLineWidth;
    public static /*const*/ String sel_childAtIndex_1;
    public static /*const*/ String sel_pathForResource_1ofType_1inDirectory_1;
    public static /*const*/ String sel_outlineView_1heightOfRowByItem_1;
    public static /*const*/ String sel_PMSymbol;
    public static /*const*/ String sel_setBackgroundStyle_1;
    public static /*const*/ String sel_decimalSeparator;
    public static /*const*/ String sel_knobThickness;
    public static /*const*/ String sel_request;
    public static /*const*/ String sel_indicesOfObjectsByEvaluatingWithContainer_1count_1;
    public static /*const*/ String sel_objectByApplyingXSLTString_1arguments_1error_1;
    public static /*const*/ String sel_colorizeByMappingGray_1toColor_1blackMapping_1whiteMapping_1;
    public static /*const*/ String sel_minusSet_1;
    public static /*const*/ String sel_setAutomaticallyRearrangesObjects_1;
    public static /*const*/ String sel_fixFontAttributeInRange_1;
    public static /*const*/ String sel_frameRotation;
    public static /*const*/ String sel_addObserver_1forKeyPath_1options_1context_1;
    public static /*const*/ String sel_collectionNames;
    public static /*const*/ String sel_titleOfColumn_1;
    public static /*const*/ String sel_characterIdentifier;
    public static /*const*/ String sel_setPanelFont_1isMultiple_1;
    public static /*const*/ String sel_ruleThickness;
    public static /*const*/ String sel_customSelector;
    public static /*const*/ String sel_startSpeakingString_1toURL_1;
    public static /*const*/ String sel_language;
    public static /*const*/ String sel_draggedImage_1endedAt_1operation_1;
    public static /*const*/ String sel_removeSelectionIndexPaths_1;
    public static /*const*/ String sel_TIFFRepresentationOfImageRepsInArray_1;
    public static /*const*/ String sel_setSet_1;
    public static /*const*/ String sel_StringWithCString_1length_1;
    public static /*const*/ String sel_objectsByEvaluatingSpecifier;
    public static /*const*/ String sel_subarrayWithRange_1;
    public static /*const*/ String sel_collectIfNeeded;
    public static /*const*/ String sel_pathWithComponents_1;
    public static /*const*/ String sel_autoreleasedObjectCount;
    public static /*const*/ String sel_addCharactersInString_1;
    public static /*const*/ String sel_setTemplate_1;
    public static /*const*/ String sel_indexOfObjectIdenticalTo_1;
    public static /*const*/ String sel_setRepresentation;
    public static /*const*/ String sel_URLResourceDidFinishLoading_1;
    public static /*const*/ String sel_type;
    public static /*const*/ String sel_setMarkedText_1selectedRange_1;
    public static /*const*/ String sel_dictionaryWithObjects_1forKeys_1;
    public static /*const*/ String sel_wantsToDelayTextChangeNotifications;
    public static /*const*/ String sel_setCompletes_1;
    public static /*const*/ String sel_releaseGState;
    public static /*const*/ String sel_descriptorWithEnumCode_1;
    public static /*const*/ String sel_label;
    public static /*const*/ String sel_run;
    public static /*const*/ String sel_hasHorizontalRuler;
    public static /*const*/ String sel_rowClass;
    public static /*const*/ String sel_automaticRearrangementKeyPaths;
    public static /*const*/ String sel_fileManager_1shouldProceedAfterError_1movingItemAtPath_1toPath_1;
    public static /*const*/ String sel_writeToURL_1atomically_1encoding_1error_1;
    public static /*const*/ String sel_deviceID;
    public static /*const*/ String sel_descriptorWithInt32_1;
    public static /*const*/ String sel_encodeInt64_1forKey_1;
    public static /*const*/ String sel_insertEntry_1atIndex_1;
    public static /*const*/ String sel_leftMargin;
    public static /*const*/ String sel_setKeyEquivalentFont_1size_1;
    public static /*const*/ String sel_colorWithDeviceHue_1saturation_1brightness_1alpha_1;
    public static /*const*/ String sel_nextState;
    public static /*const*/ String sel_scanHexInt_1;
    public static /*const*/ String sel_lineSpacing;
    public static /*const*/ String sel_textureTarget;
    public static /*const*/ String sel_miniaturize_1;
    public static /*const*/ String sel_browser_1namesOfPromisedFilesDroppedAtDestination_1forDraggedRowsWithIndexes_1inColumn_1;
    public static /*const*/ String sel_localizedNameForTIFFCompressionType_1;
    public static /*const*/ String sel_acceptConnectionInBackgroundAndNotifyForModes_1;
    public static /*const*/ String sel_setCanBecomeVisibleWithoutLogin_1;
    public static /*const*/ String sel_dictionaryWithObjectsAndKeys_1;
    public static /*const*/ String sel_ensureGlyphsForGlyphRange_1;
    public static /*const*/ String sel_indexOfTickMarkAtPoint_1;
    public static /*const*/ String sel_dayOfWeek;
    public static /*const*/ String sel_glyphRangeForCharacterRange_1actualCharacterRange_1;
    public static /*const*/ String sel_enableCollectorForPointer_1;
    public static /*const*/ String sel_rulerView_1willMoveMarker_1toLocation_1;
    public static /*const*/ String sel_comboBoxCell_1objectValueForItemAtIndex_1;
    public static /*const*/ String sel_setValidateSize_1;
    public static /*const*/ String sel_controlTint;
    public static /*const*/ String sel_deselectItemAtIndex_1;
    public static /*const*/ String sel_defaultWindingRule;
    public static /*const*/ String sel_setMaxValue_1;
    public static /*const*/ String sel_longEraSymbols;
    public static /*const*/ String sel_canRedo;
    public static /*const*/ String sel_arguments;
    public static /*const*/ String sel_windows;
    public static /*const*/ String sel_downloadDidBegin_1;
    public static /*const*/ String sel_pasteboard_1provideDataForType_1;
    public static /*const*/ String sel_length;
    public static /*const*/ String sel_imagePosition;
    public static /*const*/ String sel_setAllowedFileTypes_1;
    public static /*const*/ String sel_moveForwardAndModifySelection_1;
    public static /*const*/ String sel_filename;
    public static /*const*/ String sel_mountedLocalVolumePaths;
    public static /*const*/ String sel_sharedFontManager;
    public static /*const*/ String sel_dictionaryWithObjects_1forKeys_1count_1;
    public static /*const*/ String sel_transpose_1;
    public static /*const*/ String sel_drawTitleWithFrame_1inView_1;
    public static /*const*/ String sel_worksWhenModal;
    public static /*const*/ String sel_registerClassDescription_1;
    public static /*const*/ String sel_setAllowsTruncatedLabels_1;
    public static /*const*/ String sel_bezierPathWithRoundedRect_1xRadius_1yRadius_1;
    public static /*const*/ String sel_prefix;
    public static /*const*/ String sel_usesStrongWriteBarrier;
    public static /*const*/ String sel_argumentNames;
    public static /*const*/ String sel_setCaseSensitive_1;
    public static /*const*/ String sel_outlineView_1didClickTableColumn_1;
    public static /*const*/ String sel_textDidBeginEditing_1;
    public static /*const*/ String sel_visibleRect;
    public static /*const*/ String sel_isSubviewCollapsed_1;
    public static /*const*/ String sel_completionsForPartialWordRange_1indexOfSelectedItem_1;
    public static /*const*/ String sel_setMinDate_1;
    public static /*const*/ String sel_colorFromPasteboard_1;
    public static /*const*/ String sel_instanceMethodSignatureForSelector_1;
    public static /*const*/ String sel_makeCellAtRow_1column_1;
    public static /*const*/ String sel_pasteAsPlainText_1;
    public static /*const*/ String sel_willRemoveSubview_1;
    public static /*const*/ String sel_beginSheet_1modalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1;
    public static /*const*/ String sel_notificationCenterForType_1;
    public static /*const*/ String sel_isDaylightSavingTimeForDate_1;
    public static /*const*/ String sel_load;
    public static /*const*/ String sel_menuForSegment_1;
    public static /*const*/ String sel_scheduledTimerWithTimeInterval_1invocation_1repeats_1;
    public static /*const*/ String sel_unregisterClass_1;
    public static /*const*/ String sel_setByAddingObjectsFromSet_1;
    public static /*const*/ String sel_setDepthLimit_1;
    public static /*const*/ String sel_setVeryShortMonthSymbols_1;
    public static /*const*/ String sel_writeToURL_1ofType_1forSaveOperation_1originalContentsURL_1error_1;
    public static /*const*/ String sel_directoryAttributes;
    public static /*const*/ String sel_otherMouseDown_1;
    public static /*const*/ String sel_unhideWithoutActivation;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1startSpecifier_1endSpecifier_1;
    public static /*const*/ String sel_setHasHorizontalScroller_1;
    public static /*const*/ String sel_trackMouse_1adding_1;
    public static /*const*/ String sel_substituteGlyphsInRange_1withGlyphs_1;
    public static /*const*/ String sel_drawCell_1;
    public static /*const*/ String sel_currentCursor;
    public static /*const*/ String sel_maxSize;
    public static /*const*/ String sel_cookiesWithResponseHeaderFields_1forURL_1;
    public static /*const*/ String sel_isBycopy;
    public static /*const*/ String sel_addCursorRect_1cursor_1;
    public static /*const*/ String sel_accessibilityActionNames;
    public static /*const*/ String sel_openDocumentWithContentsOfURL_1display_1error_1;
    public static /*const*/ String sel_templateViews;
    public static /*const*/ String sel_keyPath;
    public static /*const*/ String sel_minValue;
    public static /*const*/ String sel_setImageDimsWhenDisabled_1;
    public static /*const*/ String sel_appendData_1;
    public static /*const*/ String sel_netServiceBrowser_1didFindDomain_1moreComing_1;
    public static /*const*/ String sel_initWithDescriptorType_1bytes_1length_1;
    public static /*const*/ String sel_hasReadablePropertyForKey_1;
    public static /*const*/ String sel_stopWhenAnimation_1reachesProgress_1;
    public static /*const*/ String sel_setWorksWhenModal_1;
    public static /*const*/ String sel_localizedInputManagerName;
    public static /*const*/ String sel_knobColor;
    public static /*const*/ String sel_screens;
    public static /*const*/ String sel_deminiaturize_1;
    public static /*const*/ String sel_bundleIdentifier;
    public static /*const*/ String sel_setLoopMode_1;
    public static /*const*/ String sel_expandItem_1expandChildren_1;
    public static /*const*/ String sel_dataWithContentsOfFile_1options_1error_1;
    public static /*const*/ String sel_lineBreakBeforeIndex_1withinRange_1;
    public static /*const*/ String sel_fileOwnerAccountName;
    public static /*const*/ String sel_insertColumn_1withCells_1;
    public static /*const*/ String sel_windowLevel;
    public static /*const*/ String sel_setGrammarCheckingEnabled_1;
    public static /*const*/ String sel_shortStandaloneWeekdaySymbols;
    public static /*const*/ String sel_push;
    public static /*const*/ String sel_initWithContentsOfFile_1ofType_1;
    public static /*const*/ String sel_removePortForName_1;
    public static /*const*/ String sel_setMaximumRecents_1;
    public static /*const*/ String sel_supermenu;
    public static /*const*/ String sel_setWidth_1type_1forLayer_1edge_1;
    public static /*const*/ String sel_itemRemoved_1;
    public static /*const*/ String sel_initWithBytesNoCopy_1length_1;
    public static /*const*/ String sel_printer;
    public static /*const*/ String sel_compact;
    public static /*const*/ String sel_setDefaultLineWidth_1;
    public static /*const*/ String sel_CGLPixelFormatObj;
    public static /*const*/ String sel_initWithDictionary_1copyItems_1;
    public static /*const*/ String sel_tableView_1didDragTableColumn_1;
    public static /*const*/ String sel_formattingStringsFilename;
    public static /*const*/ String sel_setScrollView_1;
    public static /*const*/ String sel_value;
    public static /*const*/ String sel_editedMask;
    public static /*const*/ String sel_ruleEditor_1displayValueForCriterion_1inRow_1;
    public static /*const*/ String sel_leading;
    public static /*const*/ String sel_titleRect;
    public static /*const*/ String sel_setColumnsAutosaveName_1;
    public static /*const*/ String sel_stop_1;
    public static /*const*/ String sel_titleColor;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1test_1;
    public static /*const*/ String sel_bytesPerPlane;
    public static /*const*/ String sel_pageScroll;
    public static /*const*/ String sel_groupingAttributes;
    public static /*const*/ String sel_setAutomaticLinkDetectionEnabled_1;
    public static /*const*/ String sel_tableView_1mouseDownInHeaderOfTableColumn_1;
    public static /*const*/ String sel_representationOfImageRepsInArray_1usingType_1properties_1;
    public static /*const*/ String sel_attributeRuns;
    public static /*const*/ String sel_decodeRect;
    public static /*const*/ String sel_drawerDidOpen_1;
    public static /*const*/ String sel_scrollerWidth;
    public static /*const*/ String sel_defaultMenu;
    public static /*const*/ String sel_URLProtocol_1didLoadData_1;
    public static /*const*/ String sel_allKeys;
    public static /*const*/ String sel_startPeriodicEventsAfterDelay_1withPeriod_1;
    public static /*const*/ String sel_tableViewSelectionDidChange_1;
    public static /*const*/ String sel_setStandalone_1;
    public static /*const*/ String sel_makeMainWindow;
    public static /*const*/ String sel_moveLeftAndModifySelection_1;
    public static /*const*/ String sel_pasteboardWithUniqueName;
    public static /*const*/ String sel_fileSystemFileNumber;
    public static /*const*/ String sel_jobDisposition;
    public static /*const*/ String sel_setCurrentVirtualScreen_1;
    public static /*const*/ String sel_setHasThousandSeparators_1;
    public static /*const*/ String sel_alternateMnemonicLocation;
    public static /*const*/ String sel_characterSetWithBitmapRepresentation_1;
    public static /*const*/ String sel_startLoading;
    public static /*const*/ String sel_member_1;
    public static /*const*/ String sel_setSelectedFont_1isMultiple_1;
    public static /*const*/ String sel_monthOfYear;
    public static /*const*/ String sel_restoreCachedImage;
    public static /*const*/ String sel_image_1didLoadPartOfRepresentation_1withValidRows_1;
    public static /*const*/ String sel_mouseEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1eventNumber_1clickCount_1pressure_1;
    public static /*const*/ String sel_setInternationalCurrencySymbol_1;
    public static /*const*/ String sel_mainThread;
    public static /*const*/ String sel_lineCapStyle;
    public static /*const*/ String sel_setDefaultParagraphStyle_1;
    public static /*const*/ String sel_cellFrameForTextContainer_1proposedLineFragment_1glyphPosition_1characterIndex_1;
    public static /*const*/ String sel_resolveInstanceMethod_1;
    public static /*const*/ String sel_illegalCharacterSet;
    public static /*const*/ String sel_setKnobThickness_1;
    public static /*const*/ String sel_runModalPageLayoutWithPrintInfo_1;
    public static /*const*/ String sel_popUpContextMenu_1withEvent_1forView_1withFont_1;
    public static /*const*/ String sel_modalWindow;
    public static /*const*/ String sel_autorelease;
    public static /*const*/ String sel_draggingEntered_1;
    public static /*const*/ String sel_allowsTruncatedLabels;
    public static /*const*/ String sel_fileDescriptor;
    public static /*const*/ String sel_ISOLanguageCodes;
    public static /*const*/ String sel_onStateImage;
    public static /*const*/ String sel_imageFrameStyle;
    public static /*const*/ String sel_setFloatValue_1;
    public static /*const*/ String sel_initWithColors_1atLocations_1colorSpace_1;
    public static /*const*/ String sel_descriptorWithString_1;
    public static /*const*/ String sel_setPoolCountHighWaterMark_1;
    public static /*const*/ String sel_veryShortStandaloneWeekdaySymbols;
    public static /*const*/ String sel_addTypes_1owner_1;
    public static /*const*/ String sel_numberWithLongLong_1;
    public static /*const*/ String sel_setDay_1;
    public static /*const*/ String sel_initWithHTML_1documentAttributes_1;
    public static /*const*/ String sel_replaceSubview_1with_1;
    public static /*const*/ String sel_makeObjectsPerformSelector_1;
    public static /*const*/ String sel_setRunLoopModes_1;
    public static /*const*/ String sel_getFileSystemRepresentation_1maxLength_1;
    public static /*const*/ String sel_scale;
    public static /*const*/ String sel_draggedImageLocation;
    public static /*const*/ String sel_setFocusStack_1;
    public static /*const*/ String sel_isReadOnlyKey_1;
    public static /*const*/ String sel_shadowOffset;
    public static /*const*/ String sel_URLHandleUsingCache_1;
    public static /*const*/ String sel_isWellFormed;
    public static /*const*/ String sel_tokenField_1editingStringForRepresentedObject_1;
    public static /*const*/ String sel_setGroupsByEvent_1;
    public static /*const*/ String sel_parser_1foundComment_1;
    public static /*const*/ String sel_initWithHTML_1baseURL_1documentAttributes_1;
    public static /*const*/ String sel_uppercaseWord_1;
    public static /*const*/ String sel_testPart_1;
    public static /*const*/ String sel_dataSource;
    public static /*const*/ String sel_lineRangeForRange_1;
    public static /*const*/ String sel_hostWithAddress_1;
    public static /*const*/ String sel_removeRunLoop_1;
    public static /*const*/ String sel_fileHandleWithStandardInput;
    public static /*const*/ String sel_itemArray;
    public static /*const*/ String sel_rectOfPathComponentCell_1withFrame_1inView_1;
    public static /*const*/ String sel_TIFFRepresentation;
    public static /*const*/ String sel_archiver_1willReplaceObject_1withObject_1;
    public static /*const*/ String sel_currentVirtualScreen;
    public static /*const*/ String sel_gridColor;
    public static /*const*/ String sel_boundingRectForGlyph_1;
    public static /*const*/ String sel_setDataSource_1;
    public static /*const*/ String sel_setDefaultLineJoinStyle_1;
    public static /*const*/ String sel_textBlocks;
    public static /*const*/ String sel_drawerDidClose_1;
    public static /*const*/ String sel_valueWithName_1inPropertyWithKey_1;
    public static /*const*/ String sel_managedObjectModel;
    public static /*const*/ String sel_outlineView_1persistentObjectForItem_1;
    public static /*const*/ String sel_setSelectedRange_1;
    public static /*const*/ String sel_magentaComponent;
    public static /*const*/ String sel_setIncrement_1;
    public static /*const*/ String sel_editingStringForObjectValue_1;
    public static /*const*/ String sel_addClip;
    public static /*const*/ String sel_setSelectionIndex_1;
    public static /*const*/ String sel_replyAppleEventForSuspensionID_1;
    public static /*const*/ String sel_URLProtocol_1didFailWithError_1;
    public static /*const*/ String sel_ignoresMouseEvents;
    public static /*const*/ String sel_dateWithNaturalLanguageString_1locale_1;
    public static /*const*/ String sel_recordDescriptor;
    public static /*const*/ String sel_makeCurrentContext;
    public static /*const*/ String sel_excludedKeys;
    public static /*const*/ String sel_fileManager_1shouldProceedAfterError_1linkingItemAtPath_1toPath_1;
    public static /*const*/ String sel_set;
    public static /*const*/ String sel_mainScreen;
    public static /*const*/ String sel_setVersion_1;
    public static /*const*/ String sel_displayRectIgnoringOpacity_1inContext_1;
    public static /*const*/ String sel_setNumberOfTickMarks_1;
    public static /*const*/ String sel_showsHelp;
    public static /*const*/ String sel_takeColorFrom_1;
    public static /*const*/ String sel_horizontalPageScroll;
    public static /*const*/ String sel_pointingHandCursor;
    public static /*const*/ String sel_vendorID;
    public static /*const*/ String sel_setSelectedRanges_1affinity_1stillSelecting_1;
    public static /*const*/ String sel_setHTTPShouldHandleCookies_1;
    public static /*const*/ String sel_initWithType_1location_1;
    public static /*const*/ String sel_StringByResolvingSymlinksInPath;
    public static /*const*/ String sel_tryLock;
    public static /*const*/ String sel_convertSizeFromBase_1;
    public static /*const*/ String sel_setCacheMode_1;
    public static /*const*/ String sel_entityName;
    public static /*const*/ String sel_takeFloatValueFrom_1;
    public static /*const*/ String sel_showsStateBy;
    public static /*const*/ String sel_highlightedItem;
    public static /*const*/ String sel_superclassDescription;
    public static /*const*/ String sel_flagsChanged_1;
    public static /*const*/ String sel_alloc;
    public static /*const*/ String sel_setDisplaysWhenScreenProfileChanges_1;
    public static /*const*/ String sel_CIImage;
    public static /*const*/ String sel_setSupermenu_1;
    public static /*const*/ String sel_setSharedURLCache_1;
    public static /*const*/ String sel_pathCell_1willPopUpMenu_1;
    public static /*const*/ String sel_setAttributes_1ofItemAtPath_1error_1;
    public static /*const*/ String sel_tableView_1typeSelectStringForTableColumn_1row_1;
    public static /*const*/ String sel_moveWordLeftAndModifySelection_1;
    public static /*const*/ String sel_whitespaceAndNewlineCharacterSet;
    public static /*const*/ String sel_pathControl_1validateDrop_1;
    public static /*const*/ String sel_createCommandInstanceWithZone_1;
    public static /*const*/ String sel_configurationDictionary;
    public static /*const*/ String sel_classFallbacksForKeyedArchiver;
    public static /*const*/ String sel_DTDKind;
    public static /*const*/ String sel_initWithPath_1documentAttributes_1;
    public static /*const*/ String sel_addObjectsFromArray_1;
    public static /*const*/ String sel_tokenField_1displayStringForRepresentedObject_1;
    public static /*const*/ String sel_firstVisibleColumn;
    public static /*const*/ String sel_gradientType;
    public static /*const*/ String sel_familyName;
    public static /*const*/ String sel_uniqueID;
    public static /*const*/ String sel_setFormatterBehavior_1;
    public static /*const*/ String sel_tokenFieldCell_1hasMenuForRepresentedObject_1;
    public static /*const*/ String sel_fileManager_1shouldCopyItemAtPath_1toPath_1;
    public static /*const*/ String sel_keySpecifier;
    public static /*const*/ String sel_copyItemAtPath_1toPath_1error_1;
    public static /*const*/ String sel_setLength_1;
    public static /*const*/ String sel_reloadItem_1;
    public static /*const*/ String sel_removeObjectsAtArrangedObjectIndexes_1;
    public static /*const*/ String sel_setVisibilityPriority_1;
    public static /*const*/ String sel_insertItemWithObjectValue_1atIndex_1;
    public static /*const*/ String sel_searchButtonCell;
    public static /*const*/ String sel_getCString_1maxLength_1range_1remainingRange_1;
    public static /*const*/ String sel_outlineView_1child_1ofItem_1;
    public static /*const*/ String sel_numberOfComponents;
    public static /*const*/ String sel_isKindOfClass_1;
    public static /*const*/ String sel_processorCount;
    public static /*const*/ String sel_lineJoinStyle;
    public static /*const*/ String sel_collectionBehavior;
    public static /*const*/ String sel_setApplicationIconImage_1;
    public static /*const*/ String sel_setLaunchPath_1;
    public static /*const*/ String sel_initFileURLWithPath_1;
    public static /*const*/ String sel_selectItemAtIndex_1;
    public static /*const*/ String sel_IBeamCursor;
    public static /*const*/ String sel_isColor;
    public static /*const*/ String sel_cancelAuthenticationChallenge_1;
    public static /*const*/ String sel_echosBullets;
    public static /*const*/ String sel_setHasUndoManager_1;
    public static /*const*/ String sel_RTFDFileWrapperFromRange_1documentAttributes_1;
    public static /*const*/ String sel_highlightCell_1atRow_1column_1;
    public static /*const*/ String sel_currentHost;
    public static /*const*/ String sel_setURI_1;
    public static /*const*/ String sel_suiteNames;
    public static /*const*/ String sel_genericGrayColorSpace;
    public static /*const*/ String sel_volatileDomainForName_1;
    public static /*const*/ String sel_tokenizingCharacterSet;
    public static /*const*/ String sel_initWithXMLString_1;
    public static /*const*/ String sel_function;
    public static /*const*/ String sel_sizeForMagnification_1;
    public static /*const*/ String sel_commitEditingWithDelegate_1didCommitSelector_1contextInfo_1;
    public static /*const*/ String sel_writeToFile_1;
    public static /*const*/ String sel_displayIfNeededInRect_1;
    public static /*const*/ String sel_optionDescriptionsForBinding_1;
    public static /*const*/ String sel_initWithSize_1;
    public static /*const*/ String sel_cornerView;
    public static /*const*/ String sel_redoActionName;
    public static /*const*/ String sel_setLocation_1forStartOfGlyphRange_1;
    public static /*const*/ String sel_setAllowedInputSourceLocales_1;
    public static /*const*/ String sel_convertRect_1toView_1;
    public static /*const*/ String sel_preferredFilenameExtensionForType_1;
    public static /*const*/ String sel_tableView_1writeRows_1toPasteboard_1;
    public static /*const*/ String sel_rootObject;
    public static /*const*/ String sel_isEqualToHashTable_1;
    public static /*const*/ String sel_indent_1;
    public static /*const*/ String sel_removeIndexesInRange_1;
    public static /*const*/ String sel_numberWithBool_1;
    public static /*const*/ String sel_setPersistentDomain_1forName_1;
    public static /*const*/ String sel_netServiceBrowser_1didRemoveService_1moreComing_1;
    public static /*const*/ String sel_timeZoneWithName_1data_1;
    public static /*const*/ String sel_drawImage_1withFrame_1inView_1;
    public static /*const*/ String sel_buttonToolTip;
    public static /*const*/ String sel_enableCursorRects;
    public static /*const*/ String sel_rulerAttributesInRange_1;
    public static /*const*/ String sel_setMemoryCapacity_1;
    public static /*const*/ String sel_isSeparatorItem;
    public static /*const*/ String sel_save_1;
    public static /*const*/ String sel_documentView;
    public static /*const*/ String sel_setHostCacheEnabled_1;
    public static /*const*/ String sel_setDatePickerElements_1;
    public static /*const*/ String sel_mixedStateImage;
    public static /*const*/ String sel_setAcceptsMouseMovedEvents_1;
    public static /*const*/ String sel_numberOfTabViewItems;
    public static /*const*/ String sel_portForName_1host_1nameServerPortNumber_1;
    public static /*const*/ String sel_printerWithName_1domain_1includeUnavailable_1;
    public static /*const*/ String sel_insertObjects_1atArrangedObjectIndexPaths_1;
    public static /*const*/ String sel_browser_1shouldTypeSelectForEvent_1withCurrentSearchString_1;
    public static /*const*/ String sel_defaultTabInterval;
    public static /*const*/ String sel_initWithTitle_1;
    public static /*const*/ String sel_timeZoneForSecondsFromGMT_1;
    public static /*const*/ String sel_initWithPasteboard_1;
    public static /*const*/ String sel_subscriptRange_1;
    public static /*const*/ String sel_highlightColorWithFrame_1inView_1;
    public static /*const*/ String sel_didChangeText;
    public static /*const*/ String sel_storagePolicy;
    public static /*const*/ String sel_respondsToSelector_1;
    public static /*const*/ String sel_namesOfPromisedFilesDroppedAtDestination_1;
    public static /*const*/ String sel_unsignedShortValue;
    public static /*const*/ String sel_setZeroSymbol_1;
    public static /*const*/ String sel_resourcePath;
    public static /*const*/ String sel_markerFormat;
    public static /*const*/ String sel_hotSpot;
    public static /*const*/ String sel_imageUnfilteredPasteboardTypes;
    public static /*const*/ String sel_editedRange;
    public static /*const*/ String sel_setMenuChangedMessagesEnabled_1;
    public static /*const*/ String sel_tailIndent;
    public static /*const*/ String sel_release;
    public static /*const*/ String sel_readFromURL_1options_1documentAttributes_1;
    public static /*const*/ String sel_underlinePosition;
    public static /*const*/ String sel_setMinItemSize_1;
    public static /*const*/ String sel_initWithImage_1foregroundColorHint_1backgroundColorHint_1hotSpot_1;
    public static /*const*/ String sel_setPlaceholderString_1;
    public static /*const*/ String sel_createDirectoryAtPath_1withIntermediateDirectories_1attributes_1error_1;
    public static /*const*/ String sel_setDefaultTabInterval_1;
    public static /*const*/ String sel_invertedSet;
    public static /*const*/ String sel_iconForFile_1;
    public static /*const*/ String sel_modifyFont_1;
    public static /*const*/ String sel_setProcessName_1;
    public static /*const*/ String sel_addObserver_1toObjectsAtIndexes_1forKeyPath_1options_1context_1;
    public static /*const*/ String sel_resolve;
    public static /*const*/ String sel_namespaces;
    public static /*const*/ String sel_drawInBezierPath_1angle_1;
    public static /*const*/ String sel_setPixelFormat_1;
    public static /*const*/ String sel_resizeUpDownCursor;
    public static /*const*/ String sel_daylightSavingTimeOffsetForDate_1;
    public static /*const*/ String sel_setCanSpawnSeparateThread_1;
    public static /*const*/ String sel_setTitleBaseWritingDirection_1;
    public static /*const*/ String sel_subscript_1;
    public static /*const*/ String sel_URL;
    public static /*const*/ String sel_headerColor;
    public static /*const*/ String sel_StringByAddingPercentEscapesUsingEncoding_1;
    public static /*const*/ String sel_draggingExited_1;
    public static /*const*/ String sel_ignoreModifierKeysWhileDragging;
    public static /*const*/ String sel_componentsToDisplayForPath_1;
    public static /*const*/ String sel_glyphRangeForBoundingRectWithoutAdditionalLayout_1inTextContainer_1;
    public static /*const*/ String sel_removeTrackingRect_1;
    public static /*const*/ String sel_handlePrintScriptCommand_1;
    public static /*const*/ String sel_viewDidMoveToWindow;
    public static /*const*/ String sel_allocateGState;
    public static /*const*/ String sel_availableStringEncodings;
    public static /*const*/ String sel_instantiateNibWithExternalNameTable_1;
    public static /*const*/ String sel_setWeekdayOrdinal_1;
    public static /*const*/ String sel_setWithCapacity_1;
    public static /*const*/ String sel_setCurrentAppleEventAndReplyEventWithSuspensionID_1;
    public static /*const*/ String sel_convertFont_1toNotHaveTrait_1;
    public static /*const*/ String sel_performSelector_1withObject_1withObject_1;
    public static /*const*/ String sel_removeIndexes_1;
    public static /*const*/ String sel_objectSpecifierWithDescriptor_1;
    public static /*const*/ String sel_objectValue;
    public static /*const*/ String sel_timeZone;
    public static /*const*/ String sel_viewSizeChanged_1;
    public static /*const*/ String sel_clearDrawable;
    public static /*const*/ String sel_parentRowForRow_1;
    public static /*const*/ String sel_trackingMode;
    public static /*const*/ String sel_selectedRanges;
    public static /*const*/ String sel_suspendExecution;
    public static /*const*/ String sel_setDefaultPrinter_1;
    public static /*const*/ String sel_loadDataRepresentation_1ofType_1;
    public static /*const*/ String sel_closestTickMarkValueToValue_1;
    public static /*const*/ String sel_removeFromRunLoop_1forMode_1;
    public static /*const*/ String sel_cancelUserAttentionRequest_1;
    public static /*const*/ String sel_dictionaryWithObject_1forKey_1;
    public static /*const*/ String sel_isDataRetained;
    public static /*const*/ String sel_setLoops_1;
    public static /*const*/ String sel_hashTableWithWeakObjects;
    public static /*const*/ String sel_documentForURL_1;
    public static /*const*/ String sel_removeRepresentation_1;
    public static /*const*/ String sel_keyClassDescription;
    public static /*const*/ String sel_noResponderFor_1;
    public static /*const*/ String sel_setBidiLevels_1forGlyphRange_1;
    public static /*const*/ String sel_cancelIncrementalLoad;
    public static /*const*/ String sel_highlightedBranchImage;
    public static /*const*/ String sel_setAttributedStringForZero_1;
    public static /*const*/ String sel_drawAtPoint_1fromRect_1operation_1fraction_1;
    public static /*const*/ String sel_fileHFSTypeCode;
    public static /*const*/ String sel_maximumRecents;
    public static /*const*/ String sel_useFont_1;
    public static /*const*/ String sel_selectKeyViewPrecedingView_1;
    public static /*const*/ String sel_attributedStringForNil;
    public static /*const*/ String sel_isGrammarCheckingEnabled;
    public static /*const*/ String sel_owner;
    public static /*const*/ String sel_searchForServicesOfType_1inDomain_1;
    public static /*const*/ String sel_frameAutosaveName;
    public static /*const*/ String sel_setCommands_1;
    public static /*const*/ String sel_URLResourceDidCancelLoading_1;
    public static /*const*/ String sel_uniqueSpellDocumentTag;
    public static /*const*/ String sel_needsToBeUpdatedFromPath_1;
    public static /*const*/ String sel_bounds;
    public static /*const*/ String sel_contextHelpForKey_1;
    public static /*const*/ String sel_setSendsActionOnEndEditing_1;
    public static /*const*/ String sel_scanDouble_1;
    public static /*const*/ String sel_download_1willResumeWithResponse_1fromByte_1;
    public static /*const*/ String sel_drawFromCenter_1radius_1toCenter_1radius_1options_1;
    public static /*const*/ String sel_defaultFlatness;
    public static /*const*/ String sel_keepBackupFile;
    public static /*const*/ String sel_willChangeValueForKey_1;
    public static /*const*/ String sel_initWithDateFormat_1allowNaturalLanguage_1;
    public static /*const*/ String sel_textView_1writablePasteboardTypesForCell_1atIndex_1;
    public static /*const*/ String sel_getTIFFCompressionTypes_1count_1;
    public static /*const*/ String sel_decodePropertyList;
    public static /*const*/ String sel_saveDocumentWithDelegate_1didSaveSelector_1contextInfo_1;
    public static /*const*/ String sel_encodePoint_1;
    public static /*const*/ String sel_selectRow_1byExtendingSelection_1;
    public static /*const*/ String sel_preservesContentDuringLiveResize;
    public static /*const*/ String sel_registerUndoWithTarget_1selector_1object_1;
    public static /*const*/ String sel_removeCollection_1;
    public static /*const*/ String sel_nextEventMatchingMask_1;
    public static /*const*/ String sel_getObjects_1andKeys_1;
    public static /*const*/ String sel_EPSRepresentation;
    public static /*const*/ String sel_isModalPanel;
    public static /*const*/ String sel_statusCode;
    public static /*const*/ String sel_setCopiesOnScroll_1;
    public static /*const*/ String sel_setHorizontalPagination_1;
    public static /*const*/ String sel_removeAllIndexes;
    public static /*const*/ String sel_download_1didFailWithError_1;
    public static /*const*/ String sel_modifierFlags;
    public static /*const*/ String sel_draggedColumn;
    public static /*const*/ String sel_initWithUser_1;
    public static /*const*/ String sel_setLayoutRect_1forTextBlock_1glyphRange_1;
    public static /*const*/ String sel_selectionAffinity;
    public static /*const*/ String sel_beginParagraph;
    public static /*const*/ String sel_runModalForTypes_1;
    public static /*const*/ String sel_reloadCriteria;
    public static /*const*/ String sel_PDFOperationWithView_1insideRect_1toData_1printInfo_1;
    public static /*const*/ String sel_cellAtRow_1column_1;
    public static /*const*/ String sel_selectColumn_1byExtendingSelection_1;
    public static /*const*/ String sel_addresses;
    public static /*const*/ String sel_setCanBeVisibleOnAllSpaces_1;
    public static /*const*/ String sel_bundleForSuite_1;
    public static /*const*/ String sel_StringWithCharacters_1length_1;
    public static /*const*/ String sel_dataWithContentsOfURL_1options_1error_1;
    public static /*const*/ String sel_isExpanded;
    public static /*const*/ String sel_rectForLayoutAtPoint_1inRect_1textContainer_1characterRange_1;
    public static /*const*/ String sel_initWithXMLString_1options_1error_1;
    public static /*const*/ String sel_datePickerCell_1validateProposedDateValue_1timeInterval_1;
    public static /*const*/ String sel_replaceCharactersInRange_1withRTFD_1;
    public static /*const*/ String sel_setNeedsDisplay_1;
    public static /*const*/ String sel_tableViewColumnDidMove_1;
    public static /*const*/ String sel_printOperationWithView_1printInfo_1;
    public static /*const*/ String sel_parserDidStartDocument_1;
    public static /*const*/ String sel_privateFrameworksPath;
    public static /*const*/ String sel_informativeText;
    public static /*const*/ String sel_attributesAtIndex_1effectiveRange_1;
    public static /*const*/ String sel_rectArrayForGlyphRange_1withinSelectedGlyphRange_1inTextContainer_1rectCount_1;
    public static /*const*/ String sel_swapWithMark_1;
    public static /*const*/ String sel_setDrawsGrid_1;
    public static /*const*/ String sel_highlight_1;
    public static /*const*/ String sel_maximumLineHeight;
    public static /*const*/ String sel_phonemesFromText_1;
    public static /*const*/ String sel_convertSize_1fromView_1;
    public static /*const*/ String sel_setProperty_1withValue_1;
    public static /*const*/ String sel_cookieAcceptPolicy;
    public static /*const*/ String sel_hasThousandSeparators;
    public static /*const*/ String sel_setTighteningFactorForTruncation_1;
    public static /*const*/ String sel_contextMenuRepresentation;
    public static /*const*/ String sel_precomposedStringWithCompatibilityMapping;
    public static /*const*/ String sel_threadDictionary;
    public static /*const*/ String sel_redoMenuTitleForUndoActionName_1;
    public static /*const*/ String sel_setNumberOfVisibleItems_1;
    public static /*const*/ String sel_preferredLanguages;
    public static /*const*/ String sel_mouseDraggedOnCharacterIndex_1atCoordinate_1withModifier_1client_1;
    public static /*const*/ String sel_setMultiplier_1;
    public static /*const*/ String sel_sortedArrayUsingSelector_1;
    public static /*const*/ String sel_drawInRect_1;
    public static /*const*/ String sel_reversedSortDescriptor;
    public static /*const*/ String sel_setIdentifier_1;
    public static /*const*/ String sel_systemLocale;
    public static /*const*/ String sel_rulerView_1didMoveMarker_1;
    public static /*const*/ String sel_serviceConnectionWithName_1rootObject_1;
    public static /*const*/ String sel_mouseDownCanMoveWindow;
    public static /*const*/ String sel_setMode_1;
    public static /*const*/ String sel_rectOfTickMarkAtIndex_1;
    public static /*const*/ String sel_rangeOfCharacterFromSet_1;
    public static /*const*/ String sel_pageUp_1;
    public static /*const*/ String sel_sendsWholeSearchString;
    public static /*const*/ String sel_selectColumnIndexes_1byExtendingSelection_1;
    public static /*const*/ String sel_localizedCaseInsensitiveCompare_1;
    public static /*const*/ String sel_isEqualToString_1;
    public static /*const*/ String sel_invalidateHashMarks;
    public static /*const*/ String sel_setInitialKey_1;
    public static /*const*/ String sel_setDividerStyle_1;
    public static /*const*/ String sel_expressionForMinusSet_1with_1;
    public static /*const*/ String sel_netService_1didNotPublish_1;
    public static /*const*/ String sel_evaluatedReceivers;
    public static /*const*/ String sel_removeTabViewItem_1;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1index_1;
    public static /*const*/ String sel_predicateWithLeftExpression_1rightExpression_1customSelector_1;
    public static /*const*/ String sel_brownColor;
    public static /*const*/ String sel_leafKeyPathForNode_1;
    public static /*const*/ String sel_drawBackgroundForGlyphRange_1atPoint_1;
    public static /*const*/ String sel_rulerView_1willSetClientView_1;
    public static /*const*/ String sel_className;
    public static /*const*/ String sel_runMode_1beforeDate_1;
    public static /*const*/ String sel_applicationShouldTerminateAfterLastWindowClosed_1;
    public static /*const*/ String sel_newDocument_1;
    public static /*const*/ String sel_arrayByAddingObject_1;
    public static /*const*/ String sel_savePanel;
    public static /*const*/ String sel_prefersTrackingUntilMouseUp;
    public static /*const*/ String sel_setLocations_1startingGlyphIndexes_1count_1forGlyphRange_1;
    public static /*const*/ String sel_setListensInForegroundOnly_1;
    public static /*const*/ String sel_initWithUnsignedShort_1;
    public static /*const*/ String sel_letterCharacterSet;
    public static /*const*/ String sel_listensInForegroundOnly;
    public static /*const*/ String sel_menu_1willHighlightItem_1;
    public static /*const*/ String sel_charactersIgnoringModifiers;
    public static /*const*/ String sel_insertionContainer;
    public static /*const*/ String sel_searchButtonRectForBounds_1;
    public static /*const*/ String sel_accessibilitySetValue_1forAttribute_1;
    public static /*const*/ String sel_setPathSeparator_1;
    public static /*const*/ String sel_applicationWillResignActive_1;
    public static /*const*/ String sel_scriptingIsLessThanOrEqualTo_1;
    public static /*const*/ String sel_decodeValuesOfObjCTypes_1;
    public static /*const*/ String sel_setIntercellSpacing_1;
    public static /*const*/ String sel_sharedSystemTypesetterForBehavior_1;
    public static /*const*/ String sel_drawFromPoint_1toPoint_1options_1;
    public static /*const*/ String sel_windowDidMove_1;
    public static /*const*/ String sel_setVisible_1;
    public static /*const*/ String sel_credentialWithUser_1password_1persistence_1;
    public static /*const*/ String sel_decomposedStringWithCanonicalMapping;
    public static /*const*/ String sel_openFile_1withApplication_1andDeactivate_1;
    public static /*const*/ String sel_convertRectToBase_1;
    public static /*const*/ String sel_outputStreamToMemory;
    public static /*const*/ String sel_autorepeat;
    public static /*const*/ String sel_servicesMenu;
    public static /*const*/ String sel_beginGrouping;
    public static /*const*/ String sel_setNilValueForKey_1;
    public static /*const*/ String sel_usesFontLeading;
    public static /*const*/ String sel_lineFragmentRectForGlyphAtIndex_1effectiveRange_1;
    public static /*const*/ String sel_takeStringValueFrom_1;
    public static /*const*/ String sel_fontDescriptorByAddingAttributes_1;
    public static /*const*/ String sel_startTrackingAt_1inView_1;
    public static /*const*/ String sel_application_1delegateHandlesKey_1;
    public static /*const*/ String sel_StringByExpandingTildeInPath;
    public static /*const*/ String sel_menu;
    public static /*const*/ String sel_setMinute_1;
    public static /*const*/ String sel_startSubelementIdentifier;
    public static /*const*/ String sel_waitForDataInBackgroundAndNotifyForModes_1;
    public static /*const*/ String sel_removeCachedResponseForRequest_1;
    public static /*const*/ String sel_attributeForLocalName_1URI_1;
    public static /*const*/ String sel_saveDocumentAs_1;
    public static /*const*/ String sel_containerIsObjectBeingTested;
    public static /*const*/ String sel_mouseDownOnCharacterIndex_1atCoordinate_1withModifier_1client_1;
    public static /*const*/ String sel_setPosition_1ofDividerAtIndex_1;
    public static /*const*/ String sel_terminationStatus;
    public static /*const*/ String sel_imageWidth;
    public static /*const*/ String sel_accessoryView;
    public static /*const*/ String sel_outlineView_1shouldTrackCell_1forTableColumn_1item_1;
    public static /*const*/ String sel_initWithLevelIndicatorStyle_1;
    public static /*const*/ String sel_deltaX;
    public static /*const*/ String sel_valueForUndefinedKey_1;
    public static /*const*/ String sel_mainDocumentURL;
    public static /*const*/ String sel_position;
    public static /*const*/ String sel_animates;
    public static /*const*/ String sel_addTabViewItem_1;
    public static /*const*/ String sel_unlockFocus;
    public static /*const*/ String sel_download_1didCreateDestination_1;
    public static /*const*/ String sel_defaults;
    public static /*const*/ String sel_viewWillDraw;
    public static /*const*/ String sel_findApplications;
    public static /*const*/ String sel_unbind_1;
    public static /*const*/ String sel_positionOfGlyph_1withRelation_1toBaseGlyph_1totalAdvancement_1metricsExist_1;
    public static /*const*/ String sel_isGreaterThan_1;
    public static /*const*/ String sel_dataWithPDFInsideRect_1;
    public static /*const*/ String sel_setAttributedTitle_1;
    public static /*const*/ String sel_expressionType;
    public static /*const*/ String sel_tokenFieldCell_1shouldAddObjects_1atIndex_1;
    public static /*const*/ String sel_removeEventHandlerForEventClass_1andEventID_1;
    public static /*const*/ String sel_postNotification_1;
    public static /*const*/ String sel_indexOfTabViewItem_1;
    public static /*const*/ String sel_outlineView_1shouldSelectItem_1;
    public static /*const*/ String sel_setSegmentStyle_1;
    public static /*const*/ String sel_stateImageRectForBounds_1;
    public static /*const*/ String sel_setContentAspectRatio_1;
    public static /*const*/ String sel_instantiateNibWithOwner_1topLevelObjects_1;
    public static /*const*/ String sel_setPrototype_1;
    public static /*const*/ String sel_allowsMultipleSelection;
    public static /*const*/ String sel_setRecentSearches_1;
    public static /*const*/ String sel_setTypingAttributes_1;
    public static /*const*/ String sel_observeValueForKeyPath_1ofObject_1change_1context_1;
    public static /*const*/ String sel_performDragOperation_1;
    public static /*const*/ String sel_processingInstructionWithName_1StringValue_1;
    public static /*const*/ String sel_initWithKind_1options_1;
    public static /*const*/ String sel_instancesRespondToSelector_1;
    public static /*const*/ String sel_keyEquivalentFont;
    public static /*const*/ String sel_calendarIdentifier;
    public static /*const*/ String sel_source;
    public static /*const*/ String sel_shouldBeTreatedAsInkEvent_1;
    public static /*const*/ String sel_queuePriority;
    public static /*const*/ String sel_autoresizesAllColumnsToFit;
    public static /*const*/ String sel_outlineView_1shouldCollapseItem_1;
    public static /*const*/ String sel_dragImage_1at_1offset_1event_1pasteboard_1source_1slideBack_1;
    public static /*const*/ String sel_sender;
    public static /*const*/ String sel_numberOfColumns;
    public static /*const*/ String sel_indexPathWithIndex_1;
    public static /*const*/ String sel_setPreferredFontNames_1;
    public static /*const*/ String sel_windowDidEndSheet_1;
    public static /*const*/ String sel_capHeight;
    public static /*const*/ String sel_matchingFontDescriptorWithMandatoryKeys_1;
    public static /*const*/ String sel_finalize;
    public static /*const*/ String sel_prepareForDragOperation_1;
    public static /*const*/ String sel_setCellAttribute_1to_1;
    public static /*const*/ String sel_metadataQuery_1replacementValueForAttribute_1value_1;
    public static /*const*/ String sel_hueComponent;
    public static /*const*/ String sel_maxValue;
    public static /*const*/ String sel_soundUnfilteredTypes;
    public static /*const*/ String sel_setFileAttributes_1;
    public static /*const*/ String sel_valueLists;
    public static /*const*/ String sel_breakLock;
    public static /*const*/ String sel_selectCellWithTag_1;
    public static /*const*/ String sel_setMovable_1;
    public static /*const*/ String sel_synchronizeFile;
    public static /*const*/ String sel_setVerticallyResizable_1;
    public static /*const*/ String sel_setButtonBordered_1;
    public static /*const*/ String sel_useOptimizedDrawing_1;
    public static /*const*/ String sel_tryLockWhenCondition_1;
    public static /*const*/ String sel_textContainer;
    public static /*const*/ String sel_setValueListAttributes_1;
    public static /*const*/ String sel_rangeOfCharacterFromSet_1options_1;
    public static /*const*/ String sel_dragFile_1fromRect_1slideBack_1event_1;
    public static /*const*/ String sel_tickMarkPosition;
    public static /*const*/ String sel_addRunLoop_1;
    public static /*const*/ String sel_dataWithCapacity_1;
    public static /*const*/ String sel_removeVolatileDomainForName_1;
    public static /*const*/ String sel_signal;
    public static /*const*/ String sel_progressMarks;
    public static /*const*/ String sel_unhide_1;
    public static /*const*/ String sel_provideNewButtonImage;
    public static /*const*/ String sel_connectionWithRegisteredName_1host_1usingNameServer_1;
    public static /*const*/ String sel_localizesFormat;
    public static /*const*/ String sel_lineScroll;
    public static /*const*/ String sel_initDirectoryWithFileWrappers_1;
    public static /*const*/ String sel_wantsToInterpretAllKeystrokes;
    public static /*const*/ String sel_convertPointToBase_1;
    public static /*const*/ String sel_keyWithAppleEventCode_1;
    public static /*const*/ String sel_loadSuiteWithDictionary_1fromBundle_1;
    public static /*const*/ String sel_automaticallyPreparesContent;
    public static /*const*/ String sel_cornerRadius;
    public static /*const*/ String sel_sharedScriptExecutionContext;
    public static /*const*/ String sel_setPoolCountHighWaterResolution_1;
    public static /*const*/ String sel_appendBezierPath_1;
    public static /*const*/ String sel_appleEventClassCode;
    public static /*const*/ String sel_initTextCell_1pullsDown_1;
    public static /*const*/ String sel_numberOfTickMarks;
    public static /*const*/ String sel_setIndependentConversationQueueing_1;
    public static /*const*/ String sel_extendPowerOffBy_1;
    public static /*const*/ String sel_isCollecting;
    public static /*const*/ String sel_canInsert;
    public static /*const*/ String sel_valuePointerFunctions;
    public static /*const*/ String sel_sizeValue;
    public static /*const*/ String sel_openOnEdge_1;
    public static /*const*/ String sel_rectOfItemAtIndex_1;
    public static /*const*/ String sel_booleanForKey_1inTable_1;
    public static /*const*/ String sel_showHelp_1;
    public static /*const*/ String sel_heightTracksTextView;
    public static /*const*/ String sel_hasTitleBar;
    public static /*const*/ String sel_setViewAnimations_1;
    public static /*const*/ String sel_updateSpellingPanelWithGrammarString_1detail_1;
    public static /*const*/ String sel_showsToolbarButton;
    public static /*const*/ String sel_environment;
    public static /*const*/ String sel_matchesAppleEventCode_1;
    public static /*const*/ String sel_hasPrefix_1;
    public static /*const*/ String sel_hasUnappliedChanges;
    public static /*const*/ String sel_setName_1;
    public static /*const*/ String sel_isMovableByWindowBackground;
    public static /*const*/ String sel_printerNames;
    public static /*const*/ String sel_initWithDictionary_1;
    public static /*const*/ String sel_StringByStandardizingPath;
    public static /*const*/ String sel_usesUserKeyEquivalents;
    public static /*const*/ String sel_drawStateImageWithFrame_1inView_1;
    public static /*const*/ String sel_openUntitledDocumentAndDisplay_1error_1;
    public static /*const*/ String sel_lastVisibleColumn;
    public static /*const*/ String sel_paste_1;
    public static /*const*/ String sel_indexOfItemWithRepresentedObject_1;
    public static /*const*/ String sel_supportsCommand_1;
    public static /*const*/ String sel_scrollPageUp_1;
    public static /*const*/ String sel_draggedImage_1endedAt_1deposited_1;
    public static /*const*/ String sel_setPositiveInfinitySymbol_1;
    public static /*const*/ String sel_noteFileSystemChanged_1;
    public static /*const*/ String sel_moveRight_1;
    public static /*const*/ String sel_arrowPosition;
    public static /*const*/ String sel_setMenuRepresentation_1;
    public static /*const*/ String sel_endLoadInBackground;
    public static /*const*/ String sel_smartInsertBeforeStringForString_1replacingRange_1;
    public static /*const*/ String sel_openUntitledDocumentOfType_1display_1;
    public static /*const*/ String sel_scriptingValueForSpecifier_1;
    public static /*const*/ String sel_setShowsSuppressionButton_1;
    public static /*const*/ String sel_resizeLeftCursor;
    public static /*const*/ String sel_setDefaultCredential_1forProtectionSpace_1;
    public static /*const*/ String sel_systemTabletID;
    public static /*const*/ String sel_unlock;
    public static /*const*/ String sel_mostCompatibleStringEncoding;
    public static /*const*/ String sel_glyphName;
    public static /*const*/ String sel_center;
    public static /*const*/ String sel_setJobTitle_1;
    public static /*const*/ String sel_cancelButtonCell;
    public static /*const*/ String sel_namespaceForPrefix_1;
    public static /*const*/ String sel_browserWillScroll_1;
    public static /*const*/ String sel_initWithCompoundTypes_1;
    public static /*const*/ String sel_setPaddingCharacter_1;
    public static /*const*/ String sel_image_1willLoadRepresentation_1;
    public static /*const*/ String sel_pasteRuler_1;
    public static /*const*/ String sel_drawGlyphsForGlyphRange_1atPoint_1;
    public static /*const*/ String sel_PMPrintSession;
    public static /*const*/ String sel_setDefaultButtonCell_1;
    public static /*const*/ String sel_printerTypes;
    public static /*const*/ String sel_findString_1inBook_1;
    public static /*const*/ String sel_executablePath;
    public static /*const*/ String sel_components_1fromDate_1toDate_1options_1;
    public static /*const*/ String sel_displayValuesForRow_1;
    public static /*const*/ String sel_pageLayout;
    public static /*const*/ String sel_resizeFlags;
    public static /*const*/ String sel_DTDNodeWithXMLString_1;
    public static /*const*/ String sel_replyToOpenOrPrint_1;
    public static /*const*/ String sel_insertTab_1;
    public static /*const*/ String sel_documents;
    public static /*const*/ String sel_tagForSegment_1;
    public static /*const*/ String sel_initForURL_1withContentsOfURL_1ofType_1error_1;
    public static /*const*/ String sel_initWithRoundingMode_1scale_1raiseOnExactness_1raiseOnOverflow_1raiseOnUnderflow_1raiseOnDivideByZero_1;
    public static /*const*/ String sel_addIndexes_1;
    public static /*const*/ String sel_setAttributeRuns_1;
    public static /*const*/ String sel_splitView_1additionalEffectiveRectOfDividerAtIndex_1;
    public static /*const*/ String sel_writeSelectionToPasteboard_1type_1;
    public static /*const*/ String sel_day;
    public static /*const*/ String sel_numberOfRowsInTableView_1;
    public static /*const*/ String sel_insertCompletion_1forPartialWordRange_1movement_1isFinal_1;
    public static /*const*/ String sel_notPredicateWithSubpredicate_1;
    public static /*const*/ String sel_rootProxyForConnectionWithRegisteredName_1host_1;
    public static /*const*/ String sel_stopSpeakingAtBoundary_1;
    public static /*const*/ String sel_pathsMatchingExtensions_1;
    public static /*const*/ String sel_caseInsensitiveCompare_1;
    public static /*const*/ String sel_labelFontOfSize_1;
    public static /*const*/ String sel_createDirectoryAtPath_1attributes_1;
    public static /*const*/ String sel_initListDescriptor;
    public static /*const*/ String sel_setParagraphSpacing_1;
    public static /*const*/ String sel_getColor_1location_1atIndex_1;
    public static /*const*/ String sel_pointerArrayWithOptions_1;
    public static /*const*/ String sel_guessesForWord_1;
    public static /*const*/ String sel_searchTextRectForBounds_1;
    public static /*const*/ String sel_allowsColumnReordering;
    public static /*const*/ String sel_isMainThread;
    public static /*const*/ String sel_accessibilityAttributeNames;
    public static /*const*/ String sel_saveOptions;
    public static /*const*/ String sel_setAutomaticallyPreparesContent_1;
    public static /*const*/ String sel_setGridColor_1;
    public static /*const*/ String sel_textAttributesForNegativeInfinity;
    public static /*const*/ String sel_decimalDigitCharacterSet;
    public static /*const*/ String sel_removeObserver_1name_1object_1;
    public static /*const*/ String sel_columnContentWidthForColumnWidth_1;
    public static /*const*/ String sel_wraps;
    public static /*const*/ String sel_getIndexes_1maxCount_1inIndexRange_1;
    public static /*const*/ String sel_doubleAction;
    public static /*const*/ String sel_layoutParagraphAtPoint_1;
    public static /*const*/ String sel_cacheDisplayInRect_1toBitmapImageRep_1;
    public static /*const*/ String sel_setUsesItemFromMenu_1;
    public static /*const*/ String sel_parserError;
    public static /*const*/ String sel_numberOfMajorTickMarks;
    public static /*const*/ String sel_changeFont_1;
    public static /*const*/ String sel_displaysWhenScreenProfileChanges;
    public static /*const*/ String sel_titleBaseWritingDirection;
    public static /*const*/ String sel_columnAtPoint_1;
    public static /*const*/ String sel_setAppliesImmediately_1;
    public static /*const*/ String sel_addAccessoryController_1;
    public static /*const*/ String sel_setEditable_1;
    public static /*const*/ String sel_moveRulerlineFromLocation_1toLocation_1;
    public static /*const*/ String sel_runModal;
    public static /*const*/ String sel_selectionShouldChangeInTableView_1;
    public static /*const*/ String sel_dragSelectionWithEvent_1offset_1slideBack_1;
    public static /*const*/ String sel_rootProxy;
    public static /*const*/ String sel_brightnessComponent;
    public static /*const*/ String sel_setLabel_1forSegment_1;
    public static /*const*/ String sel_copy;
    public static /*const*/ String sel_helpRequested_1;
    public static /*const*/ String sel_setThreadPriority_1;
    public static /*const*/ String sel_minContentSize;
    public static /*const*/ String sel_setShowsProgressPanel_1;
    public static /*const*/ String sel_setMessageText_1;
    public static /*const*/ String sel_setLayoutAlgorithm_1;
    public static /*const*/ String sel_setInContext_1;
    public static /*const*/ String sel_resultCount;
    public static /*const*/ String sel_usesDataSource;
    public static /*const*/ String sel_textLists;
    public static /*const*/ String sel_setSelectedRange_1affinity_1stillSelecting_1;
    public static /*const*/ String sel_shouldResolveExternalEntities;
    public static /*const*/ String sel_clientView;
    public static /*const*/ String sel_styleMask;
    public static /*const*/ String sel_setCurrencyCode_1;
    public static /*const*/ String sel_methodReturnType;
    public static /*const*/ String sel_dataUsingEncoding_1;
    public static /*const*/ String sel_removeTabStop_1;
    public static /*const*/ String sel_reloadItem_1reloadChildren_1;
    public static /*const*/ String sel_ancestorSharedWithView_1;
    public static /*const*/ String sel_indexLessThanOrEqualToIndex_1;
    public static /*const*/ String sel_removeAllActionsWithTarget_1;
    public static /*const*/ String sel_subtype;
    public static /*const*/ String sel_imageRectForPaper_1;
    public static /*const*/ String sel_initWithWindow_1rect_1;
    public static /*const*/ String sel_enable;
    public static /*const*/ String sel_scanInteger_1;
    public static /*const*/ String sel_initWithContentsOfURL_1encoding_1error_1;
    public static /*const*/ String sel_removeObjectIdenticalTo_1;
    public static /*const*/ String sel_createTexture_1fromView_1internalFormat_1;
    public static /*const*/ String sel_decimalNumberByRaisingToPower_1withBehavior_1;
    public static /*const*/ String sel_appendBezierPathWithArcWithCenter_1radius_1startAngle_1endAngle_1;
    public static /*const*/ String sel_fontPanel_1;
    public static /*const*/ String sel_predicateWithSubpredicates_1;
    public static /*const*/ String sel_layoutGlyphsInLayoutManager_1startingAtGlyphIndex_1maxNumberOfLineFragments_1nextGlyphIndex_1;
    public static /*const*/ String sel_attributes;
    public static /*const*/ String sel_EPSOperationWithView_1insideRect_1toData_1;
    public static /*const*/ String sel_listOptions;
    public static /*const*/ String sel_windowWillLoad;
    public static /*const*/ String sel_alwaysShowsDecimalSeparator;
    public static /*const*/ String sel_replyToApplicationShouldTerminate_1;
    public static /*const*/ String sel_setThousandSeparator_1;
    public static /*const*/ String sel_insertObject_1atArrangedObjectIndexPath_1;
    public static /*const*/ String sel_cleanUpOperation;
    public static /*const*/ String sel_trackMouse_1inRect_1ofView_1untilMouseUp_1;
    public static /*const*/ String sel_replaceLayoutManager_1;
    public static /*const*/ String sel_isPartialStringValid_1proposedSelectedRange_1originalString_1originalSelectedRange_1errorDescription_1;
    public static /*const*/ String sel_setNegativeFormat_1;
    public static /*const*/ String sel_copyFont_1;
    public static /*const*/ String sel_outlineView_1sortDescriptorsDidChange_1;
    public static /*const*/ String sel_StringWithString_1;
    public static /*const*/ String sel_valueWithUniqueID_1inPropertyWithKey_1;
    public static /*const*/ String sel_setHighlightsBy_1;
    public static /*const*/ String sel_setContinuousSpellCheckingEnabled_1;
    public static /*const*/ String sel_isMouseCoalescingEnabled;
    public static /*const*/ String sel_numberOfSelectedColumns;
    public static /*const*/ String sel_spellServer_1findMisspelledWordInString_1language_1wordCount_1countOnly_1;
    public static /*const*/ String sel_PMPageFormat;
    public static /*const*/ String sel_insertText_1client_1;
    public static /*const*/ String sel_numberWithFloat_1;
    public static /*const*/ String sel_compositeToPoint_1fromRect_1operation_1;
    public static /*const*/ String sel_numberOfPlanes;
    public static /*const*/ String sel_childrenKeyPath;
    public static /*const*/ String sel_countForObject_1;
    public static /*const*/ String sel_fontWithName_1matrix_1;
    public static /*const*/ String sel_toolbarAllowedItemIdentifiers_1;
    public static /*const*/ String sel_makeDocumentWithContentsOfURL_1ofType_1;
    public static /*const*/ String sel_initWithHTML_1options_1documentAttributes_1;
    public static /*const*/ String sel_fileSystemRepresentation;
    public static /*const*/ String sel_viewAnimations;
    public static /*const*/ String sel_tabletProximity_1;
    public static /*const*/ String sel_replacementClassForClass_1;
    public static /*const*/ String sel_columnWidthForColumnContentWidth_1;
    public static /*const*/ String sel_undoMenuItemTitle;
    public static /*const*/ String sel_expressionForAggregate_1;
    public static /*const*/ String sel_useStoredAccessor;
    public static /*const*/ String sel_ensureAttributesAreFixedInRange_1;
    public static /*const*/ String sel_StringForType_1;
    public static /*const*/ String sel_setLeaf_1;
    public static /*const*/ String sel_URLFromPasteboard_1;
    public static /*const*/ String sel_initWithURL_1byReference_1;
    public static /*const*/ String sel_readToEndOfFileInBackgroundAndNotify;
    public static /*const*/ String sel_application_1openFileWithoutUI_1;
    public static /*const*/ String sel_performClick_1;
    public static /*const*/ String sel_completes;
    public static /*const*/ String sel_setRulersVisible_1;
    public static /*const*/ String sel_minimumSize;
    public static /*const*/ String sel_setProperty_1forKey_1inRequest_1;
    public static /*const*/ String sel_isCopyingOperation;
    public static /*const*/ String sel_allowsTickMarkValuesOnly;
    public static /*const*/ String sel_insertGlyphs_1length_1forStartingGlyphAtIndex_1characterIndex_1;
    public static /*const*/ String sel_convertFont_1;
    public static /*const*/ String sel_setNegativePrefix_1;
    public static /*const*/ String sel_dispatch;
    public static /*const*/ String sel_makeNewConnection_1sender_1;
    public static /*const*/ String sel_writeToFile_1atomically_1encoding_1error_1;
    public static /*const*/ String sel_isHiddenOrHasHiddenAncestor;
    public static /*const*/ String sel_endEditingFor_1;
    public static /*const*/ String sel_acceptConnectionInBackgroundAndNotify;
    public static /*const*/ String sel_setValue_1forHTTPHeaderField_1;
    public static /*const*/ String sel_intersectSet_1;
    public static /*const*/ String sel_tabView_1shouldSelectTabViewItem_1;
    public static /*const*/ String sel_mouseDragged_1;
    public static /*const*/ String sel_dataFromRange_1documentAttributes_1error_1;
    public static /*const*/ String sel_sharedFrameworksPath;
    public static /*const*/ String sel_tableView_1writeRowsWithIndexes_1toPasteboard_1;
    public static /*const*/ String sel_setWindowFrameForAttachingToRect_1onScreen_1preferredEdge_1popUpSelectedItem_1;
    public static /*const*/ String sel_valueAtIndex_1inPropertyWithKey_1;
    public static /*const*/ String sel_setDisplaysLinkToolTips_1;
    public static /*const*/ String sel_removeObserver_1forKeyPath_1;
    public static /*const*/ String sel_hasAlpha;
    public static /*const*/ String sel_scrollCellToVisibleAtRow_1column_1;
    public static /*const*/ String sel_activateIgnoringOtherApps_1;
    public static /*const*/ String sel_getArgumentTypeAtIndex_1;
    public static /*const*/ String sel_textShouldEndEditing_1;
    public static /*const*/ String sel_nextEventMatchingMask_1untilDate_1inMode_1dequeue_1;
    public static /*const*/ String sel_timeIntervalSince1970;
    public static /*const*/ String sel_decimalNumberBySubtracting_1;
    public static /*const*/ String sel_sendBeforeDate_1;
    public static /*const*/ String sel_autohidesScrollers;
    public static /*const*/ String sel_controlPointBounds;
    public static /*const*/ String sel_setMinimumSignificantDigits_1;
    public static /*const*/ String sel_setDestination_1allowOverwrite_1;
    public static /*const*/ String sel_setTransparent_1;
    public static /*const*/ String sel_decodeArrayOfObjCType_1count_1at_1;
    public static /*const*/ String sel_isMiniaturized;
    public static /*const*/ String sel_setAlignment_1;
    public static /*const*/ String sel_setCornerRadius_1;
    public static /*const*/ String sel_foregroundColor;
    public static /*const*/ String sel_lineFragmentUsedRectForGlyphAtIndex_1effectiveRange_1;
    public static /*const*/ String sel_attributedSubStringFromRange_1;
    public static /*const*/ String sel_isSubsetOfSet_1;
    public static /*const*/ String sel_iconForFileType_1;
    public static /*const*/ String sel_readFromURL_1ofType_1;
    public static /*const*/ String sel_decodeBytesForKey_1returnedLength_1;
    public static /*const*/ String sel_parser_1foundInternalEntityDeclarationWithName_1value_1;
    public static /*const*/ String sel_commonPrefixWithString_1options_1;
    public static /*const*/ String sel_tableView_1setObjectValue_1forTableColumn_1row_1;
    public static /*const*/ String sel_fileWrapperRepresentationOfType_1;
    public static /*const*/ String sel_representedFilename;
    public static /*const*/ String sel_eventWithCGEvent_1;
    public static /*const*/ String sel_setFileURL_1;
    public static /*const*/ String sel_loadWindow;
    public static /*const*/ String sel_defaultLineJoinStyle;
    public static /*const*/ String sel_backingLocation;
    public static /*const*/ String sel_matrix;
    public static /*const*/ String sel_isEqualToTimeZone_1;
    public static /*const*/ String sel_statistics;
    public static /*const*/ String sel_launchAppWithBundleIdentifier_1options_1additionalEventParamDescriptor_1launchIdentifier_1;
    public static /*const*/ String sel_isHorizontal;
    public static /*const*/ String sel_launchPath;
    public static /*const*/ String sel_setTextAlignment_1;
    public static /*const*/ String sel_initWithBitmapDataPlanes_1pixelsWide_1pixelsHigh_1bitsPerSample_1samplesPerPixel_1hasAlpha_1isPlanar_1colorSpaceName_1bytesPerRow_1bitsPerPixel_1;
    public static /*const*/ String sel_setPatternPhase_1;
    public static /*const*/ String sel_mouseEntered_1withFrame_1inView_1;
    public static /*const*/ String sel_matchingFontDescriptorsWithMandatoryKeys_1;
    public static /*const*/ String sel_objectDidEndEditing_1;
    public static /*const*/ String sel_setMaximum_1;
    public static /*const*/ String sel_initWithIndexes_1length_1;
    public static /*const*/ String sel_tableView_1shouldShowCellExpansionForTableColumn_1row_1;
    public static /*const*/ String sel_moveToPoint_1;
    public static /*const*/ String sel_setGridStyleMask_1;
    public static /*const*/ String sel_firstUnlaidGlyphIndex;
    public static /*const*/ String sel_isProxy;
    public static /*const*/ String sel_takeValue_1forKeyPath_1;
    public static /*const*/ String sel_drawCellAtRow_1column_1;
    public static /*const*/ String sel_setRulerViewClass_1;
    public static /*const*/ String sel_objectByApplyingXSLT_1arguments_1error_1;
    public static /*const*/ String sel_setArrowPosition_1;
    public static /*const*/ String sel_setCharacterIndex_1forGlyphAtIndex_1;
    public static /*const*/ String sel_willChangeValueForKey_1withSetMutation_1usingObjects_1;
    public static /*const*/ String sel_setVerticalRulerView_1;
    public static /*const*/ String sel_suspendCurrentAppleEvent;
    public static /*const*/ String sel_drawStatusBarBackgroundInRect_1withHighlight_1;
    public static /*const*/ String sel_performClickWithFrame_1inView_1;
    public static /*const*/ String sel_coveredCharacterSet;
    public static /*const*/ String sel_browser_1numberOfRowsInColumn_1;
    public static /*const*/ String sel_isLike_1;
    public static /*const*/ String sel_blackComponent;
    public static /*const*/ String sel_appendBezierPathWithGlyph_1inFont_1;
    public static /*const*/ String sel_validateMenuItem_1;
    public static /*const*/ String sel_isEqualToIndexSet_1;
    public static /*const*/ String sel_setBezelStyle_1;
    public static /*const*/ String sel_scaleUnitSquareToSize_1;
    public static /*const*/ String sel_setStartSubelementIndex_1;
    public static /*const*/ String sel_frameOfInsideOfColumn_1;
    public static /*const*/ String sel_setBlocksOtherRecognizers_1;
    public static /*const*/ String sel_setMinSize_1;
    public static /*const*/ String sel_setEndSubelementIndex_1;
    public static /*const*/ String sel_cStringLength;
    public static /*const*/ String sel_writeWithBackupToFile_1ofType_1saveOperation_1;
    public static /*const*/ String sel_setDefaultButtonTitle_1;
    public static /*const*/ String sel_setMinContentSize_1;
    public static /*const*/ String sel_setFormattingDictionary_1;
    public static /*const*/ String sel_boundingRectForFont;
    public static /*const*/ String sel_postsBoundsChangedNotifications;
    public static /*const*/ String sel_setParagraphs_1;
    public static /*const*/ String sel_setShowsControlCharacters_1;
    public static /*const*/ String sel_writeSafelyToURL_1ofType_1forSaveOperation_1error_1;
    public static /*const*/ String sel_controlLightHighlightColor;
    public static /*const*/ String sel_objectSpecifier;
    public static /*const*/ String sel_dictionaryWithContentsOfURL_1;
    public static /*const*/ String sel_performSelector_1onThread_1withObject_1waitUntilDone_1modes_1;
    public static /*const*/ String sel_setJobStyleHint_1;
    public static /*const*/ String sel_sortedArrayUsingFunction_1context_1;
    public static /*const*/ String sel_setBoundsRect_1forTextBlock_1glyphRange_1;
    public static /*const*/ String sel_hasShadow;
    public static /*const*/ String sel_windowShouldClose_1;
    public static /*const*/ String sel_defaultTokenizingCharacterSet;
    public static /*const*/ String sel_isRulerVisible;
    public static /*const*/ String sel_setSubrowsKeyPath_1;
    public static /*const*/ String sel_animationDelay;
    public static /*const*/ String sel_selectAll_1;
    public static /*const*/ String sel_parser_1foundNotationDeclarationWithName_1publicID_1systemID_1;
    public static /*const*/ String sel_readSelectionFromPasteboard_1;
    public static /*const*/ String sel_validateAndReturnError_1;
    public static /*const*/ String sel_setScriptErrorOffendingObjectDescriptor_1;
    public static /*const*/ String sel_makeKeyWindow;
    public static /*const*/ String sel_itemAtIndex_1;
    public static /*const*/ String sel_objectAtIndex_1;
    public static /*const*/ String sel_protectionSpace;
    public static /*const*/ String sel_getCString_1;
    public static /*const*/ String sel_initSymbolicLinkWithDestination_1;
    public static /*const*/ String sel_daylightSavingTimeOffset;
    public static /*const*/ String sel_rangeOfTextList_1atIndex_1;
    public static /*const*/ String sel_currentDirectory;
    public static /*const*/ String sel_windowControllerDidLoadNib_1;
    public static /*const*/ String sel_setGroupingSize_1;
    public static /*const*/ String sel_subitems;
    public static /*const*/ String sel_initWithFileWrapper_1;
    public static /*const*/ String sel_documentVisibleRect;
    public static /*const*/ String sel_setCount_1;
    public static /*const*/ String sel_setScriptErrorExpectedTypeDescriptor_1;
    public static /*const*/ String sel_setReleasedWhenClosed_1;
    public static /*const*/ String sel_imageUnfilteredTypes;
    public static /*const*/ String sel_writeToFile_1options_1error_1;
    public static /*const*/ String sel_controlContentFontOfSize_1;
    public static /*const*/ String sel_insertRow_1withCells_1;
    public static /*const*/ String sel_temporaryAttributesAtCharacterIndex_1effectiveRange_1;
    public static /*const*/ String sel_stepForward_1;
    public static /*const*/ String sel_convertScreenToBase_1;
    public static /*const*/ String sel_printerWithType_1;
    public static /*const*/ String sel_setSliderType_1;
    public static /*const*/ String sel_applicationShouldHandleReopen_1hasVisibleWindows_1;
    public static /*const*/ String sel_selectedTextAttributes;
    public static /*const*/ String sel_setStandardError_1;
    public static /*const*/ String sel_drawRect_1;
    public static /*const*/ String sel_URLs;
    public static /*const*/ String sel_animationForKey_1;
    public static /*const*/ String sel_setSubviews_1;
    public static /*const*/ String sel_setString_1;
    public static /*const*/ String sel_openFile_1fromImage_1at_1inView_1;
    public static /*const*/ String sel_draggedImage;
    public static /*const*/ String sel_numberOfGlyphs;
    public static /*const*/ String sel_itemAtRow_1;
    public static /*const*/ String sel_drawKnob;
    public static /*const*/ String sel_imageRepsWithData_1;
    public static /*const*/ String sel_dragOperationForDraggingInfo_1type_1;
    public static /*const*/ String sel_initWithRTF_1documentAttributes_1;
    public static /*const*/ String sel_pathsForResourcesOfType_1inDirectory_1;
    public static /*const*/ String sel_fontName;
    public static /*const*/ String sel_layoutManagers;
    public static /*const*/ String sel_error;
    public static /*const*/ String sel_parentWindow;
    public static /*const*/ String sel_registerClass_1;
    public static /*const*/ String sel_hideOtherApplications;
    public static /*const*/ String sel_alphaComponent;
    public static /*const*/ String sel_setPrefersColorMatch_1;
    public static /*const*/ String sel_stopAnimation_1;
    public static /*const*/ String sel_glyphIndexForCharacterAtIndex_1;
    public static /*const*/ String sel_rulerView_1shouldAddMarker_1;
    public static /*const*/ String sel_initWithFrame_1;
    public static /*const*/ String sel_init;
    public static /*const*/ String sel_selectedColumnEnumerator;
    public static /*const*/ String sel_viewWithTag_1;
    public static /*const*/ String sel_classForKeyedUnarchiver;
    public static /*const*/ String sel_addRow_1;
    public static /*const*/ String sel_contextHelpForObject_1;
    public static /*const*/ String sel_server;
    public static /*const*/ String sel_colorUsingColorSpaceName_1device_1;
    public static /*const*/ String sel_valueTransformerForName_1;
    public static /*const*/ String sel_soundUnfilteredFileTypes;
    public static /*const*/ String sel_setSelectedTextAttributes_1;
    public static /*const*/ String sel_setLeadingOffset_1;
    public static /*const*/ String sel_scrollToPoint_1;
    public static /*const*/ String sel_lastPathComponent;
    public static /*const*/ String sel_lossyCString;
    public static /*const*/ String sel_registerServicesMenuSendTypes_1returnTypes_1;
    public static /*const*/ String sel_keyDown_1;
    public static /*const*/ String sel_setWidthTracksTextView_1;
    public static /*const*/ String sel_incrementBy_1;
    public static /*const*/ String sel_moveWordForward_1;
    public static /*const*/ String sel_dataWithContentsOfMappedFile_1;
    public static /*const*/ String sel_socket;
    public static /*const*/ String sel_EPSOperationWithView_1insideRect_1toData_1printInfo_1;
    public static /*const*/ String sel_width;
    public static /*const*/ String sel_capabilityMask;
    public static /*const*/ String sel_setBezeled_1;
    public static /*const*/ String sel_currentMode;
    public static /*const*/ String sel_sliderType;
    public static /*const*/ String sel_fileIsAppendOnly;
    public static /*const*/ String sel_isAutomaticLinkDetectionEnabled;
    public static /*const*/ String sel_setBoundsOrigin_1;
    public static /*const*/ String sel_selectionHighlightStyle;
    public static /*const*/ String sel_registerName_1;
    public static /*const*/ String sel_moveWordRightAndModifySelection_1;
    public static /*const*/ String sel_setCharacters_1;
    public static /*const*/ String sel_setWordFieldStringValue_1;
    public static /*const*/ String sel_reverseObjectEnumerator;
    public static /*const*/ String sel_encodeByrefObject_1;
    public static /*const*/ String sel_defaultDecimalNumberHandler;
    public static /*const*/ String sel_isEntryAcceptable_1;
    public static /*const*/ String sel_orderWindow_1relativeTo_1;
    public static /*const*/ String sel_writablePasteboardTypes;
    public static /*const*/ String sel_addTrackingRect_1owner_1userData_1assumeInside_1;
    public static /*const*/ String sel_setPathComponentCells_1;
    public static /*const*/ String sel_timeZoneWithName_1;
    public static /*const*/ String sel_setAutosaveTableColumns_1;
    public static /*const*/ String sel_orPredicateWithSubpredicates_1;
    public static /*const*/ String sel_isEqualToDictionary_1;
    public static /*const*/ String sel_bottomMargin;
    public static /*const*/ String sel_initWithYear_1month_1day_1hour_1minute_1second_1timeZone_1;
    public static /*const*/ String sel_scrollColumnsLeftBy_1;
    public static /*const*/ String sel_initWithContentsOfURL_1error_1;
    public static /*const*/ String sel_setTabViewType_1;
    public static /*const*/ String sel_initWithFloat_1;
    public static /*const*/ String sel_attributedStringForObjectValue_1withDefaultAttributes_1;
    public static /*const*/ String sel_sharedGlyphGenerator;
    public static /*const*/ String sel_maximumRangeOfUnit_1;
    public static /*const*/ String sel_docFormatFromRange_1documentAttributes_1;
    public static /*const*/ String sel_initWithBitmapImageRep_1;
    public static /*const*/ String sel_mnemonic;
    public static /*const*/ String sel_prefersColorMatch;
    public static /*const*/ String sel_fileSystemAttributesAtPath_1;
    public static /*const*/ String sel_rotateByRadians_1;
    public static /*const*/ String sel_createConversationForConnection_1;
    public static /*const*/ String sel_setWindow_1;
    public static /*const*/ String sel_addFontDescriptors_1toCollection_1;
    public static /*const*/ String sel_setMark_1;
    public static /*const*/ String sel_terminate;
    public static /*const*/ String sel_setTickMarkPosition_1;
    public static /*const*/ String sel_setIgnoresMouseEvents_1;
    public static /*const*/ String sel_pointerArrayWithStrongObjects;
    public static /*const*/ String sel_intersectsHashTable_1;
    public static /*const*/ String sel_initWithTransform_1;
    public static /*const*/ String sel_deviceRGBColorSpace;
    public static /*const*/ String sel_currentDiskUsage;
    public static /*const*/ String sel_writeToFile_1ofType_1;
    public static /*const*/ String sel_unionSet_1;
    public static /*const*/ String sel_bitmapFormat;
    public static /*const*/ String sel_moveItemAtPath_1toPath_1error_1;
    public static /*const*/ String sel_tableView;
    public static /*const*/ String sel_performSelectorOnMainThread_1withObject_1waitUntilDone_1modes_1;
    public static /*const*/ String sel_initAndTestWithTests_1;
    public static /*const*/ String sel_setVerticalMotionCanBeginDrag_1;
    public static /*const*/ String sel_documentClassNames;
    public static /*const*/ String sel_setShadow_1;
    public static /*const*/ String sel_beginLineWithGlyphAtIndex_1;
    public static /*const*/ String sel_predicateWithSubstitutionVariables_1;
    public static /*const*/ String sel_EPSOperationWithView_1insideRect_1toPath_1printInfo_1;
    public static /*const*/ String sel_startSubelementIndex;
    public static /*const*/ String sel_sleepUntilDate_1;
    public static /*const*/ String sel_menuForEvent_1;
    public static /*const*/ String sel_disabledControlTextColor;
    public static /*const*/ String sel_addRegularFileWithContents_1preferredFilename_1;
    public static /*const*/ String sel_setTakesTitleFromPreviousColumn_1;
    public static /*const*/ String sel_removeSelectionIndexes_1;
    public static /*const*/ String sel_resizedColumn;
    public static /*const*/ String sel_host;
    public static /*const*/ String sel_setDefaultAttachmentScaling_1;
    public static /*const*/ String sel_boundingRectWithSize_1options_1;
    public static /*const*/ String sel_magentaColor;
    public static /*const*/ String sel_performDefaultImplementation;
    public static /*const*/ String sel_getPeriodicDelay_1interval_1;
    public static /*const*/ String sel_RTFFromRange_1;
    public static /*const*/ String sel_setStringValue_1;
    public static /*const*/ String sel_setPaletteLabel_1;
    public static /*const*/ String sel_years_1months_1days_1hours_1minutes_1seconds_1sinceDate_1;
    public static /*const*/ String sel_initWithFormat_1arguments_1;
    public static /*const*/ String sel_firstUnlaidCharacterIndex;
    public static /*const*/ String sel_panelSelectionDidChange_1;
    public static /*const*/ String sel_typesFilterableTo_1;
    public static /*const*/ String sel_selectPreviousTabViewItem_1;
    public static /*const*/ String sel_URLProtocol_1didReceiveResponse_1cacheStoragePolicy_1;
    public static /*const*/ String sel_loadView;
    public static /*const*/ String sel_setPositiveSuffix_1;
    public static /*const*/ String sel_setSizeMode_1;
    public static /*const*/ String sel_addValue_1forHTTPHeaderField_1;
    public static /*const*/ String sel_replacementObjectForPortCoder_1;
    public static /*const*/ String sel_cycleToNextInputLanguage_1;
    public static /*const*/ String sel_setContentMinSize_1;
    public static /*const*/ String sel_convertWeight_1ofFont_1;
    public static /*const*/ String sel_code;
    public static /*const*/ String sel_TIFFRepresentationUsingCompression_1factor_1;
    public static /*const*/ String sel_setSelector_1;
    public static /*const*/ String sel_URLHandleResourceDidCancelLoading_1;
    public static /*const*/ String sel_setTag_1forSegment_1;
    public static /*const*/ String sel_viewFrameChanged_1;
    public static /*const*/ String sel_attachmentCell;
    public static /*const*/ String sel_removeStatusItem_1;
    public static /*const*/ String sel_pathForAuxiliaryExecutable_1;
    public static /*const*/ String sel_fileURL;
    public static /*const*/ String sel_drawerShouldOpen_1;
    public static /*const*/ String sel_initForWritingWithMutableData_1;
    public static /*const*/ String sel_content;
    public static /*const*/ String sel_addSubview_1;
    public static /*const*/ String sel_StringByReplacingOccurrencesOfString_1withString_1;
    public static /*const*/ String sel_StringWithFileSystemRepresentation_1length_1;
    public static /*const*/ String sel_isVerticallyCentered;
    public static /*const*/ String sel_setVerticallyCentered_1;
    public static /*const*/ String sel_selectPrevious_1;
    public static /*const*/ String sel_addTemporaryAttributes_1forCharacterRange_1;
    public static /*const*/ String sel_tabState;
    public static /*const*/ String sel_defaultQueue;
    public static /*const*/ String sel_showsControlCharacters;
    public static /*const*/ String sel_indexOfObject_1;
    public static /*const*/ String sel_shadow;
    public static /*const*/ String sel_fontMenu_1;
    public static /*const*/ String sel_movePath_1toPath_1handler_1;
    public static /*const*/ String sel_setDictionary_1;
    public static /*const*/ String sel_verticalLineScroll;
    public static /*const*/ String sel_showsAlpha;
    public static /*const*/ String sel_removeObserver_1;
    public static /*const*/ String sel_isFieldEditor;
    public static /*const*/ String sel_fileHandleForWriting;
    public static /*const*/ String sel_contentsAtPath_1;
    public static /*const*/ String sel_writeProperty_1forKey_1;
    public static /*const*/ String sel_drawWithRect_1options_1attributes_1;
    public static /*const*/ String sel_initWithName_1;
    public static /*const*/ String sel_getFileSystemInfoForPath_1isRemovable_1isWritable_1isUnmountable_1description_1type_1;
    public static /*const*/ String sel_setOpenGLContext_1;
    public static /*const*/ String sel_hasSubmenu;
    public static /*const*/ String sel_rangeOfTextTable_1atIndex_1;
    public static /*const*/ String sel_connection_1willCacheResponse_1;
    public static /*const*/ String sel_automaticallyRearrangesObjects;
    public static /*const*/ String sel_registerCommandDescription_1;
    public static /*const*/ String sel_indexOfSelectedItem;
    public static /*const*/ String sel_underline_1;
    public static /*const*/ String sel_beginModalSessionForWindow_1relativeToWindow_1;
    public static /*const*/ String sel_initWithData_1options_1documentAttributes_1error_1;
    public static /*const*/ String sel_revert_1;
    public static /*const*/ String sel_displayableSubpredicatesOfPredicate_1;
    public static /*const*/ String sel_dataWithData_1;
    public static /*const*/ String sel_scaleXBy_1yBy_1;
    public static /*const*/ String sel_decodeBoolForKey_1;
    public static /*const*/ String sel_itemTitles;
    public static /*const*/ String sel_removeFontDescriptor_1fromCollection_1;
    public static /*const*/ String sel_isContinuousSpellCheckingEnabled;
    public static /*const*/ String sel_paragraphSpacingBeforeGlyphAtIndex_1withProposedLineFragmentRect_1;
    public static /*const*/ String sel_ignoreSpelling_1;
    public static /*const*/ String sel_crosshairCursor;
    public static /*const*/ String sel_setSelected_1;
    public static /*const*/ String sel_RTFDFromRange_1;
    public static /*const*/ String sel_setCanSelectHiddenExtension_1;
    public static /*const*/ String sel_setNestingMode_1;
    public static /*const*/ String sel_addItemsWithObjectValues_1;
    public static /*const*/ String sel_setContentFilters_1;
    public static /*const*/ String sel_setAutorepeat_1;
    public static /*const*/ String sel_resizeWithOldSuperviewSize_1;
    public static /*const*/ String sel_areCursorRectsEnabled;
    public static /*const*/ String sel_browser_1selectCellWithString_1inColumn_1;
    public static /*const*/ String sel_setLastColumn_1;
    public static /*const*/ String sel_isContextHelpModeActive;
    public static /*const*/ String sel_setTitleColor_1;
    public static /*const*/ String sel_initWithBytes_1length_1;
    public static /*const*/ String sel_animation_1valueForProgress_1;
    public static /*const*/ String sel_fillColor;
    public static /*const*/ String sel_completionsForPartialWordRange_1inString_1language_1inSpellDocumentWithTag_1;
    public static /*const*/ String sel_typeForContentsOfURL_1error_1;
    public static /*const*/ String sel_setShowPanels_1;
    public static /*const*/ String sel_outlineView_1dataCellForTableColumn_1item_1;
    public static /*const*/ String sel_setLineJoinStyle_1;
    public static /*const*/ String sel_cancelPerformSelectorsWithTarget_1;
    public static /*const*/ String sel_nextDaylightSavingTimeTransition;
    public static /*const*/ String sel_setEndSubelementIdentifier_1;
    public static /*const*/ String sel_channelMapping;
    public static /*const*/ String sel_setTitle_1ofColumn_1;
    public static /*const*/ String sel_setHeaderToolTip_1;
    public static /*const*/ String sel_initWithChar_1;
    public static /*const*/ String sel_shouldReportNamespacePrefixes;
    public static /*const*/ String sel_decomposedStringWithCompatibilityMapping;
    public static /*const*/ String sel_undoActionName;
    public static /*const*/ String sel_attachColorList_1;
    public static /*const*/ String sel_cancelPreviousPerformRequestsWithTarget_1;
    public static /*const*/ String sel_addToolTipRect_1owner_1userData_1;
    public static /*const*/ String sel_isOptionalArgumentWithName_1;
    public static /*const*/ String sel_fileHandleForReading;
    public static /*const*/ String sel_removeConnection_1fromRunLoop_1forMode_1;
    public static /*const*/ String sel_controlTextDidBeginEditing_1;
    public static /*const*/ String sel_closePath;
    public static /*const*/ String sel_isPlaying;
    public static /*const*/ String sel_matrixClass;
    public static /*const*/ String sel_doCommandBySelector_1client_1;
    public static /*const*/ String sel_appendBytes_1length_1;
    public static /*const*/ String sel_lightGrayColor;
    public static /*const*/ String sel_menuRepresentation;
    public static /*const*/ String sel_dateWithString_1calendarFormat_1;
    public static /*const*/ String sel_decodeClassName_1asClassName_1;
    public static /*const*/ String sel_deleteToBeginningOfParagraph_1;
    public static /*const*/ String sel_runModalForDirectory_1file_1;
    public static /*const*/ String sel_inverseForRelationshipKey_1;
    public static /*const*/ String sel_cancelLoadInBackground;
    public static /*const*/ String sel_setLeftMargin_1;
    public static /*const*/ String sel_tabStopType;
    public static /*const*/ String sel_replaceCharactersInRange_1withRTF_1;
    public static /*const*/ String sel_drawInRect_1fromRect_1operation_1fraction_1;
    public static /*const*/ String sel_sound;
    public static /*const*/ String sel_localizedRecoverySuggestion;
    public static /*const*/ String sel_getInputStream_1outputStream_1;
    public static /*const*/ String sel_defaultType;
    public static /*const*/ String sel_sharedFontPanel;
    public static /*const*/ String sel_fixParagraphStyleAttributeInRange_1;
    public static /*const*/ String sel_textColor;
    public static /*const*/ String sel_noteFileSystemChanged;
    public static /*const*/ String sel_setObject_1forKey_1;
    public static /*const*/ String sel_drawAtPoint_1;
    public static /*const*/ String sel_tableView_1shouldSelectTableColumn_1;
    public static /*const*/ String sel_deleteWordBackward_1;
    public static /*const*/ String sel_pipe;
    public static /*const*/ String sel_resetStandardUserDefaults;
    public static /*const*/ String sel_orderFrontSpacingPanel_1;
    public static /*const*/ String sel_setUsesFontPanel_1;
    public static /*const*/ String sel_saveToURL_1ofType_1forSaveOperation_1delegate_1didSaveSelector_1contextInfo_1;
    public static /*const*/ String sel_linkPath_1toPath_1handler_1;
    public static /*const*/ String sel_addTimeInterval_1;
    public static /*const*/ String sel_formattingDictionary;
    public static /*const*/ String sel_ignoresMultiClick;
    public static /*const*/ String sel_encodeValuesOfObjCTypes_1;
    public static /*const*/ String sel_indexAtPosition_1;
    public static /*const*/ String sel_autoresizesSubviews;
    public static /*const*/ String sel_takesTitleFromPreviousColumn;
    public static /*const*/ String sel_titlePosition;
    public static /*const*/ String sel_currentAppleEvent;
    public static /*const*/ String sel_valueForDimension_1;
    public static /*const*/ String sel_printDocumentWithSettings_1showPrintPanel_1delegate_1didPrintSelector_1contextInfo_1;
    public static /*const*/ String sel_isZoomable;
    public static /*const*/ String sel_setNeedsDisplay;
    public static /*const*/ String sel_initWithColors_1;
    public static /*const*/ String sel_isSubclassOfClass_1;
    public static /*const*/ String sel_adobeRGB1998ColorSpace;
    public static /*const*/ String sel_textView_1willChangeSelectionFromCharacterRange_1toCharacterRange_1;
    public static /*const*/ String sel_useAllLigatures_1;
    public static /*const*/ String sel_setFrameUsingName_1force_1;
    public static /*const*/ String sel_percentSymbol;
    public static /*const*/ String sel_addRepresentations_1;
    public static /*const*/ String sel_writeEPSInsideRect_1toPasteboard_1;
    public static /*const*/ String sel_systemFontSize;
    public static /*const*/ String sel_canRemoveAllRows;
    public static /*const*/ String sel_endLineWithGlyphRange_1;
    public static /*const*/ String sel_maxItemSize;
    public static /*const*/ String sel_setImageScaling_1forSegment_1;
    public static /*const*/ String sel_reloadDefaultFontFamilies;
    public static /*const*/ String sel_removeRow_1;
    public static /*const*/ String sel_contentSize;
    public static /*const*/ String sel_setValueTransformer_1forName_1;
    public static /*const*/ String sel_defaultCStringEncoding;
    public static /*const*/ String sel_setMaxNumberOfRows_1;
    public static /*const*/ String sel_continueWithoutCredentialForAuthenticationChallenge_1;
    public static /*const*/ String sel_encodeArrayOfObjCType_1count_1at_1;
    public static /*const*/ String sel_tabStops;
    public static /*const*/ String sel_altIncrementValue;
    public static /*const*/ String sel_removeAttribute_1range_1;
    public static /*const*/ String sel_rightExpressionAttributeType;
    public static /*const*/ String sel_setAutoresizesAllColumnsToFit_1;
    public static /*const*/ String sel_removeAllToolTips;
    public static /*const*/ String sel_setNotANumberSymbol_1;
    public static /*const*/ String sel_setMinWidth_1;
    public static /*const*/ String sel_setDefaultTimeZone_1;
    public static /*const*/ String sel_setTabStops_1;
    public static /*const*/ String sel_textView_1draggedCell_1inRect_1event_1;
    public static /*const*/ String sel_PDFOperationWithView_1insideRect_1toData_1;
    public static /*const*/ String sel_outlineView_1selectionIndexesForProposedSelection_1;
    public static /*const*/ String sel_initWithContentsOfURL_1;
    public static /*const*/ String sel_setBidiProcessingEnabled_1;
    public static /*const*/ String sel_selectToMark_1;
    public static /*const*/ String sel_newlineCharacterSet;
    public static /*const*/ String sel_accessibilitySetOverrideValue_1forAttribute_1;
    public static /*const*/ String sel_setPostsFrameChangedNotifications_1;
    public static /*const*/ String sel_cellPrototype;
    public static /*const*/ String sel_unmarkText;
    public static /*const*/ String sel_displayValuesKeyPath;
    public static /*const*/ String sel_orderFrontStylesPanel_1;
    public static /*const*/ String sel_getBuffer_1length_1;
    public static /*const*/ String sel_calcDrawInfo_1;
    public static /*const*/ String sel_initWithUTF8String_1;
    public static /*const*/ String sel_deselectAllCells;
    public static /*const*/ String sel_checkGrammarOfString_1startingAt_1language_1wrap_1inSpellDocumentWithTag_1details_1;
    public static /*const*/ String sel_poolCountHighWaterResolution;
    public static /*const*/ String sel_canInitWithData_1;
    public static /*const*/ String sel_setHasVerticalScroller_1;
    public static /*const*/ String sel_flushHostCache;
    public static /*const*/ String sel_toolbarDefaultItemIdentifiers_1;
    public static /*const*/ String sel_setSearchButtonCell_1;
    public static /*const*/ String sel_defaultButtonCell;
    public static /*const*/ String sel_sizeLastColumnToFit;
    public static /*const*/ String sel_addColumn;
    public static /*const*/ String sel_failureResponse;
    public static /*const*/ String sel_insertTabIgnoringFieldEditor_1;
    public static /*const*/ String sel_locationForGlyphAtIndex_1;
    public static /*const*/ String sel_insertContainerBreak_1;
    public static /*const*/ String sel_setAutosizesCells_1;
    public static /*const*/ String sel_isEditable;
    public static /*const*/ String sel_path;
    public static /*const*/ String sel_setStringValue_1resolvingEntities_1;
    public static /*const*/ String sel_readFileContentsType_1toFile_1;
    public static /*const*/ String sel_fileExtensionHidden;
    public static /*const*/ String sel_setTextureImageToPixelBuffer_1colorBuffer_1;
    public static /*const*/ String sel_setFilename_1;
    public static /*const*/ String sel_callStackReturnAddresses;
    public static /*const*/ String sel_blocksOtherRecognizers;
    public static /*const*/ String sel_pixelBuffer;
    public static /*const*/ String sel_initWithStartingColor_1endingColor_1;
    public static /*const*/ String sel_indexOfObjectIdenticalTo_1inRange_1;
    public static /*const*/ String sel_duration;
    public static /*const*/ String sel_matchForPredicate_1;
    public static /*const*/ String sel_windowDidMiniaturize_1;
    public static /*const*/ String sel_drawWithFrame_1inView_1characterIndex_1layoutManager_1;
    public static /*const*/ String sel_setTwoDigitStartDate_1;
    public static /*const*/ String sel_selectTextAtRow_1column_1;
    public static /*const*/ String sel_splitView_1shouldHideDividerAtIndex_1;
    public static /*const*/ String sel_isExcludedFromWindowsMenu;
    public static /*const*/ String sel_earlierDate_1;
    public static /*const*/ String sel_initWithLeftExpressions_1rightExpressionAttributeType_1modifier_1operators_1options_1;
    public static /*const*/ String sel_minItemSize;
    public static /*const*/ String sel_setSearchMenuTemplate_1;
    public static /*const*/ String sel_rightMouseUp_1;
    public static /*const*/ String sel_stopSpeaking_1;
    public static /*const*/ String sel_getObjectValue_1forString_1errorDescription_1;
    public static /*const*/ String sel_unarchiver_1didDecodeObject_1;
    public static /*const*/ String sel_endSpecifier;
    public static /*const*/ String sel_ascending;
    public static /*const*/ String sel_sharedCoercionHandler;
    public static /*const*/ String sel_textAttributesForPositiveInfinity;
    public static /*const*/ String sel_isEqualToData_1;
    public static /*const*/ String sel_setHighlightMode_1;
    public static /*const*/ String sel_valueWithNonretainedObject_1;
    public static /*const*/ String sel_textAttributesForNotANumber;
    public static /*const*/ String sel_getCFRunLoop;
    public static /*const*/ String sel_invalidateGlyphsForCharacterRange_1changeInLength_1actualCharacterRange_1;
    public static /*const*/ String sel_cachedResponse;
    public static /*const*/ String sel_containerIsRangeContainerObject;
    public static /*const*/ String sel_setLanguage_1;
    public static /*const*/ String sel_loadNibFile_1externalNameTable_1withZone_1;
    public static /*const*/ String sel_offsetInFile;
    public static /*const*/ String sel_initWithRulerView_1markerLocation_1image_1imageOrigin_1;
    public static /*const*/ String sel_commandDescriptionWithAppleEventClass_1andAppleEventCode_1;
    public static /*const*/ String sel_detachDrawingThread_1toTarget_1withObject_1;
    public static /*const*/ String sel_outlineView_1shouldShowCellExpansionForTableColumn_1item_1;
    public static /*const*/ String sel_catalogNameComponent;
    public static /*const*/ String sel_monthSymbols;
    public static /*const*/ String sel_invalidateShadow;
    public static /*const*/ String sel_waitUntilDate_1;
    public static /*const*/ String sel_languageLevel;
    public static /*const*/ String sel_XMLData;
    public static /*const*/ String sel_textView_1shouldChangeTextInRanges_1replacementStrings_1;
    public static /*const*/ String sel_initWithPointerFunctions_1;
    public static /*const*/ String sel_initWithTextureTarget_1textureInternalFormat_1textureMaxMipMapLevel_1pixelsWide_1pixelsHigh_1;
    public static /*const*/ String sel_classForClassName_1;
    public static /*const*/ String sel_decodeInt64ForKey_1;
    public static /*const*/ String sel_StringWithSavedFrame;
    public static /*const*/ String sel_writeRTFDToFile_1atomically_1;
    public static /*const*/ String sel_initWithLocal_1connection_1;
    public static /*const*/ String sel_sendBeforeDate_1msgid_1components_1from_1reserved_1;
    public static /*const*/ String sel_playsEveryFrame;
    public static /*const*/ String sel_prependTransform_1;
    public static /*const*/ String sel_setUsesWeakReadAndWriteBarriers_1;
    public static /*const*/ String sel_isContinuous;
    public static /*const*/ String sel_andPredicateWithSubpredicates_1;
    public static /*const*/ String sel_cookieWithProperties_1;
    public static /*const*/ String sel_builtInPlugInsPath;
    public static /*const*/ String sel_performSelector_1onThread_1withObject_1waitUntilDone_1;
    public static /*const*/ String sel_sharedDocumentController;
    public static /*const*/ String sel_setNeedsSizing_1;
    public static /*const*/ String sel_selectorForCommand_1;
    public static /*const*/ String sel_displayIfNeededInRectIgnoringOpacity_1;
    public static /*const*/ String sel_draggingPasteboard;
    public static /*const*/ String sel_unscriptRange_1;
    public static /*const*/ String sel_launchApplication_1;
    public static /*const*/ String sel_inputClientBecomeActive_1;
    public static /*const*/ String sel_getFirstUnlaidCharacterIndex_1glyphIndex_1;
    public static /*const*/ String sel_initWithContentsOfURL_1options_1error_1;
    public static /*const*/ String sel_createSymbolicLinkAtPath_1withDestinationPath_1error_1;
    public static /*const*/ String sel_accessibilityAttributeValue_1forParameter_1;
    public static /*const*/ String sel_setPlaceholderAttributedString_1;
    public static /*const*/ String sel_initWithIndex_1;
    public static /*const*/ String sel_readFromURL_1ofType_1error_1;
    public static /*const*/ String sel_preferredFilename;
    public static /*const*/ String sel_smartInsertDeleteEnabled;
    public static /*const*/ String sel_horizontalLineScroll;
    public static /*const*/ String sel_doDoubleClick_1;
    public static /*const*/ String sel_fontDescriptorWithFace_1;
    public static /*const*/ String sel_pointerArrayWithPointerFunctions_1;
    public static /*const*/ String sel_defaultDate;
    public static /*const*/ String sel_typesetterBehavior;
    public static /*const*/ String sel_setAllowsNonContiguousLayout_1;
    public static /*const*/ String sel_control_1didFailToFormatString_1errorDescription_1;
    public static /*const*/ String sel_isBaseFont;
    public static /*const*/ String sel_removeDescriptorWithKeyword_1;
    public static /*const*/ String sel_subStringFromIndex_1;
    public static /*const*/ String sel_componentsFromLocaleIdentifier_1;
    public static /*const*/ String sel_setUsesFeedbackWindow_1;
    public static /*const*/ String sel_setAnimates_1;
    public static /*const*/ String sel_initWithDomain_1code_1userInfo_1;
    public static /*const*/ String sel_setContentView_1;
    public static /*const*/ String sel_allowedFileTypes;
    public static /*const*/ String sel_leftExpressions;
    public static /*const*/ String sel_isStandalone;
    public static /*const*/ String sel_floatForKey_1inTable_1;
    public static /*const*/ String sel_notANumber;
    public static /*const*/ String sel_updateFromPMPrintSettings;
    public static /*const*/ String sel_wantsToTrackMouse;
    public static /*const*/ String sel_initWithName_1reason_1userInfo_1;
    public static /*const*/ String sel_prepareOpenGL;
    public static /*const*/ String sel_setAttributedStringForNil_1;
    public static /*const*/ String sel_sizeToFit;
    public static /*const*/ String sel_setSortDescriptorPrototype_1;
    public static /*const*/ String sel_canHide;
    public static /*const*/ String sel_replacementObjectForArchiver_1;
    public static /*const*/ String sel_purpleColor;
    public static /*const*/ String sel_setProperty_1forKey_1;
    public static /*const*/ String sel_separatorItem;
    public static /*const*/ String sel_loadedCellAtRow_1column_1;
    public static /*const*/ String sel_containerSpecifier;
    public static /*const*/ String sel_draggingSourceOperationMaskForLocal_1;
    public static /*const*/ String sel_willPresentError_1;
    public static /*const*/ String sel_strikethroughGlyphRange_1strikethroughType_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1;
    public static /*const*/ String sel_elementWithName_1StringValue_1;
    public static /*const*/ String sel_unsignedCharValue;
    public static /*const*/ String sel_rangeOfComposedCharacterSequencesForRange_1;
    public static /*const*/ String sel_activate_1;
    public static /*const*/ String sel_controlView;
    public static /*const*/ String sel_cachePolicy;
    public static /*const*/ String sel_fontAttributesInRange_1;
    public static /*const*/ String sel_setPreservesSelection_1;
    public static /*const*/ String sel_unscript_1;
    public static /*const*/ String sel_deltaZ;
    public static /*const*/ String sel_connection_1handleRequest_1;
    public static /*const*/ String sel_caseSensitive;
    public static /*const*/ String sel_tabViewItemAtPoint_1;
    public static /*const*/ String sel_setTextAttributesForNegativeValues_1;
    public static /*const*/ String sel_underlineGlyphRange_1underlineType_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1;
    public static /*const*/ String sel_classForCoder;
    public static /*const*/ String sel_setContent_1;
    public static /*const*/ String sel_getLineStart_1end_1contentsEnd_1forRange_1;
    public static /*const*/ String sel_removeRowsAtIndexes_1includeSubrows_1;
    public static /*const*/ String sel_tokenFieldCell_1styleForRepresentedObject_1;
    public static /*const*/ String sel_setToolTip_1;
    public static /*const*/ String sel_titleHeight;
    public static /*const*/ String sel_setShowsStateBy_1;
    public static /*const*/ String sel_URLWithString_1relativeToURL_1;
    public static /*const*/ String sel_fileSystemRepresentationWithPath_1;
    public static /*const*/ String sel_setRate_1;
    public static /*const*/ String sel_extraLineFragmentTextContainer;
    public static /*const*/ String sel_insertObjects_1atArrangedObjectIndexes_1;
    public static /*const*/ String sel_fontDescriptorWithSymbolicTraits_1;
    public static /*const*/ String sel_topMargin;
    public static /*const*/ String sel_tokenField_1representedObjectForEditingString_1;
    public static /*const*/ String sel_drawInsertionPointInRect_1color_1turnedOn_1;
    public static /*const*/ String sel_fontNamed_1hasTraits_1;
    public static /*const*/ String sel_revertToSavedFromFile_1ofType_1;
    public static /*const*/ String sel_cString;
    public static /*const*/ String sel_markerForItemNumber_1;
    public static /*const*/ String sel_mapTableWithWeakToStrongObjects;
    public static /*const*/ String sel_autosaveExpandedItems;
    public static /*const*/ String sel_setMiterLimit_1;
    public static /*const*/ String sel_indentationLevel;
    public static /*const*/ String sel_fileHandleForUpdatingAtPath_1;
    public static /*const*/ String sel_fontWithDescriptor_1textTransform_1;
    public static /*const*/ String sel_selectLine_1;
    public static /*const*/ String sel_deleteForward_1;
    public static /*const*/ String sel_getAdvancements_1forPackedGlyphs_1length_1;
    public static /*const*/ String sel_usesRuler;
    public static /*const*/ String sel_performClose_1;
    public static /*const*/ String sel_trackRect;
    public static /*const*/ String sel_setFont_1;
    public static /*const*/ String sel_conformsToProtocol_1;
    public static /*const*/ String sel_appendBezierPathWithPoints_1count_1;
    public static /*const*/ String sel_defaultLineHeightForFont_1;
    public static /*const*/ String sel_mouse_1inRect_1;
    public static /*const*/ String sel_portCoderWithReceivePort_1sendPort_1components_1;
    public static /*const*/ String sel_inputClientDisabled_1;
    public static /*const*/ String sel_widthForSegment_1;
    public static /*const*/ String sel_performSelector_1;
    public static /*const*/ String sel_recalculateKeyViewLoop;
    public static /*const*/ String sel_initWithDrawSelector_1delegate_1;
    public static /*const*/ String sel_breakUndoCoalescing;
    public static /*const*/ String sel_font;
    public static /*const*/ String sel_fontDescriptorWithSize_1;
    public static /*const*/ String sel_insertItemWithTitle_1atIndex_1;
    public static /*const*/ String sel_contentAspectRatio;
    public static /*const*/ String sel_currentHandler;
    public static /*const*/ String sel_sharedAppleEventManager;
    public static /*const*/ String sel_pathForResource_1ofType_1;
    public static /*const*/ String sel_initWithRequest_1cachedResponse_1client_1;
    public static /*const*/ String sel_isTitled;
    public static /*const*/ String sel_drawerWillOpen_1;
    public static /*const*/ String sel_screenFont;
    public static /*const*/ String sel_principalClass;
    public static /*const*/ String sel_pathControl_1willDisplayOpenPanel_1;
    public static /*const*/ String sel_setGroupingSeparator_1;
    public static /*const*/ String sel_fontWithDescriptor_1size_1;
    public static /*const*/ String sel_glyphInfoWithCharacterIdentifier_1collection_1baseString_1;
    public static /*const*/ String sel_movieUnfilteredFileTypes;
    public static /*const*/ String sel_portList;
    public static /*const*/ String sel_tokenField_1readFromPasteboard_1;
    public static /*const*/ String sel_setEndSpecifier_1;
    public static /*const*/ String sel_textView_1willDisplayToolTip_1forCharacterAtIndex_1;
    public static /*const*/ String sel_applicationIconImage;
    public static /*const*/ String sel_target;
    public static /*const*/ String sel_replaceGlyphAtIndex_1withGlyph_1;
    public static /*const*/ String sel_borderColorForEdge_1;
    public static /*const*/ String sel_timeIntervalSinceDate_1;
    public static /*const*/ String sel_pathsForResourcesOfType_1inDirectory_1forLocalization_1;
    public static /*const*/ String sel_bitmapData;
    public static /*const*/ String sel_redComponent;
    public static /*const*/ String sel_numberOfVisibleItems;
    public static /*const*/ String sel_selectCell_1;
    public static /*const*/ String sel_applicationWillHide_1;
    public static /*const*/ String sel_characterIsMember_1;
    public static /*const*/ String sel_setArrowsPosition_1;
    public static /*const*/ String sel_minusSign;
    public static /*const*/ String sel_canSpawnSeparateThread;
    public static /*const*/ String sel_setContinuous_1;
    public static /*const*/ String sel_addSymbolicLinkWithDestination_1preferredFilename_1;
    public static /*const*/ String sel_destinationOfSymbolicLinkAtPath_1error_1;
    public static /*const*/ String sel_runUntilDate_1;
    public static /*const*/ String sel_StringByAbbreviatingWithTildeInPath;
    public static /*const*/ String sel_drawerWillResizeContents_1toSize_1;
    public static /*const*/ String sel_imageRectForBounds_1;
    public static /*const*/ String sel_indexGreaterThanIndex_1;
    public static /*const*/ String sel_setSelectionFrom_1to_1anchor_1highlight_1;
    public static /*const*/ String sel_unsignedIntegerValue;
    public static /*const*/ String sel_focusView;
    public static /*const*/ String sel_longCharacterIsMember_1;
    public static /*const*/ String sel_groupingSeparator;
    public static /*const*/ String sel_depthLimit;
    public static /*const*/ String sel_attributesAtIndex_1longestEffectiveRange_1inRange_1;
    public static /*const*/ String sel_setAcceptsArrowKeys_1;
    public static /*const*/ String sel_isGreaterThanOrEqualTo_1;
    public static /*const*/ String sel_maxContentSize;
    public static /*const*/ String sel_setParentWindow_1;
    public static /*const*/ String sel_importsGraphics;
    public static /*const*/ String sel_setPaddingPosition_1;
    public static /*const*/ String sel_yearOfCommonEra;
    public static /*const*/ String sel_cells;
    public static /*const*/ String sel_cyanComponent;
    public static /*const*/ String sel_documentClassForType_1;
    public static /*const*/ String sel_setSelectionHighlightStyle_1;
    public static /*const*/ String sel_addWindowController_1;
    public static /*const*/ String sel_initWithXMLString_1error_1;
    public static /*const*/ String sel_authenticateComponents_1withData_1;
    public static /*const*/ String sel_traitsOfFont_1;
    public static /*const*/ String sel_timeIntervalSinceReferenceDate;
    public static /*const*/ String sel_orderFrontCharacterPalette_1;
    public static /*const*/ String sel_setServicesProvider_1;
    public static /*const*/ String sel_setMessage_1;
    public static /*const*/ String sel_msgid;
    public static /*const*/ String sel_beginUndoGrouping;
    public static /*const*/ String sel_RTFDFromRange_1documentAttributes_1;
    public static /*const*/ String sel_selectedItem;
    public static /*const*/ String sel_addTabStop_1;
    public static /*const*/ String sel_scrollRect_1by_1;
    public static /*const*/ String sel_icon;
    public static /*const*/ String sel_setValue_1forUndefinedKey_1;
    public static /*const*/ String sel_decodeFloatForKey_1;
    public static /*const*/ String sel_commentURL;
    public static /*const*/ String sel_shortStandaloneMonthSymbols;
    public static /*const*/ String sel_browser_1titleOfColumn_1;
    public static /*const*/ String sel_exit;
    public static /*const*/ String sel_deselectAll_1;
    public static /*const*/ String sel_canRemove;
    public static /*const*/ String sel_proxyType;
    public static /*const*/ String sel_shouldCloseDocument;
    public static /*const*/ String sel_setMinimumLineHeight_1;
    public static /*const*/ String sel_grayColor;
    public static /*const*/ String sel_suspend;
    public static /*const*/ String sel_printJobTitle;
    public static /*const*/ String sel_fileHandleWithStandardOutput;
    public static /*const*/ String sel_objCType;
    public static /*const*/ String sel_maximumIntegerDigits;
    public static /*const*/ String sel_initWithKey_1ascending_1;
    public static /*const*/ String sel_paramDescriptorForKeyword_1;
    public static /*const*/ String sel_cookiesForURL_1;
    public static /*const*/ String sel_currentTextContainer;
    public static /*const*/ String sel_removeAllCachedResponses;
    public static /*const*/ String sel_setAllHTTPHeaderFields_1;
    public static /*const*/ String sel_setShortQuarterSymbols_1;
    public static /*const*/ String sel_removeItemWithObjectValue_1;
    public static /*const*/ String sel_reloadColumn_1;
    public static /*const*/ String sel_initWithData_1;
    public static /*const*/ String sel_textDidEndEditing_1;
    public static /*const*/ String sel_descriptorForKeyword_1;
    public static /*const*/ String sel_gState;
    public static /*const*/ String sel_setCellClass_1;
    public static /*const*/ String sel_requestUserAttention_1;
    public static /*const*/ String sel_disableUndoRegistration;
    public static /*const*/ String sel_currencySymbol;
    public static /*const*/ String sel_defaultWritingDirectionForLanguage_1;
    public static /*const*/ String sel_selectedCellInColumn_1;
    public static /*const*/ String sel_spellServer_1didForgetWord_1inLanguage_1;
    public static /*const*/ String sel_initWithType_1error_1;
    public static /*const*/ String sel_editedRow;
    public static /*const*/ String sel_expressionForUnionSet_1with_1;
    public static /*const*/ String sel_verticalMotionCanBeginDrag;
    public static /*const*/ String sel_selectNextKeyView_1;
    public static /*const*/ String sel_lowercaseString;
    public static /*const*/ String sel_intercellSpacing;
    public static /*const*/ String sel_selectedItemIdentifier;
    public static /*const*/ String sel_getIndexes_1;
    public static /*const*/ String sel_contentRect;
    public static /*const*/ String sel_addObjects_1;
    public static /*const*/ String sel_selectedRowIndexes;
    public static /*const*/ String sel_setSecond_1;
    public static /*const*/ String sel_setIgnoresMultiClick_1;
    public static /*const*/ String sel_hasMemberInPlane_1;
    public static /*const*/ String sel_setClientView_1;
    public static /*const*/ String sel_setInitialFirstResponder_1;
    public static /*const*/ String sel_defaultAnimationForKey_1;
    public static /*const*/ String sel_systemTimeZone;
    public static /*const*/ String sel_pageSizeForPaper_1;
    public static /*const*/ String sel_windowBackgroundColor;
    public static /*const*/ String sel_prepareGState;
    public static /*const*/ String sel_willSetLineFragmentRect_1forGlyphRange_1usedRect_1baselineOffset_1;
    public static /*const*/ String sel_setScriptingProperties_1;
    public static /*const*/ String sel_initWithScrollView_1orientation_1;
    public static /*const*/ String sel_canBecomeVisibleWithoutLogin;
    public static /*const*/ String sel_scrollLineDown_1;
    public static /*const*/ String sel_setServicesMenu_1;
    public static /*const*/ String sel_appleEventCode;
    public static /*const*/ String sel_replaceObjectsInRange_1withObjectsFromArray_1range_1;
    public static /*const*/ String sel_autosizesCells;
    public static /*const*/ String sel_tableView_1toolTipForCell_1rect_1tableColumn_1row_1mouseLocation_1;
    public static /*const*/ String sel_dateWithYear_1month_1day_1hour_1minute_1second_1timeZone_1;
    public static /*const*/ String sel_windowWillResize_1toSize_1;
    public static /*const*/ String sel_initWithUnsignedChar_1;
    public static /*const*/ String sel_suiteForAppleEventCode_1;
    public static /*const*/ String sel_setTrailingOffset_1;
    public static /*const*/ String sel_canBecomeKeyWindow;
    public static /*const*/ String sel_setAnimationBlockingMode_1;
    public static /*const*/ String sel_formUnionWithCharacterSet_1;
    public static /*const*/ String sel_typeForArgumentWithName_1;
    public static /*const*/ String sel_setFileName_1;
    public static /*const*/ String sel_createSymbolicLinkAtPath_1pathContent_1;
    public static /*const*/ String sel_undoMenuTitleForUndoActionName_1;
    public static /*const*/ String sel_dateStyle;
    public static /*const*/ String sel_currentContext;
    public static /*const*/ String sel_dequeueNotificationsMatching_1coalesceMask_1;
    public static /*const*/ String sel_thousandSeparator;
    public static /*const*/ String sel_writeData_1;
    public static /*const*/ String sel_selectedTag;
    public static /*const*/ String sel_drawWithRect_1options_1;
    public static /*const*/ String sel_canonicalLocaleIdentifierFromString_1;
    public static /*const*/ String sel_convertFontTraits_1;
    public static /*const*/ String sel_itemAdded_1;
    public static /*const*/ String sel_scriptErrorString;
    public static /*const*/ String sel_submenuAction_1;
    public static /*const*/ String sel_initWithType_1subpredicates_1;
    public static /*const*/ String sel_subpathsOfDirectoryAtPath_1error_1;
    public static /*const*/ String sel_becomesKeyOnlyIfNeeded;
    public static /*const*/ String sel_displayAllColumns;
    public static /*const*/ String sel_indexOfItemWithSubmenu_1;
    public static /*const*/ String sel_runModalSavePanelForSaveOperation_1delegate_1didSaveSelector_1contextInfo_1;
    public static /*const*/ String sel_setCollectionBehavior_1;
    public static /*const*/ String sel_boundingRectWithSize_1options_1attributes_1;
    public static /*const*/ String sel_valueForAttribute_1;
    public static /*const*/ String sel_attributedStringForNotANumber;
    public static /*const*/ String sel_indicesOfObjectsByEvaluatingObjectSpecifier_1;
    public static /*const*/ String sel_initWithPath_1;
    public static /*const*/ String sel_doCommandBySelector_1;
    public static /*const*/ String sel_numberWithChar_1;
    public static /*const*/ String sel_setAllowsMixedState_1;
    public static /*const*/ String sel_abortEditing;
    public static /*const*/ String sel_context;
    public static /*const*/ String sel_drawerShouldClose_1;
    public static /*const*/ String sel_tabViewDidChangeNumberOfTabViewItems_1;
    public static /*const*/ String sel_focusRingType;
    public static /*const*/ String sel_copyScriptingValue_1forKey_1withProperties_1;
    public static /*const*/ String sel_acceptsFirstMouse_1;
    public static /*const*/ String sel_initWithPosition_1objectSpecifier_1;
    public static /*const*/ String sel_selectionRangeForProposedRange_1granularity_1;
    public static /*const*/ String sel_isNotEqualTo_1;
    public static /*const*/ String sel_encodeRootObject_1;
    public static /*const*/ String sel_hasSuffix_1;
    public static /*const*/ String sel_initWithFontAttributes_1;
    public static /*const*/ String sel_initWithRTFDFileWrapper_1documentAttributes_1;
    public static /*const*/ String sel_miniwindowImage;
    public static /*const*/ String sel_developmentLocalization;
    public static /*const*/ String sel_localizedSummaryItems;
    public static /*const*/ String sel_intValue;
    public static /*const*/ String sel_setReturnValue_1;
    public static /*const*/ String sel_selectedMenuItemColor;
    public static /*const*/ String sel_editColumn_1row_1withEvent_1select_1;
    public static /*const*/ String sel_descriptionWithCalendarFormat_1timeZone_1locale_1;
    public static /*const*/ String sel_itemHeight;
    public static /*const*/ String sel_application_1openFiles_1;
    public static /*const*/ String sel_window;
    public static /*const*/ String sel_setShortStandaloneMonthSymbols_1;
    public static /*const*/ String sel_setTag_1;
    public static /*const*/ String sel_ignoredWordsInSpellDocumentWithTag_1;
    public static /*const*/ String sel_preferredLocalizationsFromArray_1;
    public static /*const*/ String sel_intersectsIndexesInRange_1;
    public static /*const*/ String sel_scanLongLong_1;
    public static /*const*/ String sel_characterSetWithContentsOfFile_1;
    public static /*const*/ String sel_elementWithName_1children_1attributes_1;
    public static /*const*/ String sel_removeItem_1;
    public static /*const*/ String sel_classForKeyedArchiver;
    public static /*const*/ String sel_initWithString_1locale_1;
    public static /*const*/ String sel_initWithData_1options_1error_1;
    public static /*const*/ String sel_setIsPaneSplitter_1;
    public static /*const*/ String sel_URLHandle_1resourceDataDidBecomeAvailable_1;
    public static /*const*/ String sel_systemDefaultPortNameServer;
    public static /*const*/ String sel_controlTextDidEndEditing_1;
    public static /*const*/ String sel_commandDescription;
    public static /*const*/ String sel_collapseItem_1;
    public static /*const*/ String sel_setAutoresizesOutlineColumn_1;
    public static /*const*/ String sel_isSubsetOfHashTable_1;
    public static /*const*/ String sel_discardEventsMatchingMask_1beforeEvent_1;
    public static /*const*/ String sel_highlightSelectionInClipRect_1;
    public static /*const*/ String sel_decodeSizeForKey_1;
    public static /*const*/ String sel_decimalNumberByRaisingToPower_1;
    public static /*const*/ String sel_canBecomeMainWindow;
    public static /*const*/ String sel_setMenuItem_1;
    public static /*const*/ String sel_contentRectForFrameRect_1styleMask_1;
    public static /*const*/ String sel_clearGLContext;
    public static /*const*/ String sel_setFileType_1;
    public static /*const*/ String sel_expressionForIntersectSet_1with_1;
    public static /*const*/ String sel_sharedHelpManager;
    public static /*const*/ String sel_setMiniwindowTitle_1;
    public static /*const*/ String sel_fontDescriptorWithName_1size_1;
    public static /*const*/ String sel_cookies;
    public static /*const*/ String sel_detachNewThreadSelector_1toTarget_1withObject_1;
    public static /*const*/ String sel_needsPanelToBecomeKey;
    public static /*const*/ String sel_retainArguments;
    public static /*const*/ String sel_textStorageWillProcessEditing_1;
    public static /*const*/ String sel_location;
    public static /*const*/ String sel_shouldChangeTextInRange_1replacementString_1;
    public static /*const*/ String sel_textView_1doubleClickedOnCell_1inRect_1;
    public static /*const*/ String sel_validateVisibleItems;
    public static /*const*/ String sel_isOneway;
    public static /*const*/ String sel_zone;
    public static /*const*/ String sel_titleAlignment;
    public static /*const*/ String sel_localNameForName_1;
    public static /*const*/ String sel_loopMode;
    public static /*const*/ String sel_setFocusRingType_1;
    public static /*const*/ String sel_StringForKey_1;
    public static /*const*/ String sel_initWithDomain_1type_1name_1;
    public static /*const*/ String sel_animationDidEnd_1;
    public static /*const*/ String sel_addSubview_1positioned_1relativeTo_1;
    public static /*const*/ String sel_removeObjects_1;
    public static /*const*/ String sel_graphicsContextWithBitmapImageRep_1;
    public static /*const*/ String sel_isDescendantOf_1;
    public static /*const*/ String sel_tableView_1nextTypeSelectMatchFromRow_1toRow_1forString_1;
    public static /*const*/ String sel_initWithRequest_1delegate_1startImmediately_1;
    public static /*const*/ String sel_reservedThicknessForMarkers;
    public static /*const*/ String sel_movieRect;
    public static /*const*/ String sel_portForName_1host_1;
    public static /*const*/ String sel_tabView_1willSelectTabViewItem_1;
    public static /*const*/ String sel_isOneShot;
    public static /*const*/ String sel_usesThreadedAnimation;
    public static /*const*/ String sel_shortStandaloneQuarterSymbols;
    public static /*const*/ String sel_browser_1validateDrop_1proposedRow_1column_1dropOperation_1;
    public static /*const*/ String sel_setLineSpacing_1;
    public static /*const*/ String sel_indexOfItemWithTitle_1;
    public static /*const*/ String sel_subrowsKeyPath;
    public static /*const*/ String sel_showsResizeIndicator;
    public static /*const*/ String sel_setState_1;
    public static /*const*/ String sel_fileAttributesAtPath_1traverseLink_1;
    public static /*const*/ String sel_setHorizontal_1;
    public static /*const*/ String sel_windowDidExpose_1;
    public static /*const*/ String sel_systemID;
    public static /*const*/ String sel_turnOffKerning_1;
    public static /*const*/ String sel_StringByReplacingPercentEscapesUsingEncoding_1;
    public static /*const*/ String sel_control_1textView_1completions_1forPartialWordRange_1indexOfSelectedItem_1;
    public static /*const*/ String sel_selectLastTabViewItem_1;
    public static /*const*/ String sel_setKeyEquivalentFont_1;
    public static /*const*/ String sel_invalidateCursorRectsForView_1;
    public static /*const*/ String sel_selectTextAtIndex_1;
    public static /*const*/ String sel_showPools;
    public static /*const*/ String sel_setPlaysSelectionOnly_1;
    public static /*const*/ String sel_note;
    public static /*const*/ String sel_setDrawsCellBackground_1;
    public static /*const*/ String sel_layoutCharactersInRange_1forLayoutManager_1maximumNumberOfLineFragments_1;
    public static /*const*/ String sel_lengthOfBytesUsingEncoding_1;
    public static /*const*/ String sel_columnResizingType;
    public static /*const*/ String sel_paragraphSeparatorGlyphRange;
    public static /*const*/ String sel_floatValue;
    public static /*const*/ String sel_setRoundingIncrement_1;
    public static /*const*/ String sel_dateFromString_1;
    public static /*const*/ String sel_panel_1shouldShowFilename_1;
    public static /*const*/ String sel_isEqualToDate_1;
    public static /*const*/ String sel_drawWithFrame_1inView_1characterIndex_1;
    public static /*const*/ String sel_initWithInteger_1;
    public static /*const*/ String sel_CGImage;
    public static /*const*/ String sel_endDocument;
    public static /*const*/ String sel_removeFile;
    public static /*const*/ String sel_splitView_1shouldCollapseSubview_1forDoubleClickOnDividerAtIndex_1;
    public static /*const*/ String sel_setDefaultMiterLimit_1;
    public static /*const*/ String sel_keyCode;
    public static /*const*/ String sel_raise_1format_1;
    public static /*const*/ String sel_cellSize;
    public static /*const*/ String sel_runModalForWindow_1;
    public static /*const*/ String sel_colorListNamed_1;
    public static /*const*/ String sel_detachColorList_1;
    public static /*const*/ String sel_postEvent_1atStart_1;
    public static /*const*/ String sel_setMaximumFractionDigits_1;
    public static /*const*/ String sel_setVolatileDomain_1forName_1;
    public static /*const*/ String sel_imageInterpolation;
    public static /*const*/ String sel_setTitlePosition_1;
    public static /*const*/ String sel_leadingOffset;
    public static /*const*/ String sel_invokeWithTarget_1;
    public static /*const*/ String sel_negativeFormat;
    public static /*const*/ String sel_windowController;
    public static /*const*/ String sel_setVerticalPageScroll_1;
    public static /*const*/ String sel_applicationDidUpdate_1;
    public static /*const*/ String sel_valueForProperty_1;
    public static /*const*/ String sel_tokenField_1hasMenuForRepresentedObject_1;
    public static /*const*/ String sel_resolveClassMethod_1;
    public static /*const*/ String sel_setAutomaticQuoteSubstitutionEnabled_1;
    public static /*const*/ String sel_ordinalityOfUnit_1inUnit_1forDate_1;
    public static /*const*/ String sel_initWithHost_1port_1protocol_1realm_1authenticationMethod_1;
    public static /*const*/ String sel_timeIntervalSinceNow;
    public static /*const*/ String sel_showFindIndicatorForRange_1;
    public static /*const*/ String sel_drawLabel_1inRect_1;
    public static /*const*/ String sel_startQuery;
    public static /*const*/ String sel_initWithNibNamed_1bundle_1;
    public static /*const*/ String sel_firstResponder;
    public static /*const*/ String sel_windowWillMove_1;
    public static /*const*/ String sel_dictionaryForKey_1;
    public static /*const*/ String sel_decodeValueOfObjCType_1at_1;
    public static /*const*/ String sel_activeApplication;
    public static /*const*/ String sel_initWithUnsignedLongLong_1;
    public static /*const*/ String sel_decimalNumberWithString_1;
    public static /*const*/ String sel_replaceTextStorage_1;
    public static /*const*/ String sel_relativePosition;
    public static /*const*/ String sel_objectValueOfSelectedItem;
    public static /*const*/ String sel_timeInterval;
    public static /*const*/ String sel_getBytes_1range_1;
    public static /*const*/ String sel_initWithViewAnimations_1;
    public static /*const*/ String sel_setHorizontalRulerView_1;
    public static /*const*/ String sel_keyPathsForValuesAffectingPreview;
    public static /*const*/ String sel_setWithObjects_1count_1;
    public static /*const*/ String sel_bitsPerSample;
    public static /*const*/ String sel_dayOfYear;
    public static /*const*/ String sel_maximumFractionDigits;
    public static /*const*/ String sel_isSelectionByRect;
    public static /*const*/ String sel_getRed_1green_1blue_1alpha_1;
    public static /*const*/ String sel_glyphIsEncoded_1;
    public static /*const*/ String sel_setStartSubelementIdentifier_1;
    public static /*const*/ String sel_connection_1didFailWithError_1;
    public static /*const*/ String sel_parser_1foundExternalEntityDeclarationWithName_1publicID_1systemID_1;
    public static /*const*/ String sel_outlineView_1shouldTypeSelectForEvent_1withCurrentSearchString_1;
    public static /*const*/ String sel_lowerBaseline_1;
    public static /*const*/ String sel_outlineView_1willDisplayCell_1forTableColumn_1item_1;
    public static /*const*/ String sel_notificationWithName_1object_1userInfo_1;
    public static /*const*/ String sel_setMaxConcurrentOperationCount_1;
    public static /*const*/ String sel_closeSpellDocumentWithTag_1;
    public static /*const*/ String sel_popUpStatusItemMenu_1;
    public static /*const*/ String sel_itemPrototype;
    public static /*const*/ String sel_commandName;
    public static /*const*/ String sel_setTextAttributesForZero_1;
    public static /*const*/ String sel_dateFromComponents_1;
    public static /*const*/ String sel_outlineViewColumnDidResize_1;
    public static /*const*/ String sel_setTailIndent_1;
    public static /*const*/ String sel_setRowTemplates_1;
    public static /*const*/ String sel_objectsForXQuery_1constants_1error_1;
    public static /*const*/ String sel_mutableCopyWithZone_1;
    public static /*const*/ String sel_initWithItemIdentifier_1;
    public static /*const*/ String sel_minuteOfHour;
    public static /*const*/ String sel_setAutosavingDelay_1;
    public static /*const*/ String sel_nextKeyView;
    public static /*const*/ String sel_orderFront_1;
    public static /*const*/ String sel_encodeValueOfObjCType_1at_1;
    public static /*const*/ String sel_mode;
    public static /*const*/ String sel_appleEventWithEventClass_1eventID_1targetDescriptor_1returnID_1transactionID_1;
    public static /*const*/ String sel_StringByDeletingPathExtension;
    public static /*const*/ String sel_standardOutput;
    public static /*const*/ String sel_enumCodeValue;
    public static /*const*/ String sel_setResourceData_1;
    public static /*const*/ String sel_convertRectFromBase_1;
    public static /*const*/ String sel_initWithContentRect_1styleMask_1backing_1defer_1screen_1;
    public static /*const*/ String sel_autoenablesItems;
    public static /*const*/ String sel_textContainerForGlyphAtIndex_1effectiveRange_1withoutAdditionalLayout_1;
    public static /*const*/ String sel_QTMovie;
    public static /*const*/ String sel_addObserver_1selector_1name_1object_1suspensionBehavior_1;
    public static /*const*/ String sel_getArgument_1atIndex_1;
    public static /*const*/ String sel_replaceChildAtIndex_1withNode_1;
    public static /*const*/ String sel_beginForDirectory_1file_1types_1modelessDelegate_1didEndSelector_1contextInfo_1;
    public static /*const*/ String sel_supportsMode_1;
    public static /*const*/ String sel_openFile_1;
    public static /*const*/ String sel_zero;
    public static /*const*/ String sel_compositingFilter;
    public static /*const*/ String sel_fileGroupOwnerAccountID;
    public static /*const*/ String sel_tokenField_1writeRepresentedObjects_1toPasteboard_1;
    public static /*const*/ String sel_tabViewType;
    public static /*const*/ String sel_drawSortIndicatorWithFrame_1inView_1ascending_1priority_1;
    public static /*const*/ String sel_spellCheckerDocumentTag;
    public static /*const*/ String sel_updateFromPMPageFormat;
    public static /*const*/ String sel_colorSyncProfile;
    public static /*const*/ String sel_flushBufferedKeyEvents;
    public static /*const*/ String sel_removeAllObjects;
    public static /*const*/ String sel_selectItemWithTitle_1;
    public static /*const*/ String sel_textContainers;
    public static /*const*/ String sel_isHorizontallyResizable;
    public static /*const*/ String sel_selectionIndexPaths;
    public static /*const*/ String sel_setString_1forType_1;
    public static /*const*/ String sel_setWraps_1;
    public static /*const*/ String sel_dataCell;
    public static /*const*/ String sel_addPointer_1;
    public static /*const*/ String sel_invalidate;
    public static /*const*/ String sel_draggingImageForRowsWithIndexes_1inColumn_1withEvent_1offset_1;
    public static /*const*/ String sel_horizontalEdgePadding;
    public static /*const*/ String sel_view;
    public static /*const*/ String sel_showsPrintPanel;
    public static /*const*/ String sel_hyphenationFactor;
    public static /*const*/ String sel_setAcceptsGlyphInfo_1;
    public static /*const*/ String sel_formatWidth;
    public static /*const*/ String sel_StringByAppendingFormat_1;
    public static /*const*/ String sel_documentForFileName_1;
    public static /*const*/ String sel_outlineView_1nextTypeSelectMatchFromItem_1toItem_1forString_1;
    public static /*const*/ String sel_isItemExpanded_1;
    public static /*const*/ String sel_playbackDeviceIdentifier;
    public static /*const*/ String sel_addButtonWithTitle_1;
    public static /*const*/ String sel_lowercaseLetterCharacterSet;
    public static /*const*/ String sel_netService_1didNotResolve_1;
    public static /*const*/ String sel_copiesOnScroll;
    public static /*const*/ String sel_unarchiver_1willReplaceObject_1withObject_1;
    public static /*const*/ String sel_setHasShadow_1;
    public static /*const*/ String sel_addObserver_1selector_1name_1object_1;
    public static /*const*/ String sel_setDouble_1forKey_1;
    public static /*const*/ String sel_positionOfGlyph_1struckOverRect_1metricsExist_1;
    public static /*const*/ String sel_sharedInstance;
    public static /*const*/ String sel_setPaperSize_1;
    public static /*const*/ String sel_data1;
    public static /*const*/ String sel_applicationWillBecomeActive_1;
    public static /*const*/ String sel_URLProtocol_1cachedResponseIsValid_1;
    public static /*const*/ String sel_mouseDown_1;
    public static /*const*/ String sel_setVeryShortStandaloneWeekdaySymbols_1;
    public static /*const*/ String sel_setUsesStrongWriteBarrier_1;
    public static /*const*/ String sel_second;
    public static /*const*/ String sel_predicateWithLeftExpression_1rightExpression_1modifier_1type_1options_1;
    public static /*const*/ String sel_setFloatingPanel_1;
    public static /*const*/ String sel_parser_1didEndElement_1namespaceURI_1qualifiedName_1;
    public static /*const*/ String sel_handlePortMessage_1;
    public static /*const*/ String sel_filteredSetUsingPredicate_1;
    public static /*const*/ String sel_setLocalizedKeyDictionary_1;
    public static /*const*/ String sel_drawCellInside_1;
    public static /*const*/ String sel_browserDidScroll_1;
    public static /*const*/ String sel_isDirectory;
    public static /*const*/ String sel_setEnvironment_1;
    public static /*const*/ String sel_persistence;
    public static /*const*/ String sel_backingType;
    public static /*const*/ String sel_orderedDocuments;
    public static /*const*/ String sel_windowWillUseStandardFrame_1defaultFrame_1;
    public static /*const*/ String sel_toggleTraditionalCharacterShape_1;
    public static /*const*/ String sel_fractionOfDistanceThroughGlyphForPoint_1;
    public static /*const*/ String sel_netServiceWillPublish_1;
    public static /*const*/ String sel_drawInRect_1relativeCenterPosition_1;
    public static /*const*/ String sel_setShowsAlpha_1;
    public static /*const*/ String sel_canDragRowsWithIndexes_1inColumn_1withEvent_1;
    public static /*const*/ String sel_start;
    public static /*const*/ String sel_imageRectInRuler;
    public static /*const*/ String sel_TXTRecordData;
    public static /*const*/ String sel_groupingLevel;
    public static /*const*/ String sel_response;
    public static /*const*/ String sel_insertionIndex;
    public static /*const*/ String sel_cancelPreviousPerformRequestsWithTarget_1selector_1object_1;
    public static /*const*/ String sel_itemWithTitle_1;
    public static /*const*/ String sel_insertRow_1;
    public static /*const*/ String sel_mutableChildNodes;
    public static /*const*/ String sel_removeAllPoints;
    public static /*const*/ String sel_searchForRegistrationDomains;
    public static /*const*/ String sel_replacementObjectForCoder_1;
    public static /*const*/ String sel_tangentialPressure;
    public static /*const*/ String sel_setMaxDate_1;
    public static /*const*/ String sel_performMnemonic_1;
    public static /*const*/ String sel_maximumRecentDocumentCount;
    public static /*const*/ String sel_StringsByAppendingPaths_1;
    public static /*const*/ String sel_localTimeZone;
    public static /*const*/ String sel_draggingLocation;
    public static /*const*/ String sel_searchForAllDomains;
    public static /*const*/ String sel_attributedStringWithAttachment_1;
    public static /*const*/ String sel_initWithContentsOfURL_1byReference_1;
    public static /*const*/ String sel_exchangeObjectAtIndex_1withObjectAtIndex_1;
    public static /*const*/ String sel_draw;
    public static /*const*/ String sel_fileIsImmutable;
    public static /*const*/ String sel_tokenField_1styleForRepresentedObject_1;
    public static /*const*/ String sel_setAutorecalculatesContentBorderThickness_1forEdge_1;
    public static /*const*/ String sel_firstRectForCharacterRange_1actualRange_1;
    public static /*const*/ String sel_targetForAction_1to_1from_1;
    public static /*const*/ String sel_setShouldCloseDocument_1;
    public static /*const*/ String sel_originOffset;
    public static /*const*/ String sel_sharedSupportPath;
    public static /*const*/ String sel_disableScreenUpdatesUntilFlush;
    public static /*const*/ String sel_setShortStandaloneQuarterSymbols_1;
    public static /*const*/ String sel_filenames;
    public static /*const*/ String sel_numberOfItemsInComboBox_1;
    public static /*const*/ String sel_hasBytesAvailable;
    public static /*const*/ String sel_currentConversation;
    public static /*const*/ String sel_setAllowsEditingTextAttributes_1;
    public static /*const*/ String sel_initWithName_1StringValue_1;
    public static /*const*/ String sel_tableViewColumnDidResize_1;
    public static /*const*/ String sel_knowsPageRange_1;
    public static /*const*/ String sel_uppercaseLetterCharacterSet;
    public static /*const*/ String sel_capitalizedLetterCharacterSet;
    public static /*const*/ String sel_main;
    public static /*const*/ String sel_genericRGBColorSpace;
    public static /*const*/ String sel_clearsFilterPredicateOnInsertion;
    public static /*const*/ String sel_paragraphs;
    public static /*const*/ String sel_setJobDisposition_1;
    public static /*const*/ String sel_setContainerClassDescription_1;
    public static /*const*/ String sel_StringWithContentsOfURL_1;
    public static /*const*/ String sel_setTrackingMode_1;
    public static /*const*/ String sel_canCloseDocumentWithDelegate_1shouldCloseSelector_1contextInfo_1;
    public static /*const*/ String sel_usesItemFromMenu;
    public static /*const*/ String sel_shortValue;
    public static /*const*/ String sel_readDataOfLength_1;
    public static /*const*/ String sel_descriptorWithDescriptorType_1data_1;
    public static /*const*/ String sel_setCanRemoveAllRows_1;
    public static /*const*/ String sel_defaultCenter;
    public static /*const*/ String sel_scriptingIsGreaterThan_1;
    public static /*const*/ String sel_splitView_1constrainSplitPosition_1ofSubviewAt_1;
    public static /*const*/ String sel_setTokenStyle_1;
    public static /*const*/ String sel_initWithContentRect_1styleMask_1backing_1defer_1;
    public static /*const*/ String sel_insertTabViewItem_1atIndex_1;
    public static /*const*/ String sel_rowForDisplayValue_1;
    public static /*const*/ String sel_isDrawingToScreen;
    public static /*const*/ String sel_encodeRect_1;
    public static /*const*/ String sel_controlDarkShadowColor;
    public static /*const*/ String sel_maxDate;
    public static /*const*/ String sel_lock;
    public static /*const*/ String sel_resetSystemTimeZone;
    public static /*const*/ String sel_coerceValue_1toClass_1;
    public static /*const*/ String sel_qdPort;
    public static /*const*/ String sel_resultAtIndex_1;
    public static /*const*/ String sel_descriptorWithBoolean_1;
    public static /*const*/ String sel_markedRange;
    public static /*const*/ String sel_colorWithCalibratedHue_1saturation_1brightness_1alpha_1;
    public static /*const*/ String sel_setSharedPrintInfo_1;
    public static /*const*/ String sel_setBorderColor_1;
    public static /*const*/ String sel_parser_1foundCharacters_1;
    public static /*const*/ String sel_preferredPasteboardTypeFromArray_1restrictedToTypesFromArray_1;
    public static /*const*/ String sel_resume;
    public static /*const*/ String sel_iconForFiles_1;
    public static /*const*/ String sel_drawKeyEquivalentWithFrame_1inView_1;
    public static /*const*/ String sel_boxType;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1name_1;
    public static /*const*/ String sel_setFill;
    public static /*const*/ String sel_setParagraphGlyphRange_1separatorGlyphRange_1;
    public static /*const*/ String sel_copyWithZone_1;
    public static /*const*/ String sel_self;
    public static /*const*/ String sel_reservedSpaceLength;
    public static /*const*/ String sel_unsignedIntValue;
    public static /*const*/ String sel_URLHandleResourceDidFinishLoading_1;
    public static /*const*/ String sel_menuWillOpen_1;
    public static /*const*/ String sel_menuWillClose_1;
    public static /*const*/ String sel_pointerArrayWithWeakObjects;
    public static /*const*/ String sel_fetchPredicate;
    public static /*const*/ String sel_pathToColumn_1;
    public static /*const*/ String sel_columnWithIdentifier_1;
    public static /*const*/ String sel_setShouldCreateUI_1;
    public static /*const*/ String sel_getGlyphs_1range_1;
    public static /*const*/ String sel_returnID;
    public static /*const*/ String sel_miterLimit;
    public static /*const*/ String sel_hidesEmptyCells;
    public static /*const*/ String sel_userSpaceScaleFactor;
    public static /*const*/ String sel_xHeight;
    public static /*const*/ String sel_decimalNumberByMultiplyingBy_1withBehavior_1;
    public static /*const*/ String sel_reloadData;
    public static /*const*/ String sel_setShortWeekdaySymbols_1;
    public static /*const*/ String sel_containsIndexesInRange_1;
    public static /*const*/ String sel_colorWithDeviceRed_1green_1blue_1alpha_1;
    public static /*const*/ String sel_screenFontWithRenderingMode_1;
    public static /*const*/ String sel_suggestedFilename;
    public static /*const*/ String sel_fileNameExtensionForType_1saveOperation_1;
    public static /*const*/ String sel_labelFontSize;
    public static /*const*/ String sel_setAlphaValue_1;
    public static /*const*/ String sel_openGLContext;
    public static /*const*/ String sel_scriptingIsLessThan_1;
    public static /*const*/ String sel_keysSortedByValueUsingSelector_1;
    public static /*const*/ String sel_control_1didFailToValidatePartialString_1errorDescription_1;
    public static /*const*/ String sel_offStateImage;
    public static /*const*/ String sel_bidiProcessingEnabled;
    public static /*const*/ String sel_isKeyWindow;
    public static /*const*/ String sel_initWithIconRef_1;
    public static /*const*/ String sel_changeCurrentDirectoryPath_1;
    public static /*const*/ String sel_textView;
    public static /*const*/ String sel_localizedStringForStatusCode_1;
    public static /*const*/ String sel_setWantsLayer_1;
    public static /*const*/ String sel_positivePrefix;
    public static /*const*/ String sel_setDefaultFlatness_1;
    public static /*const*/ String sel_addChild_1;
    public static /*const*/ String sel_parser_1foundAttributeDeclarationWithName_1forElement_1type_1defaultValue_1;
    public static /*const*/ String sel_scannerWithString_1;
    public static /*const*/ String sel_removeFileWrapper_1;
    public static /*const*/ String sel_setTitleWidth_1;
    public static /*const*/ String sel_setTabKeyTraversesCells_1;
    public static /*const*/ String sel_glyphRangeForBoundingRect_1inTextContainer_1;
    public static /*const*/ String sel_fileHandleForWritingAtPath_1;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1;
    public static /*const*/ String sel_fontAttributes;
    public static /*const*/ String sel_reviewUnsavedDocumentsWithAlertTitle_1cancellable_1delegate_1didReviewAllSelector_1contextInfo_1;
    public static /*const*/ String sel_minWidth;
    public static /*const*/ String sel_getLineFragmentInsertionPointsForCharacterAtIndex_1alternatePositions_1inDisplayOrder_1positions_1characterIndexes_1;
    public static /*const*/ String sel_finishDecoding;
    public static /*const*/ String sel_currentContextDrawingToScreen;
    public static /*const*/ String sel_setKeyEquivalent_1;
    public static /*const*/ String sel_smartInsertForString_1replacingRange_1beforeString_1afterString_1;
    public static /*const*/ String sel_useStandardKerning_1;
    public static /*const*/ String sel_sharedSystemTypesetter;
    public static /*const*/ String sel_setDatePickerMode_1;
    public static /*const*/ String sel_encodePoint_1forKey_1;
    public static /*const*/ String sel_colorSpace;
    public static /*const*/ String sel_pasteboardByFilteringTypesInPasteboard_1;
    public static /*const*/ String sel_sendDoubleAction;
    public static /*const*/ String sel_isColumnSelected_1;
    public static /*const*/ String sel_unarchiveObjectWithFile_1;
    public static /*const*/ String sel_usesEPSOnResolutionMismatch;
    public static /*const*/ String sel_encodeBycopyObject_1;
    public static /*const*/ String sel_removeAttributeForName_1;
    public static /*const*/ String sel_keyCell;
    public static /*const*/ String sel_allocWithZone_1;
    public static /*const*/ String sel_getCompression_1factor_1;
    public static /*const*/ String sel_insertValue_1inPropertyWithKey_1;
    public static /*const*/ String sel_drawAtPoint_1withAttributes_1;
    public static /*const*/ String sel_isTrue;
    public static /*const*/ String sel_expectedContentLength;
    public static /*const*/ String sel_setTitle_1;
    public static /*const*/ String sel_connection_1didReceiveAuthenticationChallenge_1;
    public static /*const*/ String sel_isEnabledForSegment_1;
    public static /*const*/ String sel_speechSynthesizer_1willSpeakPhoneme_1;
    public static /*const*/ String sel_setShowsStateColumn_1;
    public static /*const*/ String sel_requiredFileType;
    public static /*const*/ String sel_convertRect_1fromView_1;
    public static /*const*/ String sel_visibleFrame;
    public static /*const*/ String sel_concludeDragOperation_1;
    public static /*const*/ String sel_minimumFractionDigits;
    public static /*const*/ String sel_reopenDocumentForURL_1withContentsOfURL_1error_1;
    public static /*const*/ String sel_roundingMode;
    public static /*const*/ String sel_colorWithCatalogName_1colorName_1;
    public static /*const*/ String sel_setWithSet_1;
    public static /*const*/ String sel_fileManager_1willProcessPath_1;
    public static /*const*/ String sel_setSuspended_1;
    public static /*const*/ String sel_currentInputManager;
    public static /*const*/ String sel_operatingSystemVersionString;
    public static /*const*/ String sel_resetBytesInRange_1;
    public static /*const*/ String sel_sizeForKey_1inTable_1;
    public static /*const*/ String sel_setFloat_1forKey_1;
    public static /*const*/ String sel_enableUndoRegistration;
    public static /*const*/ String sel_initWithCGImage_1;
    public static /*const*/ String sel_initWithCIImage_1;
    public static /*const*/ String sel_addCharactersInRange_1;
    public static /*const*/ String sel_initWithRect_1options_1owner_1userInfo_1;
    public static /*const*/ String sel_incrementalLoadFromData_1complete_1;
    public static /*const*/ String sel_tableView_1acceptDrop_1row_1dropOperation_1;
    public static /*const*/ String sel_classNamed_1;
    public static /*const*/ String sel_setIndeterminate_1;
    public static /*const*/ String sel_normalizeAdjacentTextNodesPreservingCDATA_1;
    public static /*const*/ String sel_validateUserInterfaceItem_1;
    public static /*const*/ String sel_setPlaysEveryFrame_1;
    public static /*const*/ String sel_isCompiled;
    public static /*const*/ String sel_tokenFieldCell_1editingStringForRepresentedObject_1;
    public static /*const*/ String sel_tableView_1isGroupRow_1;
    public static /*const*/ String sel_orderFrontLinkPanel_1;
    public static /*const*/ String sel_alphaControlAddedOrRemoved_1;
    public static /*const*/ String sel_setShadowColor_1;
    public static /*const*/ String sel_canBecomeKeyView;
    public static /*const*/ String sel_addTimer_1forMode_1;
    public static /*const*/ String sel_clickedColumn;
    public static /*const*/ String sel_initWithName_1URI_1;
    public static /*const*/ String sel_saveDocument_1;
    public static /*const*/ String sel_observationInfo;
    public static /*const*/ String sel_readFromURL_1options_1documentAttributes_1error_1;
    public static /*const*/ String sel_addClient_1;
    public static /*const*/ String sel_appleEventForSuspensionID_1;
    public static /*const*/ String sel_setGeneratesCalendarDates_1;
    public static /*const*/ String sel_tableView_1sortDescriptorsDidChange_1;
    public static /*const*/ String sel_predicateFormat;
    public static /*const*/ String sel_windowShouldZoom_1toFrame_1;
    public static /*const*/ String sel_usesFontPanel;
    public static /*const*/ String sel_encodeNXObject_1;
    public static /*const*/ String sel_colorAtX_1y_1;
    public static /*const*/ String sel_publishWithOptions_1;
    public static /*const*/ String sel_allHTTPHeaderFields;
    public static /*const*/ String sel_registerPort_1name_1;
    public static /*const*/ String sel_lineFragmentUsedRectForGlyphAtIndex_1effectiveRange_1withoutAdditionalLayout_1;
    public static /*const*/ String sel_hour;
    public static /*const*/ String sel_setTextLists_1;
    public static /*const*/ String sel_maximumAdvancement;
    public static /*const*/ String sel_setHighlightedItemIndex_1;
    public static /*const*/ String sel_initWithMemoryCapacity_1diskCapacity_1diskPath_1;
    public static /*const*/ String sel_setDocumentContentKind_1;
    public static /*const*/ String sel_updateDragTypeRegistration;
    public static /*const*/ String sel_deviceDescription;
    public static /*const*/ String sel_setMiniwindowImage_1;
    public static /*const*/ String sel_sharedTypesetter;
    public static /*const*/ String sel_deleteToEndOfLine_1;
    public static /*const*/ String sel_setState_1atRow_1column_1;
    public static /*const*/ String sel_validModesForFontPanel_1;
    public static /*const*/ String sel_currentCalendar;
    public static /*const*/ String sel_selectionIndexPath;
    public static /*const*/ String sel_setTextFont_1;
    public static /*const*/ String sel_password;
    public static /*const*/ String sel_words;
    public static /*const*/ String sel_status;
    public static /*const*/ String sel_typingAttributes;
    public static /*const*/ String sel_handleTakeValue_1forUnboundKey_1;
    public static /*const*/ String sel_image_1didLoadRepresentation_1withStatus_1;
    public static /*const*/ String sel_setBitsPerSample_1;
    public static /*const*/ String sel_sortSubviewsUsingFunction_1context_1;
    public static /*const*/ String sel_initWithProtocolFamily_1socketType_1protocol_1socket_1;
    public static /*const*/ String sel_numberOfItemsInMenu_1;
    public static /*const*/ String sel_numberWithUnsignedShort_1;
    public static /*const*/ String sel_textView_1menu_1forEvent_1atIndex_1;
    public static /*const*/ String sel_arrowCursor;
    public static /*const*/ String sel_abbreviation;
    public static /*const*/ String sel_moveDown_1;
    public static /*const*/ String sel_activateContextHelpMode_1;
    public static /*const*/ String sel_properties;
    public static /*const*/ String sel_setObject_1forProperty_1error_1;
    public static /*const*/ String sel_setAutodisplay_1;
    public static /*const*/ String sel_locationInWindow;
    public static /*const*/ String sel_layoutManager;
    public static /*const*/ String sel_hyphenCharacterForGlyphAtIndex_1;
    public static /*const*/ String sel_play;
    public static /*const*/ String sel_compositeToPoint_1fromRect_1operation_1fraction_1;
    public static /*const*/ String sel_cellBackgroundColor;
    public static /*const*/ String sel_shouldAntialias;
    public static /*const*/ String sel_windowWillReturnFieldEditor_1toObject_1;
    public static /*const*/ String sel_setValuesForKeysWithDictionary_1;
    public static /*const*/ String sel_drawsGrid;
    public static /*const*/ String sel_patternPhase;
    public static /*const*/ String sel_setFrame_1;
    public static /*const*/ String sel_roundingIncrement;
    public static /*const*/ String sel_adjustScroll_1;
    public static /*const*/ String sel_alertShowHelp_1;
    public static /*const*/ String sel_animate_1;
    public static /*const*/ String sel_tabletID;
    public static /*const*/ String sel_selectedRowEnumerator;
    public static /*const*/ String sel_XMLString;
    public static /*const*/ String sel_setWarningValue_1;
    public static /*const*/ String sel_tableView_1validateDrop_1proposedRow_1proposedDropOperation_1;
    public static /*const*/ String sel_checkSpelling_1;
    public static /*const*/ String sel_setFormattingStringsFilename_1;
    public static /*const*/ String sel_displayIfNeeded;
    public static /*const*/ String sel_localizedName;
    public static /*const*/ String sel_isEqualToSet_1;
    public static /*const*/ String sel_initWithBytesNoCopy_1length_1encoding_1freeWhenDone_1;
    public static /*const*/ String sel_reloadPredicate;
    public static /*const*/ String sel_setNumberOfMajorTickMarks_1;
    public static /*const*/ String sel_defaultPlaceholderForMarker_1withBinding_1;
    public static /*const*/ String sel_encodeDataObject_1;
    public static /*const*/ String sel_writeToURL_1ofType_1;
    public static /*const*/ String sel_createContext;
    public static /*const*/ String sel_verticalScroller;
    public static /*const*/ String sel_setShowsInvisibleCharacters_1;
    public static /*const*/ String sel_encodeConditionalObject_1forKey_1;
    public static /*const*/ String sel_isEqualTo_1;
    public static /*const*/ String sel_translateXBy_1yBy_1;
    public static /*const*/ String sel_customizationPaletteIsRunning;
    public static /*const*/ String sel_dictionaryWithDictionary_1;
    public static /*const*/ String sel_drawMarkersInRect_1;
    public static /*const*/ String sel_centerSelectionInVisibleArea_1;
    public static /*const*/ String sel_StringByAppendingString_1;
    public static /*const*/ String sel_flushWindowIfNeeded;
    public static /*const*/ String sel_lockFocusOnRepresentation_1;
    public static /*const*/ String sel_setNotShownAttribute_1forGlyphAtIndex_1;
    public static /*const*/ String sel_currentReplyAppleEvent;
    public static /*const*/ String sel_setTitleAlignment_1;
    public static /*const*/ String sel_removeSuiteNamed_1;
    public static /*const*/ String sel_capitalizedString;
    public static /*const*/ String sel_typeFromFileExtension_1;
    public static /*const*/ String sel_allowsImageEditing;
    public static /*const*/ String sel_loosenKerning_1;
    public static /*const*/ String sel_decomposableCharacterSet;
    public static /*const*/ String sel_subdataWithRange_1;
    public static /*const*/ String sel_attachPopUpWithFrame_1inView_1;
    public static /*const*/ String sel_setColumnResizingType_1;
    public static /*const*/ String sel_genericCMYKColorSpace;
    public static /*const*/ String sel_actionForControlCharacterAtIndex_1;
    public static /*const*/ String sel_documentRect;
    public static /*const*/ String sel_dataWithContentsOfFile_1;
    public static /*const*/ String sel_localizedDescriptionForType_1;
    public static /*const*/ String sel_increment;
    public static /*const*/ String sel_deleteToEndOfParagraph_1;
    public static /*const*/ String sel_exceptionWithName_1reason_1userInfo_1;
    public static /*const*/ String sel_postscriptName;
    public static /*const*/ String sel_setPreferredFilename_1;
    public static /*const*/ String sel_setPostsBoundsChangedNotifications_1;
    public static /*const*/ String sel_decimalNumberHandlerWithRoundingMode_1scale_1raiseOnExactness_1raiseOnOverflow_1raiseOnUnderflow_1raiseOnDivideByZero_1;
    public static /*const*/ String sel_openDocumentWithContentsOfFile_1display_1;
    public static /*const*/ String sel_objectForInfoDictionaryKey_1;
    public static /*const*/ String sel_setFrameOrigin_1;
    public static /*const*/ String sel_pathControl_1willPopUpMenu_1;
    public static /*const*/ String sel_lineWidth;
    public static /*const*/ String sel_poseAsClass_1;
    public static /*const*/ String sel_selectPreviousKeyView_1;
    public static /*const*/ String sel_isKey_1inTable_1;
    public static /*const*/ String sel_isZoomed;
    public static /*const*/ String sel_setCompletionDelay_1;
    public static /*const*/ String sel_mainMenu;
    public static /*const*/ String sel_scrollView;
    public static /*const*/ String sel_dividerColor;
    public static /*const*/ String sel_requestModes;
    public static /*const*/ String sel_setShowsResizeIndicator_1;
    public static /*const*/ String sel_setScrollable_1;
    public static /*const*/ String sel_setLineScroll_1;
    public static /*const*/ String sel_resolvePrefixForNamespaceURI_1;
    public static /*const*/ String sel_bind_1toObject_1withKeyPath_1options_1;
    public static /*const*/ String sel_alignCenter_1;
    public static /*const*/ String sel_addTemporaryAttribute_1value_1forCharacterRange_1;
    public static /*const*/ String sel_expressionForConstantValue_1;
    public static /*const*/ String sel_initWithContentSize_1preferredEdge_1;
    public static /*const*/ String sel_setAccessoryView_1;
    public static /*const*/ String sel_setContentWidth_1type_1;
    public static /*const*/ String sel_searchMenuTemplate;
    public static /*const*/ String sel_imageRepClassForType_1;
    public static /*const*/ String sel_decimalValue;
    public static /*const*/ String sel_protocolSpecificInformation;
    public static /*const*/ String sel_statusBar;
    public static /*const*/ String sel_setTimeZone_1;
    public static /*const*/ String sel_setWidth_1forSegment_1;
    public static /*const*/ String sel_objectIsForcedForKey_1inDomain_1;
    public static /*const*/ String sel_evaluationErrorSpecifier;
    public static /*const*/ String sel_application_1openFile_1;
    public static /*const*/ String sel_changeDocumentBackgroundColor_1;
    public static /*const*/ String sel_volatileDomainNames;
    public static /*const*/ String sel_changeInLength;
    public static /*const*/ String sel_autoresizingMask;
    public static /*const*/ String sel_setRepresentedObject_1;
    public static /*const*/ String sel_isUndoRegistrationEnabled;
    public static /*const*/ String sel_alertWithError_1;
    public static /*const*/ String sel_saturationComponent;
    public static /*const*/ String sel_spellServer_1didLearnWord_1inLanguage_1;
    public static /*const*/ String sel_performActionWithHighlightingForItemAtIndex_1;
    public static /*const*/ String sel_loadSuitesFromBundle_1;
    public static /*const*/ String sel_firstTextView;
    public static /*const*/ String sel_targetForAction_1;
    public static /*const*/ String sel_enterExitEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1eventNumber_1trackingNumber_1userData_1;
    public static /*const*/ String sel_setHelpAnchor_1;
    public static /*const*/ String sel_printerWithName_1;
    public static /*const*/ String sel_boundingBoxForControlGlyphAtIndex_1forTextContainer_1proposedLineFragment_1glyphPosition_1characterIndex_1;
    public static /*const*/ String sel_initWithBytesNoCopy_1length_1freeWhenDone_1;
    public static /*const*/ String sel_getRow_1column_1ofCell_1;
    public static /*const*/ String sel_smartDeleteRangeForProposedRange_1;
    public static /*const*/ String sel_getHue_1saturation_1brightness_1alpha_1;
    public static /*const*/ String sel_automaticallyNotifiesObserversForKey_1;
    public static /*const*/ String sel_setAllowsImageEditing_1;
    public static /*const*/ String sel_draggingUpdated_1;
    public static /*const*/ String sel_insertRowAtIndex_1withType_1asSubrowOfRow_1animate_1;
    public static /*const*/ String sel_getRectsExposedDuringLiveResize_1count_1;
    public static /*const*/ String sel_usesSignificantDigits;
    public static /*const*/ String sel_numberOfVirtualScreens;
    public static /*const*/ String sel_sendSynchronousRequest_1returningResponse_1error_1;
    public static /*const*/ String sel_setBecomesKeyOnlyIfNeeded_1;
    public static /*const*/ String sel_autorecalculatesKeyViewLoop;
    public static /*const*/ String sel_decodeDataObject;
    public static /*const*/ String sel_setOriginOffset_1;
    public static /*const*/ String sel_pointingDeviceSerialNumber;
    public static /*const*/ String sel_drawSegment_1inFrame_1withView_1;
    public static /*const*/ String sel_close;
    public static /*const*/ String sel_setAlignmentRect_1;
    public static /*const*/ String sel_paragraphSeparatorCharacterRange;
    public static /*const*/ String sel_measurementUnits;
    public static /*const*/ String sel_setUsesEPSOnResolutionMismatch_1;
    public static /*const*/ String sel_setLineFragmentPadding_1;
    public static /*const*/ String sel_setLastComponentOfFileName_1;
    public static /*const*/ String sel_initWithSuiteName_1commandName_1dictionary_1;
    public static /*const*/ String sel_initWithContent_1;
    public static /*const*/ String sel_provideNewView_1;
    public static /*const*/ String sel_pathComponentCells;
    public static /*const*/ String sel_instanceMethodForSelector_1;
    public static /*const*/ String sel_layoutManagerDidInvalidateLayout_1;
    public static /*const*/ String sel_helpAnchor;
    public static /*const*/ String sel_URLProtocol_1wasRedirectedToRequest_1redirectResponse_1;
    public static /*const*/ String sel_setIsVisible_1;
    public static /*const*/ String sel_browser_1sizeToFitWidthOfColumn_1;
    public static /*const*/ String sel_handleFailureInMethod_1object_1file_1lineNumber_1description_1;
    public static /*const*/ String sel_serializedRepresentation;
    public static /*const*/ String sel_replaceTextContainer_1;
    public static /*const*/ String sel_speechSynthesizer_1willSpeakWord_1ofString_1;
    public static /*const*/ String sel_startSpeaking_1;
    public static /*const*/ String sel_setHyphenationFactor_1;
    public static /*const*/ String sel_retain;
    public static /*const*/ String sel_insertItem_1atIndex_1;
    public static /*const*/ String sel_sortWithSortDescriptors_1recursively_1;
    public static /*const*/ String sel_selectTabViewItem_1;
    public static /*const*/ String sel_clipRect_1;
    public static /*const*/ String sel_close_1;
    public static /*const*/ String sel_didAddSubview_1;
    public static /*const*/ String sel_markedTextSelectionChanged_1client_1;
    public static /*const*/ String sel_registerLanguage_1byVendor_1;
    public static /*const*/ String sel_removeClient_1;
    public static /*const*/ String sel_setSendsWholeSearchString_1;
    public static /*const*/ String sel_localName;
    public static /*const*/ String sel_setSelectedSegment_1;
    public static /*const*/ String sel_setLineHeightMultiple_1;
    public static /*const*/ String sel_setCanCreateDirectories_1;
    public static /*const*/ String sel_setCookieAcceptPolicy_1;
    public static /*const*/ String sel_convertFont_1toHaveTrait_1;
    public static /*const*/ String sel_headerCell;
    public static /*const*/ String sel_maximumDecimalNumber;
    public static /*const*/ String sel_browser_1isColumnValid_1;
    public static /*const*/ String sel_tableViewSelectionIsChanging_1;
    public static /*const*/ String sel_setNotificationBatchingInterval_1;
    public static /*const*/ String sel_isLeaf;
    public static /*const*/ String sel_valuesForAttributes_1;
    public static /*const*/ String sel_removeTemporaryAttribute_1forCharacterRange_1;
    public static /*const*/ String sel_pixelsWide;
    public static /*const*/ String sel_orderFrontStandardAboutPanel_1;
    public static /*const*/ String sel_beginSheetModalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1;
    public static /*const*/ String sel_setToolTip_1forSegment_1;
    public static /*const*/ String sel_canonicalXMLStringPreservingComments_1;
    public static /*const*/ String sel_orderFrontListPanel_1;
    public static /*const*/ String sel_setIsMiniaturized_1;
    public static /*const*/ String sel_download_1didReceiveDataOfLength_1;
    public static /*const*/ String sel_layoutManager_1didCompleteLayoutForTextContainer_1atEnd_1;
    public static /*const*/ String sel_standardWindowButton_1forStyleMask_1;
    public static /*const*/ String sel_writeToURL_1atomically_1;
    public static /*const*/ String sel_useStandardLigatures_1;
    public static /*const*/ String sel_currentRunLoop;
    public static /*const*/ String sel_setExtraLineFragmentRect_1usedRect_1textContainer_1;
    public static /*const*/ String sel_rootElement;
    public static /*const*/ String sel_setContentViewMargins_1;
    public static /*const*/ String sel_cancelPerformSelector_1target_1argument_1;
    public static /*const*/ String sel_outputFormat;
    public static /*const*/ String sel_arrayWithContentsOfFile_1;
    public static /*const*/ String sel_applicationWillFinishLaunching_1;
    public static /*const*/ String sel_prefixForName_1;
    public static /*const*/ String sel_decimalNumberByDividingBy_1;
    public static /*const*/ String sel_mouseUpOnCharacterIndex_1atCoordinate_1withModifier_1client_1;
    public static /*const*/ String sel_defaultVoice;
    public static /*const*/ String sel_operand;
    public static /*const*/ String sel_moveToEndOfLine_1;
    public static /*const*/ String sel_addEntry_1;
    public static /*const*/ String sel_scaleBy_1;
    public static /*const*/ String sel_setMnemonicLocation_1;
    public static /*const*/ String sel_dateWithCalendarFormat_1timeZone_1;
    public static /*const*/ String sel_setUsesFontLeading_1;
    public static /*const*/ String sel_CIContext;
    public static /*const*/ String sel_isDaylightSavingTime;
    public static /*const*/ String sel_setShowsBorderOnlyWhileMouseInside_1;
    public static /*const*/ String sel_isSetOnMouseEntered;
    public static /*const*/ String sel_StringFromDate_1;
    public static /*const*/ String sel_deselectColumn_1;
    public static /*const*/ String sel_requestHeaderFieldsWithCookies_1;
    public static /*const*/ String sel_outlineViewColumnDidMove_1;
    public static /*const*/ String sel_fileExtensionsFromType_1;
    public static /*const*/ String sel_setUsesScreenFonts_1;
    public static /*const*/ String sel_commandDescriptionsInSuite_1;
    public static /*const*/ String sel_notShownAttributeForGlyphAtIndex_1;
    public static /*const*/ String sel_isRunning;
    public static /*const*/ String sel_sharedPrintInfo;
    public static /*const*/ String sel_isValid;
    public static /*const*/ String sel_handleFailureInFunction_1file_1lineNumber_1description_1;
    public static /*const*/ String sel_localizedRecoveryOptions;
    public static /*const*/ String sel_establishConnection;
    public static /*const*/ String sel_isMainWindow;
    public static /*const*/ String sel_setDrawsBackground_1;
    public static /*const*/ String sel_intAttribute_1forGlyphAtIndex_1;
    public static /*const*/ String sel_shadowColor;
    public static /*const*/ String sel_keyEquivalentModifierMask;
    public static /*const*/ String sel_textStorageDidProcessEditing_1;
    public static /*const*/ String sel_setType_1;
    public static /*const*/ String sel_previousSibling;
    public static /*const*/ String sel_dateByAddingYears_1months_1days_1hours_1minutes_1seconds_1;
    public static /*const*/ String sel_setMinimum_1;
    public static /*const*/ String sel_columnAutoresizingStyle;
    public static /*const*/ String sel_convertPointFromBase_1;
    public static /*const*/ String sel_layout;
    public static /*const*/ String sel_textStorage;
    public static /*const*/ String sel_values;
    public static /*const*/ String sel_RTFFromRange_1documentAttributes_1;
    public static /*const*/ String sel_isMiniaturizable;
    public static /*const*/ String sel_opaqueAncestor;
    public static /*const*/ String sel_notationName;
    public static /*const*/ String sel_setBaseWritingDirection_1range_1;
    public static /*const*/ String sel_setManagedObjectContext_1;
    public static /*const*/ String sel_patternImage;
    public static /*const*/ String sel_windowDidResize_1;
    public static /*const*/ String sel_setFieldEditor_1;
    public static /*const*/ String sel_initWithContainerClassDescription_1containerSpecifier_1key_1relativePosition_1baseSpecifier_1;
    public static /*const*/ String sel_setMainMenu_1;
    public static /*const*/ String sel_setObjectZone_1;
    public static /*const*/ String sel_localizedDescription;
    public static /*const*/ String sel_setImageScaling_1;
    public static /*const*/ String sel_moveToBeginningOfLine_1;
    public static /*const*/ String sel_transposeWords_1;
    public static /*const*/ String sel_protocol;
    public static /*const*/ String sel_isHorizontallyCentered;
    public static /*const*/ String sel_invert;
    public static /*const*/ String sel_isEqualToValue_1;
    public static /*const*/ String sel_registerName_1withNameServer_1;
    public static /*const*/ String sel_writeToURL_1ofType_1error_1;
    public static /*const*/ String sel_rangeForUserTextChange;
    public static /*const*/ String sel_configurePersistentStoreCoordinatorForURL_1ofType_1error_1;
    public static /*const*/ String sel_setShouldAntialias_1;
    public static /*const*/ String sel_alignmentRect;
    public static /*const*/ String sel_zoom_1;
    public static /*const*/ String sel_rate;
    public static /*const*/ String sel_maxVisibleColumns;
    public static /*const*/ String sel_splitViewDidResizeSubviews_1;
    public static /*const*/ String sel_maxWidth;
    public static /*const*/ String sel_setData_1;
    public static /*const*/ String sel_isVisible;
    public static /*const*/ String sel_isSelected;
    public static /*const*/ String sel_rulerView_1shouldRemoveMarker_1;
    public static /*const*/ String sel_setURL_1;
    public static /*const*/ String sel_drawTitle_1withFrame_1inView_1;
    public static /*const*/ String sel_usesWeakReadAndWriteBarriers;
    public static /*const*/ String sel_elementDeclarationForName_1;
    public static /*const*/ String sel_setOneShot_1;
    public static /*const*/ String sel_shouldProcessNamespaces;
    public static /*const*/ String sel_isEqualToArray_1;
    public static /*const*/ String sel_XMLStringWithOptions_1;
    public static /*const*/ String sel_initFileURLWithPath_1isDirectory_1;
    public static /*const*/ String sel_datePickerElements;
    public static /*const*/ String sel_willChange_1valuesAtIndexes_1forKey_1;
    public static /*const*/ String sel_setSelected_1forSegment_1;
    public static /*const*/ String sel_initWithFormat_1shareContext_1;
    public static /*const*/ String sel_browser_1shouldSizeColumn_1forUserResize_1toWidth_1;
    public static /*const*/ String sel_indexSetWithIndexesInRange_1;
    public static /*const*/ String sel_netServiceBrowser_1didFindService_1moreComing_1;
    public static /*const*/ String sel_keyUp_1;
    public static /*const*/ String sel_pageHeader;
    public static /*const*/ String sel_isCancelled;
    public static /*const*/ String sel_segmentStyle;
    public static /*const*/ String sel_imageRepWithContentsOfURL_1;
    public static /*const*/ String sel_initWithNibName_1bundle_1;
    public static /*const*/ String sel_removeObserver_1fromObjectsAtIndexes_1forKeyPath_1;
    public static /*const*/ String sel_setFetchPredicate_1;
    public static /*const*/ String sel_compare_1options_1range_1;
    public static /*const*/ String sel_validateVisibleColumns;
    public static /*const*/ String sel_initWithCGColorSpace_1;
    public static /*const*/ String sel_mountNewRemovableMedia;
    public static /*const*/ String sel_compare_1options_1range_1locale_1;
    public static /*const*/ String sel_setTopMargin_1;
    public static /*const*/ String sel_maximumLengthOfBytesUsingEncoding_1;
    public static /*const*/ String sel_colorWithAlphaComponent_1;
    public static /*const*/ String sel_appendBezierPathWithRoundedRect_1xRadius_1yRadius_1;
    public static /*const*/ String sel_autosavedContentsFileURL;
    public static /*const*/ String sel_markedTextAttributes;
    public static /*const*/ String sel_predicateWithValue_1;
    public static /*const*/ String sel_makeFirstResponder_1;
    public static /*const*/ String sel_alternateTitle;
    public static /*const*/ String sel_attribute;
    public static /*const*/ String sel_decodeIntegerForKey_1;
    public static /*const*/ String sel_setSeparatesColumns_1;
    public static /*const*/ String sel_imageRepsWithContentsOfURL_1;
    public static /*const*/ String sel_isPlanar;
    public static /*const*/ String sel_download_1didReceiveAuthenticationChallenge_1;
    public static /*const*/ String sel_startingRow;
    public static /*const*/ String sel_evaluateWithObject_1substitutionVariables_1;
    public static /*const*/ String sel_initWithRTFD_1documentAttributes_1;
    public static /*const*/ String sel_ensureLayoutForTextContainer_1;
    public static /*const*/ String sel_runModalForWindow_1relativeToWindow_1;
    public static /*const*/ String sel_isResizable;
    public static /*const*/ String sel_isSymbolicLink;
    public static /*const*/ String sel_containsIndexes_1;
    public static /*const*/ String sel_splitView_1constrainMaxCoordinate_1ofSubviewAt_1;
    public static /*const*/ String sel_setImportsGraphics_1;
    public static /*const*/ String sel_action;
    public static /*const*/ String sel_noteNumberOfItemsChanged;
    public static /*const*/ String sel_drawBackgroundInClipRect_1;
    public static /*const*/ String sel_printInfo;
    public static /*const*/ String sel_performSelector_1withObject_1afterDelay_1;
    public static /*const*/ String sel_boundingRectForGlyphRange_1inTextContainer_1;
    public static /*const*/ String sel_currencyCode;
    public static /*const*/ String sel_splitView_1canCollapseSubview_1;
    public static /*const*/ String sel_hide;
    public static /*const*/ String sel_setMonth_1;
    public static /*const*/ String sel_dataFromTXTRecordDictionary_1;
    public static /*const*/ String sel_rulerView_1didAddMarker_1;
    public static /*const*/ String sel_deleteBackward_1;
    public static /*const*/ String sel_setMaximumLineHeight_1;
    public static /*const*/ String sel_orderedWindows;
    public static /*const*/ String sel_standaloneWeekdaySymbols;
    public static /*const*/ String sel_isAttached;
    public static /*const*/ String sel_resizeLeftRightCursor;
    public static /*const*/ String sel_methodSignature;
    public static /*const*/ String sel_setDiskCapacity_1;
    public static /*const*/ String sel_lineFragmentRectForGlyphAtIndex_1effectiveRange_1withoutAdditionalLayout_1;
    public static /*const*/ String sel_screen;
    public static /*const*/ String sel_windowNumber;
    public static /*const*/ String sel_selectSegmentWithTag_1;
    public static /*const*/ String sel_availableFontFamilies;
    public static /*const*/ String sel_superclass;
    public static /*const*/ String sel_registeredImageRepClasses;
    public static /*const*/ String sel_needsSizing;
    public static /*const*/ String sel_setUsesAlternatingRowBackgroundColors_1;
    public static /*const*/ String sel_getBitmapDataPlanes_1;
    public static /*const*/ String sel_fontWithFamily_1traits_1weight_1size_1;
    public static /*const*/ String sel_borderColor;
    public static /*const*/ String sel_colorUsingColorSpace_1;
    public static /*const*/ String sel_propertyForKey_1;
    public static /*const*/ String sel_setPublicID_1;
    public static /*const*/ String sel_forwardInvocation_1;
    public static /*const*/ String sel_deleteToBeginningOfLine_1;
    public static /*const*/ String sel_hasNonContiguousLayout;
    public static /*const*/ String sel_getObjects_1;
    public static /*const*/ String sel_clearRecentDocuments_1;
    public static /*const*/ String sel_paletteFontOfSize_1;
    public static /*const*/ String sel_rightMargin;
    public static /*const*/ String sel_browser_1createRowsForColumn_1inMatrix_1;
    public static /*const*/ String sel_removeItemAtPath_1error_1;
    public static /*const*/ String sel_getRectsBeingDrawn_1count_1;
    public static /*const*/ String sel_numberWithUnsignedInt_1;
    public static /*const*/ String sel_complete_1;
    public static /*const*/ String sel_synchronizeTitleAndSelectedItem;
    public static /*const*/ String sel_archiverData;
    public static /*const*/ String sel_selectNextTabViewItem_1;
    public static /*const*/ String sel_displayNameForType_1;
    public static /*const*/ String sel_defaultNameServerPortNumber;
    public static /*const*/ String sel_setFireDate_1;
    public static /*const*/ String sel_selectFirstTabViewItem_1;
    public static /*const*/ String sel_setRightMargin_1;
    public static /*const*/ String sel_menuView;
    public static /*const*/ String sel_removeObjectsFromIndices_1numIndices_1;
    public static /*const*/ String sel_tabKeyTraversesCells;
    public static /*const*/ String sel_initToBuffer_1capacity_1;
    public static /*const*/ String sel_endPage;
    public static /*const*/ String sel_setTextAttributesForNotANumber_1;
    public static /*const*/ String sel_makeNextSegmentKey;
    public static /*const*/ String sel_addAttributes_1range_1;
    public static /*const*/ String sel_lineFragmentPadding;
    public static /*const*/ String sel_showController_1adjustingSize_1;
    public static /*const*/ String sel_glyphInfoWithGlyphName_1forFont_1baseString_1;
    public static /*const*/ String sel_initWithCondition_1;
    public static /*const*/ String sel_handleMachMessage_1;
    public static /*const*/ String sel_setFontMenu_1;
    public static /*const*/ String sel_invocationWithMethodSignature_1;
    public static /*const*/ String sel_textAttributesForPositiveValues;
    public static /*const*/ String sel_decodePointForKey_1;
    public static /*const*/ String sel_doubleForKey_1;
    public static /*const*/ String sel_application_1willPresentError_1;
    public static /*const*/ String sel_setFloatingPointFormat_1left_1right_1;
    public static /*const*/ String sel_loadColumnZero;
    public static /*const*/ String sel_availableFonts;
    public static /*const*/ String sel_drawUnderlineForGlyphRange_1underlineType_1baselineOffset_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1;
    public static /*const*/ String sel_highlightedTableColumn;
    public static /*const*/ String sel_removeObjectsInRange_1;
    public static /*const*/ String sel_rectForKey_1inTable_1;
    public static /*const*/ String sel_canStoreColor;
    public static /*const*/ String sel_windowWillMiniaturize_1;
    public static /*const*/ String sel_documentForWindow_1;
    public static /*const*/ String sel_setAttributedStringForNotANumber_1;
    public static /*const*/ String sel_rangeOfString_1options_1range_1;
    public static /*const*/ String sel_pause;
    public static /*const*/ String sel_continueTracking_1at_1inView_1;
    public static /*const*/ String sel_servicesProvider;
    public static /*const*/ String sel_setIgnoredWords_1inSpellDocumentWithTag_1;
    public static /*const*/ String sel_clear_1;
    public static /*const*/ String sel_readFromData_1options_1documentAttributes_1error_1;
    public static /*const*/ String sel_columnNumber;
    public static /*const*/ String sel_components;
    public static /*const*/ String sel_image;
    public static /*const*/ String sel_setDisplayMode_1;
    public static /*const*/ String sel_insertParagraphSeparator_1;
    public static /*const*/ String sel_setPaperName_1;
    public static /*const*/ String sel_defaultFormatterBehavior;
    public static /*const*/ String sel_timeZoneWithAbbreviation_1;
    public static /*const*/ String sel_setHighlighted_1;
    public static /*const*/ String sel_addFileWithPath_1;
    public static /*const*/ String sel_allowsDocumentBackgroundColorChange;
    public static /*const*/ String sel_initWithURL_1documentAttributes_1;
    public static /*const*/ String sel_allowsUndo;
    public static /*const*/ String sel_localeIdentifierFromComponents_1;
    public static /*const*/ String sel_allowsNonContiguousLayout;
    public static /*const*/ String sel_arrayWithArray_1;
    public static /*const*/ String sel_setCompositingOperation_1;
    public static /*const*/ String sel_netServiceBrowserDidStopSearch_1;
    public static /*const*/ String sel_setHorizontalEdgePadding_1;
    public static /*const*/ String sel_accessibilityActionDescription_1;
    public static /*const*/ String sel_localizedKeyDictionary;
    public static /*const*/ String sel_initWithColorSyncProfile_1;
    public static /*const*/ String sel_displayedCommandsTitle;
    public static /*const*/ String sel_flatness;
    public static /*const*/ String sel_localizations;
    public static /*const*/ String sel_mountedRemovableMedia;
    public static /*const*/ String sel_topAutoreleasePoolCount;
    public static /*const*/ String sel_postsFrameChangedNotifications;
    public static /*const*/ String sel_performZoom_1;
    public static /*const*/ String sel_moveBackward_1;
    public static /*const*/ String sel_verticalPageScroll;
    public static /*const*/ String sel_setToolTip_1forCell_1;
    public static /*const*/ String sel_layoutManagerOwnsFirstResponderInWindow_1;
    public static /*const*/ String sel_jobStyleHint;
    public static /*const*/ String sel_selectionIndexes;
    public static /*const*/ String sel_segmentCount;
    public static /*const*/ String sel_accessibilityIsIgnored;
    public static /*const*/ String sel_hasUnautosavedChanges;
    public static /*const*/ String sel_deactivate;
    public static /*const*/ String sel_setSelectionIndexPaths_1;
    public static /*const*/ String sel_pathForSoundResource_1;
    public static /*const*/ String sel_setUsesRuler_1;
    public static /*const*/ String sel_takeSelectedTabViewItemFromSender_1;
    public static /*const*/ String sel_writeToFile_1ofType_1originalFile_1saveOperation_1;
    public static /*const*/ String sel_numberWithLong_1;
    public static /*const*/ String sel_interiorBackgroundStyle;
    public static /*const*/ String sel_insertionPointColor;
    public static /*const*/ String sel_prompt;
    public static /*const*/ String sel_finishLaunching;
    public static /*const*/ String sel_addTextContainer_1;
    public static /*const*/ String sel_setAutosavedContentsFileURL_1;
    public static /*const*/ String sel_initWithFrame_1textContainer_1;
    public static /*const*/ String sel_clearColor;
    public static /*const*/ String sel_insertText_1;
    public static /*const*/ String sel_sendAction;
    public static /*const*/ String sel_innerRect;
    public static /*const*/ String sel_pointerFunctions;
    public static /*const*/ String sel_key;
    public static /*const*/ String sel_comboBoxSelectionDidChange_1;
    public static /*const*/ String sel_hasMarkedText;
    public static /*const*/ String sel_setDefaultLineCapStyle_1;
    public static /*const*/ String sel_StringListForKey_1inTable_1;
    public static /*const*/ String sel_defaultConnection;
    public static /*const*/ String sel_pathContentOfSymbolicLinkAtPath_1;
    public static /*const*/ String sel_StringWithContentsOfFile_1encoding_1error_1;
    public static /*const*/ String sel_detachSubmenu;
    public static /*const*/ String sel_isSecure;
    public static /*const*/ String sel_movie;
    public static /*const*/ String sel_outlineViewItemWillExpand_1;
    public static /*const*/ String sel_sharedScriptSuiteRegistry;
    public static /*const*/ String sel_removeCharactersInString_1;
    public static /*const*/ String sel_setLocation_1withAdvancements_1forStartOfGlyphRange_1;
    public static /*const*/ String sel_moveDownAndModifySelection_1;
    public static /*const*/ String sel_fileAttributesToWriteToURL_1ofType_1forSaveOperation_1originalContentsURL_1error_1;
    public static /*const*/ String sel_classDescriptionForKey_1;
    public static /*const*/ String sel_addRequestMode_1;
    public static /*const*/ String sel_setPullsDown_1;
    public static /*const*/ String sel_setItemHeight_1;
    public static /*const*/ String sel_printerFont;
    public static /*const*/ String sel_linkTextAttributes;
    public static /*const*/ String sel_state;
    public static /*const*/ String sel_shouldCloseWindowController_1delegate_1shouldCloseSelector_1contextInfo_1;
    public static /*const*/ String sel_addIndex_1;
    public static /*const*/ String sel_setChildSpecifier_1;
    public static /*const*/ String sel_toolbarDidRemoveItem_1;
    public static /*const*/ String sel_displayName;
    public static /*const*/ String sel_setInsertionPointColor_1;
    public static /*const*/ String sel_bezierPathByReversingPath;
    public static /*const*/ String sel_connection_1didReceiveData_1;
    public static /*const*/ String sel_eraSymbols;
    public static /*const*/ String sel_removeObjectsForKeys_1;
    public static /*const*/ String sel_subrowIndexesForRow_1;
    public static /*const*/ String sel_increaseLengthBy_1;
    public static /*const*/ String sel_viewDidEndLiveResize;
    public static /*const*/ String sel_encodeBool_1forKey_1;
    public static /*const*/ String sel_handleQueryWithUnboundKey_1;
    public static /*const*/ String sel_elementsForName_1;
    public static /*const*/ String sel_cascadeTopLeftFromPoint_1;
    public static /*const*/ String sel_linkItemAtPath_1toPath_1error_1;
    public static /*const*/ String sel_frameSizeForContentSize_1hasHorizontalScroller_1hasVerticalScroller_1borderType_1;
    public static /*const*/ String sel_initWithString_1attributes_1;
    public static /*const*/ String sel_readFromData_1options_1documentAttributes_1;
    public static /*const*/ String sel_setAlpha_1;
    public static /*const*/ String sel_hash;
    public static /*const*/ String sel_rangeForUserParagraphAttributeChange;
    public static /*const*/ String sel_initWithData_1encoding_1;
    public static /*const*/ String sel_newScriptingObjectOfClass_1forValueForKey_1withContentsValue_1properties_1;
    public static /*const*/ String sel_pageDown_1;
    public static /*const*/ String sel_hasCloseBox;
    public static /*const*/ String sel_standardizedURL;
    public static /*const*/ String sel_setAttributes_1range_1;
    public static /*const*/ String sel_setControlSize_1;
    public static /*const*/ String sel_revertToInitialValues_1;
    public static /*const*/ String sel_setIntAttribute_1value_1forGlyphAtIndex_1;
    public static /*const*/ String sel_stopTracking_1at_1inView_1mouseIsUp_1;
    public static /*const*/ String sel_setParamDescriptor_1forKeyword_1;
    public static /*const*/ String sel_textShouldBeginEditing_1;
    public static /*const*/ String sel_applicationDidHide_1;
    public static /*const*/ String sel_beginSheetWithPrintInfo_1modalForWindow_1delegate_1didEndSelector_1contextInfo_1;
    public static /*const*/ String sel_shiftIndexesStartingAtIndex_1by_1;
    public static /*const*/ String sel_getStreamsToHost_1port_1inputStream_1outputStream_1;
    public static /*const*/ String sel_attributesOfFileSystemForPath_1error_1;
    public static /*const*/ String sel_setTemporaryAttributes_1forCharacterRange_1;
    public static /*const*/ String sel_checkSpellingOfString_1startingAt_1language_1wrap_1inSpellDocumentWithTag_1wordCount_1;
    public static /*const*/ String sel_insertChild_1atIndex_1;
    public static /*const*/ String sel_defaultManager;
    public static /*const*/ String sel_invocation;
    public static /*const*/ String sel_setMinValue_1;
    public static /*const*/ String sel_decodeSize;
    public static /*const*/ String sel_replaceObject_1withObject_1;
    public static /*const*/ String sel_descriptionWithLocale_1;
    public static /*const*/ String sel_setSharingType_1;
    public static /*const*/ String sel_isLenient;
    public static /*const*/ String sel_decimalNumberWithString_1locale_1;
    public static /*const*/ String sel_allowedTypes;
    public static /*const*/ String sel_superscript_1;
    public static /*const*/ String sel_initWithContentsOfFile_1encoding_1error_1;
    public static /*const*/ String sel_windowsMenu;
    public static /*const*/ String sel_performSelector_1target_1argument_1order_1modes_1;
    public static /*const*/ String sel_unscheduleFromRunLoop_1forMode_1;
    public static /*const*/ String sel_evaluatedArguments;
    public static /*const*/ String sel_encodeSize_1forKey_1;
    public static /*const*/ String sel_sendBeforeDate_1components_1from_1reserved_1;
    public static /*const*/ String sel_containerSize;
    public static /*const*/ String sel_selectedTextColor;
    public static /*const*/ String sel_getGlyphsInRange_1glyphs_1characterIndexes_1glyphInscriptions_1elasticBits_1;
    public static /*const*/ String sel_curveToPoint_1controlPoint1_1controlPoint2_1;
    public static /*const*/ String sel_mutableBytes;
    public static /*const*/ String sel_rangeOfUnit_1inUnit_1forDate_1;
    public static /*const*/ String sel_allowsNaturalLanguage;
    public static /*const*/ String sel_mouseLocation;
    public static /*const*/ String sel_selectCellAtRow_1column_1;
    public static /*const*/ String sel_toggleBaseWritingDirection_1;
    public static /*const*/ String sel_maximum;
    public static /*const*/ String sel_initWithFocusedViewRect_1;
    public static /*const*/ String sel_thickness;
    public static /*const*/ String sel_setImageOrigin_1;
    public static /*const*/ String sel_color;
    public static /*const*/ String sel_capitalizeWord_1;
    public static /*const*/ String sel_imageRepClassForData_1;
    public static /*const*/ String sel_outlineTableColumn;
    public static /*const*/ String sel_runModalWithPrintInfo_1;
    public static /*const*/ String sel_flushCachedData;
    public static /*const*/ String sel_exitFullScreenModeWithOptions_1;
    public static /*const*/ String sel_alertStyle;
    public static /*const*/ String sel_runModalPageLayoutWithPrintInfo_1delegate_1didRunSelector_1contextInfo_1;
    public static /*const*/ String sel_setDisplayedWhenStopped_1;
    public static /*const*/ String sel_drawBackgroundWithFrame_1inView_1characterRange_1layoutManager_1;
    public static /*const*/ String sel_addObject_1;
    public static /*const*/ String sel_dragPromisedFilesOfTypes_1fromRect_1source_1slideBack_1event_1;
    public static /*const*/ String sel_samplesPerPixel;
    public static /*const*/ String sel_negativePrefix;
    public static /*const*/ String sel_initialKey;
    public static /*const*/ String sel_orderFrontColorPanel_1;
    public static /*const*/ String sel_hasLearnedWord_1;
    public static /*const*/ String sel_setLineFragmentRect_1forGlyphRange_1usedRect_1baselineOffset_1;
    public static /*const*/ String sel_setHidesOnDeactivate_1;
    public static /*const*/ String sel_setMsgid_1;
    public static /*const*/ String sel_elementCount;
    public static /*const*/ String sel_dateWithString_1;
    public static /*const*/ String sel_rangeOfTextBlock_1atIndex_1;
    public static /*const*/ String sel_setMenuItemCell_1forItemAtIndex_1;
    public static /*const*/ String sel_defaultTimeZone;
    public static /*const*/ String sel_gotoBeginning_1;
    public static /*const*/ String sel_setDrawsOutsideLineFragment_1forGlyphAtIndex_1;
    public static /*const*/ String sel_characterCollection;
    public static /*const*/ String sel_getValues_1forParameter_1;
    public static /*const*/ String sel_removeColumn_1;
    public static /*const*/ String sel_descender;
    public static /*const*/ String sel_fragment;
    public static /*const*/ String sel_setSelectionByRect_1;
    public static /*const*/ String sel_colorWithColorSpace_1components_1count_1;
    public static /*const*/ String sel_windingRule;
    public static /*const*/ String sel_insertColumn_1;
    public static /*const*/ String sel_resumeWithSuspensionID_1;
    public static /*const*/ String sel_seekToEndOfFile;
    public static /*const*/ String sel_initWithTarget_1connection_1;
    public static /*const*/ String sel_symbolCharacterSet;
    public static /*const*/ String sel_filterPredicate;
    public static /*const*/ String sel_setAutoenablesItems_1;
    public static /*const*/ String sel_printShowingPrintPanel_1;
    public static /*const*/ String sel_pathForResource_1ofType_1inDirectory_1forLocalization_1;
    public static /*const*/ String sel_objectByApplyingXSLTAtURL_1arguments_1error_1;
    public static /*const*/ String sel_setHidesEmptyCells_1;
    public static /*const*/ String sel_date;
    public static /*const*/ String sel_writeToFile_1atomically_1;
    public static /*const*/ String sel_locale;
    public static /*const*/ String sel_localizedKeyTable;
    public static /*const*/ String sel_absoluteURL;
    public static /*const*/ String sel_bundleWithPath_1;
    public static /*const*/ String sel_setHeaderCell_1;
    public static /*const*/ String sel_setAutoresizesSubviews_1;
    public static /*const*/ String sel_URI;
    public static /*const*/ String sel_controlBackgroundColor;
    public static /*const*/ String sel_displayNameAtPath_1;
    public static /*const*/ String sel_decodePortObject;
    public static /*const*/ String sel_alpha;
    public static /*const*/ String sel_initWithLeftExpression_1rightExpression_1customSelector_1;
    public static /*const*/ String sel_secondaryGroupingSize;
    public static /*const*/ String sel_connectionDidFinishLoading_1;
    public static /*const*/ String sel_localObjects;
    public static /*const*/ String sel_enableKeyEquivalentForDefaultButtonCell;
    public static /*const*/ String sel_drawKnobSlotInRect_1highlight_1;
    public static /*const*/ String sel_dateWithString_1calendarFormat_1locale_1;
    public static /*const*/ String sel_stop;
    public static /*const*/ String sel_appendBezierPathWithOvalInRect_1;
    public static /*const*/ String sel_componentsSeparatedByCharactersInSet_1;
    public static /*const*/ String sel_tightenKerning_1;
    public static /*const*/ String sel_verticalRulerView;
    public static /*const*/ String sel_setImageAlignment_1;
    public static /*const*/ String sel_removeFrameUsingName_1;
    public static /*const*/ String sel_insertColor_1key_1atIndex_1;
    public static /*const*/ String sel_terminate_1;
    public static /*const*/ String sel_textContainerChangedTextView_1;
    public static /*const*/ String sel_removeFileAtPath_1handler_1;
    public static /*const*/ String sel_splitViewWillResizeSubviews_1;
    public static /*const*/ String sel_windowDidBecomeMain_1;
    public static /*const*/ String sel_cellBaselineOffset;
    public static /*const*/ String sel_addEntriesFromDictionary_1;
    public static /*const*/ String sel_setOnStateImage_1;
    public static /*const*/ String sel_colorWithCIColor_1;
    public static /*const*/ String sel_getCyan_1magenta_1yellow_1black_1alpha_1;
    public static /*const*/ String sel_symbolicTraits;
    public static /*const*/ String sel_StringByAppendingPathExtension_1;
    public static /*const*/ String sel_horizontalScroller;
    public static /*const*/ String sel_setInitialValue_1;
    public static /*const*/ String sel_sizeForPaperName_1;
    public static /*const*/ String sel_CGLContextObj;
    public static /*const*/ String sel_elementWithName_1;
    public static /*const*/ String sel_fileManager_1shouldMoveItemAtPath_1toPath_1;
    public static /*const*/ String sel_richTextSource;
    public static /*const*/ String sel_unregisterDraggedTypes;
    public static /*const*/ String sel_absoluteString;
    public static /*const*/ String sel_spellingPanel;
    public static /*const*/ String sel_launchedApplications;
    public static /*const*/ String sel_initWithContentsOfFile_1byReference_1;
    public static /*const*/ String sel_setLoaded_1;
    public static /*const*/ String sel_setWindowFrameAutosaveName_1;
    public static /*const*/ String sel_initOrTestWithTests_1;
    public static /*const*/ String sel_drawsBackground;
    public static /*const*/ String sel_numberWithDouble_1;
    public static /*const*/ String sel_textView_1writeCell_1atIndex_1toPasteboard_1type_1;
    public static /*const*/ String sel_defaultMiterLimit;
    public static /*const*/ String sel_containsObject_1;
    public static /*const*/ String sel_headerTextColor;
    public static /*const*/ String sel_textView_1doCommandBySelector_1;
    public static /*const*/ String sel_drawBorderAndBackgroundWithFrame_1inView_1;
    public static /*const*/ String sel_quarterSymbols;
    public static /*const*/ String sel_setContainerSize_1;
    public static /*const*/ String sel_sortUsingSelector_1;
    public static /*const*/ String sel_setKey_1;
    public static /*const*/ String sel_headerView;
    public static /*const*/ String sel_isRegularFile;
    public static /*const*/ String sel_userData;
    public static /*const*/ String sel_documentCursor;
    public static /*const*/ String sel_textEncodingName;
    public static /*const*/ String sel_performActionForItemAtIndex_1;
    public static /*const*/ String sel_isCaseInsensitiveLike_1;
    public static /*const*/ String sel_isEditing;
    public static /*const*/ String sel_selectFile_1inFileViewerRootedAtPath_1;
    public static /*const*/ String sel_messageFontOfSize_1;
    public static /*const*/ String sel_independentConversationQueueing;
    public static /*const*/ String sel_initWithCoder_1;
    public static /*const*/ String sel_rangesForUserParagraphAttributeChange;
    public static /*const*/ String sel_removeTrackingArea_1;
    public static /*const*/ String sel_glyphGenerator;
    public static /*const*/ String sel_extraLineFragmentUsedRect;
    public static /*const*/ String sel_isButtonBordered;
    public static /*const*/ String sel_setDefaultFormatterBehavior_1;
    public static /*const*/ String sel_didChange_1valuesAtIndexes_1forKey_1;
    public static /*const*/ String sel_timeoutInterval;
    public static /*const*/ String sel_initialValues;
    public static /*const*/ String sel_getRow_1column_1forPoint_1;
    public static /*const*/ String sel_tabletPoint_1;
    public static /*const*/ String sel_setAutorecalculatesKeyViewLoop_1;
    public static /*const*/ String sel_identifier;
    public static /*const*/ String sel_scheduleInRunLoop_1forMode_1;
    public static /*const*/ String sel_baseURL;
    public static /*const*/ String sel_initWithURL_1;
    public static /*const*/ String sel_setBackgroundColors_1;
    public static /*const*/ String sel_addTableColumn_1;
    public static /*const*/ String sel_fontDescriptorWithFontAttributes_1;
    public static /*const*/ String sel_dataCellForRow_1;
    public static /*const*/ String sel_speechSynthesizer_1didEncounterErrorAtIndex_1ofString_1message_1;
    public static /*const*/ String sel_recoveryAttempter;
    public static /*const*/ String sel_alignJustified_1;
    public static /*const*/ String sel_setCompression_1factor_1;
    public static /*const*/ String sel_elementsForLocalName_1URI_1;
    public static /*const*/ String sel_deviceGrayColorSpace;
    public static /*const*/ String sel_scheduledTimerWithTimeInterval_1target_1selector_1userInfo_1repeats_1;
    public static /*const*/ String sel_runModalSession_1;
    public static /*const*/ String sel_awakeFromNib;
    public static /*const*/ String sel_connectionWithReceivePort_1sendPort_1;
    public static /*const*/ String sel_outlineView_1validateDrop_1proposedItem_1proposedChildIndex_1;
    public static /*const*/ String sel_remove_1;
    public static /*const*/ String sel_setTimeInterval_1;
    public static /*const*/ String sel_splitView_1effectiveRect_1forDrawnRect_1ofDividerAtIndex_1;
    public static /*const*/ String sel_setUpGState;
    public static /*const*/ String sel_initWithResponse_1data_1;
    public static /*const*/ String sel_notificationCenter;
    public static /*const*/ String sel_setAlternateImage_1;
    public static /*const*/ String sel_mainWindow;
    public static /*const*/ String sel_subStringWithRange_1;
    public static /*const*/ String sel_forgetWord_1;
    public static /*const*/ String sel_shouldCascadeWindows;
    public static /*const*/ String sel_updateScroller;
    public static /*const*/ String sel_currentDirectoryPath;
    public static /*const*/ String sel_isPartialStringValidationEnabled;
    public static /*const*/ String sel_splitView_1constrainMinCoordinate_1ofSubviewAt_1;
    public static /*const*/ String sel_drawWithFrame_1inView_1;
    public static /*const*/ String sel_encodingScheme;
    public static /*const*/ String sel_namespaceWithName_1StringValue_1;
    public static /*const*/ String sel_initWithLongLong_1;
    public static /*const*/ String sel_processIdentifier;
    public static /*const*/ String sel_setSubmenu_1forItem_1;
    public static /*const*/ String sel_textAttributesForNil;
    public static /*const*/ String sel_lockWithPath_1;
    public static /*const*/ String sel_removeFromSuperviewWithoutNeedingDisplay;
    public static /*const*/ String sel_cut_1;
    public static /*const*/ String sel_nullDescriptor;
    public static /*const*/ String sel_menuFormRepresentation;
    public static /*const*/ String sel_removeObjectsAtIndexes_1;
    public static /*const*/ String sel_initWithSource_1;
    public static /*const*/ String sel_acceptsGlyphInfo;
    public static /*const*/ String sel_borderType;
    public static /*const*/ String sel_initWithResumeData_1delegate_1path_1;
    public static /*const*/ String sel_attachedMenu;
    public static /*const*/ String sel_stopAnimation;
    public static /*const*/ String sel_setDoubleAction_1;
    public static /*const*/ String sel_returnType;
    public static /*const*/ String sel_fontDescriptorsInCollection_1;
    public static /*const*/ String sel_setMeasurementUnits_1;
    public static /*const*/ String sel_baseWritingDirection;
    public static /*const*/ String sel_currentPoint;
    public static /*const*/ String sel_initRemoteWithTCPPort_1host_1;
    public static /*const*/ String sel_entityDeclarationForName_1;
    public static /*const*/ String sel_evaluate;
    public static /*const*/ String sel_browser_1draggingImageForRowsWithIndexes_1inColumn_1withEvent_1offset_1;
    public static /*const*/ String sel_turnOffLigatures_1;
    public static /*const*/ String sel_setTitleWithMnemonic_1;
    public static /*const*/ String sel_deepestScreen;
    public static /*const*/ String sel_connection_1shouldMakeNewConnection_1;
    public static /*const*/ String sel_selectionShouldChangeInOutlineView_1;
    public static /*const*/ String sel_preservesSelection;
    public static /*const*/ String sel_preparePageLayout_1;
    public static /*const*/ String sel_setOpaque_1;
    public static /*const*/ String sel_insertObject_1atIndex_1;
    public static /*const*/ String sel_isActive;
    public static /*const*/ String sel_drawStrikethroughForGlyphRange_1strikethroughType_1baselineOffset_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1;
    public static /*const*/ String sel_insertObject_1atArrangedObjectIndex_1;
    public static /*const*/ String sel_initWithCStringNoCopy_1length_1freeWhenDone_1;
    public static /*const*/ String sel_previousKeyView;
    public static /*const*/ String sel_performMiniaturize_1;
    public static /*const*/ String sel_decimalNumberWithDecimal_1;
    public static /*const*/ String sel_autosaveTableColumns;
    public static /*const*/ String sel_baselineOffsetInLayoutManager_1glyphIndex_1;
    public static /*const*/ String sel_keyViewSelectionDirection;
    public static /*const*/ String sel_encodeBytes_1length_1;
    public static /*const*/ String sel_fileManager_1shouldProceedAfterError_1copyingItemAtPath_1toPath_1;
    public static /*const*/ String sel_menuNeedsUpdate_1;
    public static /*const*/ String sel_paragraphSpacingAfterGlyphAtIndex_1withProposedLineFragmentRect_1;
    public static /*const*/ String sel_synchronize;
    public static /*const*/ String sel_lockFocus;
    public static /*const*/ String sel_toggleSmartInsertDelete_1;
    public static /*const*/ String sel_setMenu_1forSegment_1;
    public static /*const*/ String sel_removeParamDescriptorWithKeyword_1;
    public static /*const*/ String sel_applicationShouldOpenUntitledFile_1;
    public static /*const*/ String sel_DTD;
    public static /*const*/ String sel_cancelTracking;
    public static /*const*/ String sel_fileSystemNumber;
    public static /*const*/ String sel_setLevel_1;
    public static /*const*/ String sel_setRequiredFileType_1;
    public static /*const*/ String sel_presentError_1;
    public static /*const*/ String sel_allowsUserCustomization;
    public static /*const*/ String sel_childrenKeyPathForNode_1;
    public static /*const*/ String sel_setYear_1;
    public static /*const*/ String sel_movieController;
    public static /*const*/ String sel_unsignedLongValue;
    public static /*const*/ String sel_hashTableWithOptions_1;
    public static /*const*/ String sel_setVerticalAlignment_1;
    public static /*const*/ String sel_cycleToNextInputServerInLanguage_1;
    public static /*const*/ String sel_sendAction_1to_1from_1;
    public static /*const*/ String sel_numberFromString_1;
    public static /*const*/ String sel_setUndoManager_1;
    public static /*const*/ String sel_imageDimsWhenDisabled;
    public static /*const*/ String sel_autosavingFileType;
    public static /*const*/ String sel_unsignedLongLongValue;
    public static /*const*/ String sel_initImageCell_1;
    public static /*const*/ String sel_invalidateDisplayForCharacterRange_1;
    public static /*const*/ String sel_setMaxContentSize_1;
    public static /*const*/ String sel_outlineView_1isItemExpandable_1;
    public static /*const*/ String sel_initWithUser_1password_1persistence_1;
    public static /*const*/ String sel_setBackgroundFilters_1;
    public static /*const*/ String sel_setAllowsDocumentBackgroundColorChange_1;
    public static /*const*/ String sel_decodeNXObject;
    public static /*const*/ String sel_setMaximumSignificantDigits_1;
    public static /*const*/ String sel_URLsFromRunningOpenPanel;
    public static /*const*/ String sel_removeChildWindow_1;
    public static /*const*/ String sel_removeObjectForKey_1;
    public static /*const*/ String sel_setCellSize_1;
    public static /*const*/ String sel_getParagraphStart_1end_1contentsEnd_1forRange_1;
    public static /*const*/ String sel_connectionWithRequest_1delegate_1;
    public static /*const*/ String sel_setNotShownAttribute_1forGlyphRange_1;
    public static /*const*/ String sel_collapsesBorders;
    public static /*const*/ String sel_setNegativeInfinitySymbol_1;
    public static /*const*/ String sel_initWithKind_1;
    public static /*const*/ String sel_appleEventCodeForArgumentWithName_1;
    public static /*const*/ String sel_moveUp_1;
    public static /*const*/ String sel_initWithTextAlignment_1location_1options_1;
    public static /*const*/ String sel_systemVersion;
    public static /*const*/ String sel_numberOfItemsInComboBoxCell_1;
    public static /*const*/ String sel_readableTypes;
    public static /*const*/ String sel_setDraggingSourceOperationMask_1forLocal_1;
    public static /*const*/ String sel_insertLineBreak_1;
    public static /*const*/ String sel_inLiveResize;
    public static /*const*/ String sel_setCanHide_1;
    public static /*const*/ String sel_nextResponder;
    public static /*const*/ String sel_scrollClipView_1toPoint_1;
    public static /*const*/ String sel_positiveFormat;
    public static /*const*/ String sel_redoMenuItemTitle;
    public static /*const*/ String sel_addIndexesInRange_1;
    public static /*const*/ String sel_lockBeforeDate_1;
    public static /*const*/ String sel_unlockWithCondition_1;
    public static /*const*/ String sel_nextWordFromIndex_1forward_1;
    public static /*const*/ String sel_waitUntilAllOperationsAreFinished;
    public static /*const*/ String sel_drawRow_1clipRect_1;
    public static /*const*/ String sel_setPartialStringValidationEnabled_1;
    public static /*const*/ String sel_methodSignatureForSelector_1;
    public static /*const*/ String sel_setSecondaryGroupingSize_1;
    public static /*const*/ String sel_criteriaForRow_1;
    public static /*const*/ String sel_setShadowBlurRadius_1;
    public static /*const*/ String sel_expressionForFunction_1selectorName_1arguments_1;
    public static /*const*/ String sel_initWithWindowNibName_1;
    public static /*const*/ String sel_selectItemWithTag_1;
    public static /*const*/ String sel_characterIndexForPoint_1;
    public static /*const*/ String sel_validate;
    public static /*const*/ String sel_setHorizontalPageScroll_1;
    public static /*const*/ String sel_localizedColorNameComponent;
    public static /*const*/ String sel_setVoice_1;
    public static /*const*/ String sel_setCachedSeparately_1;
    public static /*const*/ String sel_frameRectForContentRect_1;
    public static /*const*/ String sel_bezelStyle;
    public static /*const*/ String sel_setDecimalSeparator_1;
    public static /*const*/ String sel_conversationIdentifier;
    public static /*const*/ String sel_setPrompt_1;
    public static /*const*/ String sel_setShowsFirstResponder_1;
    public static /*const*/ String sel_setRootObject_1;
    public static /*const*/ String sel_menuBarVisible;
    public static /*const*/ String sel_netServiceBrowser_1didRemoveDomain_1moreComing_1;
    public static /*const*/ String sel_threadPriority;
    public static /*const*/ String sel_countKeyPath;
    public static /*const*/ String sel_runCustomizationPalette_1;
    public static /*const*/ String sel_fileHandleWithStandardError;
    public static /*const*/ String sel_documentContentKind;
    public static /*const*/ String sel_view_1StringForToolTip_1point_1userData_1;
    public static /*const*/ String sel_nameFieldLabel;
    public static /*const*/ String sel_miniaturizeAll_1;
    public static /*const*/ String sel_initWithRepresentedObject_1;
    public static /*const*/ String sel_runOperation;
    public static /*const*/ String sel_drawBackgroundForBlock_1withFrame_1inView_1characterRange_1layoutManager_1;
    public static /*const*/ String sel_localizedInfoDictionary;
    public static /*const*/ String sel_scanFloat_1;
    public static /*const*/ String sel_scanHexDouble_1;
    public static /*const*/ String sel_continueSpeaking;
    public static /*const*/ String sel_attachedMenuView;
    public static /*const*/ String sel_wantsToHandleMouseEvents;
    public static /*const*/ String sel_attemptRecoveryFromError_1optionIndex_1;
    public static /*const*/ String sel_window_1shouldDragDocumentWithEvent_1from_1withPasteboard_1;
    public static /*const*/ String sel_mouseEntered_1;
    public static /*const*/ String sel_setNameFieldLabel_1;
    public static /*const*/ String sel_setIndentationPerLevel_1;
    public static /*const*/ String sel_setMinColumnWidth_1;
    public static /*const*/ String sel_classNameForClass_1;
    public static /*const*/ String sel_runLoopModes;
    public static /*const*/ String sel_pullsDown;
    public static /*const*/ String sel_setOutlineTableColumn_1;
    public static /*const*/ String sel_windowDidLoad;
    public static /*const*/ String sel_read_1maxLength_1;
    public static /*const*/ String sel_removeItemAtIndex_1;
    public static /*const*/ String sel_initWithColor_1;
    public static /*const*/ String sel_compare_1options_1;
    public static /*const*/ String sel_removeTableColumn_1;
    public static /*const*/ String sel_isRedoing;
    public static /*const*/ String sel_setTitleWithRepresentedFilename_1;
    public static /*const*/ String sel_setDirectory_1;
    public static /*const*/ String sel_makeDocumentWithContentsOfURL_1ofType_1error_1;
    public static /*const*/ String sel_isSelectedForSegment_1;
    public static /*const*/ String sel_month;
    public static /*const*/ String sel_addRow;
    public static /*const*/ String sel_layoutOptions;
    public static /*const*/ String sel_maxNumberOfRows;
    public static /*const*/ String sel_setUpPrintOperationDefaultValues;
    public static /*const*/ String sel_initByReferencingURL_1;
    public static /*const*/ String sel_class;
    public static /*const*/ String sel_setFrameAutosaveName_1;
    public static /*const*/ String sel_fileWrapperFromRange_1documentAttributes_1error_1;
    public static /*const*/ String sel_int32Value;
    public static /*const*/ String sel_setControlView_1;
    public static /*const*/ String sel_setCharacterEncoding_1;
    public static /*const*/ String sel_disableFlushWindow;
    public static /*const*/ String sel_insertString_1atIndex_1;
    public static /*const*/ String sel_childNodes;
    public static /*const*/ String sel_rangeContainerObject;
    public static /*const*/ String sel_kind;
    public static /*const*/ String sel_title;
    public static /*const*/ String sel_bundleWithIdentifier_1;
    public static /*const*/ String sel_initWithMovie_1;
    public static /*const*/ String sel_unionHashTable_1;
    public static /*const*/ String sel_setStartSpecifier_1;
    public static /*const*/ String sel_browser_1nextTypeSelectMatchFromRow_1toRow_1inColumn_1forString_1;
    public static /*const*/ String sel_tokenFieldCell_1representedObjectForEditingString_1;
    public static /*const*/ String sel_initWithContentsOfFile_1;
    public static /*const*/ String sel_dataWithContentsOfURL_1;
    public static /*const*/ String sel_firstWeekday;
    public static /*const*/ String sel_setInitialValues_1;
    public static /*const*/ String sel_setIntegerValue_1;
    public static /*const*/ String sel_calcSize;
    public static /*const*/ String sel_setTokenizingCharacterSet_1;
    public static /*const*/ String sel_setRepresentedFilename_1;
    public static /*const*/ String sel_colorSpaceName;
    public static /*const*/ String sel_setLineBreakMode_1;
    public static /*const*/ String sel_appliesImmediately;
    public static /*const*/ String sel_classDescriptionWithAppleEventCode_1;
    public static /*const*/ String sel_eventRef;
    public static /*const*/ String sel_textAttributesForZero;
    public static /*const*/ String sel_setAutosavesConfiguration_1;
    public static /*const*/ String sel_countOfIndexesInRange_1;
    public static /*const*/ String sel_count;
    public static /*const*/ String sel_initWithSuiteName_1className_1dictionary_1;
    public static /*const*/ String sel_isReleasedWhenClosed;
    public static /*const*/ String sel_windowWithWindowNumber_1;
    public static /*const*/ String sel_removeNamespaceForPrefix_1;
    public static /*const*/ String sel_documentWithRootElement_1;
    public static /*const*/ String sel_pageFooter;
    public static /*const*/ String sel_initWithOptions_1capacity_1;
    public static /*const*/ String sel_insertBacktab_1;
    public static /*const*/ String sel_changeWindowsItem_1title_1filename_1;
    public static /*const*/ String sel_changeCount;
    public static /*const*/ String sel_paragraphCharacterRange;
    public static /*const*/ String sel_currentProgress;
    public static /*const*/ String sel_parser_1didStartMappingPrefix_1toURI_1;
    public static /*const*/ String sel_setFormatWidth_1;
    public static /*const*/ String sel_cancelAllOperations;
    public static /*const*/ String sel_beginLoadInBackground;
    public static /*const*/ String sel_draggedDistance;
    public static /*const*/ String sel_setIndex_1;
    public static /*const*/ String sel_initWithScheme_1host_1path_1;
    public static /*const*/ String sel_toolTipForCell_1;
    public static /*const*/ String sel_predicateForRow_1;
    public static /*const*/ String sel_predefinedEntityDeclarationForName_1;
    public static /*const*/ String sel_replacePointerAtIndex_1withPointer_1;
    public static /*const*/ String sel_fileURLWithPath_1;
    public static /*const*/ String sel_currentDocument;
    public static /*const*/ String sel_shouldDrawInsertionPoint;
    public static /*const*/ String sel_saveAllDocuments_1;
    public static /*const*/ String sel_windowControllerWillLoadNib_1;
    public static /*const*/ String sel_closeAllDocumentsWithDelegate_1didCloseAllSelector_1contextInfo_1;
    public static /*const*/ String sel_tableView_1heightOfRow_1;
    public static /*const*/ String sel_postNotificationName_1object_1userInfo_1options_1;
    public static /*const*/ String sel_imageTypes;
    public static /*const*/ String sel_setPreferredBackingLocation_1;
    public static /*const*/ String sel_netServiceDidPublish_1;
    public static /*const*/ String sel_diskCapacity;
    public static /*const*/ String sel_initWithString_1calendarFormat_1locale_1;
    public static /*const*/ String sel_preferredEdge;
    public static /*const*/ String sel_comboBoxCell_1indexOfItemWithStringValue_1;
    public static /*const*/ String sel_replaceCharactersInRange_1withString_1;
    public static /*const*/ String sel_initWithTimeIntervalSinceReferenceDate_1;
    public static /*const*/ String sel_secondsFromGMT;
    public static /*const*/ String sel_hasOrderedToManyRelationshipForKey_1;
    public static /*const*/ String sel_resignFirstResponder;
    public static /*const*/ String sel_netServiceDidStop_1;
    public static /*const*/ String sel_absoluteY;
    public static /*const*/ String sel_beginModalSessionForWindow_1;
    public static /*const*/ String sel_alignment;
    public static /*const*/ String sel_setCharactersToBeSkipped_1;
    public static /*const*/ String sel_requestWithURL_1cachePolicy_1timeoutInterval_1;
    public static /*const*/ String sel_ruler;
    public static /*const*/ String sel_isSetOnMouseExited;
    public static /*const*/ String sel_setRemovable_1;
    public static /*const*/ String sel_draggingSource;
    public static /*const*/ String sel_textView_1clickedOnLink_1;
    public static /*const*/ String sel_canBeVisibleOnAllSpaces;
    public static /*const*/ String sel_setBadgeLabel_1;
    public static /*const*/ String sel_parser_1foundUnparsedEntityDeclarationWithName_1publicID_1systemID_1notationName_1;
    public static /*const*/ String sel_operations;
    public static /*const*/ String sel_setInteger_1forKey_1;
    public static /*const*/ String sel_otherMouseUp_1;
    public static /*const*/ String sel_drawImageWithFrame_1inView_1;
    public static /*const*/ String sel_getPixel_1atX_1y_1;
    public static /*const*/ String sel_standardError;
    public static /*const*/ String sel_setLabel_1;
    public static /*const*/ String sel_initWithUnsignedInt_1;
    public static /*const*/ String sel_isFinished;
    public static /*const*/ String sel_drawSwatchInRect_1;
    public static /*const*/ String sel_descriptorAtIndex_1;
    public static /*const*/ String sel_cachedHandleForURL_1;
    public static /*const*/ String sel_classCode;
    public static /*const*/ String sel_resolvesAliases;
    public static /*const*/ String sel_textTypes;
    public static /*const*/ String sel_invalidateTextContainerOrigin;
    public static /*const*/ String sel_document;
    public static /*const*/ String sel_interiorBackgroundStyleForSegment_1;
    public static /*const*/ String sel_transformedValue_1;
    public static /*const*/ String sel_subStringToIndex_1;
    public static /*const*/ String sel_addDocument_1;
    public static /*const*/ String sel_numberWithInteger_1;
    public static /*const*/ String sel_setBoundsRotation_1;
    public static /*const*/ String sel_convertFont_1toFace_1;
    public static /*const*/ String sel_updateInsertionPointStateAndRestartTimer_1;
    public static /*const*/ String sel_tryToPerform_1with_1;
    public static /*const*/ String sel_defaultLineHeightForFont;
    public static /*const*/ String sel_scriptingIsEqualTo_1;
    public static /*const*/ String sel_setDoubleValue_1;
    public static /*const*/ String sel_AMSymbol;
    public static /*const*/ String sel_valueWraps;
    public static /*const*/ String sel_allCredentials;
    public static /*const*/ String sel_editingDelegate;
    public static /*const*/ String sel_maintainsInactiveSelection;
    public static /*const*/ String sel_policyDelegate;
    public static /*const*/ String sel_preferences;
    public static /*const*/ String sel_registerViewClass_1representationClass_1forMIMEType_1;
    public static /*const*/ String sel_setHostWindow_1;
    public static /*const*/ String sel_hostWindow;
    public static /*const*/ String sel_searchFor_1direction_1caseSensitive_1wrap_1;
    public static /*const*/ String sel_initWithFrame_1frameName_1groupName_1;
    public static /*const*/ String sel_canGoBack;
    public static /*const*/ String sel_setFrameLoadDelegate_1;
    public static /*const*/ String sel_takeStringURLFrom_1;
    public static /*const*/ String sel_registerURLSchemeAsLocal_1;
    public static /*const*/ String sel_StringByEvaluatingJavaScriptFromString_1;
    public static /*const*/ String sel_replaceSelectionWithMarkupString_1;
    public static /*const*/ String sel_setPreferences_1;
    public static /*const*/ String sel_customUserAgent;
    public static /*const*/ String sel_mainFrame;
    public static /*const*/ String sel_goToBackForwardItem_1;
    public static /*const*/ String sel_pasteboardTypesForElement_1;
    public static /*const*/ String sel_applyStyle_1;
    public static /*const*/ String sel_setResourceLoadDelegate_1;
    public static /*const*/ String sel_moveToBeginningOfSentenceAndModifySelection_1;
    public static /*const*/ String sel_replaceSelectionWithArchive_1;
    public static /*const*/ String sel_userAgentForURL_1;
    public static /*const*/ String sel_frameLoadDelegate;
    public static /*const*/ String sel_windowScriptObject;
    public static /*const*/ String sel_removeDragCaret;
    public static /*const*/ String sel_editableDOMRangeForPoint_1;
    public static /*const*/ String sel_moveToEndOfSentence_1;
    public static /*const*/ String sel_preferencesIdentifier;
    public static /*const*/ String sel_setPolicyDelegate_1;
    public static /*const*/ String sel_goBack;
    public static /*const*/ String sel_downloadDelegate;
    public static /*const*/ String sel_canShowMIMEType_1;
    public static /*const*/ String sel_elementAtPoint_1;
    public static /*const*/ String sel_groupName;
    public static /*const*/ String sel_selectedFrame;
    public static /*const*/ String sel_setMIMETypesShownAsHTML_1;
    public static /*const*/ String sel_goForward;
    public static /*const*/ String sel_makeTextStandardSize_1;
    public static /*const*/ String sel_setMainFrameURL_1;
    public static /*const*/ String sel_pasteboardTypesForSelection;
    public static /*const*/ String sel_customTextEncodingName;
    public static /*const*/ String sel_MIMETypesShownAsHTML;
    public static /*const*/ String sel_replaceSelectionWithText_1;
    public static /*const*/ String sel_setTextSizeMultiplier_1;
    public static /*const*/ String sel_stopLoading_1;
    public static /*const*/ String sel_goBack_1;
    public static /*const*/ String sel_canMakeTextStandardSize;
    public static /*const*/ String sel_setCustomUserAgent_1;
    public static /*const*/ String sel_moveDragCaretToPoint_1;
    public static /*const*/ String sel_makeTextSmaller_1;
    public static /*const*/ String sel_moveToBeginningOfSentence_1;
    public static /*const*/ String sel_reload_1;
    public static /*const*/ String sel_typingStyle;
    public static /*const*/ String sel_setShouldCloseWithWindow_1;
    public static /*const*/ String sel_setMediaStyle_1;
    public static /*const*/ String sel_canMakeTextLarger;
    public static /*const*/ String sel_textSizeMultiplier;
    public static /*const*/ String sel_shouldCloseWithWindow;
    public static /*const*/ String sel_setPreferencesIdentifier_1;
    public static /*const*/ String sel_setApplicationNameForUserAgent_1;
    public static /*const*/ String sel_mainFrameURL;
    public static /*const*/ String sel_goForward_1;
    public static /*const*/ String sel_selectedDOMRange;
    public static /*const*/ String sel_setDownloadDelegate_1;
    public static /*const*/ String sel_setEditingDelegate_1;
    public static /*const*/ String sel_setUIDelegate_1;
    public static /*const*/ String sel_mainFrameTitle;
    public static /*const*/ String sel_setSelectedDOMRange_1affinity_1;
    public static /*const*/ String sel_setTypingStyle_1;
    public static /*const*/ String sel_backForwardList;
    public static /*const*/ String sel_deleteSelection;
    public static /*const*/ String sel_canGoForward;
    public static /*const*/ String sel_styleDeclarationWithText_1;
    public static /*const*/ String sel_moveToEndOfSentenceAndModifySelection_1;
    public static /*const*/ String sel_replaceSelectionWithNode_1;
    public static /*const*/ String sel_URLTitleFromPasteboard_1;
    public static /*const*/ String sel_UIDelegate;
    public static /*const*/ String sel_setMaintainsBackForwardList_1;
    public static /*const*/ String sel_mainFrameIcon;
    public static /*const*/ String sel_setGroupName_1;
    public static /*const*/ String sel_canMakeTextSmaller;
    public static /*const*/ String sel_applicationNameForUserAgent;
    public static /*const*/ String sel_supportsTextEncoding;
    public static /*const*/ String sel_canShowMIMETypeAsHTML_1;
    public static /*const*/ String sel_mediaStyle;
    public static /*const*/ String sel_makeTextLarger_1;
    public static /*const*/ String sel_writeElement_1withPasteboardTypes_1toPasteboard_1;
    public static /*const*/ String sel_estimatedProgress;
    public static /*const*/ String sel_setCustomTextEncodingName_1;
    public static /*const*/ String sel_mainFrameDocument;
    public static /*const*/ String sel_isLoading;
    public static /*const*/ String sel_selectSentence_1;
    public static /*const*/ String sel_computedStyleForElement_1pseudoElement_1;
    public static /*const*/ String sel_writeSelectionWithPasteboardTypes_1toPasteboard_1;
    public static /*const*/ String sel_resourceLoadDelegate;
    public static /*const*/ String sel_reload;
    public static /*const*/ String sel_loadAlternateHTMLString_1baseURL_1forUnreachableURL_1;
    public static /*const*/ String sel_loadHTMLString_1baseURL_1;
    public static /*const*/ String sel_loadArchive_1;
    public static /*const*/ String sel_webView;
    public static /*const*/ String sel_provisionalDataSource;
    public static /*const*/ String sel_findFrameNamed_1;
    public static /*const*/ String sel_DOMDocument;
    public static /*const*/ String sel_frameView;
    public static /*const*/ String sel_globalContext;
    public static /*const*/ String sel_windowObject;
    public static /*const*/ String sel_childFrames;
    public static /*const*/ String sel_loadData_1MIMEType_1textEncodingName_1baseURL_1;
    public static /*const*/ String sel_initWithName_1webFrameView_1webView_1;
    public static /*const*/ String sel_frameElement;
    public static /*const*/ String sel_loadRequest_1;
    public static /*const*/ String sel_parentFrame;
    public static /*const*/ String sel_representation;
    public static /*const*/ String sel_documentSource;
    public static /*const*/ String sel_webView_1didChangeLocationWithinPageForFrame_1;
    public static /*const*/ String sel_webView_1didFailProvisionalLoadWithError_1forFrame_1;
    public static /*const*/ String sel_webView_1didFinishLoadForFrame_1;
    public static /*const*/ String sel_webView_1didReceiveTitle_1forFrame_1;
    public static /*const*/ String sel_webView_1didStartProvisionalLoadForFrame_1;
    public static /*const*/ String sel_webView_1didCommitLoadForFrame_1;
    public static /*const*/ String sel_webView_1resource_1didFinishLoadingFromDataSource_1;
    public static /*const*/ String sel_webView_1resource_1didFailLoadingWithError_1fromDataSource_1;
    public static /*const*/ String sel_webView_1identifierForInitialRequest_1fromDataSource_1;
    public static /*const*/ String sel_webView_1resource_1willSendRequest_1redirectResponse_1fromDataSource_1;
    public static /*const*/ String sel_webView_1createWebViewWithRequest_1;
    public static /*const*/ String sel_webViewShow_1;
    public static /*const*/ String sel_webView_1setFrame_1;
    public static /*const*/ String sel_webViewClose_1;
    public static /*const*/ String sel_webView_1contextMenuItemsForElement_1defaultMenuItems_1;
    public static /*const*/ String sel_webView_1setStatusBarVisible_1;
    public static /*const*/ String sel_webView_1setResizable_1;
    public static /*const*/ String sel_webView_1setToolbarsVisible_1;
    public static /*const*/ String sel_webView_1setStatusText_1;
    public static /*const*/ String sel_webViewFocus_1;
    public static /*const*/ String sel_webViewUnfocus_1;
    public static /*const*/ String sel_webView_1runJavaScriptAlertPanelWithMessage_1;
    public static /*const*/ String sel_webView_1runJavaScriptConfirmPanelWithMessage_1;
    public static /*const*/ String sel_webView_1runOpenPanelForFileButtonWithResultListener_1;
    public static /*const*/ String sel_webView_1mouseDidMoveOverElement_1modifierFlags_1;
    public static /*const*/ String sel_webView_1printFrameView_1;
    public static /*const*/ String sel_webView_1decidePolicyForMIMEType_1request_1frame_1decisionListener_1;
    public static /*const*/ String sel_webView_1decidePolicyForNewWindowAction_1request_1newFrameName_1decisionListener_1;
    public static /*const*/ String sel_webView_1unableToImplementPolicyWithError_1frame_1;
    public static /*const*/ String sel_webView_1decidePolicyForNavigationAction_1request_1frame_1decisionListener_1;
    public static /*const*/ String sel_standardPreferences;
    public static /*const*/ String sel_setJavaEnabled_1;
    public static /*const*/ String sel_use;
    public static /*const*/ String sel_download;
    public static /*const*/ String sel_ignore;
    public static /*const*/ String sel_pageTitle;
    public static /*const*/ String sel_webFrame;
    public static /*const*/ String sel_chooseFilename_1;
    public static /*const*/ String sel_addEventListener_1listener_1useCapture_1;
    public static /*const*/ String sel_handleEvent_1;
    public static /*const*/ String sel_cancelable;
    public static /*const*/ String sel_timeStamp;
    public static /*const*/ String sel_initEvent_1_1_1;
    public static /*const*/ String sel_bubbles;
    public static /*const*/ String sel_stopPropagation;
    public static /*const*/ String sel_initEvent_1canBubbleArg_1cancelableArg_1;
    public static /*const*/ String sel_eventPhase;
    public static /*const*/ String sel_currentTarget;
    public static /*const*/ String sel_preventDefault;
    public static /*const*/ String sel_screenX;
    public static /*const*/ String sel_initMouseEvent_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1;
    public static /*const*/ String sel_clientY;
    public static /*const*/ String sel_charCode;
    public static /*const*/ String sel_relatedTarget;
    public static /*const*/ String sel_button;
    public static /*const*/ String sel_clientX;
    public static /*const*/ String sel_initMouseEvent_1canBubble_1cancelable_1view_1detail_1screenX_1screenY_1clientX_1clientY_1ctrlKey_1altKey_1shiftKey_1metaKey_1button_1relatedTarget_1;
    public static /*const*/ String sel_shiftKey;
    public static /*const*/ String sel_ctrlKey;
    public static /*const*/ String sel_metaKey;
    public static /*const*/ String sel_altKey;
    public static /*const*/ String sel_keyLocation;
    public static /*const*/ String sel_getModifierState_1;
    public static /*const*/ String sel_screenY;
    public static /*const*/ String sel_detail;
    public static /*const*/ String sel_handleNotification_1;
    public static /*const*/ String sel_setAllowsScrolling_1;
    public static /*const*/ String sel_allowsScrolling;
    public static /*const*/ String sel_printDocumentView;
    public static /*const*/ String sel_documentViewShouldHandlePrint;
    public static /*const*/ String sel_printOperationWithPrintInfo_1;
    public static /*const*/ String sel_canPrintHeadersAndFooters;
    public static /*const*/ String sel_wheelDelta;
    
    private static const SelectorData[] selectorData = [
        { &sel_inputClientEnabled_1, "inputClientEnabled:" },
        { &sel_setVerticalPagination_1, "setVerticalPagination:" },
        { &sel_isEqualToHost_1, "isEqualToHost:" },
        { &sel_compare_1, "compare:" },
        { &sel_printPanel, "printPanel" },
        { &sel_unregisterImageRepClass_1, "unregisterImageRepClass:" },
        { &sel_dataWithLength_1, "dataWithLength:" },
        { &sel_dismissPopUp, "dismissPopUp" },
        { &sel_substituteFontForFont_1, "substituteFontForFont:" },
        { &sel_sendAction_1to_1, "sendAction:to:" },
        { &sel_rangeOfCharacterFromSet_1options_1range_1, "rangeOfCharacterFromSet:options:range:" },
        { &sel_autoupdatingCurrentCalendar, "autoupdatingCurrentCalendar" },
        { &sel_nextDaylightSavingTimeTransitionAfterDate_1, "nextDaylightSavingTimeTransitionAfterDate:" },
        { &sel_attachmentSizeForGlyphAtIndex_1, "attachmentSizeForGlyphAtIndex:" },
        { &sel_shouldCollapseAutoExpandedItemsForDeposited_1, "shouldCollapseAutoExpandedItemsForDeposited:" },
        { &sel_decimalNumberByRoundingAccordingToBehavior_1, "decimalNumberByRoundingAccordingToBehavior:" },
        { &sel_scanHexFloat_1, "scanHexFloat:" },
        { &sel_rangesForUserTextChange, "rangesForUserTextChange" },
        { &sel_indexOfItemWithObjectValue_1, "indexOfItemWithObjectValue:" },
        { &sel_sendsSearchStringImmediately, "sendsSearchStringImmediately" },
        { &sel_isTransparent, "isTransparent" },
        { &sel_widthOfColumn_1, "widthOfColumn:" },
        { &sel_calendarFormat, "calendarFormat" },
        { &sel_lineBreakByHyphenatingBeforeIndex_1withinRange_1, "lineBreakByHyphenatingBeforeIndex:withinRange:" },
        { &sel_parentNode, "parentNode" },
        { &sel_setDrawsOutsideLineFragment_1forGlyphRange_1, "setDrawsOutsideLineFragment:forGlyphRange:" },
        { &sel_negativeSuffix, "negativeSuffix" },
        { &sel_setFlatness_1, "setFlatness:" },
        { &sel_ignoresAlpha, "ignoresAlpha" },
        { &sel_setValue_1type_1forDimension_1, "setValue:type:forDimension:" },
        { &sel_setLayer_1, "setLayer:" },
        { &sel_setActionName_1, "setActionName:" },
        { &sel_setIcon_1, "setIcon:" },
        { &sel_tokenFieldCell_1readFromPasteboard_1, "tokenFieldCell:readFromPasteboard:" },
        { &sel_setPropertyList_1forType_1, "setPropertyList:forType:" },
        { &sel_endModalSession_1, "endModalSession:" },
        { &sel_sharedColorPanel, "sharedColorPanel" },
        { &sel_contentSizeForFrameSize_1hasHorizontalScroller_1hasVerticalScroller_1borderType_1, "contentSizeForFrameSize:hasHorizontalScroller:hasVerticalScroller:borderType:" },
        { &sel_layoutRectForTextBlock_1glyphRange_1, "layoutRectForTextBlock:glyphRange:" },
        { &sel_scrollRowToVisible_1, "scrollRowToVisible:" },
        { &sel_attributedStringForZero, "attributedStringForZero" },
        { &sel_showsInvisibleCharacters, "showsInvisibleCharacters" },
        { &sel_adjustPageWidthNew_1left_1right_1limit_1, "adjustPageWidthNew:left:right:limit:" },
        { &sel_client, "client" },
        { &sel_initWithKey_1ascending_1selector_1, "initWithKey:ascending:selector:" },
        { &sel_completedString_1, "completedString:" },
        { &sel_bundleForClass_1, "bundleForClass:" },
        { &sel_pathControl_1acceptDrop_1, "pathControl:acceptDrop:" },
        { &sel_imageRepsWithPasteboard_1, "imageRepsWithPasteboard:" },
        { &sel_toolTipForSegment_1, "toolTipForSegment:" },
        { &sel_suspended, "suspended" },
        { &sel_encodeDouble_1forKey_1, "encodeDouble:forKey:" },
        { &sel_setNextState, "setNextState" },
        { &sel_ignoreWord_1inSpellDocumentWithTag_1, "ignoreWord:inSpellDocumentWithTag:" },
        { &sel_stopMonitoring, "stopMonitoring" },
        { &sel_initWithTitle_1action_1keyEquivalent_1, "initWithTitle:action:keyEquivalent:" },
        { &sel_setDropRow_1dropOperation_1, "setDropRow:dropOperation:" },
        { &sel_contentView, "contentView" },
        { &sel_setNilSymbol_1, "setNilSymbol:" },
        { &sel_removePropertyForKey_1inRequest_1, "removePropertyForKey:inRequest:" },
        { &sel_setMarkerLocation_1, "setMarkerLocation:" },
        { &sel_resolvedKeyDictionary, "resolvedKeyDictionary" },
        { &sel_enumeratorAtPath_1, "enumeratorAtPath:" },
        { &sel_decodeObjectForKey_1, "decodeObjectForKey:" },
        { &sel_loadInForeground, "loadInForeground" },
        { &sel_baseSpecifier, "baseSpecifier" },
        { &sel_isMemberOfClass_1, "isMemberOfClass:" },
        { &sel_setMaxVisibleColumns_1, "setMaxVisibleColumns:" },
        { &sel_unmountAndEjectDeviceAtPath_1, "unmountAndEjectDeviceAtPath:" },
        { &sel_openTempFile_1, "openTempFile:" },
        { &sel_isRowSelected_1, "isRowSelected:" },
        { &sel_insertItemWithItemIdentifier_1atIndex_1, "insertItemWithItemIdentifier:atIndex:" },
        { &sel_parserDidEndDocument_1, "parserDidEndDocument:" },
        { &sel_reverseTransformedValue_1, "reverseTransformedValue:" },
        { &sel_setTimeStyle_1, "setTimeStyle:" },
        { &sel_initWithContentsOfFile_1usedEncoding_1error_1, "initWithContentsOfFile:usedEncoding:error:" },
        { &sel_endGrouping, "endGrouping" },
        { &sel_initWithProxyHost_1port_1type_1realm_1authenticationMethod_1, "initWithProxyHost:port:type:realm:authenticationMethod:" },
        { &sel_tableView_1dataCellForTableColumn_1row_1, "tableView:dataCellForTableColumn:row:" },
        { &sel_convertPoint_1toView_1, "convertPoint:toView:" },
        { &sel_setFrame_1display_1animate_1, "setFrame:display:animate:" },
        { &sel_exceptionDuringOperation_1error_1leftOperand_1rightOperand_1, "exceptionDuringOperation:error:leftOperand:rightOperand:" },
        { &sel_applicationOpenUntitledFile_1, "applicationOpenUntitledFile:" },
        { &sel_initWithRootElement_1, "initWithRootElement:" },
        { &sel_setHorizontalScroller_1, "setHorizontalScroller:" },
        { &sel_finalWritePrintInfo, "finalWritePrintInfo" },
        { &sel_addItemWithTitle_1, "addItemWithTitle:" },
        { &sel_setColor_1, "setColor:" },
        { &sel_isHostCacheEnabled, "isHostCacheEnabled" },
        { &sel_controlTextDidChange_1, "controlTextDidChange:" },
        { &sel_headerLevel, "headerLevel" },
        { &sel_loadInBackground, "loadInBackground" },
        { &sel_setNeedsDisplayForItemAtIndex_1, "setNeedsDisplayForItemAtIndex:" },
        { &sel_setCellPrototype_1, "setCellPrototype:" },
        { &sel_enqueueNotification_1postingStyle_1coalesceMask_1forModes_1, "enqueueNotification:postingStyle:coalesceMask:forModes:" },
        { &sel_minColumnWidth, "minColumnWidth" },
        { &sel_tableView_1shouldTypeSelectForEvent_1withCurrentSearchString_1, "tableView:shouldTypeSelectForEvent:withCurrentSearchString:" },
        { &sel_validateValue_1forKey_1error_1, "validateValue:forKey:error:" },
        { &sel_canBeConvertedToEncoding_1, "canBeConvertedToEncoding:" },
        { &sel_numberOfItems, "numberOfItems" },
        { &sel_bestRepresentationForDevice_1, "bestRepresentationForDevice:" },
        { &sel_setBorderColor_1forEdge_1, "setBorderColor:forEdge:" },
        { &sel_setHorizontalLineScroll_1, "setHorizontalLineScroll:" },
        { &sel_sharedHTTPCookieStorage, "sharedHTTPCookieStorage" },
        { &sel_cachesBezierPath, "cachesBezierPath" },
        { &sel_strokeLineFromPoint_1toPoint_1, "strokeLineFromPoint:toPoint:" },
        { &sel_preferredBackingLocation, "preferredBackingLocation" },
        { &sel_removeRowAtIndex_1, "removeRowAtIndex:" },
        { &sel_setCurrentTime_1, "setCurrentTime:" },
        { &sel_string, "string" },
        { &sel_hasVerticalScroller, "hasVerticalScroller" },
        { &sel_initWithTimeInterval_1sinceDate_1, "initWithTimeInterval:sinceDate:" },
        { &sel_showsProgressPanel, "showsProgressPanel" },
        { &sel_setDirectParameter_1, "setDirectParameter:" },
        { &sel_storeCachedResponse_1forRequest_1, "storeCachedResponse:forRequest:" },
        { &sel_textUnfilteredPasteboardTypes, "textUnfilteredPasteboardTypes" },
        { &sel_isDragging, "isDragging" },
        { &sel_tableView_1shouldTrackCell_1forTableColumn_1row_1, "tableView:shouldTrackCell:forTableColumn:row:" },
        { &sel_dictionaryRepresentation, "dictionaryRepresentation" },
        { &sel_attributesForExtraLineFragment, "attributesForExtraLineFragment" },
        { &sel_getCharacters_1range_1, "getCharacters:range:" },
        { &sel_nibName, "nibName" },
        { &sel_initWithURL_1options_1documentAttributes_1error_1, "initWithURL:options:documentAttributes:error:" },
        { &sel_initWithFrame_1mode_1cellClass_1numberOfRows_1numberOfColumns_1, "initWithFrame:mode:cellClass:numberOfRows:numberOfColumns:" },
        { &sel_reflectScrolledClipView_1, "reflectScrolledClipView:" },
        { &sel_stringWithContentsOfURL_1usedEncoding_1error_1, "stringWithContentsOfURL:usedEncoding:error:" },
        { &sel_displayIfNeededIgnoringOpacity, "displayIfNeededIgnoringOpacity" },
        { &sel_archiverWillFinish_1, "archiverWillFinish:" },
        { &sel_initWithOptions_1, "initWithOptions:" },
        { &sel_ruleEditor_1numberOfChildrenForCriterion_1withRowType_1, "ruleEditor:numberOfChildrenForCriterion:withRowType:" },
        { &sel_removeColorWithKey_1, "removeColorWithKey:" },
        { &sel_setObjectValue_1, "setObjectValue:" },
        { &sel_graphicsContextWithGraphicsPort_1flipped_1, "graphicsContextWithGraphicsPort:flipped:" },
        { &sel_setMarkedText_1selectedRange_1replacementRange_1, "setMarkedText:selectedRange:replacementRange:" },
        { &sel_outlineView_1numberOfChildrenOfItem_1, "outlineView:numberOfChildrenOfItem:" },
        { &sel_cellFrameAtRow_1column_1, "cellFrameAtRow:column:" },
        { &sel_blueColor, "blueColor" },
        { &sel_selectedTextBackgroundColor, "selectedTextBackgroundColor" },
        { &sel_initWithFormat_1locale_1, "initWithFormat:locale:" },
        { &sel_propertyListForType_1, "propertyListForType:" },
        { &sel_setConfigurationFromDictionary_1, "setConfigurationFromDictionary:" },
        { &sel_registerClassDescription_1forClass_1, "registerClassDescription:forClass:" },
        { &sel_removeAllItems, "removeAllItems" },
        { &sel_setFontPanelFactory_1, "setFontPanelFactory:" },
        { &sel_didChangeValueForKey_1withSetMutation_1usingObjects_1, "didChangeValueForKey:withSetMutation:usingObjects:" },
        { &sel_CGEvent, "CGEvent" },
        { &sel_disable, "disable" },
        { &sel_setColumnAutoresizingStyle_1, "setColumnAutoresizingStyle:" },
        { &sel_absoluteZ, "absoluteZ" },
        { &sel_intForKey_1inTable_1, "intForKey:inTable:" },
        { &sel_minFrameWidthWithTitle_1styleMask_1, "minFrameWidthWithTitle:styleMask:" },
        { &sel_highlightColor, "highlightColor" },
        { &sel_setRoundingMode_1, "setRoundingMode:" },
        { &sel_didChangeValueForKey_1, "didChangeValueForKey:" },
        { &sel_setMenuZone_1, "setMenuZone:" },
        { &sel_updateFromPrintInfo, "updateFromPrintInfo" },
        { &sel_setSelectedItemIdentifier_1, "setSelectedItemIdentifier:" },
        { &sel_setReplyTimeout_1, "setReplyTimeout:" },
        { &sel_showsFirstResponder, "showsFirstResponder" },
        { &sel_loadNibNamed_1owner_1, "loadNibNamed:owner:" },
        { &sel_setDocument_1, "setDocument:" },
        { &sel_filePosixPermissions, "filePosixPermissions" },
        { &sel_collapseItem_1collapseChildren_1, "collapseItem:collapseChildren:" },
        { &sel_setCell_1, "setCell:" },
        { &sel_setHTTPBodyStream_1, "setHTTPBodyStream:" },
        { &sel_updateAttachmentsFromPath_1, "updateAttachmentsFromPath:" },
        { &sel_updateFontPanel, "updateFontPanel" },
        { &sel_animationDidStop_1, "animationDidStop:" },
        { &sel_URL_1resourceDidFailLoadingWithReason_1, "URL:resourceDidFailLoadingWithReason:" },
        { &sel_defaultBaselineOffsetForFont_1, "defaultBaselineOffsetForFont:" },
        { &sel_browser_1shouldShowCellExpansionForRow_1column_1, "browser:shouldShowCellExpansionForRow:column:" },
        { &sel_draggingEnded_1, "draggingEnded:" },
        { &sel_openURL_1, "openURL:" },
        { &sel_longLongValue, "longLongValue" },
        { &sel_colorPanel, "colorPanel" },
        { &sel_encodeFloat_1forKey_1, "encodeFloat:forKey:" },
        { &sel_shouldBreakLineByHyphenatingBeforeCharacterAtIndex_1, "shouldBreakLineByHyphenatingBeforeCharacterAtIndex:" },
        { &sel_performSelectorInBackground_1withObject_1, "performSelectorInBackground:withObject:" },
        { &sel_initTextCell_1, "initTextCell:" },
        { &sel_classDescription, "classDescription" },
        { &sel_menuFontOfSize_1, "menuFontOfSize:" },
        { &sel_window_1willPositionSheet_1usingRect_1, "window:willPositionSheet:usingRect:" },
        { &sel_allowsTypeSelect, "allowsTypeSelect" },
        { &sel_attributeWithName_1URI_1stringValue_1, "attributeWithName:URI:stringValue:" },
        { &sel_setLinkTextAttributes_1, "setLinkTextAttributes:" },
        { &sel_stringWithFormat_1, "stringWithFormat:" },
        { &sel_initWithTable_1startingRow_1rowSpan_1startingColumn_1columnSpan_1, "initWithTable:startingRow:rowSpan:startingColumn:columnSpan:" },
        { &sel_setShouldProcessNamespaces_1, "setShouldProcessNamespaces:" },
        { &sel_orderFrontRegardless, "orderFrontRegardless" },
        { &sel_setProtocolForProxy_1, "setProtocolForProxy:" },
        { &sel_bundlePath, "bundlePath" },
        { &sel_isAutoscroll, "isAutoscroll" },
        { &sel_addConnection_1toRunLoop_1forMode_1, "addConnection:toRunLoop:forMode:" },
        { &sel_moveWordBackwardAndModifySelection_1, "moveWordBackwardAndModifySelection:" },
        { &sel_textContainerChangedGeometry_1, "textContainerChangedGeometry:" },
        { &sel_conversation, "conversation" },
        { &sel_showWindow_1, "showWindow:" },
        { &sel_showGuessPanel_1, "showGuessPanel:" },
        { &sel_setBorderWidth_1, "setBorderWidth:" },
        { &sel_buttons, "buttons" },
        { &sel_bitmapRepresentation, "bitmapRepresentation" },
        { &sel_nextObject, "nextObject" },
        { &sel_predicate, "predicate" },
        { &sel_verticalPagination, "verticalPagination" },
        { &sel_readInBackgroundAndNotify, "readInBackgroundAndNotify" },
        { &sel_pixelBufferMipMapLevel, "pixelBufferMipMapLevel" },
        { &sel_getValue_1, "getValue:" },
        { &sel_eventID, "eventID" },
        { &sel_sortDescriptors, "sortDescriptors" },
        { &sel_removeObjectAtArrangedObjectIndexPath_1, "removeObjectAtArrangedObjectIndexPath:" },
        { &sel_decodeBytesWithReturnedLength_1, "decodeBytesWithReturnedLength:" },
        { &sel_textView_1shouldChangeTextInRange_1replacementString_1, "textView:shouldChangeTextInRange:replacementString:" },
        { &sel_removeCursorRect_1cursor_1, "removeCursorRect:cursor:" },
        { &sel_hasPassword, "hasPassword" },
        { &sel_updateWindows, "updateWindows" },
        { &sel_pasteboardWithName_1, "pasteboardWithName:" },
        { &sel_writeSelectionToPasteboard_1types_1, "writeSelectionToPasteboard:types:" },
        { &sel_setFlipped_1, "setFlipped:" },
        { &sel_glyphWithName_1, "glyphWithName:" },
        { &sel_launchApplication_1showIcon_1autolaunch_1, "launchApplication:showIcon:autolaunch:" },
        { &sel_indexPath, "indexPath" },
        { &sel_setAttributeDescriptor_1forKeyword_1, "setAttributeDescriptor:forKeyword:" },
        { &sel_removeAllActions, "removeAllActions" },
        { &sel_defaultAttachmentScaling, "defaultAttachmentScaling" },
        { &sel_localizedStringWithFormat_1, "localizedStringWithFormat:" },
        { &sel_setAutoscroll_1, "setAutoscroll:" },
        { &sel_heightAdjustLimit, "heightAdjustLimit" },
        { &sel_moveUpAndModifySelection_1, "moveUpAndModifySelection:" },
        { &sel_visibilityPriority, "visibilityPriority" },
        { &sel_textView_1clickedOnCell_1inRect_1atIndex_1, "textView:clickedOnCell:inRect:atIndex:" },
        { &sel_archivedDataWithRootObject_1, "archivedDataWithRootObject:" },
        { &sel_parser_1foundCDATA_1, "parser:foundCDATA:" },
        { &sel_setWidth_1ofColumn_1, "setWidth:ofColumn:" },
        { &sel_setHighlightedTableColumn_1, "setHighlightedTableColumn:" },
        { &sel_toggle_1, "toggle:" },
        { &sel_parent, "parent" },
        { &sel_tableView_1shouldSelectRow_1, "tableView:shouldSelectRow:" },
        { &sel_setWithObject_1, "setWithObject:" },
        { &sel_attribute_1atIndex_1effectiveRange_1, "attribute:atIndex:effectiveRange:" },
        { &sel_columnsInRect_1, "columnsInRect:" },
        { &sel_setSearchScopes_1, "setSearchScopes:" },
        { &sel_setByAddingObjectsFromArray_1, "setByAddingObjectsFromArray:" },
        { &sel_textViewDidChangeTypingAttributes_1, "textViewDidChangeTypingAttributes:" },
        { &sel_frameRate, "frameRate" },
        { &sel_browser_1writeRowsWithIndexes_1inColumn_1toPasteboard_1, "browser:writeRowsWithIndexes:inColumn:toPasteboard:" },
        { &sel_errorWithDomain_1code_1userInfo_1, "errorWithDomain:code:userInfo:" },
        { &sel_setAlternate_1, "setAlternate:" },
        { &sel_currentValue, "currentValue" },
        { &sel_download_1decideDestinationWithSuggestedFilename_1, "download:decideDestinationWithSuggestedFilename:" },
        { &sel_setBoxType_1, "setBoxType:" },
        { &sel_fileNamesFromRunningOpenPanel, "fileNamesFromRunningOpenPanel" },
        { &sel_valueWithPointer_1, "valueWithPointer:" },
        { &sel_metadataQuery_1replacementObjectForResultObject_1, "metadataQuery:replacementObjectForResultObject:" },
        { &sel_editedColumn, "editedColumn" },
        { &sel_cachedResponseForRequest_1, "cachedResponseForRequest:" },
        { &sel_failureReason, "failureReason" },
        { &sel_constantValue, "constantValue" },
        { &sel_commandClassName, "commandClassName" },
        { &sel_fileWrapper, "fileWrapper" },
        { &sel_setUsesUserKeyEquivalents_1, "setUsesUserKeyEquivalents:" },
        { &sel_prototype, "prototype" },
        { &sel_clearStartAnimation, "clearStartAnimation" },
        { &sel_setMovableByWindowBackground_1, "setMovableByWindowBackground:" },
        { &sel_setDateFormat_1, "setDateFormat:" },
        { &sel_stringWithContentsOfFile_1usedEncoding_1error_1, "stringWithContentsOfFile:usedEncoding:error:" },
        { &sel_toggleAutomaticLinkDetection_1, "toggleAutomaticLinkDetection:" },
        { &sel_statusForTable_1, "statusForTable:" },
        { &sel_setAllowsColumnSelection_1, "setAllowsColumnSelection:" },
        { &sel_lowercaseWord_1, "lowercaseWord:" },
        { &sel_setResolvesAliases_1, "setResolvesAliases:" },
        { &sel_appendFormat_1, "appendFormat:" },
        { &sel_isAnimating, "isAnimating" },
        { &sel_dateFormat, "dateFormat" },
        { &sel_setMuted_1, "setMuted:" },
        { &sel_drawWithExpansionFrame_1inView_1, "drawWithExpansionFrame:inView:" },
        { &sel_copyPath_1toPath_1handler_1, "copyPath:toPath:handler:" },
        { &sel_isExplicitlyIncluded, "isExplicitlyIncluded" },
        { &sel_isExtensionHidden, "isExtensionHidden" },
        { &sel_showPackedGlyphs_1length_1glyphRange_1atPoint_1font_1color_1printingAdjustment_1, "showPackedGlyphs:length:glyphRange:atPoint:font:color:printingAdjustment:" },
        { &sel_rulerView_1didRemoveMarker_1, "rulerView:didRemoveMarker:" },
        { &sel_setControlTint_1, "setControlTint:" },
        { &sel_isSelectable, "isSelectable" },
        { &sel_initWithMachPort_1, "initWithMachPort:" },
        { &sel_fill, "fill" },
        { &sel_isEnteringProximity, "isEnteringProximity" },
        { &sel_drawingRectForBounds_1, "drawingRectForBounds:" },
        { &sel_decodeInt32ForKey_1, "decodeInt32ForKey:" },
        { &sel_deltaY, "deltaY" },
        { &sel_displaysLinkToolTips, "displaysLinkToolTips" },
        { &sel_moveToEndOfDocument_1, "moveToEndOfDocument:" },
        { &sel_isFirstResponder, "isFirstResponder" },
        { &sel_receiversSpecifier, "receiversSpecifier" },
        { &sel_canInitWithURL_1, "canInitWithURL:" },
        { &sel_parameterString, "parameterString" },
        { &sel_isMovable, "isMovable" },
        { &sel_setAvoidsEmptySelection_1, "setAvoidsEmptySelection:" },
        { &sel_lockFocusIfCanDrawInContext_1, "lockFocusIfCanDrawInContext:" },
        { &sel_updateChangeCount_1, "updateChangeCount:" },
        { &sel_rootDocument, "rootDocument" },
        { &sel_superview, "superview" },
        { &sel_resolveNamespaceForName_1, "resolveNamespaceForName:" },
        { &sel_maxNumberOfColumns, "maxNumberOfColumns" },
        { &sel_setMaxSize_1, "setMaxSize:" },
        { &sel_completePathIntoString_1caseSensitive_1matchesIntoArray_1filterTypes_1, "completePathIntoString:caseSensitive:matchesIntoArray:filterTypes:" },
        { &sel_updateCell_1, "updateCell:" },
        { &sel_setWeek_1, "setWeek:" },
        { &sel_titleRectForBounds_1, "titleRectForBounds:" },
        { &sel_rulerView_1willAddMarker_1atLocation_1, "rulerView:willAddMarker:atLocation:" },
        { &sel_message, "message" },
        { &sel_setContentSize_1, "setContentSize:" },
        { &sel_broadcast, "broadcast" },
        { &sel_isNativeType_1, "isNativeType:" },
        { &sel_contentBorderThicknessForEdge_1, "contentBorderThicknessForEdge:" },
        { &sel_keyEquivalentOffset, "keyEquivalentOffset" },
        { &sel_makeUntitledDocumentOfType_1, "makeUntitledDocumentOfType:" },
        { &sel_windowFrameTextColor, "windowFrameTextColor" },
        { &sel_addItemsWithTitles_1, "addItemsWithTitles:" },
        { &sel_levelForRow_1, "levelForRow:" },
        { &sel_dissolveToPoint_1fromRect_1fraction_1, "dissolveToPoint:fromRect:fraction:" },
        { &sel_discardCachedImage, "discardCachedImage" },
        { &sel_rootProxyForConnectionWithRegisteredName_1host_1usingNameServer_1, "rootProxyForConnectionWithRegisteredName:host:usingNameServer:" },
        { &sel_mouseExited_1, "mouseExited:" },
        { &sel_stringWithCString_1, "stringWithCString:" },
        { &sel_standardUserDefaults, "standardUserDefaults" },
        { &sel_archiver_1didEncodeObject_1, "archiver:didEncodeObject:" },
        { &sel_canDraw, "canDraw" },
        { &sel_shouldDelayWindowOrderingForEvent_1, "shouldDelayWindowOrderingForEvent:" },
        { &sel_selectedMenuItemTextColor, "selectedMenuItemTextColor" },
        { &sel_attachSubmenuForItemAtIndex_1, "attachSubmenuForItemAtIndex:" },
        { &sel_condition, "condition" },
        { &sel_setReservedThicknessForAccessoryView_1, "setReservedThicknessForAccessoryView:" },
        { &sel_replaceObjectsInRange_1withObjectsFromArray_1, "replaceObjectsInRange:withObjectsFromArray:" },
        { &sel_placeholderString, "placeholderString" },
        { &sel_setPMSymbol_1, "setPMSymbol:" },
        { &sel_localizedNameOfStringEncoding_1, "localizedNameOfStringEncoding:" },
        { &sel_outlineViewItemWillCollapse_1, "outlineViewItemWillCollapse:" },
        { &sel_localizedKey, "localizedKey" },
        { &sel_whiteColor, "whiteColor" },
        { &sel_viewBoundsChanged_1, "viewBoundsChanged:" },
        { &sel_vendorDefined, "vendorDefined" },
        { &sel_classNameDecodedForArchiveClassName_1, "classNameDecodedForArchiveClassName:" },
        { &sel_lockDate, "lockDate" },
        { &sel_twoDigitStartDate, "twoDigitStartDate" },
        { &sel_rectOfRow_1, "rectOfRow:" },
        { &sel_receivePort, "receivePort" },
        { &sel_decimalNumberByMultiplyingByPowerOf10_1withBehavior_1, "decimalNumberByMultiplyingByPowerOf10:withBehavior:" },
        { &sel_isAnyApplicationSpeaking, "isAnyApplicationSpeaking" },
        { &sel_aeDesc, "aeDesc" },
        { &sel_windowWillBeginSheet_1, "windowWillBeginSheet:" },
        { &sel_accessibilityFocusedUIElement, "accessibilityFocusedUIElement" },
        { &sel_orderBack_1, "orderBack:" },
        { &sel_scanDecimal_1, "scanDecimal:" },
        { &sel_transformStruct, "transformStruct" },
        { &sel_fileAttributesToWriteToFile_1ofType_1saveOperation_1, "fileAttributesToWriteToFile:ofType:saveOperation:" },
        { &sel_controlCharacterSet, "controlCharacterSet" },
        { &sel_setNextResponder_1, "setNextResponder:" },
        { &sel_pasteboardChangedOwner_1, "pasteboardChangedOwner:" },
        { &sel_canSelectHiddenExtension, "canSelectHiddenExtension" },
        { &sel_attribute_1atIndex_1longestEffectiveRange_1inRange_1, "attribute:atIndex:longestEffectiveRange:inRange:" },
        { &sel_setAutovalidates_1, "setAutovalidates:" },
        { &sel_setAllowsFloats_1, "setAllowsFloats:" },
        { &sel_sortDescriptorPrototype, "sortDescriptorPrototype" },
        { &sel_trackKnob_1, "trackKnob:" },
        { &sel_comboBox_1indexOfItemWithStringValue_1, "comboBox:indexOfItemWithStringValue:" },
        { &sel_setSource_1, "setSource:" },
        { &sel_contentFilters, "contentFilters" },
        { &sel_dictionaryWithContentsOfFile_1, "dictionaryWithContentsOfFile:" },
        { &sel_drawArrow_1highlight_1, "drawArrow:highlight:" },
        { &sel_handleSaveScriptCommand_1, "handleSaveScriptCommand:" },
        { &sel_rangeOfString_1options_1, "rangeOfString:options:" },
        { &sel_setPickerMode_1, "setPickerMode:" },
        { &sel_setStandaloneQuarterSymbols_1, "setStandaloneQuarterSymbols:" },
        { &sel_setSize_1, "setSize:" },
        { &sel_setAllowsUndo_1, "setAllowsUndo:" },
        { &sel_edge, "edge" },
        { &sel_stopLoading, "stopLoading" },
        { &sel_fileURLWithPath_1isDirectory_1, "fileURLWithPath:isDirectory:" },
        { &sel_userInfo, "userInfo" },
        { &sel_components_1fromDate_1, "components:fromDate:" },
        { &sel_dictionary, "dictionary" },
        { &sel_connection_1didCancelAuthenticationChallenge_1, "connection:didCancelAuthenticationChallenge:" },
        { &sel_selectParagraph_1, "selectParagraph:" },
        { &sel_initWithCapacity_1, "initWithCapacity:" },
        { &sel_initWithObjectSpecifier_1comparisonOperator_1testObject_1, "initWithObjectSpecifier:comparisonOperator:testObject:" },
        { &sel_nestingMode, "nestingMode" },
        { &sel_paragraphSpacingBefore, "paragraphSpacingBefore" },
        { &sel_itemChanged_1, "itemChanged:" },
        { &sel_setSelectionIndexes_1, "setSelectionIndexes:" },
        { &sel_open, "open" },
        { &sel_sendActionOn_1, "sendActionOn:" },
        { &sel_initWithFireDate_1interval_1target_1selector_1userInfo_1repeats_1, "initWithFireDate:interval:target:selector:userInfo:repeats:" },
        { &sel_formatterBehavior, "formatterBehavior" },
        { &sel_fillRect_1, "fillRect:" },
        { &sel_animationCurve, "animationCurve" },
        { &sel_remoteObjects, "remoteObjects" },
        { &sel_setSelectionIndexPath_1, "setSelectionIndexPath:" },
        { &sel_availableFontNamesWithTraits_1, "availableFontNamesWithTraits:" },
        { &sel_convertFont_1toFamily_1, "convertFont:toFamily:" },
        { &sel_splitView_1resizeSubviewsWithOldSize_1, "splitView:resizeSubviewsWithOldSize:" },
        { &sel_setSmartInsertDeleteEnabled_1, "setSmartInsertDeleteEnabled:" },
        { &sel_shouldChangePrintInfo_1, "shouldChangePrintInfo:" },
        { &sel_objectBeingTested, "objectBeingTested" },
        { &sel_selectItemWithObjectValue_1, "selectItemWithObjectValue:" },
        { &sel_rightExpressions, "rightExpressions" },
        { &sel_unableToSetNilForKey_1, "unableToSetNilForKey:" },
        { &sel_visibleItems, "visibleItems" },
        { &sel_items, "items" },
        { &sel_templatesWithAttributeKeyPaths_1inEntityDescription_1, "templatesWithAttributeKeyPaths:inEntityDescription:" },
        { &sel_setMaximumIntegerDigits_1, "setMaximumIntegerDigits:" },
        { &sel_scrollRectToVisible_1, "scrollRectToVisible:" },
        { &sel_disableKeyEquivalentForDefaultButtonCell, "disableKeyEquivalentForDefaultButtonCell" },
        { &sel_objectsForXQuery_1error_1, "objectsForXQuery:error:" },
        { &sel_readToEndOfFileInBackgroundAndNotifyForModes_1, "readToEndOfFileInBackgroundAndNotifyForModes:" },
        { &sel_scanHexLongLong_1, "scanHexLongLong:" },
        { &sel_ascender, "ascender" },
        { &sel_arrangeObjects_1, "arrangeObjects:" },
        { &sel_setNegativeSuffix_1, "setNegativeSuffix:" },
        { &sel_initWithString_1, "initWithString:" },
        { &sel_initWithName_1data_1, "initWithName:data:" },
        { &sel_data, "data" },
        { &sel_encodePortObject_1, "encodePortObject:" },
        { &sel_becomeFirstResponder, "becomeFirstResponder" },
        { &sel_setImage_1forSegment_1, "setImage:forSegment:" },
        { &sel_copyRuler_1, "copyRuler:" },
        { &sel_appendBezierPathWithGlyphs_1count_1inFont_1, "appendBezierPathWithGlyphs:count:inFont:" },
        { &sel_playsSelectionOnly, "playsSelectionOnly" },
        { &sel_boundsRectForTextBlock_1glyphRange_1, "boundsRectForTextBlock:glyphRange:" },
        { &sel_makeObjectsPerformSelector_1withObject_1, "makeObjectsPerformSelector:withObject:" },
        { &sel_stringByTrimmingCharactersInSet_1, "stringByTrimmingCharactersInSet:" },
        { &sel_timerWithTimeInterval_1invocation_1repeats_1, "timerWithTimeInterval:invocation:repeats:" },
        { &sel_viewDidMoveToSuperview, "viewDidMoveToSuperview" },
        { &sel_pathCell_1willDisplayOpenPanel_1, "pathCell:willDisplayOpenPanel:" },
        { &sel_pathSeparator, "pathSeparator" },
        { &sel_generatesCalendarDates, "generatesCalendarDates" },
        { &sel_pressure, "pressure" },
        { &sel_sendPort, "sendPort" },
        { &sel_argumentsRetained, "argumentsRetained" },
        { &sel_setContainerSpecifier_1, "setContainerSpecifier:" },
        { &sel_decodeNXColor, "decodeNXColor" },
        { &sel_orientation, "orientation" },
        { &sel_setScriptErrorString_1, "setScriptErrorString:" },
        { &sel_makeDocumentWithContentsOfFile_1ofType_1, "makeDocumentWithContentsOfFile:ofType:" },
        { &sel_reason, "reason" },
        { &sel_currentEvent, "currentEvent" },
        { &sel_setOffScreen_1width_1height_1rowbytes_1, "setOffScreen:width:height:rowbytes:" },
        { &sel_invalidateAttributesInRange_1, "invalidateAttributesInRange:" },
        { &sel_descriptorWithDescriptorType_1bytes_1length_1, "descriptorWithDescriptorType:bytes:length:" },
        { &sel_setCredential_1forProtectionSpace_1, "setCredential:forProtectionSpace:" },
        { &sel_fileGroupOwnerAccountName, "fileGroupOwnerAccountName" },
        { &sel_setColor_1forKey_1, "setColor:forKey:" },
        { &sel_setAutohidesScrollers_1, "setAutohidesScrollers:" },
        { &sel_noteNumberOfRowsChanged, "noteNumberOfRowsChanged" },
        { &sel_disableCursorRects, "disableCursorRects" },
        { &sel_setLenient_1, "setLenient:" },
        { &sel_registerUnitWithName_1abbreviation_1unitToPointsConversionFactor_1stepUpCycle_1stepDownCycle_1, "registerUnitWithName:abbreviation:unitToPointsConversionFactor:stepUpCycle:stepDownCycle:" },
        { &sel_standardWindowButton_1, "standardWindowButton:" },
        { &sel_objectForProperty_1error_1, "objectForProperty:error:" },
        { &sel_imageRepWithData_1, "imageRepWithData:" },
        { &sel_flushGraphics, "flushGraphics" },
        { &sel_setCacheDepthMatchesImageDepth_1, "setCacheDepthMatchesImageDepth:" },
        { &sel_highlightColorInView_1, "highlightColorInView:" },
        { &sel_setBaseSpecifier_1, "setBaseSpecifier:" },
        { &sel_performFileOperation_1source_1destination_1files_1tag_1, "performFileOperation:source:destination:files:tag:" },
        { &sel_outlineView_1itemForPersistentObject_1, "outlineView:itemForPersistentObject:" },
        { &sel_propertyListFromData_1mutabilityOption_1format_1errorDescription_1, "propertyListFromData:mutabilityOption:format:errorDescription:" },
        { &sel_setDocumentView_1, "setDocumentView:" },
        { &sel_drawsOutsideLineFragmentForGlyphAtIndex_1, "drawsOutsideLineFragmentForGlyphAtIndex:" },
        { &sel_dragImageForSelectionWithEvent_1origin_1, "dragImageForSelectionWithEvent:origin:" },
        { &sel_buttonNumber, "buttonNumber" },
        { &sel_advancementForGlyph_1, "advancementForGlyph:" },
        { &sel_parser_1validationErrorOccurred_1, "parser:validationErrorOccurred:" },
        { &sel_reusesColumns, "reusesColumns" },
        { &sel_minute, "minute" },
        { &sel_setCanChooseFiles_1, "setCanChooseFiles:" },
        { &sel_groupingSize, "groupingSize" },
        { &sel_containsAttachments, "containsAttachments" },
        { &sel_selectedControlTextColor, "selectedControlTextColor" },
        { &sel_initWithMantissa_1exponent_1isNegative_1, "initWithMantissa:exponent:isNegative:" },
        { &sel_initWithVoice_1, "initWithVoice:" },
        { &sel_setResizingMask_1, "setResizingMask:" },
        { &sel_setOnMouseExited_1, "setOnMouseExited:" },
        { &sel_toggleContinuousSpellChecking_1, "toggleContinuousSpellChecking:" },
        { &sel_allowsCutCopyPaste, "allowsCutCopyPaste" },
        { &sel_endSheet_1, "endSheet:" },
        { &sel_allowsBranchSelection, "allowsBranchSelection" },
        { &sel_initWithRequest_1delegate_1, "initWithRequest:delegate:" },
        { &sel_isAtEnd, "isAtEnd" },
        { &sel_relativeString, "relativeString" },
        { &sel_tableView_1willDisplayCell_1forTableColumn_1row_1, "tableView:willDisplayCell:forTableColumn:row:" },
        { &sel_resizeSubviewsWithOldSize_1, "resizeSubviewsWithOldSize:" },
        { &sel_compoundPredicateType, "compoundPredicateType" },
        { &sel_accessoryControllers, "accessoryControllers" },
        { &sel_shouldDrawColor, "shouldDrawColor" },
        { &sel_applicationShouldTerminate_1, "applicationShouldTerminate:" },
        { &sel_setTextContainer_1, "setTextContainer:" },
        { &sel_discardCursorRects, "discardCursorRects" },
        { &sel_deviceCMYKColorSpace, "deviceCMYKColorSpace" },
        { &sel_setDefaultPlaceholder_1forMarker_1withBinding_1, "setDefaultPlaceholder:forMarker:withBinding:" },
        { &sel_setIsZoomed_1, "setIsZoomed:" },
        { &sel_blueComponent, "blueComponent" },
        { &sel_portWithMachPort_1options_1, "portWithMachPort:options:" },
        { &sel_restoreGraphicsState, "restoreGraphicsState" },
        { &sel_isTemplate, "isTemplate" },
        { &sel_setScanLocation_1, "setScanLocation:" },
        { &sel_initWithBool_1, "initWithBool:" },
        { &sel_initWithSet_1copyItems_1, "initWithSet:copyItems:" },
        { &sel_setPositivePrefix_1, "setPositivePrefix:" },
        { &sel_propertyForKeyIfAvailable_1, "propertyForKeyIfAvailable:" },
        { &sel_fileOwnerAccountID, "fileOwnerAccountID" },
        { &sel_initForIncrementalLoad, "initForIncrementalLoad" },
        { &sel_cellAttribute_1, "cellAttribute:" },
        { &sel_baselineLocation, "baselineLocation" },
        { &sel_initWithAttributedString_1, "initWithAttributedString:" },
        { &sel_showWindows, "showWindows" },
        { &sel_writeToFile_1atomically_1updateFilenames_1, "writeToFile:atomically:updateFilenames:" },
        { &sel_setCookies_1forURL_1mainDocumentURL_1, "setCookies:forURL:mainDocumentURL:" },
        { &sel_unarchiver_1cannotDecodeObjectOfClassName_1originalClasses_1, "unarchiver:cannotDecodeObjectOfClassName:originalClasses:" },
        { &sel_selectRow_1inColumn_1, "selectRow:inColumn:" },
        { &sel_dissolveToPoint_1fraction_1, "dissolveToPoint:fraction:" },
        { &sel_wantsToTrackMouseForEvent_1inRect_1ofView_1atCharacterIndex_1, "wantsToTrackMouseForEvent:inRect:ofView:atCharacterIndex:" },
        { &sel_openURLs_1withAppBundleIdentifier_1options_1additionalEventParamDescriptor_1launchIdentifiers_1, "openURLs:withAppBundleIdentifier:options:additionalEventParamDescriptor:launchIdentifiers:" },
        { &sel_checkForRemovableMedia, "checkForRemovableMedia" },
        { &sel_setImage_1, "setImage:" },
        { &sel_isFixedPitch, "isFixedPitch" },
        { &sel_protocolFamily, "protocolFamily" },
        { &sel_protocolCheckerWithTarget_1protocol_1, "protocolCheckerWithTarget:protocol:" },
        { &sel_streamError, "streamError" },
        { &sel_replaceBytesInRange_1withBytes_1length_1, "replaceBytesInRange:withBytes:length:" },
        { &sel_canChooseDirectories, "canChooseDirectories" },
        { &sel_classForPortCoder, "classForPortCoder" },
        { &sel_mainRunLoop, "mainRunLoop" },
        { &sel_setItemPrototype_1, "setItemPrototype:" },
        { &sel_controlShadowColor, "controlShadowColor" },
        { &sel_level, "level" },
        { &sel_setContextHelpModeActive_1, "setContextHelpModeActive:" },
        { &sel_levelForItem_1, "levelForItem:" },
        { &sel_setHeightTracksTextView_1, "setHeightTracksTextView:" },
        { &sel_applicationWillTerminate_1, "applicationWillTerminate:" },
        { &sel_wantsPeriodicDraggingUpdates, "wantsPeriodicDraggingUpdates" },
        { &sel_createCommandInstance, "createCommandInstance" },
        { &sel_parser_1foundElementDeclarationWithName_1model_1, "parser:foundElementDeclarationWithName:model:" },
        { &sel_window_1shouldPopUpDocumentPathMenu_1, "window:shouldPopUpDocumentPathMenu:" },
        { &sel_setRepresentedURL_1, "setRepresentedURL:" },
        { &sel_outlineView_1didDragTableColumn_1, "outlineView:didDragTableColumn:" },
        { &sel_appendTransform_1, "appendTransform:" },
        { &sel_setMIMEType_1, "setMIMEType:" },
        { &sel_setHeadIndent_1, "setHeadIndent:" },
        { &sel_setConstrainedFrameSize_1, "setConstrainedFrameSize:" },
        { &sel_setUsesDataSource_1, "setUsesDataSource:" },
        { &sel_replaceBytesInRange_1withBytes_1, "replaceBytesInRange:withBytes:" },
        { &sel_rowTypeKeyPath, "rowTypeKeyPath" },
        { &sel_undoManager, "undoManager" },
        { &sel_frameCenterRotation, "frameCenterRotation" },
        { &sel_setTextView_1, "setTextView:" },
        { &sel_executeAppleEvent_1error_1, "executeAppleEvent:error:" },
        { &sel_setFormatter_1, "setFormatter:" },
        { &sel_scanLocation, "scanLocation" },
        { &sel_scrollsDynamically, "scrollsDynamically" },
        { &sel_setIndentationLevel_1, "setIndentationLevel:" },
        { &sel_minimumRangeOfUnit_1, "minimumRangeOfUnit:" },
        { &sel_textViewForBeginningOfSelection, "textViewForBeginningOfSelection" },
        { &sel_tokenFieldCell_1displayStringForRepresentedObject_1, "tokenFieldCell:displayStringForRepresentedObject:" },
        { &sel_constrainFrameRect_1toScreen_1, "constrainFrameRect:toScreen:" },
        { &sel_getObjectValue_1forString_1range_1error_1, "getObjectValue:forString:range:error:" },
        { &sel_writeFileContents_1, "writeFileContents:" },
        { &sel_setProgressMarks_1, "setProgressMarks:" },
        { &sel_lastComponentOfFileName, "lastComponentOfFileName" },
        { &sel_preventWindowOrdering, "preventWindowOrdering" },
        { &sel_setDefaultDate_1, "setDefaultDate:" },
        { &sel_submenu, "submenu" },
        { &sel_setTXTRecordData_1, "setTXTRecordData:" },
        { &sel_bytesPerRow, "bytesPerRow" },
        { &sel_outlineView_1toolTipForCell_1rect_1tableColumn_1item_1mouseLocation_1, "outlineView:toolTipForCell:rect:tableColumn:item:mouseLocation:" },
        { &sel_outlineView_1shouldEditTableColumn_1item_1, "outlineView:shouldEditTableColumn:item:" },
        { &sel_initWithContainerSize_1, "initWithContainerSize:" },
        { &sel_setEvaluationErrorNumber_1, "setEvaluationErrorNumber:" },
        { &sel_setTopLevelObject_1, "setTopLevelObject:" },
        { &sel_dataOfType_1error_1, "dataOfType:error:" },
        { &sel_isSupersetOfSet_1, "isSupersetOfSet:" },
        { &sel_initWithURL_1cachePolicy_1timeoutInterval_1, "initWithURL:cachePolicy:timeoutInterval:" },
        { &sel_setAutosaveExpandedItems_1, "setAutosaveExpandedItems:" },
        { &sel_rangeValue, "rangeValue" },
        { &sel_indexPathByAddingIndex_1, "indexPathByAddingIndex:" },
        { &sel_deleteToMark_1, "deleteToMark:" },
        { &sel_appleEventCodeForSuite_1, "appleEventCodeForSuite:" },
        { &sel_getBytes_1, "getBytes:" },
        { &sel_setMinimumDaysInFirstWeek_1, "setMinimumDaysInFirstWeek:" },
        { &sel_refusesFirstResponder, "refusesFirstResponder" },
        { &sel_setMaxItemSize_1, "setMaxItemSize:" },
        { &sel_localizedStringForKey_1value_1table_1, "localizedStringForKey:value:table:" },
        { &sel_mapTableWithKeyOptions_1valueOptions_1, "mapTableWithKeyOptions:valueOptions:" },
        { &sel_test, "test" },
        { &sel_trackScrollButtons_1, "trackScrollButtons:" },
        { &sel_PDFRepresentation, "PDFRepresentation" },
        { &sel_setImageFrameStyle_1, "setImageFrameStyle:" },
        { &sel_encodeClassName_1intoClassName_1, "encodeClassName:intoClassName:" },
        { &sel_beginPageInRect_1atPlacement_1, "beginPageInRect:atPlacement:" },
        { &sel_setAllowsOtherFileTypes_1, "setAllowsOtherFileTypes:" },
        { &sel_isWordInUserDictionaries_1caseSensitive_1, "isWordInUserDictionaries:caseSensitive:" },
        { &sel_dispatchRawAppleEvent_1withRawReply_1handlerRefCon_1, "dispatchRawAppleEvent:withRawReply:handlerRefCon:" },
        { &sel_isScrollable, "isScrollable" },
        { &sel_numberOfColorStops, "numberOfColorStops" },
        { &sel_unhideAllApplications_1, "unhideAllApplications:" },
        { &sel_retainCount, "retainCount" },
        { &sel_runModalPrintOperation_1delegate_1didRunSelector_1contextInfo_1, "runModalPrintOperation:delegate:didRunSelector:contextInfo:" },
        { &sel_update, "update" },
        { &sel_isRotatedOrScaledFromBase, "isRotatedOrScaledFromBase" },
        { &sel_initWithWindowNibPath_1owner_1, "initWithWindowNibPath:owner:" },
        { &sel_entryType, "entryType" },
        { &sel_dictionaryFromTXTRecordData_1, "dictionaryFromTXTRecordData:" },
        { &sel_setLineCapStyle_1, "setLineCapStyle:" },
        { &sel_setValues_1forParameter_1, "setValues:forParameter:" },
        { &sel_numberStyle, "numberStyle" },
        { &sel_disableCollectorForPointer_1, "disableCollectorForPointer:" },
        { &sel_initWithPointerFunctions_1capacity_1, "initWithPointerFunctions:capacity:" },
        { &sel_sendEvent_1, "sendEvent:" },
        { &sel_removeSelectedObjects_1, "removeSelectedObjects:" },
        { &sel_serviceConnectionWithName_1rootObject_1usingNameServer_1, "serviceConnectionWithName:rootObject:usingNameServer:" },
        { &sel_decimalNumberByMultiplyingBy_1, "decimalNumberByMultiplyingBy:" },
        { &sel_shouldChangeTextInRanges_1replacementStrings_1, "shouldChangeTextInRanges:replacementStrings:" },
        { &sel_setResizeIncrements_1, "setResizeIncrements:" },
        { &sel_alignLeft_1, "alignLeft:" },
        { &sel_launch, "launch" },
        { &sel_executeCommand, "executeCommand" },
        { &sel_setPixelBuffer_1cubeMapFace_1mipMapLevel_1currentVirtualScreen_1, "setPixelBuffer:cubeMapFace:mipMapLevel:currentVirtualScreen:" },
        { &sel_isCachedSeparately, "isCachedSeparately" },
        { &sel_setUsesSignificantDigits_1, "setUsesSignificantDigits:" },
        { &sel_countKeyPathForNode_1, "countKeyPathForNode:" },
        { &sel_setContainerIsRangeContainerObject_1, "setContainerIsRangeContainerObject:" },
        { &sel_showsStateColumn, "showsStateColumn" },
        { &sel_uppercaseString, "uppercaseString" },
        { &sel_directoryContentsAtPath_1, "directoryContentsAtPath:" },
        { &sel_titleFont, "titleFont" },
        { &sel_comparisonPredicateModifier, "comparisonPredicateModifier" },
        { &sel_isMultiThreaded, "isMultiThreaded" },
        { &sel_setGroupingAttributes_1, "setGroupingAttributes:" },
        { &sel_selectedRowIndexesInColumn_1, "selectedRowIndexesInColumn:" },
        { &sel_isFlushWindowDisabled, "isFlushWindowDisabled" },
        { &sel_setReusesColumns_1, "setReusesColumns:" },
        { &sel_getCString_1maxLength_1, "getCString:maxLength:" },
        { &sel_setIndicatorImage_1inTableColumn_1, "setIndicatorImage:inTableColumn:" },
        { &sel_keyEquivalent, "keyEquivalent" },
        { &sel_skipDescendents, "skipDescendents" },
        { &sel_waitUntilExit, "waitUntilExit" },
        { &sel_initWithWindowNibName_1owner_1, "initWithWindowNibName:owner:" },
        { &sel_objectClass, "objectClass" },
        { &sel_allFrameworks, "allFrameworks" },
        { &sel_cellWithTag_1, "cellWithTag:" },
        { &sel_representationUsingType_1properties_1, "representationUsingType:properties:" },
        { &sel_textPasteboardTypes, "textPasteboardTypes" },
        { &sel_contentViewMargins, "contentViewMargins" },
        { &sel_canUndo, "canUndo" },
        { &sel_initWithFormat_1locale_1arguments_1, "initWithFormat:locale:arguments:" },
        { &sel_usableParts, "usableParts" },
        { &sel_comboBoxSelectionIsChanging_1, "comboBoxSelectionIsChanging:" },
        { &sel_raise_1format_1arguments_1, "raise:format:arguments:" },
        { &sel_isWindowLoaded, "isWindowLoaded" },
        { &sel_levelIndicatorStyle, "levelIndicatorStyle" },
        { &sel_localizedFailureReason, "localizedFailureReason" },
        { &sel_characterRangeForGlyphRange_1actualGlyphRange_1, "characterRangeForGlyphRange:actualGlyphRange:" },
        { &sel_lineNumber, "lineNumber" },
        { &sel_HTTPBody, "HTTPBody" },
        { &sel_lineBreakMode, "lineBreakMode" },
        { &sel_isStopped, "isStopped" },
        { &sel_canResumeDownloadDecodedWithEncodingMIMEType_1, "canResumeDownloadDecodedWithEncodingMIMEType:" },
        { &sel_removeObjectsAtArrangedObjectIndexPaths_1, "removeObjectsAtArrangedObjectIndexPaths:" },
        { &sel_isHidden, "isHidden" },
        { &sel_otherMouseDragged_1, "otherMouseDragged:" },
        { &sel_headerRectOfColumn_1, "headerRectOfColumn:" },
        { &sel_hasVerticalRuler, "hasVerticalRuler" },
        { &sel_setBottomMargin_1, "setBottomMargin:" },
        { &sel_initWithNotificationCenter_1, "initWithNotificationCenter:" },
        { &sel_addSpeechDictionary_1, "addSpeechDictionary:" },
        { &sel_setPositiveFormat_1, "setPositiveFormat:" },
        { &sel_application_1openTempFile_1, "application:openTempFile:" },
        { &sel_setEntityName_1, "setEntityName:" },
        { &sel_setForegroundColor_1, "setForegroundColor:" },
        { &sel_initWithUnsignedLong_1, "initWithUnsignedLong:" },
        { &sel_setWindowsMenu_1, "setWindowsMenu:" },
        { &sel_applicationDidUnhide_1, "applicationDidUnhide:" },
        { &sel_availableData, "availableData" },
        { &sel_setVertical_1, "setVertical:" },
        { &sel_disableUpdates, "disableUpdates" },
        { &sel_compileAndReturnError_1, "compileAndReturnError:" },
        { &sel_containsIndex_1, "containsIndex:" },
        { &sel_canSelectPrevious, "canSelectPrevious" },
        { &sel_initWithBytes_1length_1encoding_1, "initWithBytes:length:encoding:" },
        { &sel_setTextColor_1, "setTextColor:" },
        { &sel_stream_1handleEvent_1, "stream:handleEvent:" },
        { &sel_setWeekdaySymbols_1, "setWeekdaySymbols:" },
        { &sel_setHiddenUntilMouseMoves_1, "setHiddenUntilMouseMoves:" },
        { &sel_orderFrontStandardAboutPanelWithOptions_1, "orderFrontStandardAboutPanelWithOptions:" },
        { &sel_setAttributesAsDictionary_1, "setAttributesAsDictionary:" },
        { &sel_rowTypeForRow_1, "rowTypeForRow:" },
        { &sel_setRequestTimeout_1, "setRequestTimeout:" },
        { &sel_XMLDataWithOptions_1, "XMLDataWithOptions:" },
        { &sel_closedHandCursor, "closedHandCursor" },
        { &sel_nextSibling, "nextSibling" },
        { &sel_controlTextColor, "controlTextColor" },
        { &sel_abbreviationDictionary, "abbreviationDictionary" },
        { &sel_archiverDidFinish_1, "archiverDidFinish:" },
        { &sel_valueTypeForDimension_1, "valueTypeForDimension:" },
        { &sel_setCriteriaKeyPath_1, "setCriteriaKeyPath:" },
        { &sel_isLessThan_1, "isLessThan:" },
        { &sel_processName, "processName" },
        { &sel_frameOfOutlineCellAtRow_1, "frameOfOutlineCellAtRow:" },
        { &sel_removeObjectsInArray_1, "removeObjectsInArray:" },
        { &sel_leftExpression, "leftExpression" },
        { &sel_removeToolTip_1, "removeToolTip:" },
        { &sel_mutableCopy, "mutableCopy" },
        { &sel_directParameter, "directParameter" },
        { &sel_name, "name" },
        { &sel_bitsPerPixel, "bitsPerPixel" },
        { &sel_weekday, "weekday" },
        { &sel_descendantNodeAtIndexPath_1, "descendantNodeAtIndexPath:" },
        { &sel_setPercentSymbol_1, "setPercentSymbol:" },
        { &sel_selectedCell, "selectedCell" },
        { &sel_windowWillClose_1, "windowWillClose:" },
        { &sel_setDatePickerStyle_1, "setDatePickerStyle:" },
        { &sel_initWithObjects_1, "initWithObjects:" },
        { &sel_numberWithInt_1, "numberWithInt:" },
        { &sel_collection, "collection" },
        { &sel_initWithTarget_1selector_1object_1, "initWithTarget:selector:object:" },
        { &sel_insertText_1replacementRange_1, "insertText:replacementRange:" },
        { &sel_initWithAEDescNoCopy_1, "initWithAEDescNoCopy:" },
        { &sel_usesGroupingSeparator, "usesGroupingSeparator" },
        { &sel_pathControl_1shouldDragPathComponentCell_1withPasteboard_1, "pathControl:shouldDragPathComponentCell:withPasteboard:" },
        { &sel_decimalNumberByAdding_1withBehavior_1, "decimalNumberByAdding:withBehavior:" },
        { &sel_setTextContainer_1forGlyphRange_1, "setTextContainer:forGlyphRange:" },
        { &sel_needsToDrawRect_1, "needsToDrawRect:" },
        { &sel_activeConversationChanged_1toNewConversation_1, "activeConversationChanged:toNewConversation:" },
        { &sel_italicAngle, "italicAngle" },
        { &sel_aeteResource_1, "aeteResource:" },
        { &sel_noteNewRecentDocumentURL_1, "noteNewRecentDocumentURL:" },
        { &sel_setPageScroll_1, "setPageScroll:" },
        { &sel_speechSynthesizer_1didFinishSpeaking_1, "speechSynthesizer:didFinishSpeaking:" },
        { &sel_convertSizeToBase_1, "convertSizeToBase:" },
        { &sel_pointerFunctionsWithOptions_1, "pointerFunctionsWithOptions:" },
        { &sel_setHTTPBody_1, "setHTTPBody:" },
        { &sel_itemWithTag_1, "itemWithTag:" },
        { &sel_spellServer_1checkGrammarInString_1language_1details_1, "spellServer:checkGrammarInString:language:details:" },
        { &sel_vendorPointingDeviceType, "vendorPointingDeviceType" },
        { &sel_firstRectForCharacterRange_1, "firstRectForCharacterRange:" },
        { &sel_classDescriptionsInSuite_1, "classDescriptionsInSuite:" },
        { &sel_setAttachmentSize_1forGlyphRange_1, "setAttachmentSize:forGlyphRange:" },
        { &sel_isEmpty, "isEmpty" },
        { &sel_soundNamed_1, "soundNamed:" },
        { &sel_preparedCellAtColumn_1row_1, "preparedCellAtColumn:row:" },
        { &sel_setLeafKeyPath_1, "setLeafKeyPath:" },
        { &sel_initWithUnsignedInteger_1, "initWithUnsignedInteger:" },
        { &sel_fractionOfDistanceThroughGlyphForPoint_1inTextContainer_1, "fractionOfDistanceThroughGlyphForPoint:inTextContainer:" },
        { &sel_isFloatingPanel, "isFloatingPanel" },
        { &sel_replaceObjectsAtIndexes_1withObjects_1, "replaceObjectsAtIndexes:withObjects:" },
        { &sel_getComponents_1, "getComponents:" },
        { &sel_fileType, "fileType" },
        { &sel_setShowsBaselineSeparator_1, "setShowsBaselineSeparator:" },
        { &sel_removeCredential_1forProtectionSpace_1, "removeCredential:forProtectionSpace:" },
        { &sel_imageRepWithContentsOfFile_1, "imageRepWithContentsOfFile:" },
        { &sel_predicateWithFormat_1argumentArray_1, "predicateWithFormat:argumentArray:" },
        { &sel_positiveSuffix, "positiveSuffix" },
        { &sel_formatter, "formatter" },
        { &sel_setAnimationDelay_1, "setAnimationDelay:" },
        { &sel_maxConcurrentOperationCount, "maxConcurrentOperationCount" },
        { &sel_childSpecifier, "childSpecifier" },
        { &sel_cacheMode, "cacheMode" },
        { &sel_registerForServices, "registerForServices" },
        { &sel_setFirstWeekday_1, "setFirstWeekday:" },
        { &sel_rulerViewClass, "rulerViewClass" },
        { &sel_initialValue, "initialValue" },
        { &sel_redColor, "redColor" },
        { &sel_addDependency_1, "addDependency:" },
        { &sel_pathExtension, "pathExtension" },
        { &sel_fastestEncoding, "fastestEncoding" },
        { &sel_socketType, "socketType" },
        { &sel_setRuleThickness_1, "setRuleThickness:" },
        { &sel_setDTDKind_1, "setDTDKind:" },
        { &sel_setClass_1forClassName_1, "setClass:forClassName:" },
        { &sel_setDocumentCursor_1, "setDocumentCursor:" },
        { &sel_extraLineFragmentRect, "extraLineFragmentRect" },
        { &sel_attributeForName_1, "attributeForName:" },
        { &sel_defaultCredentialForProtectionSpace_1, "defaultCredentialForProtectionSpace:" },
        { &sel_indexOfItemWithTag_1, "indexOfItemWithTag:" },
        { &sel_fontManager_1willIncludeFont_1, "fontManager:willIncludeFont:" },
        { &sel_scrollRangeToVisible_1, "scrollRangeToVisible:" },
        { &sel_fileTypeFromLastRunSavePanel, "fileTypeFromLastRunSavePanel" },
        { &sel_collectionView, "collectionView" },
        { &sel_tabView, "tabView" },
        { &sel_commonISOCurrencyCodes, "commonISOCurrencyCodes" },
        { &sel_removeFontTrait_1, "removeFontTrait:" },
        { &sel_drawKnob_1, "drawKnob:" },
        { &sel_tokenField_1menuForRepresentedObject_1, "tokenField:menuForRepresentedObject:" },
        { &sel_setFrameUsingName_1, "setFrameUsingName:" },
        { &sel_classNameEncodedForTrueClassName_1, "classNameEncodedForTrueClassName:" },
        { &sel_windowFrameAutosaveName, "windowFrameAutosaveName" },
        { &sel_characterAtIndex_1, "characterAtIndex:" },
        { &sel_smartInsertAfterStringForString_1replacingRange_1, "smartInsertAfterStringForString:replacingRange:" },
        { &sel_version, "version" },
        { &sel_objectsAtIndexes_1, "objectsAtIndexes:" },
        { &sel_requestIsCacheEquivalent_1toRequest_1, "requestIsCacheEquivalent:toRequest:" },
        { &sel_columnOfMatrix_1, "columnOfMatrix:" },
        { &sel_isBezeled, "isBezeled" },
        { &sel_setAutosaveName_1, "setAutosaveName:" },
        { &sel_becomeMainWindow, "becomeMainWindow" },
        { &sel_pasteAsRichText_1, "pasteAsRichText:" },
        { &sel_isSpeaking, "isSpeaking" },
        { &sel_format, "format" },
        { &sel_volume, "volume" },
        { &sel_setMenu_1, "setMenu:" },
        { &sel_setEra_1, "setEra:" },
        { &sel_textContainerOrigin, "textContainerOrigin" },
        { &sel_setLocalizesFormat_1, "setLocalizesFormat:" },
        { &sel_removeIndex_1, "removeIndex:" },
        { &sel_gotoPosterFrame_1, "gotoPosterFrame:" },
        { &sel_validateValue_1forKeyPath_1error_1, "validateValue:forKeyPath:error:" },
        { &sel_initWithCharactersNoCopy_1length_1freeWhenDone_1, "initWithCharactersNoCopy:length:freeWhenDone:" },
        { &sel_initWithLength_1, "initWithLength:" },
        { &sel_setAllowsMultipleSelection_1, "setAllowsMultipleSelection:" },
        { &sel_isRotatedFromBase, "isRotatedFromBase" },
        { &sel_beginDocument, "beginDocument" },
        { &sel_initWithContentsOfURL_1usedEncoding_1error_1, "initWithContentsOfURL:usedEncoding:error:" },
        { &sel_showsSuppressionButton, "showsSuppressionButton" },
        { &sel_tearOffMenuRepresentation, "tearOffMenuRepresentation" },
        { &sel_otherEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1subtype_1data1_1data2_1, "otherEventWithType:location:modifierFlags:timestamp:windowNumber:context:subtype:data1:data2:" },
        { &sel_imageUnfilteredFileTypes, "imageUnfilteredFileTypes" },
        { &sel_isGathering, "isGathering" },
        { &sel_slideImage_1from_1to_1, "slideImage:from:to:" },
        { &sel_initWithTCPPort_1, "initWithTCPPort:" },
        { &sel_stringByFoldingWithOptions_1locale_1, "stringByFoldingWithOptions:locale:" },
        { &sel_viewDidUnhide, "viewDidUnhide" },
        { &sel_controlSize, "controlSize" },
        { &sel_resourceDataUsingCache_1, "resourceDataUsingCache:" },
        { &sel_startWhenAnimation_1reachesProgress_1, "startWhenAnimation:reachesProgress:" },
        { &sel_registerURLHandleClass_1, "registerURLHandleClass:" },
        { &sel_indicatorImageInTableColumn_1, "indicatorImageInTableColumn:" },
        { &sel_decimalNumberByMultiplyingByPowerOf10_1, "decimalNumberByMultiplyingByPowerOf10:" },
        { &sel_scrollPoint_1, "scrollPoint:" },
        { &sel_setValue_1forKeyPath_1, "setValue:forKeyPath:" },
        { &sel_fontDescriptorWithMatrix_1, "fontDescriptorWithMatrix:" },
        { &sel_parser_1foundProcessingInstructionWithTarget_1data_1, "parser:foundProcessingInstructionWithTarget:data:" },
        { &sel_interfaceStyle, "interfaceStyle" },
        { &sel_comboBox_1objectValueForItemAtIndex_1, "comboBox:objectValueForItemAtIndex:" },
        { &sel_applicationDidFinishLaunching_1, "applicationDidFinishLaunching:" },
        { &sel_currentMemoryUsage, "currentMemoryUsage" },
        { &sel_altersStateOfSelectedItem, "altersStateOfSelectedItem" },
        { &sel_selectedColumn, "selectedColumn" },
        { &sel_convertBaseToScreen_1, "convertBaseToScreen:" },
        { &sel_lineHeightMultiple, "lineHeightMultiple" },
        { &sel_CGColorSpace, "CGColorSpace" },
        { &sel_descriptionInStringsFileFormat, "descriptionInStringsFileFormat" },
        { &sel_isOutputStackInReverseOrder, "isOutputStackInReverseOrder" },
        { &sel_takeValue_1forKey_1, "takeValue:forKey:" },
        { &sel_stringWithContentsOfFile_1, "stringWithContentsOfFile:" },
        { &sel_addItem_1, "addItem:" },
        { &sel_viewWillMoveToWindow_1, "viewWillMoveToWindow:" },
        { &sel_changeFileAttributes_1atPath_1, "changeFileAttributes:atPath:" },
        { &sel_userFixedPitchFontOfSize_1, "userFixedPitchFontOfSize:" },
        { &sel_selectRowIndexes_1inColumn_1, "selectRowIndexes:inColumn:" },
        { &sel_defaultLineCapStyle, "defaultLineCapStyle" },
        { &sel_attributedAlternateTitle, "attributedAlternateTitle" },
        { &sel_fileExistsAtPath_1, "fileExistsAtPath:" },
        { &sel_textView_1clickedOnLink_1atIndex_1, "textView:clickedOnLink:atIndex:" },
        { &sel_drawers, "drawers" },
        { &sel_outlineView_1shouldSelectTableColumn_1, "outlineView:shouldSelectTableColumn:" },
        { &sel_pointValue, "pointValue" },
        { &sel_integerValue, "integerValue" },
        { &sel_modifyFontViaPanel_1, "modifyFontViaPanel:" },
        { &sel_windowTitleForDocumentDisplayName_1, "windowTitleForDocumentDisplayName:" },
        { &sel_shortWeekdaySymbols, "shortWeekdaySymbols" },
        { &sel_titleOfSelectedItem, "titleOfSelectedItem" },
        { &sel_setWindowsNeedUpdate_1, "setWindowsNeedUpdate:" },
        { &sel_stringWithUTF8String_1, "stringWithUTF8String:" },
        { &sel_transformedValueClass, "transformedValueClass" },
        { &sel_initWithColorsAndLocations_1, "initWithColorsAndLocations:" },
        { &sel_acceptsMouseMovedEvents, "acceptsMouseMovedEvents" },
        { &sel_toolTipsFontOfSize_1, "toolTipsFontOfSize:" },
        { &sel_setTextAttributesForPositiveValues_1, "setTextAttributesForPositiveValues:" },
        { &sel_setAlwaysShowsDecimalSeparator_1, "setAlwaysShowsDecimalSeparator:" },
        { &sel_setNumberOfColumns_1, "setNumberOfColumns:" },
        { &sel_moveRightAndModifySelection_1, "moveRightAndModifySelection:" },
        { &sel_indexOfItem_1, "indexOfItem:" },
        { &sel_moveWordRight_1, "moveWordRight:" },
        { &sel_numberWithUnsignedLongLong_1, "numberWithUnsignedLongLong:" },
        { &sel_initWithAuthenticationChallenge_1sender_1, "initWithAuthenticationChallenge:sender:" },
        { &sel_panelConvertFont_1, "panelConvertFont:" },
        { &sel_temporaryAttribute_1atCharacterIndex_1effectiveRange_1, "temporaryAttribute:atCharacterIndex:effectiveRange:" },
        { &sel_intersectHashTable_1, "intersectHashTable:" },
        { &sel_positionOfGlyph_1precededByGlyph_1isNominal_1, "positionOfGlyph:precededByGlyph:isNominal:" },
        { &sel_setLocalizedKeyTable_1, "setLocalizedKeyTable:" },
        { &sel_fileManager_1shouldLinkItemAtPath_1toPath_1, "fileManager:shouldLinkItemAtPath:toPath:" },
        { &sel_setScriptErrorNumber_1, "setScriptErrorNumber:" },
        { &sel_initWithLocaleIdentifier_1, "initWithLocaleIdentifier:" },
        { &sel_toolTip, "toolTip" },
        { &sel_alternateMnemonic, "alternateMnemonic" },
        { &sel_setChannelMapping_1, "setChannelMapping:" },
        { &sel_setLocalizedKey_1, "setLocalizedKey:" },
        { &sel_selector, "selector" },
        { &sel_setCurrencyGroupingSeparator_1, "setCurrencyGroupingSeparator:" },
        { &sel_initWithKeyOptions_1valueOptions_1capacity_1, "initWithKeyOptions:valueOptions:capacity:" },
        { &sel_setStandaloneMonthSymbols_1, "setStandaloneMonthSymbols:" },
        { &sel_physicalMemory, "physicalMemory" },
        { &sel_parse, "parse" },
        { &sel_defaultTypesetterBehavior, "defaultTypesetterBehavior" },
        { &sel_setRulerVisible_1, "setRulerVisible:" },
        { &sel_resizeDownCursor, "resizeDownCursor" },
        { &sel_getBoundingRects_1forGlyphs_1count_1, "getBoundingRects:forGlyphs:count:" },
        { &sel_openPanel, "openPanel" },
        { &sel_setEntryWidth_1, "setEntryWidth:" },
        { &sel_insertChildren_1atIndex_1, "insertChildren:atIndex:" },
        { &sel_selectNext_1, "selectNext:" },
        { &sel_paragraphGlyphRange, "paragraphGlyphRange" },
        { &sel_animations, "animations" },
        { &sel_setMarkers_1, "setMarkers:" },
        { &sel_raise, "raise" },
        { &sel_menuZone, "menuZone" },
        { &sel_weekdaySymbols, "weekdaySymbols" },
        { &sel_setHTTPMethod_1, "setHTTPMethod:" },
        { &sel_placeholderAttributedString, "placeholderAttributedString" },
        { &sel_filenameExtension_1isValidForType_1, "filenameExtension:isValidForType:" },
        { &sel_initWithReceivePort_1sendPort_1, "initWithReceivePort:sendPort:" },
        { &sel_setContextHelp_1forObject_1, "setContextHelp:forObject:" },
        { &sel_archiveRootObject_1toFile_1, "archiveRootObject:toFile:" },
        { &sel_setAnimations_1, "setAnimations:" },
        { &sel_locationOfPrintRect_1, "locationOfPrintRect:" },
        { &sel_setInterfaceStyle_1, "setInterfaceStyle:" },
        { &sel_startMonitoring, "startMonitoring" },
        { &sel_presentError_1modalForWindow_1delegate_1didPresentSelector_1contextInfo_1, "presentError:modalForWindow:delegate:didPresentSelector:contextInfo:" },
        { &sel_windowFrameColor, "windowFrameColor" },
        { &sel_paragraphSpacing, "paragraphSpacing" },
        { &sel_fileAttributes, "fileAttributes" },
        { &sel_setDisplayedCommandsTitle_1, "setDisplayedCommandsTitle:" },
        { &sel_preflightAndReturnError_1, "preflightAndReturnError:" },
        { &sel_setObservationInfo_1, "setObservationInfo:" },
        { &sel_currentCommand, "currentCommand" },
        { &sel_processInfo, "processInfo" },
        { &sel_appendString_1, "appendString:" },
        { &sel_setShowsHelp_1, "setShowsHelp:" },
        { &sel_datePickerStyle, "datePickerStyle" },
        { &sel_addFileWrapper_1, "addFileWrapper:" },
        { &sel_bitmapImageRepForCachingDisplayInRect_1, "bitmapImageRepForCachingDisplayInRect:" },
        { &sel_initWithFileAtPath_1, "initWithFileAtPath:" },
        { &sel_cellClass, "cellClass" },
        { &sel_imageRepsWithContentsOfFile_1, "imageRepsWithContentsOfFile:" },
        { &sel_localizedScannerWithString_1, "localizedScannerWithString:" },
        { &sel_isExpandable_1, "isExpandable:" },
        { &sel_isLoaded, "isLoaded" },
        { &sel_browser_1acceptDrop_1atRow_1column_1dropOperation_1, "browser:acceptDrop:atRow:column:dropOperation:" },
        { &sel_panel_1directoryDidChange_1, "panel:directoryDidChange:" },
        { &sel_publicID, "publicID" },
        { &sel_contentMaxSize, "contentMaxSize" },
        { &sel_menuDidClose_1, "menuDidClose:" },
        { &sel_setPrinter_1, "setPrinter:" },
        { &sel_keywordForDescriptorAtIndex_1, "keywordForDescriptorAtIndex:" },
        { &sel_notANumberSymbol, "notANumberSymbol" },
        { &sel_minimumLineHeight, "minimumLineHeight" },
        { &sel_setContentBorderThickness_1forEdge_1, "setContentBorderThickness:forEdge:" },
        { &sel_titleFrameOfColumn_1, "titleFrameOfColumn:" },
        { &sel_dateValue, "dateValue" },
        { &sel_numberOfRows, "numberOfRows" },
        { &sel_isReadableFileAtPath_1, "isReadableFileAtPath:" },
        { &sel_canInsertChild, "canInsertChild" },
        { &sel_stringByReplacingOccurrencesOfString_1withString_1options_1range_1, "stringByReplacingOccurrencesOfString:withString:options:range:" },
        { &sel_ok_1, "ok:" },
        { &sel_hourOfDay, "hourOfDay" },
        { &sel_paragraphRangeForRange_1, "paragraphRangeForRange:" },
        { &sel_focusStack, "focusStack" },
        { &sel_setUsesThreadedAnimation_1, "setUsesThreadedAnimation:" },
        { &sel_dataForType_1, "dataForType:" },
        { &sel_isByref, "isByref" },
        { &sel_initWithResponse_1data_1userInfo_1storagePolicy_1, "initWithResponse:data:userInfo:storagePolicy:" },
        { &sel_initWithSerializedRepresentation_1, "initWithSerializedRepresentation:" },
        { &sel_openDocument_1, "openDocument:" },
        { &sel_translateRectsNeedingDisplayInRect_1by_1, "translateRectsNeedingDisplayInRect:by:" },
        { &sel_highlightsBy, "highlightsBy" },
        { &sel_openHandCursor, "openHandCursor" },
        { &sel_lineFragmentRectForProposedRect_1remainingRect_1, "lineFragmentRectForProposedRect:remainingRect:" },
        { &sel_selectedNodes, "selectedNodes" },
        { &sel_replaceObjectAtIndex_1withObject_1, "replaceObjectAtIndex:withObject:" },
        { &sel_indexOfItemAtPoint_1, "indexOfItemAtPoint:" },
        { &sel_setCriteria_1andDisplayValues_1forRowAtIndex_1, "setCriteria:andDisplayValues:forRowAtIndex:" },
        { &sel_textStorage_1edited_1range_1changeInLength_1invalidatedRange_1, "textStorage:edited:range:changeInLength:invalidatedRange:" },
        { &sel_synchronizeWindowTitleWithDocumentName, "synchronizeWindowTitleWithDocumentName" },
        { &sel_fileHandleWithNullDevice, "fileHandleWithNullDevice" },
        { &sel_descriptorWithTypeCode_1, "descriptorWithTypeCode:" },
        { &sel_initWithDocFormat_1documentAttributes_1, "initWithDocFormat:documentAttributes:" },
        { &sel_setAutoresizingMask_1, "setAutoresizingMask:" },
        { &sel_methodReturnLength, "methodReturnLength" },
        { &sel_recentDocumentURLs, "recentDocumentURLs" },
        { &sel_setCurrentDirectoryPath_1, "setCurrentDirectoryPath:" },
        { &sel_characterSetWithRange_1, "characterSetWithRange:" },
        { &sel_resizeUpCursor, "resizeUpCursor" },
        { &sel_rect, "rect" },
        { &sel_removeCharactersInRange_1, "removeCharactersInRange:" },
        { &sel_performSelectorOnMainThread_1withObject_1waitUntilDone_1, "performSelectorOnMainThread:withObject:waitUntilDone:" },
        { &sel_elementAtIndex_1associatedPoints_1, "elementAtIndex:associatedPoints:" },
        { &sel_dataForKey_1, "dataForKey:" },
        { &sel_defaultDepthLimit, "defaultDepthLimit" },
        { &sel_rulersVisible, "rulersVisible" },
        { &sel_generalPasteboard, "generalPasteboard" },
        { &sel_setAllowsTickMarkValuesOnly_1, "setAllowsTickMarkValuesOnly:" },
        { &sel_stateImageOffset, "stateImageOffset" },
        { &sel_isBordered, "isBordered" },
        { &sel_insertPointer_1atIndex_1, "insertPointer:atIndex:" },
        { &sel_keyForFileWrapper_1, "keyForFileWrapper:" },
        { &sel_renewGState, "renewGState" },
        { &sel_autovalidates, "autovalidates" },
        { &sel_localizedNameForFamily_1face_1, "localizedNameForFamily:face:" },
        { &sel_setAltIncrementValue_1, "setAltIncrementValue:" },
        { &sel_sortUsingFunction_1context_1, "sortUsingFunction:context:" },
        { &sel_fileNameExtensionWasHiddenInLastRunSavePanel, "fileNameExtensionWasHiddenInLastRunSavePanel" },
        { &sel_endSheet_1returnCode_1, "endSheet:returnCode:" },
        { &sel_insertObjects_1atIndexes_1, "insertObjects:atIndexes:" },
        { &sel_standaloneMonthSymbols, "standaloneMonthSymbols" },
        { &sel_prefersAllColumnUserResizing, "prefersAllColumnUserResizing" },
        { &sel_separatesColumns, "separatesColumns" },
        { &sel_moveToBeginningOfDocument_1, "moveToBeginningOfDocument:" },
        { &sel_objectZone, "objectZone" },
        { &sel_initWithURL_1MIMEType_1expectedContentLength_1textEncodingName_1, "initWithURL:MIMEType:expectedContentLength:textEncodingName:" },
        { &sel_gotoEnd_1, "gotoEnd:" },
        { &sel_superscriptRange_1, "superscriptRange:" },
        { &sel_readInBackgroundAndNotifyForModes_1, "readInBackgroundAndNotifyForModes:" },
        { &sel_initWithObjects_1forKeys_1, "initWithObjects:forKeys:" },
        { &sel_cancel, "cancel" },
        { &sel_suiteName, "suiteName" },
        { &sel_sortedArrayUsingFunction_1context_1hint_1, "sortedArrayUsingFunction:context:hint:" },
        { &sel_countWordsInString_1language_1, "countWordsInString:language:" },
        { &sel_prepareWithInvocationTarget_1, "prepareWithInvocationTarget:" },
        { &sel_statusItemWithLength_1, "statusItemWithLength:" },
        { &sel_tableView_1shouldEditTableColumn_1row_1, "tableView:shouldEditTableColumn:row:" },
        { &sel_appendBezierPathWithRect_1, "appendBezierPathWithRect:" },
        { &sel_scrollColumnsRightBy_1, "scrollColumnsRightBy:" },
        { &sel_negativeInfinitySymbol, "negativeInfinitySymbol" },
        { &sel_firstLineHeadIndent, "firstLineHeadIndent" },
        { &sel_generateGlyphsForGlyphStorage_1desiredNumberOfCharacters_1glyphIndex_1characterIndex_1, "generateGlyphsForGlyphStorage:desiredNumberOfCharacters:glyphIndex:characterIndex:" },
        { &sel_dateWithTimeIntervalSinceReferenceDate_1, "dateWithTimeIntervalSinceReferenceDate:" },
        { &sel_menu_1updateItem_1atIndex_1shouldCancel_1, "menu:updateItem:atIndex:shouldCancel:" },
        { &sel_connection_1willSendRequest_1redirectResponse_1, "connection:willSendRequest:redirectResponse:" },
        { &sel_attemptRecoveryFromError_1optionIndex_1delegate_1didRecoverSelector_1contextInfo_1, "attemptRecoveryFromError:optionIndex:delegate:didRecoverSelector:contextInfo:" },
        { &sel_cursorUpdate_1, "cursorUpdate:" },
        { &sel_initWithMachPort_1options_1, "initWithMachPort:options:" },
        { &sel_applyFontTraits_1range_1, "applyFontTraits:range:" },
        { &sel_noteHeightOfRowsWithIndexesChanged_1, "noteHeightOfRowsWithIndexesChanged:" },
        { &sel_orderFrontTablePanel_1, "orderFrontTablePanel:" },
        { &sel_arrayWithObjects_1, "arrayWithObjects:" },
        { &sel_enableFlushWindow, "enableFlushWindow" },
        { &sel_minimum, "minimum" },
        { &sel_stopListening, "stopListening" },
        { &sel_endParagraph, "endParagraph" },
        { &sel_sharingType, "sharingType" },
        { &sel_backgroundLayoutEnabled, "backgroundLayoutEnabled" },
        { &sel_yellowColor, "yellowColor" },
        { &sel_columnIndexesInRect_1, "columnIndexesInRect:" },
        { &sel_compositingOperation, "compositingOperation" },
        { &sel_stopModalWithCode_1, "stopModalWithCode:" },
        { &sel_smallSystemFontSize, "smallSystemFontSize" },
        { &sel_nonretainedObjectValue, "nonretainedObjectValue" },
        { &sel_encodeBytes_1length_1forKey_1, "encodeBytes:length:forKey:" },
        { &sel_objectValues, "objectValues" },
        { &sel_destroyContext, "destroyContext" },
        { &sel_setFileModificationDate_1, "setFileModificationDate:" },
        { &sel_rightMouseDragged_1, "rightMouseDragged:" },
        { &sel_systemStatusBar, "systemStatusBar" },
        { &sel_executableArchitectures, "executableArchitectures" },
        { &sel_recentSearches, "recentSearches" },
        { &sel_getWhite_1alpha_1, "getWhite:alpha:" },
        { &sel_readDataToEndOfFile, "readDataToEndOfFile" },
        { &sel_setHour_1, "setHour:" },
        { &sel_titleBarFontOfSize_1, "titleBarFontOfSize:" },
        { &sel_canDragRowsWithIndexes_1atPoint_1, "canDragRowsWithIndexes:atPoint:" },
        { &sel_acceptsArrowKeys, "acceptsArrowKeys" },
        { &sel_availableColorLists, "availableColorLists" },
        { &sel_setUsesLazyFetching_1, "setUsesLazyFetching:" },
        { &sel_convertAttributes_1, "convertAttributes:" },
        { &sel_isWritableFileAtPath_1, "isWritableFileAtPath:" },
        { &sel_timerWithTimeInterval_1target_1selector_1userInfo_1repeats_1, "timerWithTimeInterval:target:selector:userInfo:repeats:" },
        { &sel_windowDidChangeScreen_1, "windowDidChangeScreen:" },
        { &sel_insertTextContainer_1atIndex_1, "insertTextContainer:atIndex:" },
        { &sel_weightOfFont_1, "weightOfFont:" },
        { &sel_temporaryAttributesAtCharacterIndex_1longestEffectiveRange_1inRange_1, "temporaryAttributesAtCharacterIndex:longestEffectiveRange:inRange:" },
        { &sel_trackWithEvent_1, "trackWithEvent:" },
        { &sel_selectRowIndexes_1byExtendingSelection_1, "selectRowIndexes:byExtendingSelection:" },
        { &sel_charactersToBeSkipped, "charactersToBeSkipped" },
        { &sel_names, "names" },
        { &sel_setAllowsCutCopyPaste_1, "setAllowsCutCopyPaste:" },
        { &sel_setDuration_1, "setDuration:" },
        { &sel_sleepForTimeInterval_1, "sleepForTimeInterval:" },
        { &sel_removeChildAtIndex_1, "removeChildAtIndex:" },
        { &sel_tokenFieldCell_1writeRepresentedObjects_1toPasteboard_1, "tokenFieldCell:writeRepresentedObjects:toPasteboard:" },
        { &sel_backgroundStyle, "backgroundStyle" },
        { &sel_open_1, "open:" },
        { &sel_indexGreaterThanOrEqualToIndex_1, "indexGreaterThanOrEqualToIndex:" },
        { &sel_isAbsolutePath, "isAbsolutePath" },
        { &sel_paletteLabel, "paletteLabel" },
        { &sel_setQuarterSymbols_1, "setQuarterSymbols:" },
        { &sel_suppressionButton, "suppressionButton" },
        { &sel_undo, "undo" },
        { &sel_rangeOfString_1options_1range_1locale_1, "rangeOfString:options:range:locale:" },
        { &sel_localizedName_1locale_1, "localizedName:locale:" },
        { &sel_setTableView_1, "setTableView:" },
        { &sel_isExecutableFileAtPath_1, "isExecutableFileAtPath:" },
        { &sel_standaloneQuarterSymbols, "standaloneQuarterSymbols" },
        { &sel_textView_1shouldSetSpellingState_1range_1, "textView:shouldSetSpellingState:range:" },
        { &sel_newObject, "newObject" },
        { &sel_setDocumentEdited_1, "setDocumentEdited:" },
        { &sel_setRelativePosition_1, "setRelativePosition:" },
        { &sel_allConnections, "allConnections" },
        { &sel_isLessThanOrEqualTo_1, "isLessThanOrEqualTo:" },
        { &sel_attributeWithName_1stringValue_1, "attributeWithName:stringValue:" },
        { &sel_floatForKey_1, "floatForKey:" },
        { &sel_initWithDomain_1type_1name_1port_1, "initWithDomain:type:name:port:" },
        { &sel_setShadowOffset_1, "setShadowOffset:" },
        { &sel_tabViewItems, "tabViewItems" },
        { &sel_appleEventCodeForReturnType, "appleEventCodeForReturnType" },
        { &sel_createFileAtPath_1contents_1attributes_1, "createFileAtPath:contents:attributes:" },
        { &sel_ruleEditor_1predicatePartsForCriterion_1withDisplayValue_1inRow_1, "ruleEditor:predicatePartsForCriterion:withDisplayValue:inRow:" },
        { &sel_evaluateWithObject_1, "evaluateWithObject:" },
        { &sel_pathComponents, "pathComponents" },
        { &sel_setTarget_1, "setTarget:" },
        { &sel_fileCreationDate, "fileCreationDate" },
        { &sel_port, "port" },
        { &sel_publish, "publish" },
        { &sel_downloadDidFinish_1, "downloadDidFinish:" },
        { &sel_endEditing_1, "endEditing:" },
        { &sel_expectedResourceDataSize, "expectedResourceDataSize" },
        { &sel_paddingCharacter, "paddingCharacter" },
        { &sel_convertPoint_1fromView_1, "convertPoint:fromView:" },
        { &sel_setIntValue_1, "setIntValue:" },
        { &sel_appendBezierPathWithArcFromPoint_1toPoint_1radius_1, "appendBezierPathWithArcFromPoint:toPoint:radius:" },
        { &sel_currentFontAction, "currentFontAction" },
        { &sel_expressionForFunction_1arguments_1, "expressionForFunction:arguments:" },
        { &sel_minimumDaysInFirstWeek, "minimumDaysInFirstWeek" },
        { &sel_setDeletesFileUponFailure_1, "setDeletesFileUponFailure:" },
        { &sel_pageCount, "pageCount" },
        { &sel_imageAlignment, "imageAlignment" },
        { &sel_URLProtocol_1didCancelAuthenticationChallenge_1, "URLProtocol:didCancelAuthenticationChallenge:" },
        { &sel_localizedPaperName, "localizedPaperName" },
        { &sel_setAllowsBranchSelection_1, "setAllowsBranchSelection:" },
        { &sel_symbolicLinkDestination, "symbolicLinkDestination" },
        { &sel_prepareSavePanel_1, "prepareSavePanel:" },
        { &sel_enableMultipleThreads, "enableMultipleThreads" },
        { &sel_configurePersistentStoreCoordinatorForURL_1ofType_1modelConfiguration_1storeOptions_1error_1, "configurePersistentStoreCoordinatorForURL:ofType:modelConfiguration:storeOptions:error:" },
        { &sel_backgroundLoadDidFailWithReason_1, "backgroundLoadDidFailWithReason:" },
        { &sel_copyAttributesFromContext_1withMask_1, "copyAttributesFromContext:withMask:" },
        { &sel_isVertical, "isVertical" },
        { &sel_wait, "wait" },
        { &sel_firstObjectCommonWithArray_1, "firstObjectCommonWithArray:" },
        { &sel_hideOtherApplications_1, "hideOtherApplications:" },
        { &sel_startSpeakingString_1, "startSpeakingString:" },
        { &sel_makeKeyAndOrderFront_1, "makeKeyAndOrderFront:" },
        { &sel_drawCellAtIndex_1, "drawCellAtIndex:" },
        { &sel_headerToolTip, "headerToolTip" },
        { &sel_readRTFDFromFile_1, "readRTFDFromFile:" },
        { &sel_knownTimeZoneNames, "knownTimeZoneNames" },
        { &sel_toOneRelationshipKeys, "toOneRelationshipKeys" },
        { &sel_replyTimeout, "replyTimeout" },
        { &sel_setDelegate_1, "setDelegate:" },
        { &sel_initWithTarget_1protocol_1, "initWithTarget:protocol:" },
        { &sel_setShowsPrintPanel_1, "setShowsPrintPanel:" },
        { &sel_trackingNumber, "trackingNumber" },
        { &sel_initWithDecimal_1, "initWithDecimal:" },
        { &sel_proxyWithTarget_1connection_1, "proxyWithTarget:connection:" },
        { &sel_setCompositingFilter_1, "setCompositingFilter:" },
        { &sel_systemFontSizeForControlSize_1, "systemFontSizeForControlSize:" },
        { &sel_registerDefaults_1, "registerDefaults:" },
        { &sel_veryShortStandaloneMonthSymbols, "veryShortStandaloneMonthSymbols" },
        { &sel_setPlusSign_1, "setPlusSign:" },
        { &sel_colorRenderingIntent, "colorRenderingIntent" },
        { &sel_thicknessRequiredInRuler, "thicknessRequiredInRuler" },
        { &sel_setAlertStyle_1, "setAlertStyle:" },
        { &sel_searchScopes, "searchScopes" },
        { &sel_tag, "tag" },
        { &sel_autosavingDelay, "autosavingDelay" },
        { &sel_setDateStyle_1, "setDateStyle:" },
        { &sel_setIcon_1forFile_1options_1, "setIcon:forFile:options:" },
        { &sel_internationalCurrencySymbol, "internationalCurrencySymbol" },
        { &sel_netService_1didUpdateTXTRecordData_1, "netService:didUpdateTXTRecordData:" },
        { &sel_setOnMouseEntered_1, "setOnMouseEntered:" },
        { &sel_setTextBaseWritingDirection_1, "setTextBaseWritingDirection:" },
        { &sel_startSpecifier, "startSpecifier" },
        { &sel_setExcludedFromWindowsMenu_1, "setExcludedFromWindowsMenu:" },
        { &sel_operatingSystemName, "operatingSystemName" },
        { &sel_isConcurrent, "isConcurrent" },
        { &sel_enableRelease_1, "enableRelease:" },
        { &sel_getValues_1forAttribute_1forVirtualScreen_1, "getValues:forAttribute:forVirtualScreen:" },
        { &sel_interrupt, "interrupt" },
        { &sel_whiteComponent, "whiteComponent" },
        { &sel_keyEquivalentRectForBounds_1, "keyEquivalentRectForBounds:" },
        { &sel_numberOfVisibleColumns, "numberOfVisibleColumns" },
        { &sel_windowNibName, "windowNibName" },
        { &sel_parser_1foundIgnorableWhitespace_1, "parser:foundIgnorableWhitespace:" },
        { &sel_menuItemCellForItemAtIndex_1, "menuItemCellForItemAtIndex:" },
        { &sel_addTrackingArea_1, "addTrackingArea:" },
        { &sel_arrangedObjects, "arrangedObjects" },
        { &sel_timeStyle, "timeStyle" },
        { &sel_indexPathWithIndexes_1length_1, "indexPathWithIndexes:length:" },
        { &sel_addNamespace_1, "addNamespace:" },
        { &sel_setDisplayValuesKeyPath_1, "setDisplayValuesKeyPath:" },
        { &sel_notificationBatchingInterval, "notificationBatchingInterval" },
        { &sel_MIMEType, "MIMEType" },
        { &sel_drawerWillClose_1, "drawerWillClose:" },
        { &sel_sortedArrayHint, "sortedArrayHint" },
        { &sel_shortQuarterSymbols, "shortQuarterSymbols" },
        { &sel_usesAlternatingRowBackgroundColors, "usesAlternatingRowBackgroundColors" },
        { &sel_colorWithKey_1, "colorWithKey:" },
        { &sel_rangeForUserCompletion, "rangeForUserCompletion" },
        { &sel_boolValue, "boolValue" },
        { &sel_autosaveName, "autosaveName" },
        { &sel_childWindows, "childWindows" },
        { &sel_mapTableWithStrongToWeakObjects, "mapTableWithStrongToWeakObjects" },
        { &sel_unhide, "unhide" },
        { &sel_setRowClass_1, "setRowClass:" },
        { &sel_endSubelementIndex, "endSubelementIndex" },
        { &sel_preferredLocalizations, "preferredLocalizations" },
        { &sel_fileSystemChanged, "fileSystemChanged" },
        { &sel_secondOfMinute, "secondOfMinute" },
        { &sel_scrollWheel_1, "scrollWheel:" },
        { &sel_characterIndexForGlyphAtIndex_1, "characterIndexForGlyphAtIndex:" },
        { &sel_drawRepresentation_1inRect_1, "drawRepresentation:inRect:" },
        { &sel_setByAddingObject_1, "setByAddingObject:" },
        { &sel_rotateByAngle_1, "rotateByAngle:" },
        { &sel_allValues, "allValues" },
        { &sel_addItemWithObjectValue_1, "addItemWithObjectValue:" },
        { &sel_tabViewItemAtIndex_1, "tabViewItemAtIndex:" },
        { &sel_servicePortWithName_1, "servicePortWithName:" },
        { &sel_multiplier, "multiplier" },
        { &sel_setSelectionGranularity_1, "setSelectionGranularity:" },
        { &sel_setViewsNeedDisplay_1, "setViewsNeedDisplay:" },
        { &sel_object, "object" },
        { &sel_writeFileWrapper_1, "writeFileWrapper:" },
        { &sel_authenticationMethod, "authenticationMethod" },
        { &sel_frameLength, "frameLength" },
        { &sel_nextNode, "nextNode" },
        { &sel_characterSetWithCharactersInString_1, "characterSetWithCharactersInString:" },
        { &sel_messageText, "messageText" },
        { &sel_setArguments_1, "setArguments:" },
        { &sel_getBytes_1length_1, "getBytes:length:" },
        { &sel_setDropItem_1dropChildIndex_1, "setDropItem:dropChildIndex:" },
        { &sel_expressionForVariable_1, "expressionForVariable:" },
        { &sel_rectPreservedDuringLiveResize, "rectPreservedDuringLiveResize" },
        { &sel_isMuted, "isMuted" },
        { &sel_allowsColumnResizing, "allowsColumnResizing" },
        { &sel_readFileWrapper, "readFileWrapper" },
        { &sel_undoNestedGroup, "undoNestedGroup" },
        { &sel_setIncludedKeys_1, "setIncludedKeys:" },
        { &sel_textWithStringValue_1, "textWithStringValue:" },
        { &sel_ruleEditorRowsDidChange_1, "ruleEditorRowsDidChange:" },
        { &sel_handleMouseEvent_1, "handleMouseEvent:" },
        { &sel_browser_1canDragRowsWithIndexes_1inColumn_1withEvent_1, "browser:canDragRowsWithIndexes:inColumn:withEvent:" },
        { &sel_drawPageBorderWithSize_1, "drawPageBorderWithSize:" },
        { &sel_valueWithBytes_1objCType_1, "valueWithBytes:objCType:" },
        { &sel_subpathsAtPath_1, "subpathsAtPath:" },
        { &sel_mnemonicLocation, "mnemonicLocation" },
        { &sel_dockTile, "dockTile" },
        { &sel_setFirstLineHeadIndent_1, "setFirstLineHeadIndent:" },
        { &sel_isAutomaticQuoteSubstitutionEnabled, "isAutomaticQuoteSubstitutionEnabled" },
        { &sel_allowsReverseTransformation, "allowsReverseTransformation" },
        { &sel_moveNodes_1toIndexPath_1, "moveNodes:toIndexPath:" },
        { &sel_seekToFileOffset_1, "seekToFileOffset:" },
        { &sel_scriptingBeginsWith_1, "scriptingBeginsWith:" },
        { &sel_setInformativeText_1, "setInformativeText:" },
        { &sel_initWithIndexSet_1, "initWithIndexSet:" },
        { &sel_write_1maxLength_1, "write:maxLength:" },
        { &sel_canInitWithRequest_1, "canInitWithRequest:" },
        { &sel_enqueueNotification_1postingStyle_1, "enqueueNotification:postingStyle:" },
        { &sel_setShouldResolveExternalEntities_1, "setShouldResolveExternalEntities:" },
        { &sel_usesFindPanel, "usesFindPanel" },
        { &sel_perMillSymbol, "perMillSymbol" },
        { &sel_setClearsFilterPredicateOnInsertion_1, "setClearsFilterPredicateOnInsertion:" },
        { &sel_currentLocale, "currentLocale" },
        { &sel_pasteboardByFilteringData_1ofType_1, "pasteboardByFilteringData:ofType:" },
        { &sel_isSheet, "isSheet" },
        { &sel_hasWritablePropertyForKey_1, "hasWritablePropertyForKey:" },
        { &sel_drawDividerInRect_1, "drawDividerInRect:" },
        { &sel_sharedUserDefaultsController, "sharedUserDefaultsController" },
        { &sel_preferredFontNames, "preferredFontNames" },
        { &sel_menuBarFontOfSize_1, "menuBarFontOfSize:" },
        { &sel_sharedColorPanelExists, "sharedColorPanelExists" },
        { &sel_reshape, "reshape" },
        { &sel_initWithLong_1, "initWithLong:" },
        { &sel_reservedThicknessForAccessoryView, "reservedThicknessForAccessoryView" },
        { &sel_setTitleCell_1, "setTitleCell:" },
        { &sel_sharedSpellCheckerExists, "sharedSpellCheckerExists" },
        { &sel_locationForSubmenu_1, "locationForSubmenu:" },
        { &sel_nodesForXPath_1error_1, "nodesForXPath:error:" },
        { &sel_setHasVerticalRuler_1, "setHasVerticalRuler:" },
        { &sel_controlHighlightColor, "controlHighlightColor" },
        { &sel_rowSpan, "rowSpan" },
        { &sel_decodeObject, "decodeObject" },
        { &sel_fileHandleForReadingAtPath_1, "fileHandleForReadingAtPath:" },
        { &sel_didLoadBytes_1loadComplete_1, "didLoadBytes:loadComplete:" },
        { &sel_renewRows_1columns_1, "renewRows:columns:" },
        { &sel_performKeyEquivalent_1, "performKeyEquivalent:" },
        { &sel_windowDidResignKey_1, "windowDidResignKey:" },
        { &sel_typeForKey_1, "typeForKey:" },
        { &sel_selectedObjects, "selectedObjects" },
        { &sel_defaultPrinter, "defaultPrinter" },
        { &sel_colorWithPatternImage_1, "colorWithPatternImage:" },
        { &sel_setAttributedAlternateTitle_1, "setAttributedAlternateTitle:" },
        { &sel_setValue_1forKey_1, "setValue:forKey:" },
        { &sel_drawInteriorWithFrame_1inView_1, "drawInteriorWithFrame:inView:" },
        { &sel_copy_1, "copy:" },
        { &sel_scanString_1intoString_1, "scanString:intoString:" },
        { &sel_fileManager_1shouldProceedAfterError_1, "fileManager:shouldProceedAfterError:" },
        { &sel_fileManager_1shouldRemoveItemAtPath_1, "fileManager:shouldRemoveItemAtPath:" },
        { &sel_removeSavedColumnsWithAutosaveName_1, "removeSavedColumnsWithAutosaveName:" },
        { &sel_numberWithUnsignedInteger_1, "numberWithUnsignedInteger:" },
        { &sel_rulerMarkersForTextView_1paragraphStyle_1ruler_1, "rulerMarkersForTextView:paragraphStyle:ruler:" },
        { &sel_layoutRectForTextBlock_1atIndex_1effectiveRange_1, "layoutRectForTextBlock:atIndex:effectiveRange:" },
        { &sel_maxPossiblePositionOfDividerAtIndex_1, "maxPossiblePositionOfDividerAtIndex:" },
        { &sel_removePort_1forMode_1, "removePort:forMode:" },
        { &sel_drawHashMarksAndLabelsInRect_1, "drawHashMarksAndLabelsInRect:" },
        { &sel_control_1textView_1doCommandBySelector_1, "control:textView:doCommandBySelector:" },
        { &sel_getLineFragmentRect_1usedRect_1remainingRect_1forStartingGlyphAtIndex_1proposedRect_1lineSpacing_1paragraphSpacingBefore_1paragraphSpacingAfter_1, "getLineFragmentRect:usedRect:remainingRect:forStartingGlyphAtIndex:proposedRect:lineSpacing:paragraphSpacingBefore:paragraphSpacingAfter:" },
        { &sel_textContainerInset, "textContainerInset" },
        { &sel_positionsForCompositeSequence_1numberOfGlyphs_1pointArray_1, "positionsForCompositeSequence:numberOfGlyphs:pointArray:" },
        { &sel_stringByAppendingPathComponent_1, "StringByAppendingPathComponent:" },
        { &sel_application_1printFiles_1, "application:printFiles:" },
        { &sel_scanInt_1, "scanInt:" },
        { &sel_operators, "operators" },
        { &sel_fireDate, "fireDate" },
        { &sel_isExternal, "isExternal" },
        { &sel_setImagePosition_1, "setImagePosition:" },
        { &sel_predicateWithFormat_1arguments_1, "predicateWithFormat:arguments:" },
        { &sel_stopSpeaking, "stopSpeaking" },
        { &sel_contentWidthValueType, "contentWidthValueType" },
        { &sel_paddingPosition, "paddingPosition" },
        { &sel_removeLastObject, "removeLastObject" },
        { &sel_stringByReplacingCharactersInRange_1withString_1, "stringByReplacingCharactersInRange:withString:" },
        { &sel_pointerValue, "pointerValue" },
        { &sel_setTruncatesLastVisibleLine_1, "setTruncatesLastVisibleLine:" },
        { &sel_URLHandleResourceDidBeginLoading_1, "URLHandleResourceDidBeginLoading:" },
        { &sel_valueForKeyPath_1, "valueForKeyPath:" },
        { &sel_setPeriodicDelay_1interval_1, "setPeriodicDelay:interval:" },
        { &sel_imageRepWithCIImage_1, "imageRepWithCIImage:" },
        { &sel_wantsNotificationForMarkedText, "wantsNotificationForMarkedText" },
        { &sel_rectForPart_1, "rectForPart:" },
        { &sel_setWeekday_1, "setWeekday:" },
        { &sel_streamStatus, "streamStatus" },
        { &sel_containsPoint_1, "containsPoint:" },
        { &sel_underlineThickness, "underlineThickness" },
        { &sel_allObjects, "allObjects" },
        { &sel_characters, "characters" },
        { &sel_outlineViewSelectionIsChanging_1, "outlineViewSelectionIsChanging:" },
        { &sel_netServiceBrowser_1didNotSearch_1, "netServiceBrowser:didNotSearch:" },
        { &sel_poolCountHighWaterMark, "poolCountHighWaterMark" },
        { &sel_setColorSpaceName_1, "setColorSpaceName:" },
        { &sel_graphicsPort, "graphicsPort" },
        { &sel_fontDescriptorWithName_1matrix_1, "fontDescriptorWithName:matrix:" },
        { &sel_setSelectable_1, "setSelectable:" },
        { &sel_scriptErrorOffendingObjectDescriptor, "scriptErrorOffendingObjectDescriptor" },
        { &sel_resizingMask, "resizingMask" },
        { &sel_canHandleRequest_1, "canHandleRequest:" },
        { &sel_imageRepWithPasteboard_1, "imageRepWithPasteboard:" },
        { &sel_stopQuery, "stopQuery" },
        { &sel_dataWithBytes_1length_1, "dataWithBytes:length:" },
        { &sel_setCachesBezierPath_1, "setCachesBezierPath:" },
        { &sel_arrayForKey_1, "arrayForKey:" },
        { &sel_cell, "cell" },
        { &sel_dealloc, "dealloc" },
        { &sel_constrainScrollPoint_1, "constrainScrollPoint:" },
        { &sel_printSettings, "printSettings" },
        { &sel_autoresizesOutlineColumn, "autoresizesOutlineColumn" },
        { &sel_setFont_1range_1, "setFont:range:" },
        { &sel_limitDateForMode_1, "limitDateForMode:" },
        { &sel_stroke, "stroke" },
        { &sel_parser_1parseErrorOccurred_1, "parser:parseErrorOccurred:" },
        { &sel_sendsActionOnEndEditing, "sendsActionOnEndEditing" },
        { &sel_toggleGrammarChecking_1, "toggleGrammarChecking:" },
        { &sel_acceptsBinary, "acceptsBinary" },
        { &sel_indexLessThanIndex_1, "indexLessThanIndex:" },
        { &sel_setCollapsesBorders_1, "setCollapsesBorders:" },
        { &sel_setTimeoutInterval_1, "setTimeoutInterval:" },
        { &sel_setNeedsDisplayInRect_1avoidAdditionalLayout_1, "setNeedsDisplayInRect:avoidAdditionalLayout:" },
        { &sel_encodeWithCoder_1, "encodeWithCoder:" },
        { &sel_compositeToPoint_1operation_1, "compositeToPoint:operation:" },
        { &sel_textView_1doubleClickedOnCell_1inRect_1atIndex_1, "textView:doubleClickedOnCell:inRect:atIndex:" },
        { &sel_setAlternateTitleWithMnemonic_1, "setAlternateTitleWithMnemonic:" },
        { &sel_minimumSignificantDigits, "minimumSignificantDigits" },
        { &sel_stackSize, "stackSize" },
        { &sel_setLayoutManager_1, "setLayoutManager:" },
        { &sel_image_1didLoadRepresentationHeader_1, "image:didLoadRepresentationHeader:" },
        { &sel_depth, "depth" },
        { &sel_setTypesetter_1, "setTypesetter:" },
        { &sel_isSessionOnly, "isSessionOnly" },
        { &sel_performFindPanelAction_1, "performFindPanelAction:" },
        { &sel_fileManager_1shouldProceedAfterError_1removingItemAtPath_1, "fileManager:shouldProceedAfterError:removingItemAtPath:" },
        { &sel_paperSize, "paperSize" },
        { &sel_changeColor_1, "changeColor:" },
        { &sel_unarchiverDidFinish_1, "unarchiverDidFinish:" },
        { &sel_initWithObjectsAndKeys_1, "initWithObjectsAndKeys:" },
        { &sel_notationDeclarationForName_1, "notationDeclarationForName:" },
        { &sel_maximumSignificantDigits, "maximumSignificantDigits" },
        { &sel_receivesCredentialSecurely, "receivesCredentialSecurely" },
        { &sel_setObjectBeingTested_1, "setObjectBeingTested:" },
        { &sel_cacheDepthMatchesImageDepth, "cacheDepthMatchesImageDepth" },
        { &sel_hasPropertyForKey_1, "hasPropertyForKey:" },
        { &sel_draggingDestinationWindow, "draggingDestinationWindow" },
        { &sel_typeCodeValue, "typeCodeValue" },
        { &sel_portForName_1, "portForName:" },
        { &sel_getCString_1maxLength_1encoding_1, "getCString:maxLength:encoding:" },
        { &sel_attributedString, "attributedString" },
        { &sel_fileExistsAtPath_1isDirectory_1, "fileExistsAtPath:isDirectory:" },
        { &sel_updateRuler, "updateRuler" },
        { &sel_print_1, "print:" },
        { &sel_setFrameSize_1, "setFrameSize:" },
        { &sel_dataFromPropertyList_1format_1errorDescription_1, "dataFromPropertyList:format:errorDescription:" },
        { &sel_initWithContentsOfURL_1ofType_1, "initWithContentsOfURL:ofType:" },
        { &sel_replaceValueAtIndex_1inPropertyWithKey_1withValue_1, "replaceValueAtIndex:inPropertyWithKey:withValue:" },
        { &sel_formIntersectionWithCharacterSet_1, "formIntersectionWithCharacterSet:" },
        { &sel_renderingMode, "renderingMode" },
        { &sel_viewsNeedDisplay, "viewsNeedDisplay" },
        { &sel_lineFragmentRectForProposedRect_1sweepDirection_1movementDirection_1remainingRect_1, "lineFragmentRectForProposedRect:sweepDirection:movementDirection:remainingRect:" },
        { &sel_rulerAccessoryViewForTextView_1paragraphStyle_1ruler_1enabled_1, "rulerAccessoryViewForTextView:paragraphStyle:ruler:enabled:" },
        { &sel_initWithArray_1copyItems_1, "initWithArray:copyItems:" },
        { &sel_ensureLayoutForGlyphRange_1, "ensureLayoutForGlyphRange:" },
        { &sel_availableLocaleIdentifiers, "availableLocaleIdentifiers" },
        { &sel_viewDidHide, "viewDidHide" },
        { &sel_setShouldReportNamespacePrefixes_1, "setShouldReportNamespacePrefixes:" },
        { &sel_runToolbarCustomizationPalette_1, "runToolbarCustomizationPalette:" },
        { &sel_roundingBehavior, "roundingBehavior" },
        { &sel_expressionForEvaluatedObject, "expressionForEvaluatedObject" },
        { &sel_rulerView_1handleMouseDown_1, "rulerView:handleMouseDown:" },
        { &sel_scanCharactersFromSet_1intoString_1, "scanCharactersFromSet:intoString:" },
        { &sel_applicationDidChangeScreenParameters_1, "applicationDidChangeScreenParameters:" },
        { &sel_textView_1clickedOnCell_1inRect_1, "textView:clickedOnCell:inRect:" },
        { &sel_decodeDoubleForKey_1, "decodeDoubleForKey:" },
        { &sel_URLHandle_1resourceDidFailLoadingWithReason_1, "URLHandle:resourceDidFailLoadingWithReason:" },
        { &sel_setCountKeyPath_1, "setCountKeyPath:" },
        { &sel_showContextHelpForObject_1locationHint_1, "showContextHelpForObject:locationHint:" },
        { &sel_setData_1forType_1, "setData:forType:" },
        { &sel_setPixel_1atX_1y_1, "setPixel:atX:y:" },
        { &sel_setReceiversSpecifier_1, "setReceiversSpecifier:" },
        { &sel_postNotificationName_1object_1userInfo_1, "postNotificationName:object:userInfo:" },
        { &sel_rowForItem_1, "rowForItem:" },
        { &sel_fetch_1, "fetch:" },
        { &sel_propertyList_1isValidForFormat_1, "propertyList:isValidForFormat:" },
        { &sel_configureAsServer, "configureAsServer" },
        { &sel_setAllowsColumnReordering_1, "setAllowsColumnReordering:" },
        { &sel_charValue, "charValue" },
        { &sel_setInsertionClassDescription_1, "setInsertionClassDescription:" },
        { &sel_cyanColor, "cyanColor" },
        { &sel_lockWhenCondition_1, "lockWhenCondition:" },
        { &sel_cacheImageInRect_1, "cacheImageInRect:" },
        { &sel_keyboardFocusIndicatorColor, "keyboardFocusIndicatorColor" },
        { &sel_hasUndoManager, "hasUndoManager" },
        { &sel_drawInBezierPath_1relativeCenterPosition_1, "drawInBezierPath:relativeCenterPosition:" },
        { &sel_decimalNumberByAdding_1, "decimalNumberByAdding:" },
        { &sel_initWithDescriptorType_1data_1, "initWithDescriptorType:data:" },
        { &sel_isUndoing, "isUndoing" },
        { &sel_boolForKey_1, "boolForKey:" },
        { &sel_localizedCatalogNameComponent, "localizedCatalogNameComponent" },
        { &sel_representations, "representations" },
        { &sel_expressionValueWithObject_1context_1, "expressionValueWithObject:context:" },
        { &sel_viewWillMoveToSuperview_1, "viewWillMoveToSuperview:" },
        { &sel_alphaValue, "alphaValue" },
        { &sel_learnWord_1, "learnWord:" },
        { &sel_releaseGlobally, "releaseGlobally" },
        { &sel_defaultCompletionDelay, "defaultCompletionDelay" },
        { &sel_control_1textShouldEndEditing_1, "control:textShouldEndEditing:" },
        { &sel_alertWithMessageText_1defaultButton_1alternateButton_1otherButton_1informativeTextWithFormat_1, "alertWithMessageText:defaultButton:alternateButton:otherButton:informativeTextWithFormat:" },
        { &sel_control_1textShouldBeginEditing_1, "control:textShouldBeginEditing:" },
        { &sel_sizeMode, "sizeMode" },
        { &sel_representedURL, "representedURL" },
        { &sel_fileHFSCreatorCode, "fileHFSCreatorCode" },
        { &sel_removeDependency_1, "removeDependency:" },
        { &sel_parentForItem_1, "parentForItem:" },
        { &sel_adjustPageHeightNew_1top_1bottom_1limit_1, "adjustPageHeightNew:top:bottom:limit:" },
        { &sel_showPanels, "showPanels" },
        { &sel_alwaysUsesMultipleValuesMarker, "alwaysUsesMultipleValuesMarker" },
        { &sel_setUpFieldEditorAttributes_1, "setUpFieldEditorAttributes:" },
        { &sel_comboBoxCell_1completedString_1, "comboBoxCell:completedString:" },
        { &sel_null, "null" },
        { &sel_setTextAttributesForNil_1, "setTextAttributesForNil:" },
        { &sel_currencyGroupingSeparator, "currencyGroupingSeparator" },
        { &sel_toolbarSelectableItemIdentifiers_1, "toolbarSelectableItemIdentifiers:" },
        { &sel_size, "size" },
        { &sel_fileModificationDate, "fileModificationDate" },
        { &sel_timestamp, "timestamp" },
        { &sel_canonicalRequestForRequest_1, "canonicalRequestForRequest:" },
        { &sel_moveBackwardAndModifySelection_1, "moveBackwardAndModifySelection:" },
        { &sel_frameOfColumn_1, "frameOfColumn:" },
        { &sel_setRefusesFirstResponder_1, "setRefusesFirstResponder:" },
        { &sel_hasDynamicDepthLimit, "hasDynamicDepthLimit" },
        { &sel_decodeIntForKey_1, "decodeIntForKey:" },
        { &sel_autoupdatingCurrentLocale, "autoupdatingCurrentLocale" },
        { &sel_transformBezierPath_1, "transformBezierPath:" },
        { &sel_registerPort_1name_1nameServerPortNumber_1, "registerPort:name:nameServerPortNumber:" },
        { &sel_contentWidth, "contentWidth" },
        { &sel_noteUserDefaultsChanged, "noteUserDefaultsChanged" },
        { &sel_orangeColor, "orangeColor" },
        { &sel_lastItem, "lastItem" },
        { &sel_setButtonType_1, "setButtonType:" },
        { &sel_initWithContentsOfURL_1ofType_1error_1, "initWithContentsOfURL:ofType:error:" },
        { &sel_rowTemplates, "rowTemplates" },
        { &sel_setEnabled_1forSegment_1, "setEnabled:forSegment:" },
        { &sel_avoidsEmptySelection, "avoidsEmptySelection" },
        { &sel_encodeInt_1forKey_1, "encodeInt:forKey:" },
        { &sel_dictionaryWithValuesForKeys_1, "dictionaryWithValuesForKeys:" },
        { &sel_start_1, "start:" },
        { &sel_sortUsingDescriptors_1, "sortUsingDescriptors:" },
        { &sel_currentParagraphStyle, "currentParagraphStyle" },
        { &sel_treeNodeWithRepresentedObject_1, "treeNodeWithRepresentedObject:" },
        { &sel_tableColumnWithIdentifier_1, "tableColumnWithIdentifier:" },
        { &sel_attributedTitle, "attributedTitle" },
        { &sel_setEntryType_1, "setEntryType:" },
        { &sel_pixelFormat, "pixelFormat" },
        { &sel_temporaryAttribute_1atCharacterIndex_1longestEffectiveRange_1inRange_1, "temporaryAttribute:atCharacterIndex:longestEffectiveRange:inRange:" },
        { &sel_treatsFilePackagesAsDirectories, "treatsFilePackagesAsDirectories" },
        { &sel_glyphAtIndex_1, "glyphAtIndex:" },
        { &sel_titleWidth_1, "titleWidth:" },
        { &sel_setWords_1, "setWords:" },
        { &sel_glyphIndexForPoint_1inTextContainer_1, "glyphIndexForPoint:inTextContainer:" },
        { &sel_alternateSelectedControlColor, "alternateSelectedControlColor" },
        { &sel_sizeToCells, "sizeToCells" },
        { &sel_flushWindow, "flushWindow" },
        { &sel_URLAtIndex_1effectiveRange_1, "URLAtIndex:effectiveRange:" },
        { &sel_isSimpleRectangularTextContainer, "isSimpleRectangularTextContainer" },
        { &sel_dragImageForRowsWithIndexes_1tableColumns_1event_1offset_1, "dragImageForRowsWithIndexes:tableColumns:event:offset:" },
        { &sel_takeDoubleValueFrom_1, "takeDoubleValueFrom:" },
        { &sel_selectItem_1, "selectItem:" },
        { &sel_isMultiple, "isMultiple" },
        { &sel_arrangeInFront_1, "arrangeInFront:" },
        { &sel_defaultFocusRingType, "defaultFocusRingType" },
        { &sel_componentsSeparatedByString_1, "componentsSeparatedByString:" },
        { &sel_calendar, "calendar" },
        { &sel_openFile_1withApplication_1, "openFile:withApplication:" },
        { &sel_moveWordBackward_1, "moveWordBackward:" },
        { &sel_getCharacters_1, "getCharacters:" },
        { &sel_initWithInt_1, "initWithInt:" },
        { &sel_initWithReceivePort_1sendPort_1components_1, "initWithReceivePort:sendPort:components:" },
        { &sel_setBool_1forKey_1, "setBool:forKey:" },
        { &sel_keyPathsForValuesAffectingValueForKey_1, "keyPathsForValuesAffectingValueForKey:" },
        { &sel_saveDocumentTo_1, "saveDocumentTo:" },
        { &sel_knobRectFlipped_1, "knobRectFlipped:" },
        { &sel_isEqualToAttributedString_1, "isEqualToAttributedString:" },
        { &sel_indexOfResult_1, "indexOfResult:" },
        { &sel_attributesForVoice_1, "attributesForVoice:" },
        { &sel_encodeConditionalObject_1, "encodeConditionalObject:" },
        { &sel_pixelBufferCubeMapFace, "pixelBufferCubeMapFace" },
        { &sel_index, "index" },
        { &sel_transactionID, "transactionID" },
        { &sel_displayRectIgnoringOpacity_1, "displayRectIgnoringOpacity:" },
        { &sel_setKeyboardFocusRingNeedsDisplayInRect_1, "setKeyboardFocusRingNeedsDisplayInRect:" },
        { &sel_invalidateLayoutForCharacterRange_1isSoft_1actualCharacterRange_1, "invalidateLayoutForCharacterRange:isSoft:actualCharacterRange:" },
        { &sel_contentsEqualAtPath_1andPath_1, "contentsEqualAtPath:andPath:" },
        { &sel_cancelOperation_1, "cancelOperation:" },
        { &sel_accessibilityAttributeValue_1, "accessibilityAttributeValue:" },
        { &sel_windowNibPath, "windowNibPath" },
        { &sel_saveToFile_1saveOperation_1delegate_1didSaveSelector_1contextInfo_1, "saveToFile:saveOperation:delegate:didSaveSelector:contextInfo:" },
        { &sel_setMixedStateImage_1, "setMixedStateImage:" },
        { &sel_predicateWithFormat_1, "predicateWithFormat:" },
        { &sel_initWithSendPort_1receivePort_1components_1, "initWithSendPort:receivePort:components:" },
        { &sel_setRecentsAutosaveName_1, "setRecentsAutosaveName:" },
        { &sel_autosavesConfiguration, "autosavesConfiguration" },
        { &sel_setSubitems_1, "setSubitems:" },
        { &sel_setPathStyle_1, "setPathStyle:" },
        { &sel_startAnimation_1, "startAnimation:" },
        { &sel_bezierPath, "bezierPath" },
        { &sel_archiver_1willEncodeObject_1, "archiver:willEncodeObject:" },
        { &sel_acceptInputForMode_1beforeDate_1, "acceptInputForMode:beforeDate:" },
        { &sel_setTearOffMenuRepresentation_1, "setTearOffMenuRepresentation:" },
        { &sel_writableTypes, "writableTypes" },
        { &sel_domain, "domain" },
        { &sel_removeDocument_1, "removeDocument:" },
        { &sel_showsBaselineSeparator, "showsBaselineSeparator" },
        { &sel_dragImageForRows_1event_1dragImageOffset_1, "dragImageForRows:event:dragImageOffset:" },
        { &sel_table, "table" },
        { &sel_initRegularFileWithContents_1, "initRegularFileWithContents:" },
        { &sel_add_1, "add:" },
        { &sel_stateImageWidth, "stateImageWidth" },
        { &sel_URLProtocol_1didReceiveAuthenticationChallenge_1, "URLProtocol:didReceiveAuthenticationChallenge:" },
        { &sel_imageAndTitleWidth, "imageAndTitleWidth" },
        { &sel_trackingAreas, "trackingAreas" },
        { &sel_initRecordDescriptor, "initRecordDescriptor" },
        { &sel_itemIdentifier, "itemIdentifier" },
        { &sel_doubleClickAtIndex_1, "doubleClickAtIndex:" },
        { &sel_fixesAttributesLazily, "fixesAttributesLazily" },
        { &sel_netServiceBrowserWillSearch_1, "netServiceBrowserWillSearch:" },
        { &sel_textureInternalFormat, "textureInternalFormat" },
        { &sel_valueWithSize_1, "valueWithSize:" },
        { &sel_setVerticalScroller_1, "setVerticalScroller:" },
        { &sel_absolutePathForAppBundleWithIdentifier_1, "absolutePathForAppBundleWithIdentifier:" },
        { &sel_contentMinSize, "contentMinSize" },
        { &sel_persistentDomainForName_1, "persistentDomainForName:" },
        { &sel_cellAtIndex_1, "cellAtIndex:" },
        { &sel_setWithArray_1, "setWithArray:" },
        { &sel_resetCursorRects, "resetCursorRects" },
        { &sel_imageRepClassForFileType_1, "imageRepClassForFileType:" },
        { &sel_setContainerIsObjectBeingTested_1, "setContainerIsObjectBeingTested:" },
        { &sel_removeProgressMark_1, "removeProgressMark:" },
        { &sel_hitTestForEvent_1inRect_1ofView_1, "hitTestForEvent:inRect:ofView:" },
        { &sel_listDescriptor, "listDescriptor" },
        { &sel_rangeOfUnit_1startDate_1interval_1forDate_1, "rangeOfUnit:startDate:interval:forDate:" },
        { &sel_checkSpaceForParts, "checkSpaceForParts" },
        { &sel_availableVoices, "availableVoices" },
        { &sel_PMPrintSettings, "PMPrintSettings" },
        { &sel_nonBaseCharacterSet, "nonBaseCharacterSet" },
        { &sel_launchedTaskWithLaunchPath_1arguments_1, "launchedTaskWithLaunchPath:arguments:" },
        { &sel_clearCurrentContext, "clearCurrentContext" },
        { &sel_applicationWillUpdate_1, "applicationWillUpdate:" },
        { &sel_addFontTrait_1, "addFontTrait:" },
        { &sel_arrayByAddingObjectsFromArray_1, "arrayByAddingObjectsFromArray:" },
        { &sel_abortParsing, "abortParsing" },
        { &sel_subviews, "subviews" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1uniqueID_1, "initWithContainerClassDescription:containerSpecifier:key:uniqueID:" },
        { &sel_acceptableDragTypes, "acceptableDragTypes" },
        { &sel_managedObjectContext, "managedObjectContext" },
        { &sel_resizeWithMagnification_1, "resizeWithMagnification:" },
        { &sel_setUsesFindPanel_1, "setUsesFindPanel:" },
        { &sel_application_1printFiles_1withSettings_1showPrintPanels_1, "application:printFiles:withSettings:showPrintPanels:" },
        { &sel_loadAndReturnError_1, "loadAndReturnError:" },
        { &sel_initWithLeftExpressions_1rightExpressions_1modifier_1operators_1options_1, "initWithLeftExpressions:rightExpressions:modifier:operators:options:" },
        { &sel_addSelectionIndexes_1, "addSelectionIndexes:" },
        { &sel_initWithBitmapDataPlanes_1pixelsWide_1pixelsHigh_1bitsPerSample_1samplesPerPixel_1hasAlpha_1isPlanar_1colorSpaceName_1bitmapFormat_1bytesPerRow_1bitsPerPixel_1, "initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bitmapFormat:bytesPerRow:bitsPerPixel:" },
        { &sel_initToFileAtPath_1append_1, "initToFileAtPath:append:" },
        { &sel_currencyDecimalSeparator, "currencyDecimalSeparator" },
        { &sel_expansionFrameWithFrame_1inView_1, "expansionFrameWithFrame:inView:" },
        { &sel_HTTPShouldHandleCookies, "HTTPShouldHandleCookies" },
        { &sel_rearrangeObjects, "rearrangeObjects" },
        { &sel_graphicsContextWithWindow_1, "graphicsContextWithWindow:" },
        { &sel_stringWithCapacity_1, "stringWithCapacity:" },
        { &sel_results, "results" },
        { &sel_loadFileWrapperRepresentation_1ofType_1, "loadFileWrapperRepresentation:ofType:" },
        { &sel_secondsFromGMTForDate_1, "secondsFromGMTForDate:" },
        { &sel_clearStopAnimation, "clearStopAnimation" },
        { &sel_numberWithShort_1, "numberWithShort:" },
        { &sel_setHorizontallyCentered_1, "setHorizontallyCentered:" },
        { &sel_setNeedsDisplayInRect_1, "setNeedsDisplayInRect:" },
        { &sel_objectDidBeginEditing_1, "objectDidBeginEditing:" },
        { &sel_rightMouseDown_1, "rightMouseDown:" },
        { &sel_data2, "data2" },
        { &sel_initWithCalendarIdentifier_1, "initWithCalendarIdentifier:" },
        { &sel_containsValueForKey_1, "containsValueForKey:" },
        { &sel_result, "result" },
        { &sel_printDocument_1, "printDocument:" },
        { &sel_addSuiteNamed_1, "addSuiteNamed:" },
        { &sel_deleteCookie_1, "deleteCookie:" },
        { &sel_isLocationRequiredToCreateForKey_1, "isLocationRequiredToCreateForKey:" },
        { &sel_saveGraphicsState, "saveGraphicsState" },
        { &sel_getInfoForFile_1application_1type_1, "getInfoForFile:application:type:" },
        { &sel_HTTPBodyStream, "HTTPBodyStream" },
        { &sel_accessibilityParameterizedAttributeNames, "accessibilityParameterizedAttributeNames" },
        { &sel_objectForKey_1, "objectForKey:" },
        { &sel_classForArchiver, "classForArchiver" },
        { &sel_allBundles, "allBundles" },
        { &sel_rangeOfComposedCharacterSequenceAtIndex_1, "rangeOfComposedCharacterSequenceAtIndex:" },
        { &sel_allowsDuplicatesInToolbar, "allowsDuplicatesInToolbar" },
        { &sel_speechSynthesizer_1didEncounterSyncMessage_1, "speechSynthesizer:didEncounterSyncMessage:" },
        { &sel_performSelector_1withObject_1afterDelay_1inModes_1, "performSelector:withObject:afterDelay:inModes:" },
        { &sel_setScalesWhenResized_1, "setScalesWhenResized:" },
        { &sel_fileWrappers, "fileWrappers" },
        { &sel_setSubmenu_1, "setSubmenu:" },
        { &sel_setSendsSearchStringImmediately_1, "setSendsSearchStringImmediately:" },
        { &sel_movieUnfilteredPasteboardTypes, "movieUnfilteredPasteboardTypes" },
        { &sel_browser_1willDisplayCell_1atRow_1column_1, "browser:willDisplayCell:atRow:column:" },
        { &sel_valueOfAttribute_1forResultAtIndex_1, "valueOfAttribute:forResultAtIndex:" },
        { &sel_rightExpression, "rightExpression" },
        { &sel_moveNode_1toIndexPath_1, "moveNode:toIndexPath:" },
        { &sel_insertionKey, "insertionKey" },
        { &sel_columnsAutosaveName, "columnsAutosaveName" },
        { &sel_connection_1didReceiveResponse_1, "connection:didReceiveResponse:" },
        { &sel_delegate, "delegate" },
        { &sel_valueForHTTPHeaderField_1, "valueForHTTPHeaderField:" },
        { &sel_requiredThickness, "requiredThickness" },
        { &sel_selectedCells, "selectedCells" },
        { &sel_setResizable_1, "setResizable:" },
        { &sel_resizeRightCursor, "resizeRightCursor" },
        { &sel_arrayWithContentsOfURL_1, "arrayWithContentsOfURL:" },
        { &sel_setEchosBullets_1, "setEchosBullets:" },
        { &sel_outlineViewItemDidCollapse_1, "outlineViewItemDidCollapse:" },
        { &sel_mutableSetValueForKey_1, "mutableSetValueForKey:" },
        { &sel_initWithObjects_1forKeys_1count_1, "initWithObjects:forKeys:count:" },
        { &sel_canBeDisabled, "canBeDisabled" },
        { &sel_selectTabViewItemWithIdentifier_1, "selectTabViewItemWithIdentifier:" },
        { &sel_setLongEraSymbols_1, "setLongEraSymbols:" },
        { &sel_displayRect_1, "displayRect:" },
        { &sel_initRemoteWithProtocolFamily_1socketType_1protocol_1address_1, "initRemoteWithProtocolFamily:socketType:protocol:address:" },
        { &sel_setQueuePriority_1, "setQueuePriority:" },
        { &sel_initWithFileDescriptor_1closeOnDealloc_1, "initWithFileDescriptor:closeOnDealloc:" },
        { &sel_comboBoxWillDismiss_1, "comboBoxWillDismiss:" },
        { &sel_setMatchesOnMultipleResolution_1, "setMatchesOnMultipleResolution:" },
        { &sel_connection, "connection" },
        { &sel_includedKeys, "includedKeys" },
        { &sel_writeToURL_1options_1error_1, "writeToURL:options:error:" },
        { &sel_activeProcessorCount, "activeProcessorCount" },
        { &sel_countByEnumeratingWithState_1objects_1count_1, "countByEnumeratingWithState:objects:count:" },
        { &sel_setTransformStruct_1, "setTransformStruct:" },
        { &sel_setVeryShortWeekdaySymbols_1, "setVeryShortWeekdaySymbols:" },
        { &sel_markerLocation, "markerLocation" },
        { &sel_widthForLayer_1edge_1, "widthForLayer:edge:" },
        { &sel_transform, "transform" },
        { &sel_addSelectionIndexPaths_1, "addSelectionIndexPaths:" },
        { &sel_removeRequestMode_1, "removeRequestMode:" },
        { &sel_indexOfObject_1inRange_1, "indexOfObject:inRange:" },
        { &sel_awakeAfterUsingCoder_1, "awakeAfterUsingCoder:" },
        { &sel_setKnobProportion_1, "setKnobProportion:" },
        { &sel_setAllowsUserCustomization_1, "setAllowsUserCustomization:" },
        { &sel_setCurrentOperation_1, "setCurrentOperation:" },
        { &sel_outlineView_1isGroupItem_1, "outlineView:isGroupItem:" },
        { &sel_deleteGlyphsInRange_1, "deleteGlyphsInRange:" },
        { &sel_setSelectedObjects_1, "setSelectedObjects:" },
        { &sel_pathComponentCellAtPoint_1withFrame_1inView_1, "pathComponentCellAtPoint:withFrame:inView:" },
        { &sel_outlineView_1acceptDrop_1item_1childIndex_1, "outlineView:acceptDrop:item:childIndex:" },
        { &sel_setBackgroundColor_1, "setBackgroundColor:" },
        { &sel_canSelectNext, "canSelectNext" },
        { &sel_encodeRect_1forKey_1, "encodeRect:forKey:" },
        { &sel_resetCursorRect_1inView_1, "resetCursorRect:inView:" },
        { &sel_resumeData, "resumeData" },
        { &sel_levelsOfUndo, "levelsOfUndo" },
        { &sel_objectIsForcedForKey_1, "objectIsForcedForKey:" },
        { &sel_minSize, "minSize" },
        { &sel_indentationPerLevel, "indentationPerLevel" },
        { &sel_browserColumnConfigurationDidChange_1, "browserColumnConfigurationDidChange:" },
        { &sel_startAnimation, "startAnimation" },
        { &sel_outlineView_1namesOfPromisedFilesDroppedAtDestination_1forDraggedItems_1, "outlineView:namesOfPromisedFilesDroppedAtDestination:forDraggedItems:" },
        { &sel_setAlignment_1range_1, "setAlignment:range:" },
        { &sel_zeroSymbol, "zeroSymbol" },
        { &sel_draggedImage_1beganAt_1, "draggedImage:beganAt:" },
        { &sel_buttonMask, "buttonMask" },
        { &sel_frame, "frame" },
        { &sel_markers, "markers" },
        { &sel_initWithObjects_1count_1, "initWithObjects:count:" },
        { &sel_unload, "unload" },
        { &sel_initForReadingWithData_1, "initForReadingWithData:" },
        { &sel_year, "year" },
        { &sel_ruleEditor_1child_1forCriterion_1withRowType_1, "ruleEditor:child:forCriterion:withRowType:" },
        { &sel_dayOfMonth, "dayOfMonth" },
        { &sel_colorUsingColorSpaceName_1, "colorUsingColorSpaceName:" },
        { &sel_registerCoercer_1selector_1toConvertFromClass_1toClass_1, "registerCoercer:selector:toConvertFromClass:toClass:" },
        { &sel_removeObject_1inRange_1, "removeObject:inRange:" },
        { &sel_setFrameFromString_1, "setFrameFromString:" },
        { &sel_canAdd, "canAdd" },
        { &sel_era, "era" },
        { &sel_expressionForSubquery_1usingIteratorVariable_1predicate_1, "expressionForSubquery:usingIteratorVariable:predicate:" },
        { &sel_setAMSymbol_1, "setAMSymbol:" },
        { &sel_groupedResults, "groupedResults" },
        { &sel_attributedStringValue, "attributedStringValue" },
        { &sel_enclosingScrollView, "enclosingScrollView" },
        { &sel_isEqualToNumber_1, "isEqualToNumber:" },
        { &sel_mainBundle, "mainBundle" },
        { &sel_textContainerForGlyphAtIndex_1effectiveRange_1, "textContainerForGlyphAtIndex:effectiveRange:" },
        { &sel_setUsesGroupingSeparator_1, "setUsesGroupingSeparator:" },
        { &sel_pointerAtIndex_1, "pointerAtIndex:" },
        { &sel_arrowsPosition, "arrowsPosition" },
        { &sel_panel_1compareFilename_1with_1caseSensitive_1, "panel:compareFilename:with:caseSensitive:" },
        { &sel_drawSeparatorItemWithFrame_1inView_1, "drawSeparatorItemWithFrame:inView:" },
        { &sel_objectsByEvaluatingWithContainers_1, "objectsByEvaluatingWithContainers:" },
        { &sel_textTabForGlyphLocation_1writingDirection_1maxLocation_1, "textTabForGlyphLocation:writingDirection:maxLocation:" },
        { &sel_fontDescriptor, "fontDescriptor" },
        { &sel_validAttributesForMarkedText, "validAttributesForMarkedText" },
        { &sel_scriptingEndsWith_1, "scriptingEndsWith:" },
        { &sel_scrollViaScroller_1, "scrollViaScroller:" },
        { &sel_setAlwaysUsesMultipleValuesMarker_1, "setAlwaysUsesMultipleValuesMarker:" },
        { &sel_attributeKeys, "attributeKeys" },
        { &sel_darkGrayColor, "darkGrayColor" },
        { &sel_setExtensionHidden_1, "setExtensionHidden:" },
        { &sel_drawInRect_1withAttributes_1, "drawInRect:withAttributes:" },
        { &sel_selectTabViewItemAtIndex_1, "selectTabViewItemAtIndex:" },
        { &sel_contentRectForFrameRect_1, "contentRectForFrameRect:" },
        { &sel_setParagraphSpacingBefore_1, "setParagraphSpacingBefore:" },
        { &sel_minDate, "minDate" },
        { &sel_isARepeat, "isARepeat" },
        { &sel_selectedTabViewItem, "selectedTabViewItem" },
        { &sel_minusHashTable_1, "minusHashTable:" },
        { &sel_preferredLocalizationsFromArray_1forPreferences_1, "preferredLocalizationsFromArray:forPreferences:" },
        { &sel_setTextBlocks_1, "setTextBlocks:" },
        { &sel_writePrintInfo, "writePrintInfo" },
        { &sel_paperName, "paperName" },
        { &sel_pauseSpeakingAtBoundary_1, "pauseSpeakingAtBoundary:" },
        { &sel_markedTextAbandoned_1, "markedTextAbandoned:" },
        { &sel_setTitled_1, "setTitled:" },
        { &sel_hidesOnDeactivate, "hidesOnDeactivate" },
        { &sel_selectedRange, "selectedRange" },
        { &sel_reportException_1, "reportException:" },
        { &sel_drawBezelWithFrame_1inView_1, "drawBezelWithFrame:inView:" },
        { &sel_relativeMoveToPoint_1, "relativeMoveToPoint:" },
        { &sel_printingAdjustmentInLayoutManager_1forNominallySpacedGlyphRange_1packedGlyphs_1count_1, "printingAdjustmentInLayoutManager:forNominallySpacedGlyphRange:packedGlyphs:count:" },
        { &sel_longValue, "longValue" },
        { &sel_setMaxNumberOfColumns_1, "setMaxNumberOfColumns:" },
        { &sel_textView_1draggedCell_1inRect_1event_1atIndex_1, "textView:draggedCell:inRect:event:atIndex:" },
        { &sel_isRemovable, "isRemovable" },
        { &sel_handleCloseScriptCommand_1, "handleCloseScriptCommand:" },
        { &sel_layoutManager_1shouldUseTemporaryAttributes_1forDrawingToScreen_1atCharacterIndex_1effectiveRange_1, "layoutManager:shouldUseTemporaryAttributes:forDrawingToScreen:atCharacterIndex:effectiveRange:" },
        { &sel_expressionForKeyPath_1, "expressionForKeyPath:" },
        { &sel_bezierPathWithOvalInRect_1, "bezierPathWithOvalInRect:" },
        { &sel_deselectSelectedCell, "deselectSelectedCell" },
        { &sel_defaultSubcontainerAttributeKey, "defaultSubcontainerAttributeKey" },
        { &sel_yank_1, "yank:" },
        { &sel_changeSpelling_1, "changeSpelling:" },
        { &sel_totalAutoreleasedObjects, "totalAutoreleasedObjects" },
        { &sel_loops, "loops" },
        { &sel_boundsRectForTextBlock_1atIndex_1effectiveRange_1, "boundsRectForTextBlock:atIndex:effectiveRange:" },
        { &sel_resignMainWindow, "resignMainWindow" },
        { &sel_availableLanguages, "availableLanguages" },
        { &sel_initWithMarkerFormat_1options_1, "initWithMarkerFormat:options:" },
        { &sel_runInNewThread, "runInNewThread" },
        { &sel_tableView_1selectionIndexesForProposedSelection_1, "tableView:selectionIndexesForProposedSelection:" },
        { &sel_fetchWithRequest_1merge_1error_1, "fetchWithRequest:merge:error:" },
        { &sel_endSubelementIdentifier, "endSubelementIdentifier" },
        { &sel_implementationClassName, "implementationClassName" },
        { &sel_eventNumber, "eventNumber" },
        { &sel_requestTimeout, "requestTimeout" },
        { &sel_boldSystemFontOfSize_1, "boldSystemFontOfSize:" },
        { &sel_setPixelsWide_1, "setPixelsWide:" },
        { &sel_labelForSegment_1, "labelForSegment:" },
        { &sel_setAlternateTitle_1, "setAlternateTitle:" },
        { &sel_shouldBreakLineByWordBeforeCharacterAtIndex_1, "shouldBreakLineByWordBeforeCharacterAtIndex:" },
        { &sel_lockFocusIfCanDraw, "lockFocusIfCanDraw" },
        { &sel_setFormat_1, "setFormat:" },
        { &sel_setSegmentCount_1, "setSegmentCount:" },
        { &sel_accessInstanceVariablesDirectly, "accessInstanceVariablesDirectly" },
        { &sel_comboBox_1completedString_1, "comboBox:completedString:" },
        { &sel_moveToBeginningOfParagraph_1, "moveToBeginningOfParagraph:" },
        { &sel_defaultParagraphStyle, "defaultParagraphStyle" },
        { &sel_availableTypeFromArray_1, "availableTypeFromArray:" },
        { &sel_setGregorianStartDate_1, "setGregorianStartDate:" },
        { &sel_dateWithTimeIntervalSince1970_1, "dateWithTimeIntervalSince1970:" },
        { &sel_imagePasteboardTypes, "imagePasteboardTypes" },
        { &sel_laterDate_1, "laterDate:" },
        { &sel_setBounds_1, "setBounds:" },
        { &sel_HTTPMethod, "HTTPMethod" },
        { &sel_getGlyphsInRange_1glyphs_1characterIndexes_1glyphInscriptions_1elasticBits_1bidiLevels_1, "getGlyphsInRange:glyphs:characterIndexes:glyphInscriptions:elasticBits:bidiLevels:" },
        { &sel_rectArrayForCharacterRange_1withinSelectedCharacterRange_1inTextContainer_1rectCount_1, "rectArrayForCharacterRange:withinSelectedCharacterRange:inTextContainer:rectCount:" },
        { &sel_drawGridInClipRect_1, "drawGridInClipRect:" },
        { &sel_isStarted, "isStarted" },
        { &sel_descriptorType, "descriptorType" },
        { &sel_ISOCurrencyCodes, "ISOCurrencyCodes" },
        { &sel_resetCancelButtonCell, "resetCancelButtonCell" },
        { &sel_positiveInfinitySymbol, "positiveInfinitySymbol" },
        { &sel_sendsActionOnArrowKeys, "sendsActionOnArrowKeys" },
        { &sel_delete_1, "delete:" },
        { &sel_toolbarWillAddItem_1, "toolbarWillAddItem:" },
        { &sel_updateCellInside_1, "updateCellInside:" },
        { &sel_inputClientResignActive_1, "inputClientResignActive:" },
        { &sel_initWithEventClass_1eventID_1targetDescriptor_1returnID_1transactionID_1, "initWithEventClass:eventID:targetDescriptor:returnID:transactionID:" },
        { &sel_decimalNumberByDividingBy_1withBehavior_1, "decimalNumberByDividingBy:withBehavior:" },
        { &sel_spellServer_1suggestCompletionsForPartialWordRange_1inString_1language_1, "spellServer:suggestCompletionsForPartialWordRange:inString:language:" },
        { &sel_arrayWithObjects_1count_1, "arrayWithObjects:count:" },
        { &sel_connectionWithRegisteredName_1host_1, "connectionWithRegisteredName:host:" },
        { &sel_initWithFormat_1, "initWithFormat:" },
        { &sel_sharedURLCache, "sharedURLCache" },
        { &sel_edited_1range_1changeInLength_1, "edited:range:changeInLength:" },
        { &sel_prepareContent, "prepareContent" },
        { &sel_stringWithCString_1encoding_1, "stringWithCString:encoding:" },
        { &sel_postNotificationName_1object_1userInfo_1deliverImmediately_1, "postNotificationName:object:userInfo:deliverImmediately:" },
        { &sel_coerceToDescriptorType_1, "coerceToDescriptorType:" },
        { &sel_selectionIndex, "selectionIndex" },
        { &sel_setContentMaxSize_1, "setContentMaxSize:" },
        { &sel_setColor_1atX_1y_1, "setColor:atX:y:" },
        { &sel_graphicsContext, "graphicsContext" },
        { &sel_hostWithName_1, "hostWithName:" },
        { &sel_toggleRuler_1, "toggleRuler:" },
        { &sel_glyphInfoWithGlyph_1forFont_1baseString_1, "glyphInfoWithGlyph:forFont:baseString:" },
        { &sel_panel_1willExpand_1, "panel:willExpand:" },
        { &sel_selectText_1, "selectText:" },
        { &sel_setShortMonthSymbols_1, "setShortMonthSymbols:" },
        { &sel_setBorderType_1, "setBorderType:" },
        { &sel_rangeOfString_1, "rangeOfString:" },
        { &sel_invalidateGlyphsOnLayoutInvalidationForGlyphRange_1, "invalidateGlyphsOnLayoutInvalidationForGlyphRange:" },
        { &sel_availableMembersOfFontFamily_1, "availableMembersOfFontFamily:" },
        { &sel_XPath, "XPath" },
        { &sel_contentsOfDirectoryAtPath_1error_1, "contentsOfDirectoryAtPath:error:" },
        { &sel_newItemForRepresentedObject_1, "newItemForRepresentedObject:" },
        { &sel_setMatrixClass_1, "setMatrixClass:" },
        { &sel_compositeToPoint_1operation_1fraction_1, "compositeToPoint:operation:fraction:" },
        { &sel_setHorizontallyResizable_1, "setHorizontallyResizable:" },
        { &sel_mapTableWithStrongToStrongObjects, "mapTableWithStrongToStrongObjects" },
        { &sel_colorSpaceModel, "colorSpaceModel" },
        { &sel_setCriticalValue_1, "setCriticalValue:" },
        { &sel_allowsToolTipsWhenApplicationIsInactive, "allowsToolTipsWhenApplicationIsInactive" },
        { &sel_transformUsingAffineTransform_1, "transformUsingAffineTransform:" },
        { &sel_initWithInvocation_1, "initWithInvocation:" },
        { &sel_containerClassDescription, "containerClassDescription" },
        { &sel_parser_1resolveExternalEntityName_1systemID_1, "parser:resolveExternalEntityName:systemID:" },
        { &sel_mouseLocationOutsideOfEventStream, "mouseLocationOutsideOfEventStream" },
        { &sel_detach, "detach" },
        { &sel_setPickerMask_1, "setPickerMask:" },
        { &sel_tokenStyle, "tokenStyle" },
        { &sel_setOptions_1, "setOptions:" },
        { &sel_PDFOperationWithView_1insideRect_1toPath_1printInfo_1, "PDFOperationWithView:insideRect:toPath:printInfo:" },
        { &sel_parser_1didStartElement_1namespaceURI_1qualifiedName_1attributes_1, "parser:didStartElement:namespaceURI:qualifiedName:attributes:" },
        { &sel_availableFontNamesMatchingFontDescriptor_1, "availableFontNamesMatchingFontDescriptor:" },
        { &sel_relativePath, "relativePath" },
        { &sel_moveWordForwardAndModifySelection_1, "moveWordForwardAndModifySelection:" },
        { &sel_currentTime, "currentTime" },
        { &sel_slideDraggedImageTo_1, "slideDraggedImageTo:" },
        { &sel_application_1printFile_1, "application:printFile:" },
        { &sel_punctuationCharacterSet, "punctuationCharacterSet" },
        { &sel_allKeysForObject_1, "allKeysForObject:" },
        { &sel_pathStyle, "pathStyle" },
        { &sel_allowsEditingTextAttributes, "allowsEditingTextAttributes" },
        { &sel_lineSpacingAfterGlyphAtIndex_1withProposedLineFragmentRect_1, "lineSpacingAfterGlyphAtIndex:withProposedLineFragmentRect:" },
        { &sel_initWithContentsOfMappedFile_1, "initWithContentsOfMappedFile:" },
        { &sel_initWithFrame_1pullsDown_1, "initWithFrame:pullsDown:" },
        { &sel_setView_1, "setView:" },
        { &sel_outlineViewSelectionDidChange_1, "outlineViewSelectionDidChange:" },
        { &sel_widthValueTypeForLayer_1edge_1, "widthValueTypeForLayer:edge:" },
        { &sel_dateWithTimeIntervalSinceNow_1, "dateWithTimeIntervalSinceNow:" },
        { &sel_display, "display" },
        { &sel_setRoundingBehavior_1, "setRoundingBehavior:" },
        { &sel_valueWithPoint_1, "valueWithPoint:" },
        { &sel_tickMarkValueAtIndex_1, "tickMarkValueAtIndex:" },
        { &sel_addColumnWithCells_1, "addColumnWithCells:" },
        { &sel_exposeBinding_1, "exposeBinding:" },
        { &sel_weekdayOrdinal, "weekdayOrdinal" },
        { &sel_canAddChild, "canAddChild" },
        { &sel_hitTest_1, "hitTest:" },
        { &sel_nibBundle, "nibBundle" },
        { &sel_resumeExecutionWithResult_1, "resumeExecutionWithResult:" },
        { &sel_setMonthSymbols_1, "setMonthSymbols:" },
        { &sel_hitPart, "hitPart" },
        { &sel_download_1didCancelAuthenticationChallenge_1, "download:didCancelAuthenticationChallenge:" },
        { &sel_descriptionWithCalendarFormat_1, "descriptionWithCalendarFormat:" },
        { &sel_setProtocolSpecificInformation_1, "setProtocolSpecificInformation:" },
        { &sel_tokenField_1shouldAddObjects_1atIndex_1, "tokenField:shouldAddObjects:atIndex:" },
        { &sel_popUpContextMenu_1withEvent_1forView_1, "popUpContextMenu:withEvent:forView:" },
        { &sel_stopPeriodicEvents, "stopPeriodicEvents" },
        { &sel_setDTD_1, "setDTD:" },
        { &sel_glyphAtIndex_1isValidIndex_1, "glyphAtIndex:isValidIndex:" },
        { &sel_encodeSize_1, "encodeSize:" },
        { &sel_windowForSheet, "windowForSheet" },
        { &sel_displayMode, "displayMode" },
        { &sel_revertDocumentToSaved_1, "revertDocumentToSaved:" },
        { &sel_tableView_1objectValueForTableColumn_1row_1, "tableView:objectValueForTableColumn:row:" },
        { &sel_setBackingType_1, "setBackingType:" },
        { &sel_scanUpToCharactersFromSet_1intoString_1, "scanUpToCharactersFromSet:intoString:" },
        { &sel_nextValidKeyView, "nextValidKeyView" },
        { &sel_arrayWithObject_1, "arrayWithObject:" },
        { &sel_flushBuffer, "flushBuffer" },
        { &sel_hasValidObjectValue, "hasValidObjectValue" },
        { &sel_numberWithUnsignedLong_1, "numberWithUnsignedLong:" },
        { &sel_collectExhaustively, "collectExhaustively" },
        { &sel_setImageInterpolation_1, "setImageInterpolation:" },
        { &sel_setSystemID_1, "setSystemID:" },
        { &sel_setCornerView_1, "setCornerView:" },
        { &sel_initWithDouble_1, "initWithDouble:" },
        { &sel_sortedArrayUsingDescriptors_1, "sortedArrayUsingDescriptors:" },
        { &sel_removeTextContainerAtIndex_1, "removeTextContainerAtIndex:" },
        { &sel_whitespaceCharacterSet, "whitespaceCharacterSet" },
        { &sel_classDescriptionForClass_1, "classDescriptionForClass:" },
        { &sel_setAttributedString_1, "setAttributedString:" },
        { &sel_setPixelsHigh_1, "setPixelsHigh:" },
        { &sel_setDynamicDepthLimit_1, "setDynamicDepthLimit:" },
        { &sel_sharedApplication, "sharedApplication" },
        { &sel_sound_1didFinishPlaying_1, "sound:didFinishPlaying:" },
        { &sel_defaultBehavior, "defaultBehavior" },
        { &sel_beginSheetForDirectory_1file_1types_1modalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1, "beginSheetForDirectory:file:types:modalForWindow:modalDelegate:didEndSelector:contextInfo:" },
        { &sel_orderFrontFontPanel_1, "orderFrontFontPanel:" },
        { &sel_searchForBrowsableDomains, "searchForBrowsableDomains" },
        { &sel_toggleAutomaticQuoteSubstitution_1, "toggleAutomaticQuoteSubstitution:" },
        { &sel_textView_1willChangeSelectionFromCharacterRanges_1toCharacterRanges_1, "textView:willChangeSelectionFromCharacterRanges:toCharacterRanges:" },
        { &sel_alignRight_1, "alignRight:" },
        { &sel_getBytes_1maxLength_1usedLength_1encoding_1options_1range_1remainingRange_1, "getBytes:maxLength:usedLength:encoding:options:range:remainingRange:" },
        { &sel_keyPointerFunctions, "keyPointerFunctions" },
        { &sel_mouseDownFlags, "mouseDownFlags" },
        { &sel_expandItem_1, "expandItem:" },
        { &sel_bezierPathWithRect_1, "bezierPathWithRect:" },
        { &sel_setGradientType_1, "setGradientType:" },
        { &sel_alphanumericCharacterSet, "alphanumericCharacterSet" },
        { &sel_deleteWordForward_1, "deleteWordForward:" },
        { &sel_cStringUsingEncoding_1, "cStringUsingEncoding:" },
        { &sel_storedValueForKey_1, "storedValueForKey:" },
        { &sel_fileSize, "fileSize" },
        { &sel_elementWithName_1URI_1, "elementWithName:URI:" },
        { &sel_pointSize, "pointSize" },
        { &sel_veryShortMonthSymbols, "veryShortMonthSymbols" },
        { &sel_transformSize_1, "transformSize:" },
        { &sel_titleWidth, "titleWidth" },
        { &sel_setTextContainerInset_1, "setTextContainerInset:" },
        { &sel_supportedWindowDepths, "supportedWindowDepths" },
        { &sel_appleEvent, "appleEvent" },
        { &sel_valueClassForBinding_1, "valueClassForBinding:" },
        { &sel_setFullScreen, "setFullScreen" },
        { &sel_encodeObject_1forKey_1, "encodeObject:forKey:" },
        { &sel_setSpellingState_1range_1, "setSpellingState:range:" },
        { &sel_greenComponent, "greenComponent" },
        { &sel_textBackgroundColor, "textBackgroundColor" },
        { &sel_currentEditor, "currentEditor" },
        { &sel_attachedSheet, "attachedSheet" },
        { &sel_new, "new" },
        { &sel_setChildren_1, "setChildren:" },
        { &sel_options, "options" },
        { &sel_setObjectClass_1, "setObjectClass:" },
        { &sel_borderWidth, "borderWidth" },
        { &sel_secondarySelectedControlColor, "secondarySelectedControlColor" },
        { &sel_scrollItemAtIndexToVisible_1, "scrollItemAtIndexToVisible:" },
        { &sel_wantsLayer, "wantsLayer" },
        { &sel_setPath_1, "setPath:" },
        { &sel_setKeys_1triggerChangeNotificationsForDependentKey_1, "setKeys:triggerChangeNotificationsForDependentKey:" },
        { &sel_verticalAlignment, "verticalAlignment" },
        { &sel_selectionGranularity, "selectionGranularity" },
        { &sel_minimumIntegerDigits, "minimumIntegerDigits" },
        { &sel_canCreateDirectories, "canCreateDirectories" },
        { &sel_fixAttributesInRange_1, "fixAttributesInRange:" },
        { &sel_URLWithString_1, "URLWithString:" },
        { &sel_setFrameFromContentFrame_1, "setFrameFromContentFrame:" },
        { &sel_setFillColor_1, "setFillColor:" },
        { &sel_dictionaryWithCapacity_1, "dictionaryWithCapacity:" },
        { &sel_updateFromPath_1, "updateFromPath:" },
        { &sel_netServiceDidResolveAddress_1, "netServiceDidResolveAddress:" },
        { &sel_usesLazyFetching, "usesLazyFetching" },
        { &sel_setMenuBarVisible_1, "setMenuBarVisible:" },
        { &sel_windowDidBecomeKey_1, "windowDidBecomeKey:" },
        { &sel_menuChanged_1, "menuChanged:" },
        { &sel_itemObjectValueAtIndex_1, "itemObjectValueAtIndex:" },
        { &sel_setClassName_1forClass_1, "setClassName:forClass:" },
        { &sel_setShowsToolbarButton_1, "setShowsToolbarButton:" },
        { &sel_plusSign, "plusSign" },
        { &sel_sharedSpellChecker, "sharedSpellChecker" },
        { &sel_getNumberOfRows_1columns_1, "getNumberOfRows:columns:" },
        { &sel_valueTransformerNames, "valueTransformerNames" },
        { &sel_interpolatedColorAtLocation_1, "interpolatedColorAtLocation:" },
        { &sel_updateSpellingPanelWithMisspelledWord_1, "updateSpellingPanelWithMisspelledWord:" },
        { &sel_yellowComponent, "yellowComponent" },
        { &sel_acceptsFirstResponder, "acceptsFirstResponder" },
        { &sel_valueWithRect_1, "valueWithRect:" },
        { &sel_frameOfCellAtColumn_1row_1, "frameOfCellAtColumn:row:" },
        { &sel_makeWindowsPerform_1inOrder_1, "makeWindowsPerform:inOrder:" },
        { &sel_lastIndex, "lastIndex" },
        { &sel_initWithCharacters_1length_1, "initWithCharacters:length:" },
        { &sel_initWithIdentifier_1, "initWithIdentifier:" },
        { &sel_proxyWithLocal_1connection_1, "proxyWithLocal:connection:" },
        { &sel_scrollColumnToVisible_1, "scrollColumnToVisible:" },
        { &sel_descriptor, "descriptor" },
        { &sel_ISOCountryCodes, "ISOCountryCodes" },
        { &sel_setStandardInput_1, "setStandardInput:" },
        { &sel_getAdvancements_1forGlyphs_1count_1, "getAdvancements:forGlyphs:count:" },
        { &sel_displayColumn_1, "displayColumn:" },
        { &sel_setAltersStateOfSelectedItem_1, "setAltersStateOfSelectedItem:" },
        { &sel_setFrameRotation_1, "setFrameRotation:" },
        { &sel_clickedOnLink_1atIndex_1, "clickedOnLink:atIndex:" },
        { &sel_addAttribute_1, "addAttribute:" },
        { &sel_readPrintInfo, "readPrintInfo" },
        { &sel_setCurrentContext_1, "setCurrentContext:" },
        { &sel_setVerticalLineScroll_1, "setVerticalLineScroll:" },
        { &sel_commands, "commands" },
        { &sel_setNamespaces_1, "setNamespaces:" },
        { &sel_removeEntryAtIndex_1, "removeEntryAtIndex:" },
        { &sel_setAllowsColumnResizing_1, "setAllowsColumnResizing:" },
        { &sel_colorWithDeviceCyan_1magenta_1yellow_1black_1alpha_1, "colorWithDeviceCyan:magenta:yellow:black:alpha:" },
        { &sel_textView_1shouldChangeTypingAttributes_1toAttributes_1, "textView:shouldChangeTypingAttributes:toAttributes:" },
        { &sel_usesFeedbackWindow, "usesFeedbackWindow" },
        { &sel_setCookie_1, "setCookie:" },
        { &sel_keyWindow, "keyWindow" },
        { &sel_headIndent, "headIndent" },
        { &sel_removeObjectIdenticalTo_1inRange_1, "removeObjectIdenticalTo:inRange:" },
        { &sel_applicationWillUnhide_1, "applicationWillUnhide:" },
        { &sel_currentPage, "currentPage" },
        { &sel_setOffStateImage_1, "setOffStateImage:" },
        { &sel_addRowWithCells_1, "addRowWithCells:" },
        { &sel_setInterlineSpacing_1, "setInterlineSpacing:" },
        { &sel_imageFileTypes, "imageFileTypes" },
        { &sel_setArray_1, "setArray:" },
        { &sel_addLayoutManager_1, "addLayoutManager:" },
        { &sel_outputStreamToFileAtPath_1append_1, "outputStreamToFileAtPath:append:" },
        { &sel_registeredDraggedTypes, "registeredDraggedTypes" },
        { &sel_colorWithCalibratedRed_1green_1blue_1alpha_1, "colorWithCalibratedRed:green:blue:alpha:" },
        { &sel_invalidateClassDescriptionCache, "invalidateClassDescriptionCache" },
        { &sel_URLProtocolDidFinishLoading_1, "URLProtocolDidFinishLoading:" },
        { &sel_didChangeArrangementCriteria, "didChangeArrangementCriteria" },
        { &sel_ICCProfileData, "ICCProfileData" },
        { &sel_availableResourceData, "availableResourceData" },
        { &sel_glyphIndexForPoint_1inTextContainer_1fractionOfDistanceThroughGlyph_1, "glyphIndexForPoint:inTextContainer:fractionOfDistanceThroughGlyph:" },
        { &sel_moveToEndOfParagraph_1, "moveToEndOfParagraph:" },
        { &sel_enterFullScreenMode_1withOptions_1, "enterFullScreenMode:withOptions:" },
        { &sel_fieldEditor_1forObject_1, "fieldEditor:forObject:" },
        { &sel_setTreatsFilePackagesAsDirectories_1, "setTreatsFilePackagesAsDirectories:" },
        { &sel_setLevelIndicatorStyle_1, "setLevelIndicatorStyle:" },
        { &sel_minimumDecimalNumber, "minimumDecimalNumber" },
        { &sel_hasSpaceAvailable, "hasSpaceAvailable" },
        { &sel_widthOfString_1, "widthOfString:" },
        { &sel_setLocale_1, "setLocale:" },
        { &sel_setPreferredEdge_1, "setPreferredEdge:" },
        { &sel_setRichText_1, "setRichText:" },
        { &sel_rangesForUserCharacterAttributeChange, "rangesForUserCharacterAttributeChange" },
        { &sel_rectForPage_1, "rectForPage:" },
        { &sel_rowHeight, "rowHeight" },
        { &sel_windowDidChangeScreenProfile_1, "windowDidChangeScreenProfile:" },
        { &sel_setCachePolicy_1, "setCachePolicy:" },
        { &sel_parser_1didEndMappingPrefix_1, "parser:didEndMappingPrefix:" },
        { &sel_cleanUpAfterDragOperation, "cleanUpAfterDragOperation" },
        { &sel_browser_1typeSelectStringForRow_1inColumn_1, "browser:typeSelectStringForRow:inColumn:" },
        { &sel_canInitWithPasteboard_1, "canInitWithPasteboard:" },
        { &sel_startListening, "startListening" },
        { &sel_setExcludedKeys_1, "setExcludedKeys:" },
        { &sel_readFromFile_1ofType_1, "readFromFile:ofType:" },
        { &sel_setReservedThicknessForMarkers_1, "setReservedThicknessForMarkers:" },
        { &sel_windowRef, "windowRef" },
        { &sel_browser_1selectRow_1inColumn_1, "browser:selectRow:inColumn:" },
        { &sel_isOpaque, "isOpaque" },
        { &sel_fontDescriptorWithFamily_1, "fontDescriptorWithFamily:" },
        { &sel_itemTitleAtIndex_1, "itemTitleAtIndex:" },
        { &sel_boundingBox, "boundingBox" },
        { &sel_moveColumn_1toColumn_1, "moveColumn:toColumn:" },
        { &sel_badgeLabel, "badgeLabel" },
        { &sel_outline_1, "outline:" },
        { &sel_characterIndexForInsertionAtPoint_1, "characterIndexForInsertionAtPoint:" },
        { &sel_URLHandleClassForURL_1, "URLHandleClassForURL:" },
        { &sel_selectKeyViewFollowingView_1, "selectKeyViewFollowingView:" },
        { &sel_fullPathForApplication_1, "fullPathForApplication:" },
        { &sel_outlineView_1willDisplayOutlineCell_1forTableColumn_1item_1, "outlineView:willDisplayOutlineCell:forTableColumn:item:" },
        { &sel_encodePropertyList_1, "encodePropertyList:" },
        { &sel_generatesDecimalNumbers, "generatesDecimalNumbers" },
        { &sel_appendAttributedString_1, "appendAttributedString:" },
        { &sel_persistentDomainNames, "persistentDomainNames" },
        { &sel_setUserFont_1, "setUserFont:" },
        { &sel_initWithProperties_1, "initWithProperties:" },
        { &sel_loadResourceDataNotifyingClient_1usingCache_1, "loadResourceDataNotifyingClient:usingCache:" },
        { &sel_closeFile, "closeFile" },
        { &sel_allHeaderFields, "allHeaderFields" },
        { &sel_unlearnWord_1, "unlearnWord:" },
        { &sel_drawsCellBackground, "drawsCellBackground" },
        { &sel_PICTRepresentation, "PICTRepresentation" },
        { &sel_imageScaling, "imageScaling" },
        { &sel_scanUpToString_1intoString_1, "scanUpToString:intoString:" },
        { &sel_scrollBarColor, "scrollBarColor" },
        { &sel_initWithDelegate_1name_1, "initWithDelegate:name:" },
        { &sel_setDateValue_1, "setDateValue:" },
        { &sel_dividerStyle, "dividerStyle" },
        { &sel_scrollPageDown_1, "scrollPageDown:" },
        { &sel_removeLayoutManager_1, "removeLayoutManager:" },
        { &sel_textAttributesForNegativeValues, "textAttributesForNegativeValues" },
        { &sel_attachment, "attachment" },
        { &sel_reset, "reset" },
        { &sel_initWithAttributes_1, "initWithAttributes:" },
        { &sel_allowsMixedState, "allowsMixedState" },
        { &sel_addPort_1forMode_1, "addPort:forMode:" },
        { &sel_windowDidDeminiaturize_1, "windowDidDeminiaturize:" },
        { &sel_setRowHeight_1, "setRowHeight:" },
        { &sel_setGraphicsState_1, "setGraphicsState:" },
        { &sel_replaceCharactersInRange_1withAttributedString_1, "replaceCharactersInRange:withAttributedString:" },
        { &sel_setAttributedStringValue_1, "setAttributedStringValue:" },
        { &sel_criteriaKeyPath, "criteriaKeyPath" },
        { &sel_standardInput, "standardInput" },
        { &sel_isFontAvailable_1, "isFontAvailable:" },
        { &sel_setAllowsTypeSelect_1, "setAllowsTypeSelect:" },
        { &sel_portWithMachPort_1, "portWithMachPort:" },
        { &sel_panel_1isValidFilename_1, "panel:isValidFilename:" },
        { &sel_imageablePageBounds, "imageablePageBounds" },
        { &sel_notificationWithName_1object_1, "notificationWithName:object:" },
        { &sel_sharedFontPanelExists, "sharedFontPanelExists" },
        { &sel_blackColor, "blackColor" },
        { &sel_removeDescriptorAtIndex_1, "removeDescriptorAtIndex:" },
        { &sel_dataUsingEncoding_1allowLossyConversion_1, "dataUsingEncoding:allowLossyConversion:" },
        { &sel_propertyForKey_1inRequest_1, "propertyForKey:inRequest:" },
        { &sel_setHeaderLevel_1, "setHeaderLevel:" },
        { &sel_jobTitle, "jobTitle" },
        { &sel_removePersistentDomainForName_1, "removePersistentDomainForName:" },
        { &sel_contentResizeIncrements, "contentResizeIncrements" },
        { &sel_textFileTypes, "textFileTypes" },
        { &sel_setAction_1, "setAction:" },
        { &sel_knobProportion, "knobProportion" },
        { &sel_numberOfArguments, "numberOfArguments" },
        { &sel_setScrollsDynamically_1, "setScrollsDynamically:" },
        { &sel_setTextColor_1range_1, "setTextColor:range:" },
        { &sel_setBoundsSize_1, "setBoundsSize:" },
        { &sel_setVolume_1, "setVolume:" },
        { &sel_windowControllers, "windowControllers" },
        { &sel_insertAttributedString_1atIndex_1, "insertAttributedString:atIndex:" },
        { &sel_eventWithEventRef_1, "eventWithEventRef:" },
        { &sel_initByReferencingFile_1, "initByReferencingFile:" },
        { &sel_fire, "fire" },
        { &sel_writeToPasteboard_1, "writeToPasteboard:" },
        { &sel_connectionForProxy, "connectionForProxy" },
        { &sel_outlineView_1mouseDownInHeaderOfTableColumn_1, "outlineView:mouseDownInHeaderOfTableColumn:" },
        { &sel_mutableArrayValueForKeyPath_1, "mutableArrayValueForKeyPath:" },
        { &sel_validRequestorForSendType_1returnType_1, "validRequestorForSendType:returnType:" },
        { &sel_isRichText, "isRichText" },
        { &sel_moveWordLeft_1, "moveWordLeft:" },
        { &sel_indexSetWithIndex_1, "indexSetWithIndex:" },
        { &sel_setContextMenuRepresentation_1, "setContextMenuRepresentation:" },
        { &sel_updateTrackingAreas, "updateTrackingAreas" },
        { &sel_defaultCollector, "defaultCollector" },
        { &sel_orderedIndex, "orderedIndex" },
        { &sel_relativeCurveToPoint_1controlPoint1_1controlPoint2_1, "relativeCurveToPoint:controlPoint1:controlPoint2:" },
        { &sel_setShowsApplicationBadge_1, "setShowsApplicationBadge:" },
        { &sel_setValue_1, "setValue:" },
        { &sel_attributeDeclarationForName_1elementName_1, "attributeDeclarationForName:elementName:" },
        { &sel_setWidth_1type_1forLayer_1, "setWidth:type:forLayer:" },
        { &sel_decodePoint, "decodePoint" },
        { &sel_makeWindowControllers, "makeWindowControllers" },
        { &sel_userFontOfSize_1, "userFontOfSize:" },
        { &sel_dependencies, "dependencies" },
        { &sel_setAttributes_1, "setAttributes:" },
        { &sel_setFrameCenterRotation_1, "setFrameCenterRotation:" },
        { &sel_nilSymbol, "nilSymbol" },
        { &sel_scalesWhenResized, "scalesWhenResized" },
        { &sel_setMinusSign_1, "setMinusSign:" },
        { &sel_predicateOperatorType, "predicateOperatorType" },
        { &sel_replyWithException_1, "replyWithException:" },
        { &sel_fileName, "fileName" },
        { &sel_indexPathByRemovingLastIndex, "indexPathByRemovingLastIndex" },
        { &sel_openHelpAnchor_1inBook_1, "openHelpAnchor:inBook:" },
        { &sel_initWithBytes_1objCType_1, "initWithBytes:objCType:" },
        { &sel_removeObject_1, "removeObject:" },
        { &sel_colorNameComponent, "colorNameComponent" },
        { &sel_setCellBackgroundColor_1, "setCellBackgroundColor:" },
        { &sel_getLineDash_1count_1phase_1, "getLineDash:count:phase:" },
        { &sel_scriptingContains_1, "scriptingContains:" },
        { &sel_setDefaultWindingRule_1, "setDefaultWindingRule:" },
        { &sel_outputStreamToBuffer_1capacity_1, "outputStreamToBuffer:capacity:" },
        { &sel_defaultButtonTitle, "defaultButtonTitle" },
        { &sel_draggingSourceOperationMask, "draggingSourceOperationMask" },
        { &sel_textDidChange_1, "textDidChange:" },
        { &sel_drawSheetBorderWithSize_1, "drawSheetBorderWithSize:" },
        { &sel_integerForKey_1, "integerForKey:" },
        { &sel_setDefaultNameServerPortNumber_1, "setDefaultNameServerPortNumber:" },
        { &sel_previousNode, "previousNode" },
        { &sel_trackingArea, "trackingArea" },
        { &sel_highlightWithLevel_1, "highlightWithLevel:" },
        { &sel_trackMouse_1inRect_1ofView_1atCharacterIndex_1untilMouseUp_1, "trackMouse:inRect:ofView:atCharacterIndex:untilMouseUp:" },
        { &sel_signatureWithObjCTypes_1, "signatureWithObjCTypes:" },
        { &sel_saveToURL_1ofType_1forSaveOperation_1error_1, "saveToURL:ofType:forSaveOperation:error:" },
        { &sel_dataWithBytesNoCopy_1length_1freeWhenDone_1, "dataWithBytesNoCopy:length:freeWhenDone:" },
        { &sel_encodeInteger_1forKey_1, "encodeInteger:forKey:" },
        { &sel_removeFromSuperview, "removeFromSuperview" },
        { &sel_dataWithBytesNoCopy_1length_1, "dataWithBytesNoCopy:length:" },
        { &sel_initWithIndexesInRange_1, "initWithIndexesInRange:" },
        { &sel_initWithKeyPointerFunctions_1valuePointerFunctions_1capacity_1, "initWithKeyPointerFunctions:valuePointerFunctions:capacity:" },
        { &sel_tilt, "tilt" },
        { &sel_setHidden_1, "setHidden:" },
        { &sel_setMenuFormRepresentation_1, "setMenuFormRepresentation:" },
        { &sel_setCanChooseDirectories_1, "setCanChooseDirectories:" },
        { &sel_usedRectForTextContainer_1, "usedRectForTextContainer:" },
        { &sel_allowsColumnSelection, "allowsColumnSelection" },
        { &sel_orderOut_1, "orderOut:" },
        { &sel_filterUsingPredicate_1, "filterUsingPredicate:" },
        { &sel_setTest_1, "setTest:" },
        { &sel_setAllowedTypes_1, "setAllowedTypes:" },
        { &sel_registerForDraggedTypes_1, "registerForDraggedTypes:" },
        { &sel_objectEnumerator, "objectEnumerator" },
        { &sel_setWindowController_1, "setWindowController:" },
        { &sel_setDestination_1, "setDestination:" },
        { &sel_addRepresentation_1, "addRepresentation:" },
        { &sel_isEqual_1, "isEqual:" },
        { &sel_glyphRangeForTextContainer_1, "glyphRangeForTextContainer:" },
        { &sel_setStandaloneWeekdaySymbols_1, "setStandaloneWeekdaySymbols:" },
        { &sel_setIgnoresAlpha_1, "setIgnoresAlpha:" },
        { &sel_drawBarInside_1flipped_1, "drawBarInside:flipped:" },
        { &sel_doesNotRecognizeSelector_1, "doesNotRecognizeSelector:" },
        { &sel_windowDidResignMain_1, "windowDidResignMain:" },
        { &sel_scrollItemAtIndexToTop_1, "scrollItemAtIndexToTop:" },
        { &sel_makePreviousSegmentKey, "makePreviousSegmentKey" },
        { &sel_download_1shouldDecodeSourceDataOfMIMEType_1, "download:shouldDecodeSourceDataOfMIMEType:" },
        { &sel_compareObject_1toObject_1, "compareObject:toObject:" },
        { &sel_widthTracksTextView, "widthTracksTextView" },
        { &sel_subpredicates, "subpredicates" },
        { &sel_relativeLineToPoint_1, "relativeLineToPoint:" },
        { &sel_gridStyleMask, "gridStyleMask" },
        { &sel_initWithCString_1, "initWithCString:" },
        { &sel_imageScalingForSegment_1, "imageScalingForSegment:" },
        { &sel_editWithFrame_1inView_1editor_1delegate_1event_1, "editWithFrame:inView:editor:delegate:event:" },
        { &sel_glyphPacking, "glyphPacking" },
        { &sel_resolveWithTimeout_1, "resolveWithTimeout:" },
        { &sel_hasEditedDocuments, "hasEditedDocuments" },
        { &sel_getLineFragmentRect_1usedRect_1forParagraphSeparatorGlyphRange_1atProposedOrigin_1, "getLineFragmentRect:usedRect:forParagraphSeparatorGlyphRange:atProposedOrigin:" },
        { &sel_autosaveDocumentWithDelegate_1didAutosaveSelector_1contextInfo_1, "autosaveDocumentWithDelegate:didAutosaveSelector:contextInfo:" },
        { &sel_readSelectionFromPasteboard_1type_1, "readSelectionFromPasteboard:type:" },
        { &sel_spellServer_1suggestGuessesForWord_1inLanguage_1, "spellServer:suggestGuessesForWord:inLanguage:" },
        { &sel_initWithTimeIntervalSinceNow_1, "initWithTimeIntervalSinceNow:" },
        { &sel_setMaxWidth_1, "setMaxWidth:" },
        { &sel_userDefaultsChanged, "userDefaultsChanged" },
        { &sel_setWidth_1, "setWidth:" },
        { &sel_setPrintPanel_1, "setPrintPanel:" },
        { &sel_setCurrentPage_1, "setCurrentPage:" },
        { &sel_resizeIncrements, "resizeIncrements" },
        { &sel_selectWithFrame_1inView_1editor_1delegate_1start_1length_1, "selectWithFrame:inView:editor:delegate:start:length:" },
        { &sel_sRGBColorSpace, "sRGBColorSpace" },
        { &sel_scriptErrorExpectedTypeDescriptor, "scriptErrorExpectedTypeDescriptor" },
        { &sel_setHasHorizontalRuler_1, "setHasHorizontalRuler:" },
        { &sel_initialFirstResponder, "initialFirstResponder" },
        { &sel_stringForObjectValue_1, "stringForObjectValue:" },
        { &sel_pageRange, "pageRange" },
        { &sel_printOperationWithView_1, "printOperationWithView:" },
        { &sel_initWithFrame_1pixelFormat_1, "initWithFrame:pixelFormat:" },
        { &sel_fileWrapperOfType_1error_1, "fileWrapperOfType:error:" },
        { &sel_doesContain_1, "doesContain:" },
        { &sel_mutableSetValueForKeyPath_1, "mutableSetValueForKeyPath:" },
        { &sel_initWithURL_1cached_1, "initWithURL:cached:" },
        { &sel_controlAlternatingRowBackgroundColors, "controlAlternatingRowBackgroundColors" },
        { &sel_pathComponentCellClass, "pathComponentCellClass" },
        { &sel_arrayWithCapacity_1, "arrayWithCapacity:" },
        { &sel_types, "types" },
        { &sel_setPrintInfo_1, "setPrintInfo:" },
        { &sel_indexOfTabViewItemWithIdentifier_1, "indexOfTabViewItemWithIdentifier:" },
        { &sel_isEnabled, "isEnabled" },
        { &sel_setHeaderView_1, "setHeaderView:" },
        { &sel_accessibilityHitTest_1, "accessibilityHitTest:" },
        { &sel_removeMarker_1, "removeMarker:" },
        { &sel_showContextHelp_1, "showContextHelp:" },
        { &sel_selectsInsertedObjects, "selectsInsertedObjects" },
        { &sel_selectedRowInColumn_1, "selectedRowInColumn:" },
        { &sel_noteNewRecentDocument_1, "noteNewRecentDocument:" },
        { &sel_setAttachment_1, "setAttachment:" },
        { &sel_localeIdentifier, "localeIdentifier" },
        { &sel_scrollLineUp_1, "scrollLineUp:" },
        { &sel_setCalendarFormat_1, "setCalendarFormat:" },
        { &sel_setAssociatedPoints_1atIndex_1, "setAssociatedPoints:atIndex:" },
        { &sel_resourceData, "resourceData" },
        { &sel_setVeryShortStandaloneMonthSymbols_1, "setVeryShortStandaloneMonthSymbols:" },
        { &sel_windowDidUpdate_1, "windowDidUpdate:" },
        { &sel_moveLeft_1, "moveLeft:" },
        { &sel_showsBorderOnlyWhileMouseInside, "showsBorderOnlyWhileMouseInside" },
        { &sel_valueForKey_1, "valueForKey:" },
        { &sel_setContentResizeIncrements_1, "setContentResizeIncrements:" },
        { &sel_drain, "drain" },
        { &sel_concat, "concat" },
        { &sel_scrollerWidthForControlSize_1, "scrollerWidthForControlSize:" },
        { &sel_insertItemWithTitle_1action_1keyEquivalent_1atIndex_1, "insertItemWithTitle:action:keyEquivalent:atIndex:" },
        { &sel_doubleValue, "doubleValue" },
        { &sel_dividerThickness, "dividerThickness" },
        { &sel_rowAtPoint_1, "rowAtPoint:" },
        { &sel_updateWindowsItem_1, "updateWindowsItem:" },
        { &sel_calendarDate, "calendarDate" },
        { &sel_fixAttachmentAttributeInRange_1, "fixAttachmentAttributeInRange:" },
        { &sel_mapTableWithWeakToWeakObjects, "mapTableWithWeakToWeakObjects" },
        { &sel_setClip, "setClip" },
        { &sel_evaluationErrorNumber, "evaluationErrorNumber" },
        { &sel_revertToSavedFromURL_1ofType_1, "revertToSavedFromURL:ofType:" },
        { &sel_autorecalculatesContentBorderThicknessForEdge_1, "autorecalculatesContentBorderThicknessForEdge:" },
        { &sel_lineToPoint_1, "lineToPoint:" },
        { &sel_insertionReplaces, "insertionReplaces" },
        { &sel_smallestEncoding, "smallestEncoding" },
        { &sel_elementAtIndex_1, "elementAtIndex:" },
        { &sel_getReturnValue_1, "getReturnValue:" },
        { &sel_regularFileContents, "regularFileContents" },
        { &sel_recache, "recache" },
        { &sel_setTextAttributesForNegativeInfinity_1, "setTextAttributesForNegativeInfinity:" },
        { &sel_horizontalRulerView, "horizontalRulerView" },
        { &sel_initToMemory, "initToMemory" },
        { &sel_shouldCreateUI, "shouldCreateUI" },
        { &sel_scheme, "scheme" },
        { &sel_raiseBaseline_1, "raiseBaseline:" },
        { &sel_initWithArray_1, "initWithArray:" },
        { &sel_displayNameForKey_1value_1, "displayNameForKey:value:" },
        { &sel_centerScanRect_1, "centerScanRect:" },
        { &sel_memoryCapacity, "memoryCapacity" },
        { &sel_setBackgroundLayoutEnabled_1, "setBackgroundLayoutEnabled:" },
        { &sel_machPort, "machPort" },
        { &sel_selectedFont, "selectedFont" },
        { &sel_tableColumns, "tableColumns" },
        { &sel_removeObjectAtIndex_1, "removeObjectAtIndex:" },
        { &sel_insertNewButtonImage_1in_1, "insertNewButtonImage:in:" },
        { &sel_stringWithContentsOfURL_1encoding_1error_1, "stringWithContentsOfURL:encoding:error:" },
        { &sel_menuChangedMessagesEnabled, "menuChangedMessagesEnabled" },
        { &sel_initWithShort_1, "initWithShort:" },
        { &sel_setColorRenderingIntent_1, "setColorRenderingIntent:" },
        { &sel_descriptionWithCalendarFormat_1locale_1, "descriptionWithCalendarFormat:locale:" },
        { &sel_resourceSpecifier, "resourceSpecifier" },
        { &sel_pasteboardByFilteringFile_1, "pasteboardByFilteringFile:" },
        { &sel_dragColor_1withEvent_1fromView_1, "dragColor:withEvent:fromView:" },
        { &sel_setStroke, "setStroke" },
        { &sel_isControllerVisible, "isControllerVisible" },
        { &sel_putCell_1atRow_1column_1, "putCell:atRow:column:" },
        { &sel_firstIndex, "firstIndex" },
        { &sel_setFontManagerFactory_1, "setFontManagerFactory:" },
        { &sel_exponentSymbol, "exponentSymbol" },
        { &sel_stringValue, "stringValue" },
        { &sel_getObjects_1range_1, "getObjects:range:" },
        { &sel_scriptingProperties, "scriptingProperties" },
        { &sel_query, "query" },
        { &sel_eventClass, "eventClass" },
        { &sel_dateWithNaturalLanguageString_1, "dateWithNaturalLanguageString:" },
        { &sel_datePickerMode, "datePickerMode" },
        { &sel_setAlternateMnemonicLocation_1, "setAlternateMnemonicLocation:" },
        { &sel_stringByDeletingLastPathComponent, "stringByDeletingLastPathComponent" },
        { &sel_encodeObject_1, "encodeObject:" },
        { &sel_unarchiveObjectWithData_1, "unarchiveObjectWithData:" },
        { &sel_destination, "destination" },
        { &sel_ensureLayoutForCharacterRange_1, "ensureLayoutForCharacterRange:" },
        { &sel_tabView_1didSelectTabViewItem_1, "tabView:didSelectTabViewItem:" },
        { &sel_removeContextHelpForObject_1, "removeContextHelpForObject:" },
        { &sel_ensureGlyphsForCharacterRange_1, "ensureGlyphsForCharacterRange:" },
        { &sel_setMinimumFractionDigits_1, "setMinimumFractionDigits:" },
        { &sel_boundsRotation, "boundsRotation" },
        { &sel_invalidateDisplayForGlyphRange_1, "invalidateDisplayForGlyphRange:" },
        { &sel_rectForBlock_1layoutAtPoint_1inRect_1textContainer_1characterRange_1, "rectForBlock:layoutAtPoint:inRect:textContainer:characterRange:" },
        { &sel_pasteFont_1, "pasteFont:" },
        { &sel_backgroundColor, "backgroundColor" },
        { &sel_stringFromNumber_1, "stringFromNumber:" },
        { &sel_expiresDate, "expiresDate" },
        { &sel_initWithWindowRef_1, "initWithWindowRef:" },
        { &sel_toggleToolbarShown_1, "toggleToolbarShown:" },
        { &sel_outlineViewItemDidExpand_1, "outlineViewItemDidExpand:" },
        { &sel_TIFFRepresentationOfImageRepsInArray_1usingCompression_1factor_1, "TIFFRepresentationOfImageRepsInArray:usingCompression:factor:" },
        { &sel_variable, "variable" },
        { &sel_objectsForKeys_1notFoundMarker_1, "objectsForKeys:notFoundMarker:" },
        { &sel_controlColor, "controlColor" },
        { &sel_unarchiverWillFinish_1, "unarchiverWillFinish:" },
        { &sel_proposedCredential, "proposedCredential" },
        { &sel_isPaneSplitter, "isPaneSplitter" },
        { &sel_endUndoGrouping, "endUndoGrouping" },
        { &sel_setFrameRate_1, "setFrameRate:" },
        { &sel_completionDelay, "completionDelay" },
        { &sel_setUserFixedPitchFont_1, "setUserFixedPitchFont:" },
        { &sel_isIndeterminate, "isIndeterminate" },
        { &sel_menuItem, "menuItem" },
        { &sel_setNumberStyle_1, "setNumberStyle:" },
        { &sel_takeIntegerValueFrom_1, "takeIntegerValueFrom:" },
        { &sel_setIndentationMarkerFollowsCell_1, "setIndentationMarkerFollowsCell:" },
        { &sel_tile, "tile" },
        { &sel_cancelButtonRectForBounds_1, "cancelButtonRectForBounds:" },
        { &sel_deselectRow_1, "deselectRow:" },
        { &sel_setMouseCoalescingEnabled_1, "setMouseCoalescingEnabled:" },
        { &sel_removeWindowController_1, "removeWindowController:" },
        { &sel_warningValue, "warningValue" },
        { &sel_isVerticallyResizable, "isVerticallyResizable" },
        { &sel_defaultFetchRequest, "defaultFetchRequest" },
        { &sel_netServiceWillResolve_1, "netServiceWillResolve:" },
        { &sel_addProgressMark_1, "addProgressMark:" },
        { &sel_recentsAutosaveName, "recentsAutosaveName" },
        { &sel_commitEditing, "commitEditing" },
        { &sel_attributesOfItemAtPath_1error_1, "attributesOfItemAtPath:error:" },
        { &sel_download_1willSendRequest_1redirectResponse_1, "download:willSendRequest:redirectResponse:" },
        { &sel_canBeCompressedUsing_1, "canBeCompressedUsing:" },
        { &sel_strokeRect_1, "strokeRect:" },
        { &sel_descriptionWithLocale_1indent_1, "descriptionWithLocale:indent:" },
        { &sel_applicationDockMenu_1, "applicationDockMenu:" },
        { &sel_initWithCString_1length_1, "initWithCString:length:" },
        { &sel_runPageLayout_1, "runPageLayout:" },
        { &sel_toolbar_1itemForItemIdentifier_1willBeInsertedIntoToolbar_1, "toolbar:itemForItemIdentifier:willBeInsertedIntoToolbar:" },
        { &sel_setSelectsInsertedObjects_1, "setSelectsInsertedObjects:" },
        { &sel_alternateSelectedControlTextColor, "alternateSelectedControlTextColor" },
        { &sel_isValidGlyphIndex_1, "isValidGlyphIndex:" },
        { &sel_stringForKey_1inTable_1, "stringForKey:inTable:" },
        { &sel_cellSizeForBounds_1, "cellSizeForBounds:" },
        { &sel_beginSheetForDirectory_1file_1modalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1, "beginSheetForDirectory:file:modalForWindow:modalDelegate:didEndSelector:contextInfo:" },
        { &sel_invalidateLayoutForCharacterRange_1actualCharacterRange_1, "invalidateLayoutForCharacterRange:actualCharacterRange:" },
        { &sel_initAsTearOff, "initAsTearOff" },
        { &sel_allowsOtherFileTypes, "allowsOtherFileTypes" },
        { &sel_mouseMoved_1, "mouseMoved:" },
        { &sel_deleteCharactersInRange_1, "deleteCharactersInRange:" },
        { &sel_setTitleFont_1, "setTitleFont:" },
        { &sel_showsApplicationBadge, "showsApplicationBadge" },
        { &sel_initWithLeftExpression_1rightExpression_1modifier_1type_1options_1, "initWithLeftExpression:rightExpression:modifier:type:options:" },
        { &sel_distantPast, "distantPast" },
        { &sel_isReady, "isReady" },
        { &sel_draggedImage_1movedTo_1, "draggedImage:movedTo:" },
        { &sel_resetTotalAutoreleasedObjects, "resetTotalAutoreleasedObjects" },
        { &sel_setGlyphGenerator_1, "setGlyphGenerator:" },
        { &sel_groupsByEvent, "groupsByEvent" },
        { &sel_shortMonthSymbols, "shortMonthSymbols" },
        { &sel_setDescriptor_1forKeyword_1, "setDescriptor:forKeyword:" },
        { &sel_description, "description" },
        { &sel_replaceOccurrencesOfString_1withString_1options_1range_1, "replaceOccurrencesOfString:withString:options:range:" },
        { &sel_boundsRectForContentRect_1inRect_1textContainer_1characterRange_1, "boundsRectForContentRect:inRect:textContainer:characterRange:" },
        { &sel_authenticationDataForComponents_1, "authenticationDataForComponents:" },
        { &sel_isExecuting, "isExecuting" },
        { &sel_branchImage, "branchImage" },
        { &sel_decodeRectForKey_1, "decodeRectForKey:" },
        { &sel_rectValue, "rectValue" },
        { &sel_setFrameTopLeftPoint_1, "setFrameTopLeftPoint:" },
        { &sel_initWithFileDescriptor_1, "initWithFileDescriptor:" },
        { &sel_removePointerAtIndex_1, "removePointerAtIndex:" },
        { &sel_executeAndReturnError_1, "executeAndReturnError:" },
        { &sel_changeCaseOfLetter_1, "changeCaseOfLetter:" },
        { &sel_appendBezierPathWithArcWithCenter_1radius_1startAngle_1endAngle_1clockwise_1, "appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:clockwise:" },
        { &sel_insertNewlineIgnoringFieldEditor_1, "insertNewlineIgnoringFieldEditor:" },
        { &sel_attributeDescriptorForKeyword_1, "attributeDescriptorForKeyword:" },
        { &sel_decimalNumberWithMantissa_1exponent_1isNegative_1, "decimalNumberWithMantissa:exponent:isNegative:" },
        { &sel_activeConversationWillChange_1fromOldConversation_1, "activeConversationWillChange:fromOldConversation:" },
        { &sel_layoutAlgorithm, "layoutAlgorithm" },
        { &sel_itemNumberInTextList_1atIndex_1, "itemNumberInTextList:atIndex:" },
        { &sel_initWithImage_1hotSpot_1, "initWithImage:hotSpot:" },
        { &sel_setStackSize_1, "setStackSize:" },
        { &sel_matrixInColumn_1, "matrixInColumn:" },
        { &sel_performSelector_1withObject_1, "performSelector:withObject:" },
        { &sel_setSound_1, "setSound:" },
        { &sel_accessibilityPerformAction_1, "accessibilityPerformAction:" },
        { &sel_comment, "comment" },
        { &sel_rangeOfNominallySpacedGlyphsContainingIndex_1, "rangeOfNominallySpacedGlyphsContainingIndex:" },
        { &sel_showAttachmentCell_1inRect_1characterIndex_1, "showAttachmentCell:inRect:characterIndex:" },
        { &sel_isDisplayedWhenStopped, "isDisplayedWhenStopped" },
        { &sel_addCollection_1options_1, "addCollection:options:" },
        { &sel_drawInRect_1angle_1, "drawInRect:angle:" },
        { &sel_initWithFrame_1mode_1prototype_1numberOfRows_1numberOfColumns_1, "initWithFrame:mode:prototype:numberOfRows:numberOfColumns:" },
        { &sel_sharedCredentialStorage, "sharedCredentialStorage" },
        { &sel_colorWithDeviceWhite_1alpha_1, "colorWithDeviceWhite:alpha:" },
        { &sel_setMainDocumentURL_1, "setMainDocumentURL:" },
        { &sel_interpretKeyEvents_1, "interpretKeyEvents:" },
        { &sel_readFromData_1ofType_1error_1, "readFromData:ofType:error:" },
        { &sel_tokenFieldCell_1menuForRepresentedObject_1, "tokenFieldCell:menuForRepresentedObject:" },
        { &sel_setEventHandler_1andSelector_1forEventClass_1andEventID_1, "setEventHandler:andSelector:forEventClass:andEventID:" },
        { &sel_addAttribute_1value_1range_1, "addAttribute:value:range:" },
        { &sel_outlineView_1writeItems_1toPasteboard_1, "outlineView:writeItems:toPasteboard:" },
        { &sel_initWithCString_1encoding_1, "initWithCString:encoding:" },
        { &sel_setTypesetterBehavior_1, "setTypesetterBehavior:" },
        { &sel_removeObjectAtArrangedObjectIndex_1, "removeObjectAtArrangedObjectIndex:" },
        { &sel_redo, "redo" },
        { &sel_addMarker_1, "addMarker:" },
        { &sel_backgroundColors, "backgroundColors" },
        { &sel_leafKeyPath, "leafKeyPath" },
        { &sel_setMinimumIntegerDigits_1, "setMinimumIntegerDigits:" },
        { &sel_waitForDataInBackgroundAndNotify, "waitForDataInBackgroundAndNotify" },
        { &sel_setPreservesContentDuringLiveResize_1, "setPreservesContentDuringLiveResize:" },
        { &sel_setRootElement_1, "setRootElement:" },
        { &sel_dataWithEPSInsideRect_1, "dataWithEPSInsideRect:" },
        { &sel_valuesForKeys_1, "valuesForKeys:" },
        { &sel_imageOrigin, "imageOrigin" },
        { &sel_writePDFInsideRect_1toPasteboard_1, "writePDFInsideRect:toPasteboard:" },
        { &sel_sortIndicatorRectForBounds_1, "sortIndicatorRectForBounds:" },
        { &sel_predefinedNamespaceForPrefix_1, "predefinedNamespaceForPrefix:" },
        { &sel_viewWillStartLiveResize, "viewWillStartLiveResize" },
        { &sel_becomeKeyWindow, "becomeKeyWindow" },
        { &sel_isHighlighted, "isHighlighted" },
        { &sel_initWithPickerMask_1colorPanel_1, "initWithPickerMask:colorPanel:" },
        { &sel_systemFontOfSize_1, "systemFontOfSize:" },
        { &sel_decimalNumberBySubtracting_1withBehavior_1, "decimalNumberBySubtracting:withBehavior:" },
        { &sel_hide_1, "hide:" },
        { &sel_resetSearchButtonCell, "resetSearchButtonCell" },
        { &sel_runModalForDirectory_1file_1types_1, "runModalForDirectory:file:types:" },
        { &sel_pathForImageResource_1, "pathForImageResource:" },
        { &sel_setFilterPredicate_1, "setFilterPredicate:" },
        { &sel_validateEditing, "validateEditing" },
        { &sel_makeDocumentForURL_1withContentsOfURL_1ofType_1error_1, "makeDocumentForURL:withContentsOfURL:ofType:error:" },
        { &sel_localizedCompare_1, "localizedCompare:" },
        { &sel_sharedWorkspace, "sharedWorkspace" },
        { &sel_deliverResult, "deliverResult" },
        { &sel_aspectRatio, "aspectRatio" },
        { &sel_keyEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1characters_1charactersIgnoringModifiers_1isARepeat_1keyCode_1, "keyEventWithType:location:modifierFlags:timestamp:windowNumber:context:characters:charactersIgnoringModifiers:isARepeat:keyCode:" },
        { &sel_soundUnfilteredPasteboardTypes, "soundUnfilteredPasteboardTypes" },
        { &sel_dateByAddingComponents_1toDate_1options_1, "dateByAddingComponents:toDate:options:" },
        { &sel_indentationMarkerFollowsCell, "indentationMarkerFollowsCell" },
        { &sel_typesetter, "typesetter" },
        { &sel_childCount, "childCount" },
        { &sel_borderRect, "borderRect" },
        { &sel_setPageOrder_1, "setPageOrder:" },
        { &sel_currentThread, "currentThread" },
        { &sel_textViewDidChangeSelection_1, "textViewDidChangeSelection:" },
        { &sel_setBaseWritingDirection_1, "setBaseWritingDirection:" },
        { &sel_attributedSubStringForProposedRange_1actualRange_1, "attributedSubStringForProposedRange:actualRange:" },
        { &sel_pop, "pop" },
        { &sel_animator, "animator" },
        { &sel_allowsEmptySelection, "allowsEmptySelection" },
        { &sel_scriptingIsGreaterThanOrEqualTo_1, "scriptingIsGreaterThanOrEqualTo:" },
        { &sel_numberOfSelectedRows, "numberOfSelectedRows" },
        { &sel_imageDidNotDraw_1inRect_1, "imageDidNotDraw:inRect:" },
        { &sel_topLevelObject, "topLevelObject" },
        { &sel_openDocumentWithContentsOfURL_1display_1, "openDocumentWithContentsOfURL:display:" },
        { &sel_valueListAttributes, "valueListAttributes" },
        { &sel_enableFreedObjectCheck_1, "enableFreedObjectCheck:" },
        { &sel_moveForward_1, "moveForward:" },
        { &sel_setSendsActionOnArrowKeys_1, "setSendsActionOnArrowKeys:" },
        { &sel_versionForClassName_1, "versionForClassName:" },
        { &sel_coerceValue_1forKey_1, "coerceValue:forKey:" },
        { &sel_operatingSystem, "operatingSystem" },
        { &sel_characterEncoding, "characterEncoding" },
        { &sel_blendedColorWithFraction_1ofColor_1, "blendedColorWithFraction:ofColor:" },
        { &sel_panel_1userEnteredFilename_1confirmed_1, "panel:userEnteredFilename:confirmed:" },
        { &sel_addSelectedObjects_1, "addSelectedObjects:" },
        { &sel_pointingDeviceID, "pointingDeviceID" },
        { &sel_children, "children" },
        { &sel_takeObjectValueFrom_1, "takeObjectValueFrom:" },
        { &sel_indexSet, "indexSet" },
        { &sel_setMovie_1, "setMovie:" },
        { &sel_setKeyEquivalentModifierMask_1, "setKeyEquivalentModifierMask:" },
        { &sel_allowsKeyedCoding, "allowsKeyedCoding" },
        { &sel_rotateByDegrees_1, "rotateByDegrees:" },
        { &sel_compoundTypes, "compoundTypes" },
        { &sel_setShortStandaloneWeekdaySymbols_1, "setShortStandaloneWeekdaySymbols:" },
        { &sel_removeWindowsItem_1, "removeWindowsItem:" },
        { &sel_stringArrayForKey_1, "stringArrayForKey:" },
        { &sel_outlineView_1typeSelectStringForTableColumn_1item_1, "outlineView:typeSelectStringForTableColumn:item:" },
        { &sel_initWithWindow_1, "initWithWindow:" },
        { &sel_accessibilityIsAttributeSettable_1, "accessibilityIsAttributeSettable:" },
        { &sel_rangeForUserCharacterAttributeChange, "rangeForUserCharacterAttributeChange" },
        { &sel_setCalendar_1, "setCalendar:" },
        { &sel_beginEditing, "beginEditing" },
        { &sel_enableUpdates, "enableUpdates" },
        { &sel_setPrefersAllColumnUserResizing_1, "setPrefersAllColumnUserResizing:" },
        { &sel_isTornOff, "isTornOff" },
        { &sel_checkSpellingOfString_1startingAt_1, "checkSpellingOfString:startingAt:" },
        { &sel_drawPackedGlyphs_1atPoint_1, "drawPackedGlyphs:atPoint:" },
        { &sel_graphicsContextWithAttributes_1, "graphicsContextWithAttributes:" },
        { &sel_textView_1completions_1forPartialWordRange_1indexOfSelectedItem_1, "textView:completions:forPartialWordRange:indexOfSelectedItem:" },
        { &sel_outlineView_1shouldExpandItem_1, "outlineView:shouldExpandItem:" },
        { &sel_isInFullScreenMode, "isInFullScreenMode" },
        { &sel_userKeyEquivalent, "userKeyEquivalent" },
        { &sel_menuBarHeight, "menuBarHeight" },
        { &sel_initWithSize_1depth_1separate_1alpha_1, "initWithSize:depth:separate:alpha:" },
        { &sel_criticalValue, "criticalValue" },
        { &sel_tableView_1didClickTableColumn_1, "tableView:didClickTableColumn:" },
        { &sel_addChildWindow_1ordered_1, "addChildWindow:ordered:" },
        { &sel_autoscroll_1, "autoscroll:" },
        { &sel_infoDictionary, "infoDictionary" },
        { &sel_printOperationWithSettings_1error_1, "printOperationWithSettings:error:" },
        { &sel_translateOriginToPoint_1, "translateOriginToPoint:" },
        { &sel_takeStoredValue_1forKey_1, "takeStoredValue:forKey:" },
        { &sel_mouseUp_1, "mouseUp:" },
        { &sel_setNotationName_1, "setNotationName:" },
        { &sel_setArgument_1atIndex_1, "setArgument:atIndex:" },
        { &sel_setSelectedAttributes_1isMultiple_1, "setSelectedAttributes:isMultiple:" },
        { &sel_dayOfCommonEra, "dayOfCommonEra" },
        { &sel_greenColor, "greenColor" },
        { &sel_initWithProtocolFamily_1socketType_1protocol_1address_1, "initWithProtocolFamily:socketType:protocol:address:" },
        { &sel_setAttachmentCell_1, "setAttachmentCell:" },
        { &sel_previousFailureCount, "previousFailureCount" },
        { &sel_currentOperation, "currentOperation" },
        { &sel_tokenField_1completionsForSubString_1indexOfToken_1indexOfSelectedItem_1, "tokenField:completionsForSubString:indexOfToken:indexOfSelectedItem:" },
        { &sel_positionOfGlyph_1struckOverGlyph_1metricsExist_1, "positionOfGlyph:struckOverGlyph:metricsExist:" },
        { &sel_setMarkedTextAttributes_1, "setMarkedTextAttributes:" },
        { &sel_validateToolbarItem_1, "validateToolbarItem:" },
        { &sel_startingColumn, "startingColumn" },
        { &sel_setSelectedRanges_1, "setSelectedRanges:" },
        { &sel_addItemWithTitle_1action_1keyEquivalent_1, "addItemWithTitle:action:keyEquivalent:" },
        { &sel_postNotificationName_1object_1, "postNotificationName:object:" },
        { &sel_replacementObjectForKeyedArchiver_1, "replacementObjectForKeyedArchiver:" },
        { &sel_deletesFileUponFailure, "deletesFileUponFailure" },
        { &sel_speechRecognizer_1didRecognizeCommand_1, "speechRecognizer:didRecognizeCommand:" },
        { &sel_columnSpan, "columnSpan" },
        { &sel_animationBlockingMode, "animationBlockingMode" },
        { &sel_drawParts, "drawParts" },
        { &sel_style, "style" },
        { &sel_makeUntitledDocumentOfType_1error_1, "makeUntitledDocumentOfType:error:" },
        { &sel_filteredArrayUsingPredicate_1, "filteredArrayUsingPredicate:" },
        { &sel_wantsDefaultClipping, "wantsDefaultClipping" },
        { &sel_one, "one" },
        { &sel_persistentStoreTypeForFileType_1, "persistentStoreTypeForFileType:" },
        { &sel_pixelsHigh, "pixelsHigh" },
        { &sel_rulerView_1shouldMoveMarker_1, "rulerView:shouldMoveMarker:" },
        { &sel_sizeWithAttributes_1, "sizeWithAttributes:" },
        { &sel_drawTitleOfColumn_1inRect_1, "drawTitleOfColumn:inRect:" },
        { &sel_setLevelsOfUndo_1, "setLevelsOfUndo:" },
        { &sel_invoke, "invoke" },
        { &sel_keyEnumerator, "keyEnumerator" },
        { &sel_convertFont_1toSize_1, "convertFont:toSize:" },
        { &sel_mouseExited_1withFrame_1inView_1, "mouseExited:withFrame:inView:" },
        { &sel_widthAdjustLimit, "widthAdjustLimit" },
        { &sel_animationResizeTime_1, "animationResizeTime:" },
        { &sel_ensureLayoutForBoundingRect_1inTextContainer_1, "ensureLayoutForBoundingRect:inTextContainer:" },
        { &sel_initWithExpressionType_1, "initWithExpressionType:" },
        { &sel_numberWithUnsignedChar_1, "numberWithUnsignedChar:" },
        { &sel_directory, "directory" },
        { &sel_address, "address" },
        { &sel_defaultPixelFormat, "defaultPixelFormat" },
        { &sel_deleteBackwardByDecomposingPreviousCharacter_1, "deleteBackwardByDecomposingPreviousCharacter:" },
        { &sel_clickCount, "clickCount" },
        { &sel_trackMarker_1withMouseEvent_1, "trackMarker:withMouseEvent:" },
        { &sel_URL_1resourceDataDidBecomeAvailable_1, "URL:resourceDataDidBecomeAvailable:" },
        { &sel_outlineView_1setObjectValue_1forTableColumn_1byItem_1, "outlineView:setObjectValue:forTableColumn:byItem:" },
        { &sel_insert_1, "insert:" },
        { &sel_methodForSelector_1, "methodForSelector:" },
        { &sel_insertGlyph_1atGlyphIndex_1characterIndex_1, "insertGlyph:atGlyphIndex:characterIndex:" },
        { &sel_readFromFileWrapper_1ofType_1error_1, "readFromFileWrapper:ofType:error:" },
        { &sel_selectedControlColor, "selectedControlColor" },
        { &sel_selectedRow, "selectedRow" },
        { &sel_control_1isValidObject_1, "control:isValidObject:" },
        { &sel_setUniqueID_1, "setUniqueID:" },
        { &sel_initWithName_1fromFile_1, "initWithName:fromFile:" },
        { &sel_sizeOfLabel_1, "sizeOfLabel:" },
        { &sel_credentialsForProtectionSpace_1, "credentialsForProtectionSpace:" },
        { &sel_anyObject, "anyObject" },
        { &sel_runLoopModesForAnimating, "runLoopModesForAnimating" },
        { &sel_setSortDescriptors_1, "setSortDescriptors:" },
        { &sel_convertSize_1toView_1, "convertSize:toView:" },
        { &sel_setLineFragmentRect_1forGlyphRange_1usedRect_1, "setLineFragmentRect:forGlyphRange:usedRect:" },
        { &sel_discardEditing, "discardEditing" },
        { &sel_isAutodisplay, "isAutodisplay" },
        { &sel_matchesOnMultipleResolution, "matchesOnMultipleResolution" },
        { &sel_multipleThreadsEnabled, "multipleThreadsEnabled" },
        { &sel_positionOfGlyph_1forCharacter_1struckOverRect_1, "positionOfGlyph:forCharacter:struckOverRect:" },
        { &sel_boundsRectForBlock_1contentRect_1inRect_1textContainer_1characterRange_1, "boundsRectForBlock:contentRect:inRect:textContainer:characterRange:" },
        { &sel_outlineView_1objectValueForTableColumn_1byItem_1, "outlineView:objectValueForTableColumn:byItem:" },
        { &sel_transformPoint_1, "transformPoint:" },
        { &sel_createClassDescription, "createClassDescription" },
        { &sel_inputStreamWithFileAtPath_1, "inputStreamWithFileAtPath:" },
        { &sel_menuForEvent_1inRect_1ofView_1, "menuForEvent:inRect:ofView:" },
        { &sel_setRowTypeKeyPath_1, "setRowTypeKeyPath:" },
        { &sel_infoForBinding_1, "infoForBinding:" },
        { &sel_setDataRetained_1, "setDataRetained:" },
        { &sel_revertToContentsOfURL_1ofType_1error_1, "revertToContentsOfURL:ofType:error:" },
        { &sel_currentControlTint, "currentControlTint" },
        { &sel_selection, "selection" },
        { &sel_array, "array" },
        { &sel_setStyle_1, "setStyle:" },
        { &sel_setPredicate_1, "setPredicate:" },
        { &sel_endEditing, "endEditing" },
        { &sel_doClick_1, "doClick:" },
        { &sel_toManyRelationshipKeys, "toManyRelationshipKeys" },
        { &sel_selectedKnobColor, "selectedKnobColor" },
        { &sel_setOrderedIndex_1, "setOrderedIndex:" },
        { &sel_initWithSet_1, "initWithSet:" },
        { &sel_drawSelector, "drawSelector" },
        { &sel_requestWithURL_1, "requestWithURL:" },
        { &sel_imageNamed_1, "imageNamed:" },
        { &sel_hyphenationFactorForGlyphAtIndex_1, "hyphenationFactorForGlyphAtIndex:" },
        { &sel_miniwindowTitle, "miniwindowTitle" },
        { &sel_isFileURL, "isFileURL" },
        { &sel_selectedSegment, "selectedSegment" },
        { &sel_applicationDidResignActive_1, "applicationDidResignActive:" },
        { &sel_initWithString_1calendarFormat_1, "initWithString:calendarFormat:" },
        { &sel_initWithProtectionSpace_1proposedCredential_1previousFailureCount_1failureResponse_1error_1sender_1, "initWithProtectionSpace:proposedCredential:previousFailureCount:failureResponse:error:sender:" },
        { &sel_menuHasKeyEquivalent_1forEvent_1target_1action_1, "menuHasKeyEquivalent:forEvent:target:action:" },
        { &sel_minPossiblePositionOfDividerAtIndex_1, "minPossiblePositionOfDividerAtIndex:" },
        { &sel_abbreviationForDate_1, "abbreviationForDate:" },
        { &sel_absoluteX, "absoluteX" },
        { &sel_scriptErrorNumber, "scriptErrorNumber" },
        { &sel_previousValidKeyView, "previousValidKeyView" },
        { &sel_valueWithRange_1, "valueWithRange:" },
        { &sel_initWithDefaults_1initialValues_1, "initWithDefaults:initialValues:" },
        { &sel_initNotTestWithTest_1, "initNotTestWithTest:" },
        { &sel_abortModal, "abortModal" },
        { &sel_isSuspended, "isSuspended" },
        { &sel_isFilePackageAtPath_1, "isFilePackageAtPath:" },
        { &sel_useCredential_1forAuthenticationChallenge_1, "useCredential:forAuthenticationChallenge:" },
        { &sel_draggingSequenceNumber, "draggingSequenceNumber" },
        { &sel_lastColumn, "lastColumn" },
        { &sel_distantFuture, "distantFuture" },
        { &sel_download_1didReceiveResponse_1, "download:didReceiveResponse:" },
        { &sel_textTransform, "textTransform" },
        { &sel_hasHorizontalScroller, "hasHorizontalScroller" },
        { &sel_shadowBlurRadius, "shadowBlurRadius" },
        { &sel_pointingDeviceType, "pointingDeviceType" },
        { &sel_setMenuView_1, "setMenuView:" },
        { &sel_setWindingRule_1, "setWindingRule:" },
        { &sel_imageForSegment_1, "imageForSegment:" },
        { &sel_bytes, "bytes" },
        { &sel_propertyListFromStringsFileFormat, "propertyListFromStringsFileFormat" },
        { &sel_setParagraphStyle_1, "setParagraphStyle:" },
        { &sel_highlightMode, "highlightMode" },
        { &sel_voice, "voice" },
        { &sel_hostName, "hostName" },
        { &sel_removeAccessoryController_1, "removeAccessoryController:" },
        { &sel_rowsInRect_1, "rowsInRect:" },
        { &sel_registerImageRepClass_1, "registerImageRepClass:" },
        { &sel_value_1withObjCType_1, "value:withObjCType:" },
        { &sel_enclosingMenuItem, "enclosingMenuItem" },
        { &sel_exposedBindings, "exposedBindings" },
        { &sel_setSharedScriptSuiteRegistry_1, "setSharedScriptSuiteRegistry:" },
        { &sel_readablePasteboardTypes, "readablePasteboardTypes" },
        { &sel_drawViewBackgroundInRect_1, "drawViewBackgroundInRect:" },
        { &sel_setDataCell_1, "setDataCell:" },
        { &sel_dataRepresentationOfType_1, "dataRepresentationOfType:" },
        { &sel_setOrientation_1, "setOrientation:" },
        { &sel_setFileWrapper_1, "setFileWrapper:" },
        { &sel_runModalOpenPanel_1forTypes_1, "runModalOpenPanel:forTypes:" },
        { &sel_adjustSubviews, "adjustSubviews" },
        { &sel_setCurrencyDecimalSeparator_1, "setCurrencyDecimalSeparator:" },
        { &sel_needsDisplay, "needsDisplay" },
        { &sel_insertValue_1atIndex_1inPropertyWithKey_1, "insertValue:atIndex:inPropertyWithKey:" },
        { &sel_setTextStorage_1, "setTextStorage:" },
        { &sel_isAlternate, "isAlternate" },
        { &sel_setOutputFormat_1, "setOutputFormat:" },
        { &sel_comboBoxWillPopUp_1, "comboBoxWillPopUp:" },
        { &sel_insertChild_1, "insertChild:" },
        { &sel_initWithCommandDescription_1, "initWithCommandDescription:" },
        { &sel_setLineDash_1count_1phase_1, "setLineDash:count:phase:" },
        { &sel_setHardInvalidation_1forGlyphRange_1, "setHardInvalidation:forGlyphRange:" },
        { &sel_setAllowsToolTipsWhenApplicationIsInactive_1, "setAllowsToolTipsWhenApplicationIsInactive:" },
        { &sel_tableView_1namesOfPromisedFilesDroppedAtDestination_1forDraggedRowsWithIndexes_1, "tableView:namesOfPromisedFilesDroppedAtDestination:forDraggedRowsWithIndexes:" },
        { &sel_highlightedItemIndex, "highlightedItemIndex" },
        { &sel_trailingOffset, "trailingOffset" },
        { &sel_layer, "layer" },
        { &sel_isDeletableFileAtPath_1, "isDeletableFileAtPath:" },
        { &sel_textUnfilteredTypes, "textUnfilteredTypes" },
        { &sel_gregorianStartDate, "gregorianStartDate" },
        { &sel_isDocumentEdited, "isDocumentEdited" },
        { &sel_colorWithCalibratedWhite_1alpha_1, "colorWithCalibratedWhite:alpha:" },
        { &sel_shouldRunSavePanelWithAccessoryView, "shouldRunSavePanelWithAccessoryView" },
        { &sel_finishEncoding, "finishEncoding" },
        { &sel_setKeyCell_1, "setKeyCell:" },
        { &sel_isPartialStringValid_1newEditingString_1errorDescription_1, "isPartialStringValid:newEditingString:errorDescription:" },
        { &sel_setRangeContainerObject_1, "setRangeContainerObject:" },
        { &sel_typeOfFile_1error_1, "typeOfFile:error:" },
        { &sel_disappearingItemCursor, "disappearingItemCursor" },
        { &sel_textureMaxMipMapLevel, "textureMaxMipMapLevel" },
        { &sel_setEraSymbols_1, "setEraSymbols:" },
        { &sel_setBordered_1, "setBordered:" },
        { &sel_precomposedStringWithCanonicalMapping, "precomposedStringWithCanonicalMapping" },
        { &sel_setEnabled_1, "setEnabled:" },
        { &sel_setChildrenKeyPath_1, "setChildrenKeyPath:" },
        { &sel_applicationDidBecomeActive_1, "applicationDidBecomeActive:" },
        { &sel_setCancelButtonCell_1, "setCancelButtonCell:" },
        { &sel_backgroundFilters, "backgroundFilters" },
        { &sel_indexOfCellWithTag_1, "indexOfCellWithTag:" },
        { &sel_UTF8String, "UTF8String" },
        { &sel_horizontalPagination, "horizontalPagination" },
        { &sel_allowedInputSourceLocales, "allowedInputSourceLocales" },
        { &sel_toolbar, "toolbar" },
        { &sel_setGeneratesDecimalNumbers_1, "setGeneratesDecimalNumbers:" },
        { &sel_highlight_1withFrame_1inView_1, "highlight:withFrame:inView:" },
        { &sel_rotation, "rotation" },
        { &sel_colorForControlTint_1, "colorForControlTint:" },
        { &sel_mutableString, "mutableString" },
        { &sel_shadowWithLevel_1, "shadowWithLevel:" },
        { &sel_frameRectForContentRect_1styleMask_1, "frameRectForContentRect:styleMask:" },
        { &sel_numberOfColorComponents, "numberOfColorComponents" },
        { &sel_alternateImage, "alternateImage" },
        { &sel_initWithString_1relativeToURL_1, "initWithString:relativeToURL:" },
        { &sel_pageOrder, "pageOrder" },
        { &sel_cancel_1, "cancel:" },
        { &sel_declareTypes_1owner_1, "declareTypes:owner:" },
        { &sel_lastObject, "lastObject" },
        { &sel_type_1conformsToType_1, "type:conformsToType:" },
        { &sel_mutableArrayValueForKey_1, "mutableArrayValueForKey:" },
        { &sel_initWithName_1host_1, "initWithName:host:" },
        { &sel_keyEquivalentWidth, "keyEquivalentWidth" },
        { &sel_modifier, "modifier" },
        { &sel_setPerMillSymbol_1, "setPerMillSymbol:" },
        { &sel_setToolbar_1, "setToolbar:" },
        { &sel_changeAttributes_1, "changeAttributes:" },
        { &sel_removeItemWithTitle_1, "removeItemWithTitle:" },
        { &sel_setAspectRatio_1, "setAspectRatio:" },
        { &sel_undoManagerForTextView_1, "undoManagerForTextView:" },
        { &sel_clickedPathComponentCell, "clickedPathComponentCell" },
        { &sel_commentWithStringValue_1, "commentWithStringValue:" },
        { &sel_initWithContainerSpecifier_1key_1, "initWithContainerSpecifier:key:" },
        { &sel_windowWillReturnUndoManager_1, "windowWillReturnUndoManager:" },
        { &sel_imageAndTitleOffset, "imageAndTitleOffset" },
        { &sel_initialize, "initialize" },
        { &sel_truncatesLastVisibleLine, "truncatesLastVisibleLine" },
        { &sel_setExponentSymbol_1, "setExponentSymbol:" },
        { &sel_setCurrentProgress_1, "setCurrentProgress:" },
        { &sel_initWithContentsOfFile_1options_1error_1, "initWithContentsOfFile:options:error:" },
        { &sel_titleCell, "titleCell" },
        { &sel_setCurrencySymbol_1, "setCurrencySymbol:" },
        { &sel_usesScreenFonts, "usesScreenFonts" },
        { &sel_propertyList, "propertyList" },
        { &sel_subgroups, "subgroups" },
        { &sel_setFloatValue_1knobProportion_1, "setFloatValue:knobProportion:" },
        { &sel_componentsJoinedByString_1, "componentsJoinedByString:" },
        { &sel_initWithICCProfileData_1, "initWithICCProfileData:" },
        { &sel_setNextKeyView_1, "setNextKeyView:" },
        { &sel_setAnimationCurve_1, "setAnimationCurve:" },
        { &sel_tokenFieldCell_1completionsForSubString_1indexOfToken_1indexOfSelectedItem_1, "tokenFieldCell:completionsForSubString:indexOfToken:indexOfSelectedItem:" },
        { &sel_takeValuesFromDictionary_1, "takeValuesFromDictionary:" },
        { &sel_imageRepClassForPasteboardType_1, "imageRepClassForPasteboardType:" },
        { &sel_setPlaybackDeviceIdentifier_1, "setPlaybackDeviceIdentifier:" },
        { &sel_globallyUniqueString, "globallyUniqueString" },
        { &sel_setLineWidth_1, "setLineWidth:" },
        { &sel_selectedColumnIndexes, "selectedColumnIndexes" },
        { &sel_addWindowsItem_1title_1filename_1, "addWindowsItem:title:filename:" },
        { &sel_truncateFileAtOffset_1, "truncateFileAtOffset:" },
        { &sel_setStandardOutput_1, "setStandardOutput:" },
        { &sel_encodeInt32_1forKey_1, "encodeInt32:forKey:" },
        { &sel_baselineDeltaForCharacterAtIndex_1, "baselineDeltaForCharacterAtIndex:" },
        { &sel_setValueWraps_1, "setValueWraps:" },
        { &sel_addOperation_1, "addOperation:" },
        { &sel_resignKeyWindow, "resignKeyWindow" },
        { &sel_insertNewline_1, "insertNewline:" },
        { &sel_saveFrameUsingName_1, "saveFrameUsingName:" },
        { &sel_setWithObjects_1, "setWithObjects:" },
        { &sel_indexOfItemWithTarget_1andAction_1, "indexOfItemWithTarget:andAction:" },
        { &sel_processEditing, "processEditing" },
        { &sel_removeValueAtIndex_1fromPropertyWithKey_1, "removeValueAtIndex:fromPropertyWithKey:" },
        { &sel_setShouldCascadeWindows_1, "setShouldCascadeWindows:" },
        { &sel_stepBack_1, "stepBack:" },
        { &sel_lockWhenCondition_1beforeDate_1, "lockWhenCondition:beforeDate:" },
        { &sel_realm, "realm" },
        { &sel_appendBezierPathWithPackedGlyphs_1, "appendBezierPathWithPackedGlyphs:" },
        { &sel_inputStreamWithData_1, "inputStreamWithData:" },
        { &sel_clickedRow, "clickedRow" },
        { &sel_animationShouldStart_1, "animationShouldStart:" },
        { &sel_appleEventCodeForKey_1, "appleEventCodeForKey:" },
        { &sel_sendAction_1to_1forAllCells_1, "sendAction:to:forAllCells:" },
        { &sel_writableTypesForSaveOperation_1, "writableTypesForSaveOperation:" },
        { &sel_drawWellInside_1, "drawWellInside:" },
        { &sel_intersectsSet_1, "intersectsSet:" },
        { &sel_runOperationModalForWindow_1delegate_1didRunSelector_1contextInfo_1, "runOperationModalForWindow:delegate:didRunSelector:contextInfo:" },
        { &sel_setAllowsEmptySelection_1, "setAllowsEmptySelection:" },
        { &sel_tighteningFactorForTruncation, "tighteningFactorForTruncation" },
        { &sel_insertDescriptor_1atIndex_1, "insertDescriptor:atIndex:" },
        { &sel_setDefaultBehavior_1, "setDefaultBehavior:" },
        { &sel_allowsFloats, "allowsFloats" },
        { &sel_representedObject, "representedObject" },
        { &sel_isFlipped, "isFlipped" },
        { &sel_rectOfColumn_1, "rectOfColumn:" },
        { &sel_setFrame_1display_1, "setFrame:display:" },
        { &sel_setTextAttributesForPositiveInfinity_1, "setTextAttributesForPositiveInfinity:" },
        { &sel_textUnfilteredFileTypes, "textUnfilteredFileTypes" },
        { &sel_bezierPathByFlatteningPath, "bezierPathByFlatteningPath" },
        { &sel_week, "week" },
        { &sel_takeIntValueFrom_1, "takeIntValueFrom:" },
        { &sel_setWantsNotificationForMarkedText_1, "setWantsNotificationForMarkedText:" },
        { &sel_stringByPaddingToLength_1withString_1startingAtIndex_1, "stringByPaddingToLength:withString:startingAtIndex:" },
        { &sel_stopModal, "stopModal" },
        { &sel_veryShortWeekdaySymbols, "veryShortWeekdaySymbols" },
        { &sel_user, "user" },
        { &sel_animation_1didReachProgressMark_1, "animation:didReachProgressMark:" },
        { &sel_fontWithName_1size_1, "fontWithName:size:" },
        { &sel_selectWord_1, "selectWord:" },
        { &sel_initWithDuration_1animationCurve_1, "initWithDuration:animationCurve:" },
        { &sel_afmDictionary, "afmDictionary" },
        { &sel_canChooseFiles, "canChooseFiles" },
        { &sel_defaultLineWidth, "defaultLineWidth" },
        { &sel_childAtIndex_1, "childAtIndex:" },
        { &sel_pathForResource_1ofType_1inDirectory_1, "pathForResource:ofType:inDirectory:" },
        { &sel_outlineView_1heightOfRowByItem_1, "outlineView:heightOfRowByItem:" },
        { &sel_PMSymbol, "PMSymbol" },
        { &sel_setBackgroundStyle_1, "setBackgroundStyle:" },
        { &sel_decimalSeparator, "decimalSeparator" },
        { &sel_knobThickness, "knobThickness" },
        { &sel_request, "request" },
        { &sel_indicesOfObjectsByEvaluatingWithContainer_1count_1, "indicesOfObjectsByEvaluatingWithContainer:count:" },
        { &sel_objectByApplyingXSLTString_1arguments_1error_1, "objectByApplyingXSLTString:arguments:error:" },
        { &sel_colorizeByMappingGray_1toColor_1blackMapping_1whiteMapping_1, "colorizeByMappingGray:toColor:blackMapping:whiteMapping:" },
        { &sel_minusSet_1, "minusSet:" },
        { &sel_setAutomaticallyRearrangesObjects_1, "setAutomaticallyRearrangesObjects:" },
        { &sel_fixFontAttributeInRange_1, "fixFontAttributeInRange:" },
        { &sel_frameRotation, "frameRotation" },
        { &sel_addObserver_1forKeyPath_1options_1context_1, "addObserver:forKeyPath:options:context:" },
        { &sel_collectionNames, "collectionNames" },
        { &sel_titleOfColumn_1, "titleOfColumn:" },
        { &sel_characterIdentifier, "characterIdentifier" },
        { &sel_setPanelFont_1isMultiple_1, "setPanelFont:isMultiple:" },
        { &sel_ruleThickness, "ruleThickness" },
        { &sel_customSelector, "customSelector" },
        { &sel_startSpeakingString_1toURL_1, "startSpeakingString:toURL:" },
        { &sel_language, "language" },
        { &sel_draggedImage_1endedAt_1operation_1, "draggedImage:endedAt:operation:" },
        { &sel_removeSelectionIndexPaths_1, "removeSelectionIndexPaths:" },
        { &sel_TIFFRepresentationOfImageRepsInArray_1, "TIFFRepresentationOfImageRepsInArray:" },
        { &sel_setSet_1, "setSet:" },
        { &sel_stringWithCString_1length_1, "stringWithCString:length:" },
        { &sel_objectsByEvaluatingSpecifier, "objectsByEvaluatingSpecifier" },
        { &sel_subarrayWithRange_1, "subarrayWithRange:" },
        { &sel_collectIfNeeded, "collectIfNeeded" },
        { &sel_pathWithComponents_1, "pathWithComponents:" },
        { &sel_autoreleasedObjectCount, "autoreleasedObjectCount" },
        { &sel_addCharactersInString_1, "addCharactersInString:" },
        { &sel_setTemplate_1, "setTemplate:" },
        { &sel_indexOfObjectIdenticalTo_1, "indexOfObjectIdenticalTo:" },
        { &sel_setRepresentation, "setRepresentation" },
        { &sel_URLResourceDidFinishLoading_1, "URLResourceDidFinishLoading:" },
        { &sel_type, "type" },
        { &sel_setMarkedText_1selectedRange_1, "setMarkedText:selectedRange:" },
        { &sel_dictionaryWithObjects_1forKeys_1, "dictionaryWithObjects:forKeys:" },
        { &sel_wantsToDelayTextChangeNotifications, "wantsToDelayTextChangeNotifications" },
        { &sel_setCompletes_1, "setCompletes:" },
        { &sel_releaseGState, "releaseGState" },
        { &sel_descriptorWithEnumCode_1, "descriptorWithEnumCode:" },
        { &sel_label, "label" },
        { &sel_run, "run" },
        { &sel_hasHorizontalRuler, "hasHorizontalRuler" },
        { &sel_rowClass, "rowClass" },
        { &sel_automaticRearrangementKeyPaths, "automaticRearrangementKeyPaths" },
        { &sel_fileManager_1shouldProceedAfterError_1movingItemAtPath_1toPath_1, "fileManager:shouldProceedAfterError:movingItemAtPath:toPath:" },
        { &sel_writeToURL_1atomically_1encoding_1error_1, "writeToURL:atomically:encoding:error:" },
        { &sel_deviceID, "deviceID" },
        { &sel_descriptorWithInt32_1, "descriptorWithInt32:" },
        { &sel_encodeInt64_1forKey_1, "encodeInt64:forKey:" },
        { &sel_insertEntry_1atIndex_1, "insertEntry:atIndex:" },
        { &sel_leftMargin, "leftMargin" },
        { &sel_setKeyEquivalentFont_1size_1, "setKeyEquivalentFont:size:" },
        { &sel_colorWithDeviceHue_1saturation_1brightness_1alpha_1, "colorWithDeviceHue:saturation:brightness:alpha:" },
        { &sel_nextState, "nextState" },
        { &sel_scanHexInt_1, "scanHexInt:" },
        { &sel_lineSpacing, "lineSpacing" },
        { &sel_textureTarget, "textureTarget" },
        { &sel_miniaturize_1, "miniaturize:" },
        { &sel_browser_1namesOfPromisedFilesDroppedAtDestination_1forDraggedRowsWithIndexes_1inColumn_1, "browser:namesOfPromisedFilesDroppedAtDestination:forDraggedRowsWithIndexes:inColumn:" },
        { &sel_localizedNameForTIFFCompressionType_1, "localizedNameForTIFFCompressionType:" },
        { &sel_acceptConnectionInBackgroundAndNotifyForModes_1, "acceptConnectionInBackgroundAndNotifyForModes:" },
        { &sel_setCanBecomeVisibleWithoutLogin_1, "setCanBecomeVisibleWithoutLogin:" },
        { &sel_dictionaryWithObjectsAndKeys_1, "dictionaryWithObjectsAndKeys:" },
        { &sel_ensureGlyphsForGlyphRange_1, "ensureGlyphsForGlyphRange:" },
        { &sel_indexOfTickMarkAtPoint_1, "indexOfTickMarkAtPoint:" },
        { &sel_dayOfWeek, "dayOfWeek" },
        { &sel_glyphRangeForCharacterRange_1actualCharacterRange_1, "glyphRangeForCharacterRange:actualCharacterRange:" },
        { &sel_enableCollectorForPointer_1, "enableCollectorForPointer:" },
        { &sel_rulerView_1willMoveMarker_1toLocation_1, "rulerView:willMoveMarker:toLocation:" },
        { &sel_comboBoxCell_1objectValueForItemAtIndex_1, "comboBoxCell:objectValueForItemAtIndex:" },
        { &sel_setValidateSize_1, "setValidateSize:" },
        { &sel_controlTint, "controlTint" },
        { &sel_deselectItemAtIndex_1, "deselectItemAtIndex:" },
        { &sel_defaultWindingRule, "defaultWindingRule" },
        { &sel_setMaxValue_1, "setMaxValue:" },
        { &sel_longEraSymbols, "longEraSymbols" },
        { &sel_canRedo, "canRedo" },
        { &sel_arguments, "arguments" },
        { &sel_windows, "windows" },
        { &sel_downloadDidBegin_1, "downloadDidBegin:" },
        { &sel_pasteboard_1provideDataForType_1, "pasteboard:provideDataForType:" },
        { &sel_length, "length" },
        { &sel_imagePosition, "imagePosition" },
        { &sel_setAllowedFileTypes_1, "setAllowedFileTypes:" },
        { &sel_moveForwardAndModifySelection_1, "moveForwardAndModifySelection:" },
        { &sel_filename, "filename" },
        { &sel_mountedLocalVolumePaths, "mountedLocalVolumePaths" },
        { &sel_sharedFontManager, "sharedFontManager" },
        { &sel_dictionaryWithObjects_1forKeys_1count_1, "dictionaryWithObjects:forKeys:count:" },
        { &sel_transpose_1, "transpose:" },
        { &sel_drawTitleWithFrame_1inView_1, "drawTitleWithFrame:inView:" },
        { &sel_worksWhenModal, "worksWhenModal" },
        { &sel_registerClassDescription_1, "registerClassDescription:" },
        { &sel_setAllowsTruncatedLabels_1, "setAllowsTruncatedLabels:" },
        { &sel_bezierPathWithRoundedRect_1xRadius_1yRadius_1, "bezierPathWithRoundedRect:xRadius:yRadius:" },
        { &sel_prefix, "prefix" },
        { &sel_usesStrongWriteBarrier, "usesStrongWriteBarrier" },
        { &sel_argumentNames, "argumentNames" },
        { &sel_setCaseSensitive_1, "setCaseSensitive:" },
        { &sel_outlineView_1didClickTableColumn_1, "outlineView:didClickTableColumn:" },
        { &sel_textDidBeginEditing_1, "textDidBeginEditing:" },
        { &sel_visibleRect, "visibleRect" },
        { &sel_isSubviewCollapsed_1, "isSubviewCollapsed:" },
        { &sel_completionsForPartialWordRange_1indexOfSelectedItem_1, "completionsForPartialWordRange:indexOfSelectedItem:" },
        { &sel_setMinDate_1, "setMinDate:" },
        { &sel_colorFromPasteboard_1, "colorFromPasteboard:" },
        { &sel_instanceMethodSignatureForSelector_1, "instanceMethodSignatureForSelector:" },
        { &sel_makeCellAtRow_1column_1, "makeCellAtRow:column:" },
        { &sel_pasteAsPlainText_1, "pasteAsPlainText:" },
        { &sel_willRemoveSubview_1, "willRemoveSubview:" },
        { &sel_beginSheet_1modalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1, "beginSheet:modalForWindow:modalDelegate:didEndSelector:contextInfo:" },
        { &sel_notificationCenterForType_1, "notificationCenterForType:" },
        { &sel_isDaylightSavingTimeForDate_1, "isDaylightSavingTimeForDate:" },
        { &sel_load, "load" },
        { &sel_menuForSegment_1, "menuForSegment:" },
        { &sel_scheduledTimerWithTimeInterval_1invocation_1repeats_1, "scheduledTimerWithTimeInterval:invocation:repeats:" },
        { &sel_unregisterClass_1, "unregisterClass:" },
        { &sel_setByAddingObjectsFromSet_1, "setByAddingObjectsFromSet:" },
        { &sel_setDepthLimit_1, "setDepthLimit:" },
        { &sel_setVeryShortMonthSymbols_1, "setVeryShortMonthSymbols:" },
        { &sel_writeToURL_1ofType_1forSaveOperation_1originalContentsURL_1error_1, "writeToURL:ofType:forSaveOperation:originalContentsURL:error:" },
        { &sel_directoryAttributes, "directoryAttributes" },
        { &sel_otherMouseDown_1, "otherMouseDown:" },
        { &sel_unhideWithoutActivation, "unhideWithoutActivation" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1startSpecifier_1endSpecifier_1, "initWithContainerClassDescription:containerSpecifier:key:startSpecifier:endSpecifier:" },
        { &sel_setHasHorizontalScroller_1, "setHasHorizontalScroller:" },
        { &sel_trackMouse_1adding_1, "trackMouse:adding:" },
        { &sel_substituteGlyphsInRange_1withGlyphs_1, "substituteGlyphsInRange:withGlyphs:" },
        { &sel_drawCell_1, "drawCell:" },
        { &sel_currentCursor, "currentCursor" },
        { &sel_maxSize, "maxSize" },
        { &sel_cookiesWithResponseHeaderFields_1forURL_1, "cookiesWithResponseHeaderFields:forURL:" },
        { &sel_isBycopy, "isBycopy" },
        { &sel_addCursorRect_1cursor_1, "addCursorRect:cursor:" },
        { &sel_accessibilityActionNames, "accessibilityActionNames" },
        { &sel_openDocumentWithContentsOfURL_1display_1error_1, "openDocumentWithContentsOfURL:display:error:" },
        { &sel_templateViews, "templateViews" },
        { &sel_keyPath, "keyPath" },
        { &sel_minValue, "minValue" },
        { &sel_setImageDimsWhenDisabled_1, "setImageDimsWhenDisabled:" },
        { &sel_appendData_1, "appendData:" },
        { &sel_netServiceBrowser_1didFindDomain_1moreComing_1, "netServiceBrowser:didFindDomain:moreComing:" },
        { &sel_initWithDescriptorType_1bytes_1length_1, "initWithDescriptorType:bytes:length:" },
        { &sel_hasReadablePropertyForKey_1, "hasReadablePropertyForKey:" },
        { &sel_stopWhenAnimation_1reachesProgress_1, "stopWhenAnimation:reachesProgress:" },
        { &sel_setWorksWhenModal_1, "setWorksWhenModal:" },
        { &sel_localizedInputManagerName, "localizedInputManagerName" },
        { &sel_knobColor, "knobColor" },
        { &sel_screens, "screens" },
        { &sel_deminiaturize_1, "deminiaturize:" },
        { &sel_bundleIdentifier, "bundleIdentifier" },
        { &sel_setLoopMode_1, "setLoopMode:" },
        { &sel_expandItem_1expandChildren_1, "expandItem:expandChildren:" },
        { &sel_dataWithContentsOfFile_1options_1error_1, "dataWithContentsOfFile:options:error:" },
        { &sel_lineBreakBeforeIndex_1withinRange_1, "lineBreakBeforeIndex:withinRange:" },
        { &sel_fileOwnerAccountName, "fileOwnerAccountName" },
        { &sel_insertColumn_1withCells_1, "insertColumn:withCells:" },
        { &sel_windowLevel, "windowLevel" },
        { &sel_setGrammarCheckingEnabled_1, "setGrammarCheckingEnabled:" },
        { &sel_shortStandaloneWeekdaySymbols, "shortStandaloneWeekdaySymbols" },
        { &sel_push, "push" },
        { &sel_initWithContentsOfFile_1ofType_1, "initWithContentsOfFile:ofType:" },
        { &sel_removePortForName_1, "removePortForName:" },
        { &sel_setMaximumRecents_1, "setMaximumRecents:" },
        { &sel_supermenu, "supermenu" },
        { &sel_setWidth_1type_1forLayer_1edge_1, "setWidth:type:forLayer:edge:" },
        { &sel_itemRemoved_1, "itemRemoved:" },
        { &sel_initWithBytesNoCopy_1length_1, "initWithBytesNoCopy:length:" },
        { &sel_printer, "printer" },
        { &sel_compact, "compact" },
        { &sel_setDefaultLineWidth_1, "setDefaultLineWidth:" },
        { &sel_CGLPixelFormatObj, "CGLPixelFormatObj" },
        { &sel_initWithDictionary_1copyItems_1, "initWithDictionary:copyItems:" },
        { &sel_tableView_1didDragTableColumn_1, "tableView:didDragTableColumn:" },
        { &sel_formattingStringsFilename, "formattingStringsFilename" },
        { &sel_setScrollView_1, "setScrollView:" },
        { &sel_value, "value" },
        { &sel_editedMask, "editedMask" },
        { &sel_ruleEditor_1displayValueForCriterion_1inRow_1, "ruleEditor:displayValueForCriterion:inRow:" },
        { &sel_leading, "leading" },
        { &sel_titleRect, "titleRect" },
        { &sel_setColumnsAutosaveName_1, "setColumnsAutosaveName:" },
        { &sel_stop_1, "stop:" },
        { &sel_titleColor, "titleColor" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1test_1, "initWithContainerClassDescription:containerSpecifier:key:test:" },
        { &sel_bytesPerPlane, "bytesPerPlane" },
        { &sel_pageScroll, "pageScroll" },
        { &sel_groupingAttributes, "groupingAttributes" },
        { &sel_setAutomaticLinkDetectionEnabled_1, "setAutomaticLinkDetectionEnabled:" },
        { &sel_tableView_1mouseDownInHeaderOfTableColumn_1, "tableView:mouseDownInHeaderOfTableColumn:" },
        { &sel_representationOfImageRepsInArray_1usingType_1properties_1, "representationOfImageRepsInArray:usingType:properties:" },
        { &sel_attributeRuns, "attributeRuns" },
        { &sel_decodeRect, "decodeRect" },
        { &sel_drawerDidOpen_1, "drawerDidOpen:" },
        { &sel_scrollerWidth, "scrollerWidth" },
        { &sel_defaultMenu, "defaultMenu" },
        { &sel_URLProtocol_1didLoadData_1, "URLProtocol:didLoadData:" },
        { &sel_allKeys, "allKeys" },
        { &sel_startPeriodicEventsAfterDelay_1withPeriod_1, "startPeriodicEventsAfterDelay:withPeriod:" },
        { &sel_tableViewSelectionDidChange_1, "tableViewSelectionDidChange:" },
        { &sel_setStandalone_1, "setStandalone:" },
        { &sel_makeMainWindow, "makeMainWindow" },
        { &sel_moveLeftAndModifySelection_1, "moveLeftAndModifySelection:" },
        { &sel_pasteboardWithUniqueName, "pasteboardWithUniqueName" },
        { &sel_fileSystemFileNumber, "fileSystemFileNumber" },
        { &sel_jobDisposition, "jobDisposition" },
        { &sel_setCurrentVirtualScreen_1, "setCurrentVirtualScreen:" },
        { &sel_setHasThousandSeparators_1, "setHasThousandSeparators:" },
        { &sel_alternateMnemonicLocation, "alternateMnemonicLocation" },
        { &sel_characterSetWithBitmapRepresentation_1, "characterSetWithBitmapRepresentation:" },
        { &sel_startLoading, "startLoading" },
        { &sel_member_1, "member:" },
        { &sel_setSelectedFont_1isMultiple_1, "setSelectedFont:isMultiple:" },
        { &sel_monthOfYear, "monthOfYear" },
        { &sel_restoreCachedImage, "restoreCachedImage" },
        { &sel_image_1didLoadPartOfRepresentation_1withValidRows_1, "image:didLoadPartOfRepresentation:withValidRows:" },
        { &sel_mouseEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1eventNumber_1clickCount_1pressure_1, "mouseEventWithType:location:modifierFlags:timestamp:windowNumber:context:eventNumber:clickCount:pressure:" },
        { &sel_setInternationalCurrencySymbol_1, "setInternationalCurrencySymbol:" },
        { &sel_mainThread, "mainThread" },
        { &sel_lineCapStyle, "lineCapStyle" },
        { &sel_setDefaultParagraphStyle_1, "setDefaultParagraphStyle:" },
        { &sel_cellFrameForTextContainer_1proposedLineFragment_1glyphPosition_1characterIndex_1, "cellFrameForTextContainer:proposedLineFragment:glyphPosition:characterIndex:" },
        { &sel_resolveInstanceMethod_1, "resolveInstanceMethod:" },
        { &sel_illegalCharacterSet, "illegalCharacterSet" },
        { &sel_setKnobThickness_1, "setKnobThickness:" },
        { &sel_runModalPageLayoutWithPrintInfo_1, "runModalPageLayoutWithPrintInfo:" },
        { &sel_popUpContextMenu_1withEvent_1forView_1withFont_1, "popUpContextMenu:withEvent:forView:withFont:" },
        { &sel_modalWindow, "modalWindow" },
        { &sel_autorelease, "autorelease" },
        { &sel_draggingEntered_1, "draggingEntered:" },
        { &sel_allowsTruncatedLabels, "allowsTruncatedLabels" },
        { &sel_fileDescriptor, "fileDescriptor" },
        { &sel_ISOLanguageCodes, "ISOLanguageCodes" },
        { &sel_onStateImage, "onStateImage" },
        { &sel_imageFrameStyle, "imageFrameStyle" },
        { &sel_setFloatValue_1, "setFloatValue:" },
        { &sel_initWithColors_1atLocations_1colorSpace_1, "initWithColors:atLocations:colorSpace:" },
        { &sel_descriptorWithString_1, "descriptorWithString:" },
        { &sel_setPoolCountHighWaterMark_1, "setPoolCountHighWaterMark:" },
        { &sel_veryShortStandaloneWeekdaySymbols, "veryShortStandaloneWeekdaySymbols" },
        { &sel_addTypes_1owner_1, "addTypes:owner:" },
        { &sel_numberWithLongLong_1, "numberWithLongLong:" },
        { &sel_setDay_1, "setDay:" },
        { &sel_initWithHTML_1documentAttributes_1, "initWithHTML:documentAttributes:" },
        { &sel_replaceSubview_1with_1, "replaceSubview:with:" },
        { &sel_makeObjectsPerformSelector_1, "makeObjectsPerformSelector:" },
        { &sel_setRunLoopModes_1, "setRunLoopModes:" },
        { &sel_getFileSystemRepresentation_1maxLength_1, "getFileSystemRepresentation:maxLength:" },
        { &sel_scale, "scale" },
        { &sel_draggedImageLocation, "draggedImageLocation" },
        { &sel_setFocusStack_1, "setFocusStack:" },
        { &sel_isReadOnlyKey_1, "isReadOnlyKey:" },
        { &sel_shadowOffset, "shadowOffset" },
        { &sel_URLHandleUsingCache_1, "URLHandleUsingCache:" },
        { &sel_isWellFormed, "isWellFormed" },
        { &sel_tokenField_1editingStringForRepresentedObject_1, "tokenField:editingStringForRepresentedObject:" },
        { &sel_setGroupsByEvent_1, "setGroupsByEvent:" },
        { &sel_parser_1foundComment_1, "parser:foundComment:" },
        { &sel_initWithHTML_1baseURL_1documentAttributes_1, "initWithHTML:baseURL:documentAttributes:" },
        { &sel_uppercaseWord_1, "uppercaseWord:" },
        { &sel_testPart_1, "testPart:" },
        { &sel_dataSource, "dataSource" },
        { &sel_lineRangeForRange_1, "lineRangeForRange:" },
        { &sel_hostWithAddress_1, "hostWithAddress:" },
        { &sel_removeRunLoop_1, "removeRunLoop:" },
        { &sel_fileHandleWithStandardInput, "fileHandleWithStandardInput" },
        { &sel_itemArray, "itemArray" },
        { &sel_rectOfPathComponentCell_1withFrame_1inView_1, "rectOfPathComponentCell:withFrame:inView:" },
        { &sel_TIFFRepresentation, "TIFFRepresentation" },
        { &sel_archiver_1willReplaceObject_1withObject_1, "archiver:willReplaceObject:withObject:" },
        { &sel_currentVirtualScreen, "currentVirtualScreen" },
        { &sel_gridColor, "gridColor" },
        { &sel_boundingRectForGlyph_1, "boundingRectForGlyph:" },
        { &sel_setDataSource_1, "setDataSource:" },
        { &sel_setDefaultLineJoinStyle_1, "setDefaultLineJoinStyle:" },
        { &sel_textBlocks, "textBlocks" },
        { &sel_drawerDidClose_1, "drawerDidClose:" },
        { &sel_valueWithName_1inPropertyWithKey_1, "valueWithName:inPropertyWithKey:" },
        { &sel_managedObjectModel, "managedObjectModel" },
        { &sel_outlineView_1persistentObjectForItem_1, "outlineView:persistentObjectForItem:" },
        { &sel_setSelectedRange_1, "setSelectedRange:" },
        { &sel_magentaComponent, "magentaComponent" },
        { &sel_setIncrement_1, "setIncrement:" },
        { &sel_editingStringForObjectValue_1, "editingStringForObjectValue:" },
        { &sel_addClip, "addClip" },
        { &sel_setSelectionIndex_1, "setSelectionIndex:" },
        { &sel_replyAppleEventForSuspensionID_1, "replyAppleEventForSuspensionID:" },
        { &sel_URLProtocol_1didFailWithError_1, "URLProtocol:didFailWithError:" },
        { &sel_ignoresMouseEvents, "ignoresMouseEvents" },
        { &sel_dateWithNaturalLanguageString_1locale_1, "dateWithNaturalLanguageString:locale:" },
        { &sel_recordDescriptor, "recordDescriptor" },
        { &sel_makeCurrentContext, "makeCurrentContext" },
        { &sel_excludedKeys, "excludedKeys" },
        { &sel_fileManager_1shouldProceedAfterError_1linkingItemAtPath_1toPath_1, "fileManager:shouldProceedAfterError:linkingItemAtPath:toPath:" },
        { &sel_set, "set" },
        { &sel_mainScreen, "mainScreen" },
        { &sel_setVersion_1, "setVersion:" },
        { &sel_displayRectIgnoringOpacity_1inContext_1, "displayRectIgnoringOpacity:inContext:" },
        { &sel_setNumberOfTickMarks_1, "setNumberOfTickMarks:" },
        { &sel_showsHelp, "showsHelp" },
        { &sel_takeColorFrom_1, "takeColorFrom:" },
        { &sel_horizontalPageScroll, "horizontalPageScroll" },
        { &sel_pointingHandCursor, "pointingHandCursor" },
        { &sel_vendorID, "vendorID" },
        { &sel_setSelectedRanges_1affinity_1stillSelecting_1, "setSelectedRanges:affinity:stillSelecting:" },
        { &sel_setHTTPShouldHandleCookies_1, "setHTTPShouldHandleCookies:" },
        { &sel_initWithType_1location_1, "initWithType:location:" },
        { &sel_stringByResolvingSymlinksInPath, "stringByResolvingSymlinksInPath" },
        { &sel_tryLock, "tryLock" },
        { &sel_convertSizeFromBase_1, "convertSizeFromBase:" },
        { &sel_setCacheMode_1, "setCacheMode:" },
        { &sel_entityName, "entityName" },
        { &sel_takeFloatValueFrom_1, "takeFloatValueFrom:" },
        { &sel_showsStateBy, "showsStateBy" },
        { &sel_highlightedItem, "highlightedItem" },
        { &sel_superclassDescription, "superclassDescription" },
        { &sel_flagsChanged_1, "flagsChanged:" },
        { &sel_alloc, "alloc" },
        { &sel_setDisplaysWhenScreenProfileChanges_1, "setDisplaysWhenScreenProfileChanges:" },
        { &sel_CIImage, "CIImage" },
        { &sel_setSupermenu_1, "setSupermenu:" },
        { &sel_setSharedURLCache_1, "setSharedURLCache:" },
        { &sel_pathCell_1willPopUpMenu_1, "pathCell:willPopUpMenu:" },
        { &sel_setAttributes_1ofItemAtPath_1error_1, "setAttributes:ofItemAtPath:error:" },
        { &sel_tableView_1typeSelectStringForTableColumn_1row_1, "tableView:typeSelectStringForTableColumn:row:" },
        { &sel_moveWordLeftAndModifySelection_1, "moveWordLeftAndModifySelection:" },
        { &sel_whitespaceAndNewlineCharacterSet, "whitespaceAndNewlineCharacterSet" },
        { &sel_pathControl_1validateDrop_1, "pathControl:validateDrop:" },
        { &sel_createCommandInstanceWithZone_1, "createCommandInstanceWithZone:" },
        { &sel_configurationDictionary, "configurationDictionary" },
        { &sel_classFallbacksForKeyedArchiver, "classFallbacksForKeyedArchiver" },
        { &sel_DTDKind, "DTDKind" },
        { &sel_initWithPath_1documentAttributes_1, "initWithPath:documentAttributes:" },
        { &sel_addObjectsFromArray_1, "addObjectsFromArray:" },
        { &sel_tokenField_1displayStringForRepresentedObject_1, "tokenField:displayStringForRepresentedObject:" },
        { &sel_firstVisibleColumn, "firstVisibleColumn" },
        { &sel_gradientType, "gradientType" },
        { &sel_familyName, "familyName" },
        { &sel_uniqueID, "uniqueID" },
        { &sel_setFormatterBehavior_1, "setFormatterBehavior:" },
        { &sel_tokenFieldCell_1hasMenuForRepresentedObject_1, "tokenFieldCell:hasMenuForRepresentedObject:" },
        { &sel_fileManager_1shouldCopyItemAtPath_1toPath_1, "fileManager:shouldCopyItemAtPath:toPath:" },
        { &sel_keySpecifier, "keySpecifier" },
        { &sel_copyItemAtPath_1toPath_1error_1, "copyItemAtPath:toPath:error:" },
        { &sel_setLength_1, "setLength:" },
        { &sel_reloadItem_1, "reloadItem:" },
        { &sel_removeObjectsAtArrangedObjectIndexes_1, "removeObjectsAtArrangedObjectIndexes:" },
        { &sel_setVisibilityPriority_1, "setVisibilityPriority:" },
        { &sel_insertItemWithObjectValue_1atIndex_1, "insertItemWithObjectValue:atIndex:" },
        { &sel_searchButtonCell, "searchButtonCell" },
        { &sel_getCString_1maxLength_1range_1remainingRange_1, "getCString:maxLength:range:remainingRange:" },
        { &sel_outlineView_1child_1ofItem_1, "outlineView:child:ofItem:" },
        { &sel_numberOfComponents, "numberOfComponents" },
        { &sel_isKindOfClass_1, "isKindOfClass:" },
        { &sel_processorCount, "processorCount" },
        { &sel_lineJoinStyle, "lineJoinStyle" },
        { &sel_collectionBehavior, "collectionBehavior" },
        { &sel_setApplicationIconImage_1, "setApplicationIconImage:" },
        { &sel_setLaunchPath_1, "setLaunchPath:" },
        { &sel_initFileURLWithPath_1, "initFileURLWithPath:" },
        { &sel_selectItemAtIndex_1, "selectItemAtIndex:" },
        { &sel_IBeamCursor, "IBeamCursor" },
        { &sel_isColor, "isColor" },
        { &sel_cancelAuthenticationChallenge_1, "cancelAuthenticationChallenge:" },
        { &sel_echosBullets, "echosBullets" },
        { &sel_setHasUndoManager_1, "setHasUndoManager:" },
        { &sel_RTFDFileWrapperFromRange_1documentAttributes_1, "RTFDFileWrapperFromRange:documentAttributes:" },
        { &sel_highlightCell_1atRow_1column_1, "highlightCell:atRow:column:" },
        { &sel_currentHost, "currentHost" },
        { &sel_setURI_1, "setURI:" },
        { &sel_suiteNames, "suiteNames" },
        { &sel_genericGrayColorSpace, "genericGrayColorSpace" },
        { &sel_volatileDomainForName_1, "volatileDomainForName:" },
        { &sel_tokenizingCharacterSet, "tokenizingCharacterSet" },
        { &sel_initWithXMLString_1, "initWithXMLString:" },
        { &sel_function, "function" },
        { &sel_sizeForMagnification_1, "sizeForMagnification:" },
        { &sel_commitEditingWithDelegate_1didCommitSelector_1contextInfo_1, "commitEditingWithDelegate:didCommitSelector:contextInfo:" },
        { &sel_writeToFile_1, "writeToFile:" },
        { &sel_displayIfNeededInRect_1, "displayIfNeededInRect:" },
        { &sel_optionDescriptionsForBinding_1, "optionDescriptionsForBinding:" },
        { &sel_initWithSize_1, "initWithSize:" },
        { &sel_cornerView, "cornerView" },
        { &sel_redoActionName, "redoActionName" },
        { &sel_setLocation_1forStartOfGlyphRange_1, "setLocation:forStartOfGlyphRange:" },
        { &sel_setAllowedInputSourceLocales_1, "setAllowedInputSourceLocales:" },
        { &sel_convertRect_1toView_1, "convertRect:toView:" },
        { &sel_preferredFilenameExtensionForType_1, "preferredFilenameExtensionForType:" },
        { &sel_tableView_1writeRows_1toPasteboard_1, "tableView:writeRows:toPasteboard:" },
        { &sel_rootObject, "rootObject" },
        { &sel_isEqualToHashTable_1, "isEqualToHashTable:" },
        { &sel_indent_1, "indent:" },
        { &sel_removeIndexesInRange_1, "removeIndexesInRange:" },
        { &sel_numberWithBool_1, "numberWithBool:" },
        { &sel_setPersistentDomain_1forName_1, "setPersistentDomain:forName:" },
        { &sel_netServiceBrowser_1didRemoveService_1moreComing_1, "netServiceBrowser:didRemoveService:moreComing:" },
        { &sel_timeZoneWithName_1data_1, "timeZoneWithName:data:" },
        { &sel_drawImage_1withFrame_1inView_1, "drawImage:withFrame:inView:" },
        { &sel_buttonToolTip, "buttonToolTip" },
        { &sel_enableCursorRects, "enableCursorRects" },
        { &sel_rulerAttributesInRange_1, "rulerAttributesInRange:" },
        { &sel_setMemoryCapacity_1, "setMemoryCapacity:" },
        { &sel_isSeparatorItem, "isSeparatorItem" },
        { &sel_save_1, "save:" },
        { &sel_documentView, "documentView" },
        { &sel_setHostCacheEnabled_1, "setHostCacheEnabled:" },
        { &sel_setDatePickerElements_1, "setDatePickerElements:" },
        { &sel_mixedStateImage, "mixedStateImage" },
        { &sel_setAcceptsMouseMovedEvents_1, "setAcceptsMouseMovedEvents:" },
        { &sel_numberOfTabViewItems, "numberOfTabViewItems" },
        { &sel_portForName_1host_1nameServerPortNumber_1, "portForName:host:nameServerPortNumber:" },
        { &sel_printerWithName_1domain_1includeUnavailable_1, "printerWithName:domain:includeUnavailable:" },
        { &sel_insertObjects_1atArrangedObjectIndexPaths_1, "insertObjects:atArrangedObjectIndexPaths:" },
        { &sel_browser_1shouldTypeSelectForEvent_1withCurrentSearchString_1, "browser:shouldTypeSelectForEvent:withCurrentSearchString:" },
        { &sel_defaultTabInterval, "defaultTabInterval" },
        { &sel_initWithTitle_1, "initWithTitle:" },
        { &sel_timeZoneForSecondsFromGMT_1, "timeZoneForSecondsFromGMT:" },
        { &sel_initWithPasteboard_1, "initWithPasteboard:" },
        { &sel_subscriptRange_1, "subscriptRange:" },
        { &sel_highlightColorWithFrame_1inView_1, "highlightColorWithFrame:inView:" },
        { &sel_didChangeText, "didChangeText" },
        { &sel_storagePolicy, "storagePolicy" },
        { &sel_respondsToSelector_1, "respondsToSelector:" },
        { &sel_namesOfPromisedFilesDroppedAtDestination_1, "namesOfPromisedFilesDroppedAtDestination:" },
        { &sel_unsignedShortValue, "unsignedShortValue" },
        { &sel_setZeroSymbol_1, "setZeroSymbol:" },
        { &sel_resourcePath, "resourcePath" },
        { &sel_markerFormat, "markerFormat" },
        { &sel_hotSpot, "hotSpot" },
        { &sel_imageUnfilteredPasteboardTypes, "imageUnfilteredPasteboardTypes" },
        { &sel_editedRange, "editedRange" },
        { &sel_setMenuChangedMessagesEnabled_1, "setMenuChangedMessagesEnabled:" },
        { &sel_tailIndent, "tailIndent" },
        { &sel_release, "release" },
        { &sel_readFromURL_1options_1documentAttributes_1, "readFromURL:options:documentAttributes:" },
        { &sel_underlinePosition, "underlinePosition" },
        { &sel_setMinItemSize_1, "setMinItemSize:" },
        { &sel_initWithImage_1foregroundColorHint_1backgroundColorHint_1hotSpot_1, "initWithImage:foregroundColorHint:backgroundColorHint:hotSpot:" },
        { &sel_setPlaceholderString_1, "setPlaceholderString:" },
        { &sel_createDirectoryAtPath_1withIntermediateDirectories_1attributes_1error_1, "createDirectoryAtPath:withIntermediateDirectories:attributes:error:" },
        { &sel_setDefaultTabInterval_1, "setDefaultTabInterval:" },
        { &sel_invertedSet, "invertedSet" },
        { &sel_iconForFile_1, "iconForFile:" },
        { &sel_modifyFont_1, "modifyFont:" },
        { &sel_setProcessName_1, "setProcessName:" },
        { &sel_addObserver_1toObjectsAtIndexes_1forKeyPath_1options_1context_1, "addObserver:toObjectsAtIndexes:forKeyPath:options:context:" },
        { &sel_resolve, "resolve" },
        { &sel_namespaces, "namespaces" },
        { &sel_drawInBezierPath_1angle_1, "drawInBezierPath:angle:" },
        { &sel_setPixelFormat_1, "setPixelFormat:" },
        { &sel_resizeUpDownCursor, "resizeUpDownCursor" },
        { &sel_daylightSavingTimeOffsetForDate_1, "daylightSavingTimeOffsetForDate:" },
        { &sel_setCanSpawnSeparateThread_1, "setCanSpawnSeparateThread:" },
        { &sel_setTitleBaseWritingDirection_1, "setTitleBaseWritingDirection:" },
        { &sel_subscript_1, "subscript:" },
        { &sel_URL, "URL" },
        { &sel_headerColor, "headerColor" },
        { &sel_stringByAddingPercentEscapesUsingEncoding_1, "stringByAddingPercentEscapesUsingEncoding:" },
        { &sel_draggingExited_1, "draggingExited:" },
        { &sel_ignoreModifierKeysWhileDragging, "ignoreModifierKeysWhileDragging" },
        { &sel_componentsToDisplayForPath_1, "componentsToDisplayForPath:" },
        { &sel_glyphRangeForBoundingRectWithoutAdditionalLayout_1inTextContainer_1, "glyphRangeForBoundingRectWithoutAdditionalLayout:inTextContainer:" },
        { &sel_removeTrackingRect_1, "removeTrackingRect:" },
        { &sel_handlePrintScriptCommand_1, "handlePrintScriptCommand:" },
        { &sel_viewDidMoveToWindow, "viewDidMoveToWindow" },
        { &sel_allocateGState, "allocateGState" },
        { &sel_availableStringEncodings, "availableStringEncodings" },
        { &sel_instantiateNibWithExternalNameTable_1, "instantiateNibWithExternalNameTable:" },
        { &sel_setWeekdayOrdinal_1, "setWeekdayOrdinal:" },
        { &sel_setWithCapacity_1, "setWithCapacity:" },
        { &sel_setCurrentAppleEventAndReplyEventWithSuspensionID_1, "setCurrentAppleEventAndReplyEventWithSuspensionID:" },
        { &sel_convertFont_1toNotHaveTrait_1, "convertFont:toNotHaveTrait:" },
        { &sel_performSelector_1withObject_1withObject_1, "performSelector:withObject:withObject:" },
        { &sel_removeIndexes_1, "removeIndexes:" },
        { &sel_objectSpecifierWithDescriptor_1, "objectSpecifierWithDescriptor:" },
        { &sel_objectValue, "objectValue" },
        { &sel_timeZone, "timeZone" },
        { &sel_viewSizeChanged_1, "viewSizeChanged:" },
        { &sel_clearDrawable, "clearDrawable" },
        { &sel_parentRowForRow_1, "parentRowForRow:" },
        { &sel_trackingMode, "trackingMode" },
        { &sel_selectedRanges, "selectedRanges" },
        { &sel_suspendExecution, "suspendExecution" },
        { &sel_setDefaultPrinter_1, "setDefaultPrinter:" },
        { &sel_loadDataRepresentation_1ofType_1, "loadDataRepresentation:ofType:" },
        { &sel_closestTickMarkValueToValue_1, "closestTickMarkValueToValue:" },
        { &sel_removeFromRunLoop_1forMode_1, "removeFromRunLoop:forMode:" },
        { &sel_cancelUserAttentionRequest_1, "cancelUserAttentionRequest:" },
        { &sel_dictionaryWithObject_1forKey_1, "dictionaryWithObject:forKey:" },
        { &sel_isDataRetained, "isDataRetained" },
        { &sel_setLoops_1, "setLoops:" },
        { &sel_hashTableWithWeakObjects, "hashTableWithWeakObjects" },
        { &sel_documentForURL_1, "documentForURL:" },
        { &sel_removeRepresentation_1, "removeRepresentation:" },
        { &sel_keyClassDescription, "keyClassDescription" },
        { &sel_noResponderFor_1, "noResponderFor:" },
        { &sel_setBidiLevels_1forGlyphRange_1, "setBidiLevels:forGlyphRange:" },
        { &sel_cancelIncrementalLoad, "cancelIncrementalLoad" },
        { &sel_highlightedBranchImage, "highlightedBranchImage" },
        { &sel_setAttributedStringForZero_1, "setAttributedStringForZero:" },
        { &sel_drawAtPoint_1fromRect_1operation_1fraction_1, "drawAtPoint:fromRect:operation:fraction:" },
        { &sel_fileHFSTypeCode, "fileHFSTypeCode" },
        { &sel_maximumRecents, "maximumRecents" },
        { &sel_useFont_1, "useFont:" },
        { &sel_selectKeyViewPrecedingView_1, "selectKeyViewPrecedingView:" },
        { &sel_attributedStringForNil, "attributedStringForNil" },
        { &sel_isGrammarCheckingEnabled, "isGrammarCheckingEnabled" },
        { &sel_owner, "owner" },
        { &sel_searchForServicesOfType_1inDomain_1, "searchForServicesOfType:inDomain:" },
        { &sel_frameAutosaveName, "frameAutosaveName" },
        { &sel_setCommands_1, "setCommands:" },
        { &sel_URLResourceDidCancelLoading_1, "URLResourceDidCancelLoading:" },
        { &sel_uniqueSpellDocumentTag, "uniqueSpellDocumentTag" },
        { &sel_needsToBeUpdatedFromPath_1, "needsToBeUpdatedFromPath:" },
        { &sel_bounds, "bounds" },
        { &sel_contextHelpForKey_1, "contextHelpForKey:" },
        { &sel_setSendsActionOnEndEditing_1, "setSendsActionOnEndEditing:" },
        { &sel_scanDouble_1, "scanDouble:" },
        { &sel_download_1willResumeWithResponse_1fromByte_1, "download:willResumeWithResponse:fromByte:" },
        { &sel_drawFromCenter_1radius_1toCenter_1radius_1options_1, "drawFromCenter:radius:toCenter:radius:options:" },
        { &sel_defaultFlatness, "defaultFlatness" },
        { &sel_keepBackupFile, "keepBackupFile" },
        { &sel_willChangeValueForKey_1, "willChangeValueForKey:" },
        { &sel_initWithDateFormat_1allowNaturalLanguage_1, "initWithDateFormat:allowNaturalLanguage:" },
        { &sel_textView_1writablePasteboardTypesForCell_1atIndex_1, "textView:writablePasteboardTypesForCell:atIndex:" },
        { &sel_getTIFFCompressionTypes_1count_1, "getTIFFCompressionTypes:count:" },
        { &sel_decodePropertyList, "decodePropertyList" },
        { &sel_saveDocumentWithDelegate_1didSaveSelector_1contextInfo_1, "saveDocumentWithDelegate:didSaveSelector:contextInfo:" },
        { &sel_encodePoint_1, "encodePoint:" },
        { &sel_selectRow_1byExtendingSelection_1, "selectRow:byExtendingSelection:" },
        { &sel_preservesContentDuringLiveResize, "preservesContentDuringLiveResize" },
        { &sel_registerUndoWithTarget_1selector_1object_1, "registerUndoWithTarget:selector:object:" },
        { &sel_removeCollection_1, "removeCollection:" },
        { &sel_nextEventMatchingMask_1, "nextEventMatchingMask:" },
        { &sel_getObjects_1andKeys_1, "getObjects:andKeys:" },
        { &sel_EPSRepresentation, "EPSRepresentation" },
        { &sel_isModalPanel, "isModalPanel" },
        { &sel_statusCode, "statusCode" },
        { &sel_setCopiesOnScroll_1, "setCopiesOnScroll:" },
        { &sel_setHorizontalPagination_1, "setHorizontalPagination:" },
        { &sel_removeAllIndexes, "removeAllIndexes" },
        { &sel_download_1didFailWithError_1, "download:didFailWithError:" },
        { &sel_modifierFlags, "modifierFlags" },
        { &sel_draggedColumn, "draggedColumn" },
        { &sel_initWithUser_1, "initWithUser:" },
        { &sel_setLayoutRect_1forTextBlock_1glyphRange_1, "setLayoutRect:forTextBlock:glyphRange:" },
        { &sel_selectionAffinity, "selectionAffinity" },
        { &sel_beginParagraph, "beginParagraph" },
        { &sel_runModalForTypes_1, "runModalForTypes:" },
        { &sel_reloadCriteria, "reloadCriteria" },
        { &sel_PDFOperationWithView_1insideRect_1toData_1printInfo_1, "PDFOperationWithView:insideRect:toData:printInfo:" },
        { &sel_cellAtRow_1column_1, "cellAtRow:column:" },
        { &sel_selectColumn_1byExtendingSelection_1, "selectColumn:byExtendingSelection:" },
        { &sel_addresses, "addresses" },
        { &sel_setCanBeVisibleOnAllSpaces_1, "setCanBeVisibleOnAllSpaces:" },
        { &sel_bundleForSuite_1, "bundleForSuite:" },
        { &sel_stringWithCharacters_1length_1, "stringWithCharacters:length:" },
        { &sel_dataWithContentsOfURL_1options_1error_1, "dataWithContentsOfURL:options:error:" },
        { &sel_isExpanded, "isExpanded" },
        { &sel_rectForLayoutAtPoint_1inRect_1textContainer_1characterRange_1, "rectForLayoutAtPoint:inRect:textContainer:characterRange:" },
        { &sel_initWithXMLString_1options_1error_1, "initWithXMLString:options:error:" },
        { &sel_datePickerCell_1validateProposedDateValue_1timeInterval_1, "datePickerCell:validateProposedDateValue:timeInterval:" },
        { &sel_replaceCharactersInRange_1withRTFD_1, "replaceCharactersInRange:withRTFD:" },
        { &sel_setNeedsDisplay_1, "setNeedsDisplay:" },
        { &sel_tableViewColumnDidMove_1, "tableViewColumnDidMove:" },
        { &sel_printOperationWithView_1printInfo_1, "printOperationWithView:printInfo:" },
        { &sel_parserDidStartDocument_1, "parserDidStartDocument:" },
        { &sel_privateFrameworksPath, "privateFrameworksPath" },
        { &sel_informativeText, "informativeText" },
        { &sel_attributesAtIndex_1effectiveRange_1, "attributesAtIndex:effectiveRange:" },
        { &sel_rectArrayForGlyphRange_1withinSelectedGlyphRange_1inTextContainer_1rectCount_1, "rectArrayForGlyphRange:withinSelectedGlyphRange:inTextContainer:rectCount:" },
        { &sel_swapWithMark_1, "swapWithMark:" },
        { &sel_setDrawsGrid_1, "setDrawsGrid:" },
        { &sel_highlight_1, "highlight:" },
        { &sel_maximumLineHeight, "maximumLineHeight" },
        { &sel_phonemesFromText_1, "phonemesFromText:" },
        { &sel_convertSize_1fromView_1, "convertSize:fromView:" },
        { &sel_setProperty_1withValue_1, "setProperty:withValue:" },
        { &sel_cookieAcceptPolicy, "cookieAcceptPolicy" },
        { &sel_hasThousandSeparators, "hasThousandSeparators" },
        { &sel_setTighteningFactorForTruncation_1, "setTighteningFactorForTruncation:" },
        { &sel_contextMenuRepresentation, "contextMenuRepresentation" },
        { &sel_precomposedStringWithCompatibilityMapping, "precomposedStringWithCompatibilityMapping" },
        { &sel_threadDictionary, "threadDictionary" },
        { &sel_redoMenuTitleForUndoActionName_1, "redoMenuTitleForUndoActionName:" },
        { &sel_setNumberOfVisibleItems_1, "setNumberOfVisibleItems:" },
        { &sel_preferredLanguages, "preferredLanguages" },
        { &sel_mouseDraggedOnCharacterIndex_1atCoordinate_1withModifier_1client_1, "mouseDraggedOnCharacterIndex:atCoordinate:withModifier:client:" },
        { &sel_setMultiplier_1, "setMultiplier:" },
        { &sel_sortedArrayUsingSelector_1, "sortedArrayUsingSelector:" },
        { &sel_drawInRect_1, "drawInRect:" },
        { &sel_reversedSortDescriptor, "reversedSortDescriptor" },
        { &sel_setIdentifier_1, "setIdentifier:" },
        { &sel_systemLocale, "systemLocale" },
        { &sel_rulerView_1didMoveMarker_1, "rulerView:didMoveMarker:" },
        { &sel_serviceConnectionWithName_1rootObject_1, "serviceConnectionWithName:rootObject:" },
        { &sel_mouseDownCanMoveWindow, "mouseDownCanMoveWindow" },
        { &sel_setMode_1, "setMode:" },
        { &sel_rectOfTickMarkAtIndex_1, "rectOfTickMarkAtIndex:" },
        { &sel_rangeOfCharacterFromSet_1, "rangeOfCharacterFromSet:" },
        { &sel_pageUp_1, "pageUp:" },
        { &sel_sendsWholeSearchString, "sendsWholeSearchString" },
        { &sel_selectColumnIndexes_1byExtendingSelection_1, "selectColumnIndexes:byExtendingSelection:" },
        { &sel_localizedCaseInsensitiveCompare_1, "localizedCaseInsensitiveCompare:" },
        { &sel_isEqualToString_1, "isEqualToString:" },
        { &sel_invalidateHashMarks, "invalidateHashMarks" },
        { &sel_setInitialKey_1, "setInitialKey:" },
        { &sel_setDividerStyle_1, "setDividerStyle:" },
        { &sel_expressionForMinusSet_1with_1, "expressionForMinusSet:with:" },
        { &sel_netService_1didNotPublish_1, "netService:didNotPublish:" },
        { &sel_evaluatedReceivers, "evaluatedReceivers" },
        { &sel_removeTabViewItem_1, "removeTabViewItem:" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1index_1, "initWithContainerClassDescription:containerSpecifier:key:index:" },
        { &sel_predicateWithLeftExpression_1rightExpression_1customSelector_1, "predicateWithLeftExpression:rightExpression:customSelector:" },
        { &sel_brownColor, "brownColor" },
        { &sel_leafKeyPathForNode_1, "leafKeyPathForNode:" },
        { &sel_drawBackgroundForGlyphRange_1atPoint_1, "drawBackgroundForGlyphRange:atPoint:" },
        { &sel_rulerView_1willSetClientView_1, "rulerView:willSetClientView:" },
        { &sel_className, "className" },
        { &sel_runMode_1beforeDate_1, "runMode:beforeDate:" },
        { &sel_applicationShouldTerminateAfterLastWindowClosed_1, "applicationShouldTerminateAfterLastWindowClosed:" },
        { &sel_newDocument_1, "newDocument:" },
        { &sel_arrayByAddingObject_1, "arrayByAddingObject:" },
        { &sel_savePanel, "savePanel" },
        { &sel_prefersTrackingUntilMouseUp, "prefersTrackingUntilMouseUp" },
        { &sel_setLocations_1startingGlyphIndexes_1count_1forGlyphRange_1, "setLocations:startingGlyphIndexes:count:forGlyphRange:" },
        { &sel_setListensInForegroundOnly_1, "setListensInForegroundOnly:" },
        { &sel_initWithUnsignedShort_1, "initWithUnsignedShort:" },
        { &sel_letterCharacterSet, "letterCharacterSet" },
        { &sel_listensInForegroundOnly, "listensInForegroundOnly" },
        { &sel_menu_1willHighlightItem_1, "menu:willHighlightItem:" },
        { &sel_charactersIgnoringModifiers, "charactersIgnoringModifiers" },
        { &sel_insertionContainer, "insertionContainer" },
        { &sel_searchButtonRectForBounds_1, "searchButtonRectForBounds:" },
        { &sel_accessibilitySetValue_1forAttribute_1, "accessibilitySetValue:forAttribute:" },
        { &sel_setPathSeparator_1, "setPathSeparator:" },
        { &sel_applicationWillResignActive_1, "applicationWillResignActive:" },
        { &sel_scriptingIsLessThanOrEqualTo_1, "scriptingIsLessThanOrEqualTo:" },
        { &sel_decodeValuesOfObjCTypes_1, "decodeValuesOfObjCTypes:" },
        { &sel_setIntercellSpacing_1, "setIntercellSpacing:" },
        { &sel_sharedSystemTypesetterForBehavior_1, "sharedSystemTypesetterForBehavior:" },
        { &sel_drawFromPoint_1toPoint_1options_1, "drawFromPoint:toPoint:options:" },
        { &sel_windowDidMove_1, "windowDidMove:" },
        { &sel_setVisible_1, "setVisible:" },
        { &sel_credentialWithUser_1password_1persistence_1, "credentialWithUser:password:persistence:" },
        { &sel_decomposedStringWithCanonicalMapping, "decomposedStringWithCanonicalMapping" },
        { &sel_openFile_1withApplication_1andDeactivate_1, "openFile:withApplication:andDeactivate:" },
        { &sel_convertRectToBase_1, "convertRectToBase:" },
        { &sel_outputStreamToMemory, "outputStreamToMemory" },
        { &sel_autorepeat, "autorepeat" },
        { &sel_servicesMenu, "servicesMenu" },
        { &sel_beginGrouping, "beginGrouping" },
        { &sel_setNilValueForKey_1, "setNilValueForKey:" },
        { &sel_usesFontLeading, "usesFontLeading" },
        { &sel_lineFragmentRectForGlyphAtIndex_1effectiveRange_1, "lineFragmentRectForGlyphAtIndex:effectiveRange:" },
        { &sel_takeStringValueFrom_1, "takeStringValueFrom:" },
        { &sel_fontDescriptorByAddingAttributes_1, "fontDescriptorByAddingAttributes:" },
        { &sel_startTrackingAt_1inView_1, "startTrackingAt:inView:" },
        { &sel_application_1delegateHandlesKey_1, "application:delegateHandlesKey:" },
        { &sel_stringByExpandingTildeInPath, "stringByExpandingTildeInPath" },
        { &sel_menu, "menu" },
        { &sel_setMinute_1, "setMinute:" },
        { &sel_startSubelementIdentifier, "startSubelementIdentifier" },
        { &sel_waitForDataInBackgroundAndNotifyForModes_1, "waitForDataInBackgroundAndNotifyForModes:" },
        { &sel_removeCachedResponseForRequest_1, "removeCachedResponseForRequest:" },
        { &sel_attributeForLocalName_1URI_1, "attributeForLocalName:URI:" },
        { &sel_saveDocumentAs_1, "saveDocumentAs:" },
        { &sel_containerIsObjectBeingTested, "containerIsObjectBeingTested" },
        { &sel_mouseDownOnCharacterIndex_1atCoordinate_1withModifier_1client_1, "mouseDownOnCharacterIndex:atCoordinate:withModifier:client:" },
        { &sel_setPosition_1ofDividerAtIndex_1, "setPosition:ofDividerAtIndex:" },
        { &sel_terminationStatus, "terminationStatus" },
        { &sel_imageWidth, "imageWidth" },
        { &sel_accessoryView, "accessoryView" },
        { &sel_outlineView_1shouldTrackCell_1forTableColumn_1item_1, "outlineView:shouldTrackCell:forTableColumn:item:" },
        { &sel_initWithLevelIndicatorStyle_1, "initWithLevelIndicatorStyle:" },
        { &sel_deltaX, "deltaX" },
        { &sel_valueForUndefinedKey_1, "valueForUndefinedKey:" },
        { &sel_mainDocumentURL, "mainDocumentURL" },
        { &sel_position, "position" },
        { &sel_animates, "animates" },
        { &sel_addTabViewItem_1, "addTabViewItem:" },
        { &sel_unlockFocus, "unlockFocus" },
        { &sel_download_1didCreateDestination_1, "download:didCreateDestination:" },
        { &sel_defaults, "defaults" },
        { &sel_viewWillDraw, "viewWillDraw" },
        { &sel_findApplications, "findApplications" },
        { &sel_unbind_1, "unbind:" },
        { &sel_positionOfGlyph_1withRelation_1toBaseGlyph_1totalAdvancement_1metricsExist_1, "positionOfGlyph:withRelation:toBaseGlyph:totalAdvancement:metricsExist:" },
        { &sel_isGreaterThan_1, "isGreaterThan:" },
        { &sel_dataWithPDFInsideRect_1, "dataWithPDFInsideRect:" },
        { &sel_setAttributedTitle_1, "setAttributedTitle:" },
        { &sel_expressionType, "expressionType" },
        { &sel_tokenFieldCell_1shouldAddObjects_1atIndex_1, "tokenFieldCell:shouldAddObjects:atIndex:" },
        { &sel_removeEventHandlerForEventClass_1andEventID_1, "removeEventHandlerForEventClass:andEventID:" },
        { &sel_postNotification_1, "postNotification:" },
        { &sel_indexOfTabViewItem_1, "indexOfTabViewItem:" },
        { &sel_outlineView_1shouldSelectItem_1, "outlineView:shouldSelectItem:" },
        { &sel_setSegmentStyle_1, "setSegmentStyle:" },
        { &sel_stateImageRectForBounds_1, "stateImageRectForBounds:" },
        { &sel_setContentAspectRatio_1, "setContentAspectRatio:" },
        { &sel_instantiateNibWithOwner_1topLevelObjects_1, "instantiateNibWithOwner:topLevelObjects:" },
        { &sel_setPrototype_1, "setPrototype:" },
        { &sel_allowsMultipleSelection, "allowsMultipleSelection" },
        { &sel_setRecentSearches_1, "setRecentSearches:" },
        { &sel_setTypingAttributes_1, "setTypingAttributes:" },
        { &sel_observeValueForKeyPath_1ofObject_1change_1context_1, "observeValueForKeyPath:ofObject:change:context:" },
        { &sel_performDragOperation_1, "performDragOperation:" },
        { &sel_processingInstructionWithName_1stringValue_1, "processingInstructionWithName:stringValue:" },
        { &sel_initWithKind_1options_1, "initWithKind:options:" },
        { &sel_instancesRespondToSelector_1, "instancesRespondToSelector:" },
        { &sel_keyEquivalentFont, "keyEquivalentFont" },
        { &sel_calendarIdentifier, "calendarIdentifier" },
        { &sel_source, "source" },
        { &sel_shouldBeTreatedAsInkEvent_1, "shouldBeTreatedAsInkEvent:" },
        { &sel_queuePriority, "queuePriority" },
        { &sel_autoresizesAllColumnsToFit, "autoresizesAllColumnsToFit" },
        { &sel_outlineView_1shouldCollapseItem_1, "outlineView:shouldCollapseItem:" },
        { &sel_dragImage_1at_1offset_1event_1pasteboard_1source_1slideBack_1, "dragImage:at:offset:event:pasteboard:source:slideBack:" },
        { &sel_sender, "sender" },
        { &sel_numberOfColumns, "numberOfColumns" },
        { &sel_indexPathWithIndex_1, "indexPathWithIndex:" },
        { &sel_setPreferredFontNames_1, "setPreferredFontNames:" },
        { &sel_windowDidEndSheet_1, "windowDidEndSheet:" },
        { &sel_capHeight, "capHeight" },
        { &sel_matchingFontDescriptorWithMandatoryKeys_1, "matchingFontDescriptorWithMandatoryKeys:" },
        { &sel_finalize, "finalize" },
        { &sel_prepareForDragOperation_1, "prepareForDragOperation:" },
        { &sel_setCellAttribute_1to_1, "setCellAttribute:to:" },
        { &sel_metadataQuery_1replacementValueForAttribute_1value_1, "metadataQuery:replacementValueForAttribute:value:" },
        { &sel_hueComponent, "hueComponent" },
        { &sel_maxValue, "maxValue" },
        { &sel_soundUnfilteredTypes, "soundUnfilteredTypes" },
        { &sel_setFileAttributes_1, "setFileAttributes:" },
        { &sel_valueLists, "valueLists" },
        { &sel_breakLock, "breakLock" },
        { &sel_selectCellWithTag_1, "selectCellWithTag:" },
        { &sel_setMovable_1, "setMovable:" },
        { &sel_synchronizeFile, "synchronizeFile" },
        { &sel_setVerticallyResizable_1, "setVerticallyResizable:" },
        { &sel_setButtonBordered_1, "setButtonBordered:" },
        { &sel_useOptimizedDrawing_1, "useOptimizedDrawing:" },
        { &sel_tryLockWhenCondition_1, "tryLockWhenCondition:" },
        { &sel_textContainer, "textContainer" },
        { &sel_setValueListAttributes_1, "setValueListAttributes:" },
        { &sel_rangeOfCharacterFromSet_1options_1, "rangeOfCharacterFromSet:options:" },
        { &sel_dragFile_1fromRect_1slideBack_1event_1, "dragFile:fromRect:slideBack:event:" },
        { &sel_tickMarkPosition, "tickMarkPosition" },
        { &sel_addRunLoop_1, "addRunLoop:" },
        { &sel_dataWithCapacity_1, "dataWithCapacity:" },
        { &sel_removeVolatileDomainForName_1, "removeVolatileDomainForName:" },
        { &sel_signal, "signal" },
        { &sel_progressMarks, "progressMarks" },
        { &sel_unhide_1, "unhide:" },
        { &sel_provideNewButtonImage, "provideNewButtonImage" },
        { &sel_connectionWithRegisteredName_1host_1usingNameServer_1, "connectionWithRegisteredName:host:usingNameServer:" },
        { &sel_localizesFormat, "localizesFormat" },
        { &sel_lineScroll, "lineScroll" },
        { &sel_initDirectoryWithFileWrappers_1, "initDirectoryWithFileWrappers:" },
        { &sel_wantsToInterpretAllKeystrokes, "wantsToInterpretAllKeystrokes" },
        { &sel_convertPointToBase_1, "convertPointToBase:" },
        { &sel_keyWithAppleEventCode_1, "keyWithAppleEventCode:" },
        { &sel_loadSuiteWithDictionary_1fromBundle_1, "loadSuiteWithDictionary:fromBundle:" },
        { &sel_automaticallyPreparesContent, "automaticallyPreparesContent" },
        { &sel_cornerRadius, "cornerRadius" },
        { &sel_sharedScriptExecutionContext, "sharedScriptExecutionContext" },
        { &sel_setPoolCountHighWaterResolution_1, "setPoolCountHighWaterResolution:" },
        { &sel_appendBezierPath_1, "appendBezierPath:" },
        { &sel_appleEventClassCode, "appleEventClassCode" },
        { &sel_initTextCell_1pullsDown_1, "initTextCell:pullsDown:" },
        { &sel_numberOfTickMarks, "numberOfTickMarks" },
        { &sel_setIndependentConversationQueueing_1, "setIndependentConversationQueueing:" },
        { &sel_extendPowerOffBy_1, "extendPowerOffBy:" },
        { &sel_isCollecting, "isCollecting" },
        { &sel_canInsert, "canInsert" },
        { &sel_valuePointerFunctions, "valuePointerFunctions" },
        { &sel_sizeValue, "sizeValue" },
        { &sel_openOnEdge_1, "openOnEdge:" },
        { &sel_rectOfItemAtIndex_1, "rectOfItemAtIndex:" },
        { &sel_booleanForKey_1inTable_1, "booleanForKey:inTable:" },
        { &sel_showHelp_1, "showHelp:" },
        { &sel_heightTracksTextView, "heightTracksTextView" },
        { &sel_hasTitleBar, "hasTitleBar" },
        { &sel_setViewAnimations_1, "setViewAnimations:" },
        { &sel_updateSpellingPanelWithGrammarString_1detail_1, "updateSpellingPanelWithGrammarString:detail:" },
        { &sel_showsToolbarButton, "showsToolbarButton" },
        { &sel_environment, "environment" },
        { &sel_matchesAppleEventCode_1, "matchesAppleEventCode:" },
        { &sel_hasPrefix_1, "hasPrefix:" },
        { &sel_hasUnappliedChanges, "hasUnappliedChanges" },
        { &sel_setName_1, "setName:" },
        { &sel_isMovableByWindowBackground, "isMovableByWindowBackground" },
        { &sel_printerNames, "printerNames" },
        { &sel_initWithDictionary_1, "initWithDictionary:" },
        { &sel_stringByStandardizingPath, "stringByStandardizingPath" },
        { &sel_usesUserKeyEquivalents, "usesUserKeyEquivalents" },
        { &sel_drawStateImageWithFrame_1inView_1, "drawStateImageWithFrame:inView:" },
        { &sel_openUntitledDocumentAndDisplay_1error_1, "openUntitledDocumentAndDisplay:error:" },
        { &sel_lastVisibleColumn, "lastVisibleColumn" },
        { &sel_paste_1, "paste:" },
        { &sel_indexOfItemWithRepresentedObject_1, "indexOfItemWithRepresentedObject:" },
        { &sel_supportsCommand_1, "supportsCommand:" },
        { &sel_scrollPageUp_1, "scrollPageUp:" },
        { &sel_draggedImage_1endedAt_1deposited_1, "draggedImage:endedAt:deposited:" },
        { &sel_setPositiveInfinitySymbol_1, "setPositiveInfinitySymbol:" },
        { &sel_noteFileSystemChanged_1, "noteFileSystemChanged:" },
        { &sel_moveRight_1, "moveRight:" },
        { &sel_arrowPosition, "arrowPosition" },
        { &sel_setMenuRepresentation_1, "setMenuRepresentation:" },
        { &sel_endLoadInBackground, "endLoadInBackground" },
        { &sel_smartInsertBeforeStringForString_1replacingRange_1, "smartInsertBeforeStringForString:replacingRange:" },
        { &sel_openUntitledDocumentOfType_1display_1, "openUntitledDocumentOfType:display:" },
        { &sel_scriptingValueForSpecifier_1, "scriptingValueForSpecifier:" },
        { &sel_setShowsSuppressionButton_1, "setShowsSuppressionButton:" },
        { &sel_resizeLeftCursor, "resizeLeftCursor" },
        { &sel_setDefaultCredential_1forProtectionSpace_1, "setDefaultCredential:forProtectionSpace:" },
        { &sel_systemTabletID, "systemTabletID" },
        { &sel_unlock, "unlock" },
        { &sel_mostCompatibleStringEncoding, "mostCompatibleStringEncoding" },
        { &sel_glyphName, "glyphName" },
        { &sel_center, "center" },
        { &sel_setJobTitle_1, "setJobTitle:" },
        { &sel_cancelButtonCell, "cancelButtonCell" },
        { &sel_namespaceForPrefix_1, "namespaceForPrefix:" },
        { &sel_browserWillScroll_1, "browserWillScroll:" },
        { &sel_initWithCompoundTypes_1, "initWithCompoundTypes:" },
        { &sel_setPaddingCharacter_1, "setPaddingCharacter:" },
        { &sel_image_1willLoadRepresentation_1, "image:willLoadRepresentation:" },
        { &sel_pasteRuler_1, "pasteRuler:" },
        { &sel_drawGlyphsForGlyphRange_1atPoint_1, "drawGlyphsForGlyphRange:atPoint:" },
        { &sel_PMPrintSession, "PMPrintSession" },
        { &sel_setDefaultButtonCell_1, "setDefaultButtonCell:" },
        { &sel_printerTypes, "printerTypes" },
        { &sel_findString_1inBook_1, "findString:inBook:" },
        { &sel_executablePath, "executablePath" },
        { &sel_components_1fromDate_1toDate_1options_1, "components:fromDate:toDate:options:" },
        { &sel_displayValuesForRow_1, "displayValuesForRow:" },
        { &sel_pageLayout, "pageLayout" },
        { &sel_resizeFlags, "resizeFlags" },
        { &sel_DTDNodeWithXMLString_1, "DTDNodeWithXMLString:" },
        { &sel_replyToOpenOrPrint_1, "replyToOpenOrPrint:" },
        { &sel_insertTab_1, "insertTab:" },
        { &sel_documents, "documents" },
        { &sel_tagForSegment_1, "tagForSegment:" },
        { &sel_initForURL_1withContentsOfURL_1ofType_1error_1, "initForURL:withContentsOfURL:ofType:error:" },
        { &sel_initWithRoundingMode_1scale_1raiseOnExactness_1raiseOnOverflow_1raiseOnUnderflow_1raiseOnDivideByZero_1, "initWithRoundingMode:scale:raiseOnExactness:raiseOnOverflow:raiseOnUnderflow:raiseOnDivideByZero:" },
        { &sel_addIndexes_1, "addIndexes:" },
        { &sel_setAttributeRuns_1, "setAttributeRuns:" },
        { &sel_splitView_1additionalEffectiveRectOfDividerAtIndex_1, "splitView:additionalEffectiveRectOfDividerAtIndex:" },
        { &sel_writeSelectionToPasteboard_1type_1, "writeSelectionToPasteboard:type:" },
        { &sel_day, "day" },
        { &sel_numberOfRowsInTableView_1, "numberOfRowsInTableView:" },
        { &sel_insertCompletion_1forPartialWordRange_1movement_1isFinal_1, "insertCompletion:forPartialWordRange:movement:isFinal:" },
        { &sel_notPredicateWithSubpredicate_1, "notPredicateWithSubpredicate:" },
        { &sel_rootProxyForConnectionWithRegisteredName_1host_1, "rootProxyForConnectionWithRegisteredName:host:" },
        { &sel_stopSpeakingAtBoundary_1, "stopSpeakingAtBoundary:" },
        { &sel_pathsMatchingExtensions_1, "pathsMatchingExtensions:" },
        { &sel_caseInsensitiveCompare_1, "caseInsensitiveCompare:" },
        { &sel_labelFontOfSize_1, "labelFontOfSize:" },
        { &sel_createDirectoryAtPath_1attributes_1, "createDirectoryAtPath:attributes:" },
        { &sel_initListDescriptor, "initListDescriptor" },
        { &sel_setParagraphSpacing_1, "setParagraphSpacing:" },
        { &sel_getColor_1location_1atIndex_1, "getColor:location:atIndex:" },
        { &sel_pointerArrayWithOptions_1, "pointerArrayWithOptions:" },
        { &sel_guessesForWord_1, "guessesForWord:" },
        { &sel_searchTextRectForBounds_1, "searchTextRectForBounds:" },
        { &sel_allowsColumnReordering, "allowsColumnReordering" },
        { &sel_isMainThread, "isMainThread" },
        { &sel_accessibilityAttributeNames, "accessibilityAttributeNames" },
        { &sel_saveOptions, "saveOptions" },
        { &sel_setAutomaticallyPreparesContent_1, "setAutomaticallyPreparesContent:" },
        { &sel_setGridColor_1, "setGridColor:" },
        { &sel_textAttributesForNegativeInfinity, "textAttributesForNegativeInfinity" },
        { &sel_decimalDigitCharacterSet, "decimalDigitCharacterSet" },
        { &sel_removeObserver_1name_1object_1, "removeObserver:name:object:" },
        { &sel_columnContentWidthForColumnWidth_1, "columnContentWidthForColumnWidth:" },
        { &sel_wraps, "wraps" },
        { &sel_getIndexes_1maxCount_1inIndexRange_1, "getIndexes:maxCount:inIndexRange:" },
        { &sel_doubleAction, "doubleAction" },
        { &sel_layoutParagraphAtPoint_1, "layoutParagraphAtPoint:" },
        { &sel_cacheDisplayInRect_1toBitmapImageRep_1, "cacheDisplayInRect:toBitmapImageRep:" },
        { &sel_setUsesItemFromMenu_1, "setUsesItemFromMenu:" },
        { &sel_parserError, "parserError" },
        { &sel_numberOfMajorTickMarks, "numberOfMajorTickMarks" },
        { &sel_changeFont_1, "changeFont:" },
        { &sel_displaysWhenScreenProfileChanges, "displaysWhenScreenProfileChanges" },
        { &sel_titleBaseWritingDirection, "titleBaseWritingDirection" },
        { &sel_columnAtPoint_1, "columnAtPoint:" },
        { &sel_setAppliesImmediately_1, "setAppliesImmediately:" },
        { &sel_addAccessoryController_1, "addAccessoryController:" },
        { &sel_setEditable_1, "setEditable:" },
        { &sel_moveRulerlineFromLocation_1toLocation_1, "moveRulerlineFromLocation:toLocation:" },
        { &sel_runModal, "runModal" },
        { &sel_selectionShouldChangeInTableView_1, "selectionShouldChangeInTableView:" },
        { &sel_dragSelectionWithEvent_1offset_1slideBack_1, "dragSelectionWithEvent:offset:slideBack:" },
        { &sel_rootProxy, "rootProxy" },
        { &sel_brightnessComponent, "brightnessComponent" },
        { &sel_setLabel_1forSegment_1, "setLabel:forSegment:" },
        { &sel_copy, "copy" },
        { &sel_helpRequested_1, "helpRequested:" },
        { &sel_setThreadPriority_1, "setThreadPriority:" },
        { &sel_minContentSize, "minContentSize" },
        { &sel_setShowsProgressPanel_1, "setShowsProgressPanel:" },
        { &sel_setMessageText_1, "setMessageText:" },
        { &sel_setLayoutAlgorithm_1, "setLayoutAlgorithm:" },
        { &sel_setInContext_1, "setInContext:" },
        { &sel_resultCount, "resultCount" },
        { &sel_usesDataSource, "usesDataSource" },
        { &sel_textLists, "textLists" },
        { &sel_setSelectedRange_1affinity_1stillSelecting_1, "setSelectedRange:affinity:stillSelecting:" },
        { &sel_shouldResolveExternalEntities, "shouldResolveExternalEntities" },
        { &sel_clientView, "clientView" },
        { &sel_styleMask, "styleMask" },
        { &sel_setCurrencyCode_1, "setCurrencyCode:" },
        { &sel_methodReturnType, "methodReturnType" },
        { &sel_dataUsingEncoding_1, "dataUsingEncoding:" },
        { &sel_removeTabStop_1, "removeTabStop:" },
        { &sel_reloadItem_1reloadChildren_1, "reloadItem:reloadChildren:" },
        { &sel_ancestorSharedWithView_1, "ancestorSharedWithView:" },
        { &sel_indexLessThanOrEqualToIndex_1, "indexLessThanOrEqualToIndex:" },
        { &sel_removeAllActionsWithTarget_1, "removeAllActionsWithTarget:" },
        { &sel_subtype, "subtype" },
        { &sel_imageRectForPaper_1, "imageRectForPaper:" },
        { &sel_initWithWindow_1rect_1, "initWithWindow:rect:" },
        { &sel_enable, "enable" },
        { &sel_scanInteger_1, "scanInteger:" },
        { &sel_initWithContentsOfURL_1encoding_1error_1, "initWithContentsOfURL:encoding:error:" },
        { &sel_removeObjectIdenticalTo_1, "removeObjectIdenticalTo:" },
        { &sel_createTexture_1fromView_1internalFormat_1, "createTexture:fromView:internalFormat:" },
        { &sel_decimalNumberByRaisingToPower_1withBehavior_1, "decimalNumberByRaisingToPower:withBehavior:" },
        { &sel_appendBezierPathWithArcWithCenter_1radius_1startAngle_1endAngle_1, "appendBezierPathWithArcWithCenter:radius:startAngle:endAngle:" },
        { &sel_fontPanel_1, "fontPanel:" },
        { &sel_predicateWithSubpredicates_1, "predicateWithSubpredicates:" },
        { &sel_layoutGlyphsInLayoutManager_1startingAtGlyphIndex_1maxNumberOfLineFragments_1nextGlyphIndex_1, "layoutGlyphsInLayoutManager:startingAtGlyphIndex:maxNumberOfLineFragments:nextGlyphIndex:" },
        { &sel_attributes, "attributes" },
        { &sel_EPSOperationWithView_1insideRect_1toData_1, "EPSOperationWithView:insideRect:toData:" },
        { &sel_listOptions, "listOptions" },
        { &sel_windowWillLoad, "windowWillLoad" },
        { &sel_alwaysShowsDecimalSeparator, "alwaysShowsDecimalSeparator" },
        { &sel_replyToApplicationShouldTerminate_1, "replyToApplicationShouldTerminate:" },
        { &sel_setThousandSeparator_1, "setThousandSeparator:" },
        { &sel_insertObject_1atArrangedObjectIndexPath_1, "insertObject:atArrangedObjectIndexPath:" },
        { &sel_cleanUpOperation, "cleanUpOperation" },
        { &sel_trackMouse_1inRect_1ofView_1untilMouseUp_1, "trackMouse:inRect:ofView:untilMouseUp:" },
        { &sel_replaceLayoutManager_1, "replaceLayoutManager:" },
        { &sel_isPartialStringValid_1proposedSelectedRange_1originalString_1originalSelectedRange_1errorDescription_1, "isPartialStringValid:proposedSelectedRange:originalString:originalSelectedRange:errorDescription:" },
        { &sel_setNegativeFormat_1, "setNegativeFormat:" },
        { &sel_copyFont_1, "copyFont:" },
        { &sel_outlineView_1sortDescriptorsDidChange_1, "outlineView:sortDescriptorsDidChange:" },
        { &sel_stringWithString_1, "stringWithString:" },
        { &sel_valueWithUniqueID_1inPropertyWithKey_1, "valueWithUniqueID:inPropertyWithKey:" },
        { &sel_setHighlightsBy_1, "setHighlightsBy:" },
        { &sel_setContinuousSpellCheckingEnabled_1, "setContinuousSpellCheckingEnabled:" },
        { &sel_isMouseCoalescingEnabled, "isMouseCoalescingEnabled" },
        { &sel_numberOfSelectedColumns, "numberOfSelectedColumns" },
        { &sel_spellServer_1findMisspelledWordInString_1language_1wordCount_1countOnly_1, "spellServer:findMisspelledWordInString:language:wordCount:countOnly:" },
        { &sel_PMPageFormat, "PMPageFormat" },
        { &sel_insertText_1client_1, "insertText:client:" },
        { &sel_numberWithFloat_1, "numberWithFloat:" },
        { &sel_compositeToPoint_1fromRect_1operation_1, "compositeToPoint:fromRect:operation:" },
        { &sel_numberOfPlanes, "numberOfPlanes" },
        { &sel_childrenKeyPath, "childrenKeyPath" },
        { &sel_countForObject_1, "countForObject:" },
        { &sel_fontWithName_1matrix_1, "fontWithName:matrix:" },
        { &sel_toolbarAllowedItemIdentifiers_1, "toolbarAllowedItemIdentifiers:" },
        { &sel_makeDocumentWithContentsOfURL_1ofType_1, "makeDocumentWithContentsOfURL:ofType:" },
        { &sel_initWithHTML_1options_1documentAttributes_1, "initWithHTML:options:documentAttributes:" },
        { &sel_fileSystemRepresentation, "fileSystemRepresentation" },
        { &sel_viewAnimations, "viewAnimations" },
        { &sel_tabletProximity_1, "tabletProximity:" },
        { &sel_replacementClassForClass_1, "replacementClassForClass:" },
        { &sel_columnWidthForColumnContentWidth_1, "columnWidthForColumnContentWidth:" },
        { &sel_undoMenuItemTitle, "undoMenuItemTitle" },
        { &sel_expressionForAggregate_1, "expressionForAggregate:" },
        { &sel_useStoredAccessor, "useStoredAccessor" },
        { &sel_ensureAttributesAreFixedInRange_1, "ensureAttributesAreFixedInRange:" },
        { &sel_stringForType_1, "stringForType:" },
        { &sel_setLeaf_1, "setLeaf:" },
        { &sel_URLFromPasteboard_1, "URLFromPasteboard:" },
        { &sel_initWithURL_1byReference_1, "initWithURL:byReference:" },
        { &sel_readToEndOfFileInBackgroundAndNotify, "readToEndOfFileInBackgroundAndNotify" },
        { &sel_application_1openFileWithoutUI_1, "application:openFileWithoutUI:" },
        { &sel_performClick_1, "performClick:" },
        { &sel_completes, "completes" },
        { &sel_setRulersVisible_1, "setRulersVisible:" },
        { &sel_minimumSize, "minimumSize" },
        { &sel_setProperty_1forKey_1inRequest_1, "setProperty:forKey:inRequest:" },
        { &sel_isCopyingOperation, "isCopyingOperation" },
        { &sel_allowsTickMarkValuesOnly, "allowsTickMarkValuesOnly" },
        { &sel_insertGlyphs_1length_1forStartingGlyphAtIndex_1characterIndex_1, "insertGlyphs:length:forStartingGlyphAtIndex:characterIndex:" },
        { &sel_convertFont_1, "convertFont:" },
        { &sel_setNegativePrefix_1, "setNegativePrefix:" },
        { &sel_dispatch, "dispatch" },
        { &sel_makeNewConnection_1sender_1, "makeNewConnection:sender:" },
        { &sel_writeToFile_1atomically_1encoding_1error_1, "writeToFile:atomically:encoding:error:" },
        { &sel_isHiddenOrHasHiddenAncestor, "isHiddenOrHasHiddenAncestor" },
        { &sel_endEditingFor_1, "endEditingFor:" },
        { &sel_acceptConnectionInBackgroundAndNotify, "acceptConnectionInBackgroundAndNotify" },
        { &sel_setValue_1forHTTPHeaderField_1, "setValue:forHTTPHeaderField:" },
        { &sel_intersectSet_1, "intersectSet:" },
        { &sel_tabView_1shouldSelectTabViewItem_1, "tabView:shouldSelectTabViewItem:" },
        { &sel_mouseDragged_1, "mouseDragged:" },
        { &sel_dataFromRange_1documentAttributes_1error_1, "dataFromRange:documentAttributes:error:" },
        { &sel_sharedFrameworksPath, "sharedFrameworksPath" },
        { &sel_tableView_1writeRowsWithIndexes_1toPasteboard_1, "tableView:writeRowsWithIndexes:toPasteboard:" },
        { &sel_setWindowFrameForAttachingToRect_1onScreen_1preferredEdge_1popUpSelectedItem_1, "setWindowFrameForAttachingToRect:onScreen:preferredEdge:popUpSelectedItem:" },
        { &sel_valueAtIndex_1inPropertyWithKey_1, "valueAtIndex:inPropertyWithKey:" },
        { &sel_setDisplaysLinkToolTips_1, "setDisplaysLinkToolTips:" },
        { &sel_removeObserver_1forKeyPath_1, "removeObserver:forKeyPath:" },
        { &sel_hasAlpha, "hasAlpha" },
        { &sel_scrollCellToVisibleAtRow_1column_1, "scrollCellToVisibleAtRow:column:" },
        { &sel_activateIgnoringOtherApps_1, "activateIgnoringOtherApps:" },
        { &sel_getArgumentTypeAtIndex_1, "getArgumentTypeAtIndex:" },
        { &sel_textShouldEndEditing_1, "textShouldEndEditing:" },
        { &sel_nextEventMatchingMask_1untilDate_1inMode_1dequeue_1, "nextEventMatchingMask:untilDate:inMode:dequeue:" },
        { &sel_timeIntervalSince1970, "timeIntervalSince1970" },
        { &sel_decimalNumberBySubtracting_1, "decimalNumberBySubtracting:" },
        { &sel_sendBeforeDate_1, "sendBeforeDate:" },
        { &sel_autohidesScrollers, "autohidesScrollers" },
        { &sel_controlPointBounds, "controlPointBounds" },
        { &sel_setMinimumSignificantDigits_1, "setMinimumSignificantDigits:" },
        { &sel_setDestination_1allowOverwrite_1, "setDestination:allowOverwrite:" },
        { &sel_setTransparent_1, "setTransparent:" },
        { &sel_decodeArrayOfObjCType_1count_1at_1, "decodeArrayOfObjCType:count:at:" },
        { &sel_isMiniaturized, "isMiniaturized" },
        { &sel_setAlignment_1, "setAlignment:" },
        { &sel_setCornerRadius_1, "setCornerRadius:" },
        { &sel_foregroundColor, "foregroundColor" },
        { &sel_lineFragmentUsedRectForGlyphAtIndex_1effectiveRange_1, "lineFragmentUsedRectForGlyphAtIndex:effectiveRange:" },
        { &sel_attributedSubStringFromRange_1, "attributedSubStringFromRange:" },
        { &sel_isSubsetOfSet_1, "isSubsetOfSet:" },
        { &sel_iconForFileType_1, "iconForFileType:" },
        { &sel_readFromURL_1ofType_1, "readFromURL:ofType:" },
        { &sel_decodeBytesForKey_1returnedLength_1, "decodeBytesForKey:returnedLength:" },
        { &sel_parser_1foundInternalEntityDeclarationWithName_1value_1, "parser:foundInternalEntityDeclarationWithName:value:" },
        { &sel_commonPrefixWithString_1options_1, "commonPrefixWithString:options:" },
        { &sel_tableView_1setObjectValue_1forTableColumn_1row_1, "tableView:setObjectValue:forTableColumn:row:" },
        { &sel_fileWrapperRepresentationOfType_1, "fileWrapperRepresentationOfType:" },
        { &sel_representedFilename, "representedFilename" },
        { &sel_eventWithCGEvent_1, "eventWithCGEvent:" },
        { &sel_setFileURL_1, "setFileURL:" },
        { &sel_loadWindow, "loadWindow" },
        { &sel_defaultLineJoinStyle, "defaultLineJoinStyle" },
        { &sel_backingLocation, "backingLocation" },
        { &sel_matrix, "matrix" },
        { &sel_isEqualToTimeZone_1, "isEqualToTimeZone:" },
        { &sel_statistics, "statistics" },
        { &sel_launchAppWithBundleIdentifier_1options_1additionalEventParamDescriptor_1launchIdentifier_1, "launchAppWithBundleIdentifier:options:additionalEventParamDescriptor:launchIdentifier:" },
        { &sel_isHorizontal, "isHorizontal" },
        { &sel_launchPath, "launchPath" },
        { &sel_setTextAlignment_1, "setTextAlignment:" },
        { &sel_initWithBitmapDataPlanes_1pixelsWide_1pixelsHigh_1bitsPerSample_1samplesPerPixel_1hasAlpha_1isPlanar_1colorSpaceName_1bytesPerRow_1bitsPerPixel_1, "initWithBitmapDataPlanes:pixelsWide:pixelsHigh:bitsPerSample:samplesPerPixel:hasAlpha:isPlanar:colorSpaceName:bytesPerRow:bitsPerPixel:" },
        { &sel_setPatternPhase_1, "setPatternPhase:" },
        { &sel_mouseEntered_1withFrame_1inView_1, "mouseEntered:withFrame:inView:" },
        { &sel_matchingFontDescriptorsWithMandatoryKeys_1, "matchingFontDescriptorsWithMandatoryKeys:" },
        { &sel_objectDidEndEditing_1, "objectDidEndEditing:" },
        { &sel_setMaximum_1, "setMaximum:" },
        { &sel_initWithIndexes_1length_1, "initWithIndexes:length:" },
        { &sel_tableView_1shouldShowCellExpansionForTableColumn_1row_1, "tableView:shouldShowCellExpansionForTableColumn:row:" },
        { &sel_moveToPoint_1, "moveToPoint:" },
        { &sel_setGridStyleMask_1, "setGridStyleMask:" },
        { &sel_firstUnlaidGlyphIndex, "firstUnlaidGlyphIndex" },
        { &sel_isProxy, "isProxy" },
        { &sel_takeValue_1forKeyPath_1, "takeValue:forKeyPath:" },
        { &sel_drawCellAtRow_1column_1, "drawCellAtRow:column:" },
        { &sel_setRulerViewClass_1, "setRulerViewClass:" },
        { &sel_objectByApplyingXSLT_1arguments_1error_1, "objectByApplyingXSLT:arguments:error:" },
        { &sel_setArrowPosition_1, "setArrowPosition:" },
        { &sel_setCharacterIndex_1forGlyphAtIndex_1, "setCharacterIndex:forGlyphAtIndex:" },
        { &sel_willChangeValueForKey_1withSetMutation_1usingObjects_1, "willChangeValueForKey:withSetMutation:usingObjects:" },
        { &sel_setVerticalRulerView_1, "setVerticalRulerView:" },
        { &sel_suspendCurrentAppleEvent, "suspendCurrentAppleEvent" },
        { &sel_drawStatusBarBackgroundInRect_1withHighlight_1, "drawStatusBarBackgroundInRect:withHighlight:" },
        { &sel_performClickWithFrame_1inView_1, "performClickWithFrame:inView:" },
        { &sel_coveredCharacterSet, "coveredCharacterSet" },
        { &sel_browser_1numberOfRowsInColumn_1, "browser:numberOfRowsInColumn:" },
        { &sel_isLike_1, "isLike:" },
        { &sel_blackComponent, "blackComponent" },
        { &sel_appendBezierPathWithGlyph_1inFont_1, "appendBezierPathWithGlyph:inFont:" },
        { &sel_validateMenuItem_1, "validateMenuItem:" },
        { &sel_isEqualToIndexSet_1, "isEqualToIndexSet:" },
        { &sel_setBezelStyle_1, "setBezelStyle:" },
        { &sel_scaleUnitSquareToSize_1, "scaleUnitSquareToSize:" },
        { &sel_setStartSubelementIndex_1, "setStartSubelementIndex:" },
        { &sel_frameOfInsideOfColumn_1, "frameOfInsideOfColumn:" },
        { &sel_setBlocksOtherRecognizers_1, "setBlocksOtherRecognizers:" },
        { &sel_setMinSize_1, "setMinSize:" },
        { &sel_setEndSubelementIndex_1, "setEndSubelementIndex:" },
        { &sel_cStringLength, "cStringLength" },
        { &sel_writeWithBackupToFile_1ofType_1saveOperation_1, "writeWithBackupToFile:ofType:saveOperation:" },
        { &sel_setDefaultButtonTitle_1, "setDefaultButtonTitle:" },
        { &sel_setMinContentSize_1, "setMinContentSize:" },
        { &sel_setFormattingDictionary_1, "setFormattingDictionary:" },
        { &sel_boundingRectForFont, "boundingRectForFont" },
        { &sel_postsBoundsChangedNotifications, "postsBoundsChangedNotifications" },
        { &sel_setParagraphs_1, "setParagraphs:" },
        { &sel_setShowsControlCharacters_1, "setShowsControlCharacters:" },
        { &sel_writeSafelyToURL_1ofType_1forSaveOperation_1error_1, "writeSafelyToURL:ofType:forSaveOperation:error:" },
        { &sel_controlLightHighlightColor, "controlLightHighlightColor" },
        { &sel_objectSpecifier, "objectSpecifier" },
        { &sel_dictionaryWithContentsOfURL_1, "dictionaryWithContentsOfURL:" },
        { &sel_performSelector_1onThread_1withObject_1waitUntilDone_1modes_1, "performSelector:onThread:withObject:waitUntilDone:modes:" },
        { &sel_setJobStyleHint_1, "setJobStyleHint:" },
        { &sel_sortedArrayUsingFunction_1context_1, "sortedArrayUsingFunction:context:" },
        { &sel_setBoundsRect_1forTextBlock_1glyphRange_1, "setBoundsRect:forTextBlock:glyphRange:" },
        { &sel_hasShadow, "hasShadow" },
        { &sel_windowShouldClose_1, "windowShouldClose:" },
        { &sel_defaultTokenizingCharacterSet, "defaultTokenizingCharacterSet" },
        { &sel_isRulerVisible, "isRulerVisible" },
        { &sel_setSubrowsKeyPath_1, "setSubrowsKeyPath:" },
        { &sel_animationDelay, "animationDelay" },
        { &sel_selectAll_1, "selectAll:" },
        { &sel_parser_1foundNotationDeclarationWithName_1publicID_1systemID_1, "parser:foundNotationDeclarationWithName:publicID:systemID:" },
        { &sel_readSelectionFromPasteboard_1, "readSelectionFromPasteboard:" },
        { &sel_validateAndReturnError_1, "validateAndReturnError:" },
        { &sel_setScriptErrorOffendingObjectDescriptor_1, "setScriptErrorOffendingObjectDescriptor:" },
        { &sel_makeKeyWindow, "makeKeyWindow" },
        { &sel_itemAtIndex_1, "itemAtIndex:" },
        { &sel_objectAtIndex_1, "objectAtIndex:" },
        { &sel_protectionSpace, "protectionSpace" },
        { &sel_getCString_1, "getCString:" },
        { &sel_initSymbolicLinkWithDestination_1, "initSymbolicLinkWithDestination:" },
        { &sel_daylightSavingTimeOffset, "daylightSavingTimeOffset" },
        { &sel_rangeOfTextList_1atIndex_1, "rangeOfTextList:atIndex:" },
        { &sel_currentDirectory, "currentDirectory" },
        { &sel_windowControllerDidLoadNib_1, "windowControllerDidLoadNib:" },
        { &sel_setGroupingSize_1, "setGroupingSize:" },
        { &sel_subitems, "subitems" },
        { &sel_initWithFileWrapper_1, "initWithFileWrapper:" },
        { &sel_documentVisibleRect, "documentVisibleRect" },
        { &sel_setCount_1, "setCount:" },
        { &sel_setScriptErrorExpectedTypeDescriptor_1, "setScriptErrorExpectedTypeDescriptor:" },
        { &sel_setReleasedWhenClosed_1, "setReleasedWhenClosed:" },
        { &sel_imageUnfilteredTypes, "imageUnfilteredTypes" },
        { &sel_writeToFile_1options_1error_1, "writeToFile:options:error:" },
        { &sel_controlContentFontOfSize_1, "controlContentFontOfSize:" },
        { &sel_insertRow_1withCells_1, "insertRow:withCells:" },
        { &sel_temporaryAttributesAtCharacterIndex_1effectiveRange_1, "temporaryAttributesAtCharacterIndex:effectiveRange:" },
        { &sel_stepForward_1, "stepForward:" },
        { &sel_convertScreenToBase_1, "convertScreenToBase:" },
        { &sel_printerWithType_1, "printerWithType:" },
        { &sel_setSliderType_1, "setSliderType:" },
        { &sel_applicationShouldHandleReopen_1hasVisibleWindows_1, "applicationShouldHandleReopen:hasVisibleWindows:" },
        { &sel_selectedTextAttributes, "selectedTextAttributes" },
        { &sel_setStandardError_1, "setStandardError:" },
        { &sel_drawRect_1, "drawRect:" },
        { &sel_URLs, "URLs" },
        { &sel_animationForKey_1, "animationForKey:" },
        { &sel_setSubviews_1, "setSubviews:" },
        { &sel_setString_1, "setString:" },
        { &sel_openFile_1fromImage_1at_1inView_1, "openFile:fromImage:at:inView:" },
        { &sel_draggedImage, "draggedImage" },
        { &sel_numberOfGlyphs, "numberOfGlyphs" },
        { &sel_itemAtRow_1, "itemAtRow:" },
        { &sel_drawKnob, "drawKnob" },
        { &sel_imageRepsWithData_1, "imageRepsWithData:" },
        { &sel_dragOperationForDraggingInfo_1type_1, "dragOperationForDraggingInfo:type:" },
        { &sel_initWithRTF_1documentAttributes_1, "initWithRTF:documentAttributes:" },
        { &sel_pathsForResourcesOfType_1inDirectory_1, "pathsForResourcesOfType:inDirectory:" },
        { &sel_fontName, "fontName" },
        { &sel_layoutManagers, "layoutManagers" },
        { &sel_error, "error" },
        { &sel_parentWindow, "parentWindow" },
        { &sel_registerClass_1, "registerClass:" },
        { &sel_hideOtherApplications, "hideOtherApplications" },
        { &sel_alphaComponent, "alphaComponent" },
        { &sel_setPrefersColorMatch_1, "setPrefersColorMatch:" },
        { &sel_stopAnimation_1, "stopAnimation:" },
        { &sel_glyphIndexForCharacterAtIndex_1, "glyphIndexForCharacterAtIndex:" },
        { &sel_rulerView_1shouldAddMarker_1, "rulerView:shouldAddMarker:" },
        { &sel_initWithFrame_1, "initWithFrame:" },
        { &sel_init, "init" },
        { &sel_selectedColumnEnumerator, "selectedColumnEnumerator" },
        { &sel_viewWithTag_1, "viewWithTag:" },
        { &sel_classForKeyedUnarchiver, "classForKeyedUnarchiver" },
        { &sel_addRow_1, "addRow:" },
        { &sel_contextHelpForObject_1, "contextHelpForObject:" },
        { &sel_server, "server" },
        { &sel_colorUsingColorSpaceName_1device_1, "colorUsingColorSpaceName:device:" },
        { &sel_valueTransformerForName_1, "valueTransformerForName:" },
        { &sel_soundUnfilteredFileTypes, "soundUnfilteredFileTypes" },
        { &sel_setSelectedTextAttributes_1, "setSelectedTextAttributes:" },
        { &sel_setLeadingOffset_1, "setLeadingOffset:" },
        { &sel_scrollToPoint_1, "scrollToPoint:" },
        { &sel_lastPathComponent, "lastPathComponent" },
        { &sel_lossyCString, "lossyCString" },
        { &sel_registerServicesMenuSendTypes_1returnTypes_1, "registerServicesMenuSendTypes:returnTypes:" },
        { &sel_keyDown_1, "keyDown:" },
        { &sel_setWidthTracksTextView_1, "setWidthTracksTextView:" },
        { &sel_incrementBy_1, "incrementBy:" },
        { &sel_moveWordForward_1, "moveWordForward:" },
        { &sel_dataWithContentsOfMappedFile_1, "dataWithContentsOfMappedFile:" },
        { &sel_socket, "socket" },
        { &sel_EPSOperationWithView_1insideRect_1toData_1printInfo_1, "EPSOperationWithView:insideRect:toData:printInfo:" },
        { &sel_width, "width" },
        { &sel_capabilityMask, "capabilityMask" },
        { &sel_setBezeled_1, "setBezeled:" },
        { &sel_currentMode, "currentMode" },
        { &sel_sliderType, "sliderType" },
        { &sel_fileIsAppendOnly, "fileIsAppendOnly" },
        { &sel_isAutomaticLinkDetectionEnabled, "isAutomaticLinkDetectionEnabled" },
        { &sel_setBoundsOrigin_1, "setBoundsOrigin:" },
        { &sel_selectionHighlightStyle, "selectionHighlightStyle" },
        { &sel_registerName_1, "registerName:" },
        { &sel_moveWordRightAndModifySelection_1, "moveWordRightAndModifySelection:" },
        { &sel_setCharacters_1, "setCharacters:" },
        { &sel_setWordFieldStringValue_1, "setWordFieldStringValue:" },
        { &sel_reverseObjectEnumerator, "reverseObjectEnumerator" },
        { &sel_encodeByrefObject_1, "encodeByrefObject:" },
        { &sel_defaultDecimalNumberHandler, "defaultDecimalNumberHandler" },
        { &sel_isEntryAcceptable_1, "isEntryAcceptable:" },
        { &sel_orderWindow_1relativeTo_1, "orderWindow:relativeTo:" },
        { &sel_writablePasteboardTypes, "writablePasteboardTypes" },
        { &sel_addTrackingRect_1owner_1userData_1assumeInside_1, "addTrackingRect:owner:userData:assumeInside:" },
        { &sel_setPathComponentCells_1, "setPathComponentCells:" },
        { &sel_timeZoneWithName_1, "timeZoneWithName:" },
        { &sel_setAutosaveTableColumns_1, "setAutosaveTableColumns:" },
        { &sel_orPredicateWithSubpredicates_1, "orPredicateWithSubpredicates:" },
        { &sel_isEqualToDictionary_1, "isEqualToDictionary:" },
        { &sel_bottomMargin, "bottomMargin" },
        { &sel_initWithYear_1month_1day_1hour_1minute_1second_1timeZone_1, "initWithYear:month:day:hour:minute:second:timeZone:" },
        { &sel_scrollColumnsLeftBy_1, "scrollColumnsLeftBy:" },
        { &sel_initWithContentsOfURL_1error_1, "initWithContentsOfURL:error:" },
        { &sel_setTabViewType_1, "setTabViewType:" },
        { &sel_initWithFloat_1, "initWithFloat:" },
        { &sel_attributedStringForObjectValue_1withDefaultAttributes_1, "attributedStringForObjectValue:withDefaultAttributes:" },
        { &sel_sharedGlyphGenerator, "sharedGlyphGenerator" },
        { &sel_maximumRangeOfUnit_1, "maximumRangeOfUnit:" },
        { &sel_docFormatFromRange_1documentAttributes_1, "docFormatFromRange:documentAttributes:" },
        { &sel_initWithBitmapImageRep_1, "initWithBitmapImageRep:" },
        { &sel_mnemonic, "mnemonic" },
        { &sel_prefersColorMatch, "prefersColorMatch" },
        { &sel_fileSystemAttributesAtPath_1, "fileSystemAttributesAtPath:" },
        { &sel_rotateByRadians_1, "rotateByRadians:" },
        { &sel_createConversationForConnection_1, "createConversationForConnection:" },
        { &sel_setWindow_1, "setWindow:" },
        { &sel_addFontDescriptors_1toCollection_1, "addFontDescriptors:toCollection:" },
        { &sel_setMark_1, "setMark:" },
        { &sel_terminate, "terminate" },
        { &sel_setTickMarkPosition_1, "setTickMarkPosition:" },
        { &sel_setIgnoresMouseEvents_1, "setIgnoresMouseEvents:" },
        { &sel_pointerArrayWithStrongObjects, "pointerArrayWithStrongObjects" },
        { &sel_intersectsHashTable_1, "intersectsHashTable:" },
        { &sel_initWithTransform_1, "initWithTransform:" },
        { &sel_deviceRGBColorSpace, "deviceRGBColorSpace" },
        { &sel_currentDiskUsage, "currentDiskUsage" },
        { &sel_writeToFile_1ofType_1, "writeToFile:ofType:" },
        { &sel_unionSet_1, "unionSet:" },
        { &sel_bitmapFormat, "bitmapFormat" },
        { &sel_moveItemAtPath_1toPath_1error_1, "moveItemAtPath:toPath:error:" },
        { &sel_tableView, "tableView" },
        { &sel_performSelectorOnMainThread_1withObject_1waitUntilDone_1modes_1, "performSelectorOnMainThread:withObject:waitUntilDone:modes:" },
        { &sel_initAndTestWithTests_1, "initAndTestWithTests:" },
        { &sel_setVerticalMotionCanBeginDrag_1, "setVerticalMotionCanBeginDrag:" },
        { &sel_documentClassNames, "documentClassNames" },
        { &sel_setShadow_1, "setShadow:" },
        { &sel_beginLineWithGlyphAtIndex_1, "beginLineWithGlyphAtIndex:" },
        { &sel_predicateWithSubstitutionVariables_1, "predicateWithSubstitutionVariables:" },
        { &sel_EPSOperationWithView_1insideRect_1toPath_1printInfo_1, "EPSOperationWithView:insideRect:toPath:printInfo:" },
        { &sel_startSubelementIndex, "startSubelementIndex" },
        { &sel_sleepUntilDate_1, "sleepUntilDate:" },
        { &sel_menuForEvent_1, "menuForEvent:" },
        { &sel_disabledControlTextColor, "disabledControlTextColor" },
        { &sel_addRegularFileWithContents_1preferredFilename_1, "addRegularFileWithContents:preferredFilename:" },
        { &sel_setTakesTitleFromPreviousColumn_1, "setTakesTitleFromPreviousColumn:" },
        { &sel_removeSelectionIndexes_1, "removeSelectionIndexes:" },
        { &sel_resizedColumn, "resizedColumn" },
        { &sel_host, "host" },
        { &sel_setDefaultAttachmentScaling_1, "setDefaultAttachmentScaling:" },
        { &sel_boundingRectWithSize_1options_1, "boundingRectWithSize:options:" },
        { &sel_magentaColor, "magentaColor" },
        { &sel_performDefaultImplementation, "performDefaultImplementation" },
        { &sel_getPeriodicDelay_1interval_1, "getPeriodicDelay:interval:" },
        { &sel_RTFFromRange_1, "RTFFromRange:" },
        { &sel_setStringValue_1, "setStringValue:" },
        { &sel_setPaletteLabel_1, "setPaletteLabel:" },
        { &sel_years_1months_1days_1hours_1minutes_1seconds_1sinceDate_1, "years:months:days:hours:minutes:seconds:sinceDate:" },
        { &sel_initWithFormat_1arguments_1, "initWithFormat:arguments:" },
        { &sel_firstUnlaidCharacterIndex, "firstUnlaidCharacterIndex" },
        { &sel_panelSelectionDidChange_1, "panelSelectionDidChange:" },
        { &sel_typesFilterableTo_1, "typesFilterableTo:" },
        { &sel_selectPreviousTabViewItem_1, "selectPreviousTabViewItem:" },
        { &sel_URLProtocol_1didReceiveResponse_1cacheStoragePolicy_1, "URLProtocol:didReceiveResponse:cacheStoragePolicy:" },
        { &sel_loadView, "loadView" },
        { &sel_setPositiveSuffix_1, "setPositiveSuffix:" },
        { &sel_setSizeMode_1, "setSizeMode:" },
        { &sel_addValue_1forHTTPHeaderField_1, "addValue:forHTTPHeaderField:" },
        { &sel_replacementObjectForPortCoder_1, "replacementObjectForPortCoder:" },
        { &sel_cycleToNextInputLanguage_1, "cycleToNextInputLanguage:" },
        { &sel_setContentMinSize_1, "setContentMinSize:" },
        { &sel_convertWeight_1ofFont_1, "convertWeight:ofFont:" },
        { &sel_code, "code" },
        { &sel_TIFFRepresentationUsingCompression_1factor_1, "TIFFRepresentationUsingCompression:factor:" },
        { &sel_setSelector_1, "setSelector:" },
        { &sel_URLHandleResourceDidCancelLoading_1, "URLHandleResourceDidCancelLoading:" },
        { &sel_setTag_1forSegment_1, "setTag:forSegment:" },
        { &sel_viewFrameChanged_1, "viewFrameChanged:" },
        { &sel_attachmentCell, "attachmentCell" },
        { &sel_removeStatusItem_1, "removeStatusItem:" },
        { &sel_pathForAuxiliaryExecutable_1, "pathForAuxiliaryExecutable:" },
        { &sel_fileURL, "fileURL" },
        { &sel_drawerShouldOpen_1, "drawerShouldOpen:" },
        { &sel_initForWritingWithMutableData_1, "initForWritingWithMutableData:" },
        { &sel_content, "content" },
        { &sel_addSubview_1, "addSubview:" },
        { &sel_stringByReplacingOccurrencesOfString_1withString_1, "stringByReplacingOccurrencesOfString:withString:" },
        { &sel_stringWithFileSystemRepresentation_1length_1, "stringWithFileSystemRepresentation:length:" },
        { &sel_isVerticallyCentered, "isVerticallyCentered" },
        { &sel_setVerticallyCentered_1, "setVerticallyCentered:" },
        { &sel_selectPrevious_1, "selectPrevious:" },
        { &sel_addTemporaryAttributes_1forCharacterRange_1, "addTemporaryAttributes:forCharacterRange:" },
        { &sel_tabState, "tabState" },
        { &sel_defaultQueue, "defaultQueue" },
        { &sel_showsControlCharacters, "showsControlCharacters" },
        { &sel_indexOfObject_1, "indexOfObject:" },
        { &sel_shadow, "shadow" },
        { &sel_fontMenu_1, "fontMenu:" },
        { &sel_movePath_1toPath_1handler_1, "movePath:toPath:handler:" },
        { &sel_setDictionary_1, "setDictionary:" },
        { &sel_verticalLineScroll, "verticalLineScroll" },
        { &sel_showsAlpha, "showsAlpha" },
        { &sel_removeObserver_1, "removeObserver:" },
        { &sel_isFieldEditor, "isFieldEditor" },
        { &sel_fileHandleForWriting, "fileHandleForWriting" },
        { &sel_contentsAtPath_1, "contentsAtPath:" },
        { &sel_writeProperty_1forKey_1, "writeProperty:forKey:" },
        { &sel_drawWithRect_1options_1attributes_1, "drawWithRect:options:attributes:" },
        { &sel_initWithName_1, "initWithName:" },
        { &sel_getFileSystemInfoForPath_1isRemovable_1isWritable_1isUnmountable_1description_1type_1, "getFileSystemInfoForPath:isRemovable:isWritable:isUnmountable:description:type:" },
        { &sel_setOpenGLContext_1, "setOpenGLContext:" },
        { &sel_hasSubmenu, "hasSubmenu" },
        { &sel_rangeOfTextTable_1atIndex_1, "rangeOfTextTable:atIndex:" },
        { &sel_connection_1willCacheResponse_1, "connection:willCacheResponse:" },
        { &sel_automaticallyRearrangesObjects, "automaticallyRearrangesObjects" },
        { &sel_registerCommandDescription_1, "registerCommandDescription:" },
        { &sel_indexOfSelectedItem, "indexOfSelectedItem" },
        { &sel_underline_1, "underline:" },
        { &sel_beginModalSessionForWindow_1relativeToWindow_1, "beginModalSessionForWindow:relativeToWindow:" },
        { &sel_initWithData_1options_1documentAttributes_1error_1, "initWithData:options:documentAttributes:error:" },
        { &sel_revert_1, "revert:" },
        { &sel_displayableSubpredicatesOfPredicate_1, "displayableSubpredicatesOfPredicate:" },
        { &sel_dataWithData_1, "dataWithData:" },
        { &sel_scaleXBy_1yBy_1, "scaleXBy:yBy:" },
        { &sel_decodeBoolForKey_1, "decodeBoolForKey:" },
        { &sel_itemTitles, "itemTitles" },
        { &sel_removeFontDescriptor_1fromCollection_1, "removeFontDescriptor:fromCollection:" },
        { &sel_isContinuousSpellCheckingEnabled, "isContinuousSpellCheckingEnabled" },
        { &sel_paragraphSpacingBeforeGlyphAtIndex_1withProposedLineFragmentRect_1, "paragraphSpacingBeforeGlyphAtIndex:withProposedLineFragmentRect:" },
        { &sel_ignoreSpelling_1, "ignoreSpelling:" },
        { &sel_crosshairCursor, "crosshairCursor" },
        { &sel_setSelected_1, "setSelected:" },
        { &sel_RTFDFromRange_1, "RTFDFromRange:" },
        { &sel_setCanSelectHiddenExtension_1, "setCanSelectHiddenExtension:" },
        { &sel_setNestingMode_1, "setNestingMode:" },
        { &sel_addItemsWithObjectValues_1, "addItemsWithObjectValues:" },
        { &sel_setContentFilters_1, "setContentFilters:" },
        { &sel_setAutorepeat_1, "setAutorepeat:" },
        { &sel_resizeWithOldSuperviewSize_1, "resizeWithOldSuperviewSize:" },
        { &sel_areCursorRectsEnabled, "areCursorRectsEnabled" },
        { &sel_browser_1selectCellWithString_1inColumn_1, "browser:selectCellWithString:inColumn:" },
        { &sel_setLastColumn_1, "setLastColumn:" },
        { &sel_isContextHelpModeActive, "isContextHelpModeActive" },
        { &sel_setTitleColor_1, "setTitleColor:" },
        { &sel_initWithBytes_1length_1, "initWithBytes:length:" },
        { &sel_animation_1valueForProgress_1, "animation:valueForProgress:" },
        { &sel_fillColor, "fillColor" },
        { &sel_completionsForPartialWordRange_1inString_1language_1inSpellDocumentWithTag_1, "completionsForPartialWordRange:inString:language:inSpellDocumentWithTag:" },
        { &sel_typeForContentsOfURL_1error_1, "typeForContentsOfURL:error:" },
        { &sel_setShowPanels_1, "setShowPanels:" },
        { &sel_outlineView_1dataCellForTableColumn_1item_1, "outlineView:dataCellForTableColumn:item:" },
        { &sel_setLineJoinStyle_1, "setLineJoinStyle:" },
        { &sel_cancelPerformSelectorsWithTarget_1, "cancelPerformSelectorsWithTarget:" },
        { &sel_nextDaylightSavingTimeTransition, "nextDaylightSavingTimeTransition" },
        { &sel_setEndSubelementIdentifier_1, "setEndSubelementIdentifier:" },
        { &sel_channelMapping, "channelMapping" },
        { &sel_setTitle_1ofColumn_1, "setTitle:ofColumn:" },
        { &sel_setHeaderToolTip_1, "setHeaderToolTip:" },
        { &sel_initWithChar_1, "initWithChar:" },
        { &sel_shouldReportNamespacePrefixes, "shouldReportNamespacePrefixes" },
        { &sel_decomposedStringWithCompatibilityMapping, "decomposedStringWithCompatibilityMapping" },
        { &sel_undoActionName, "undoActionName" },
        { &sel_attachColorList_1, "attachColorList:" },
        { &sel_cancelPreviousPerformRequestsWithTarget_1, "cancelPreviousPerformRequestsWithTarget:" },
        { &sel_addToolTipRect_1owner_1userData_1, "addToolTipRect:owner:userData:" },
        { &sel_isOptionalArgumentWithName_1, "isOptionalArgumentWithName:" },
        { &sel_fileHandleForReading, "fileHandleForReading" },
        { &sel_removeConnection_1fromRunLoop_1forMode_1, "removeConnection:fromRunLoop:forMode:" },
        { &sel_controlTextDidBeginEditing_1, "controlTextDidBeginEditing:" },
        { &sel_closePath, "closePath" },
        { &sel_isPlaying, "isPlaying" },
        { &sel_matrixClass, "matrixClass" },
        { &sel_doCommandBySelector_1client_1, "doCommandBySelector:client:" },
        { &sel_appendBytes_1length_1, "appendBytes:length:" },
        { &sel_lightGrayColor, "lightGrayColor" },
        { &sel_menuRepresentation, "menuRepresentation" },
        { &sel_dateWithString_1calendarFormat_1, "dateWithString:calendarFormat:" },
        { &sel_decodeClassName_1asClassName_1, "decodeClassName:asClassName:" },
        { &sel_deleteToBeginningOfParagraph_1, "deleteToBeginningOfParagraph:" },
        { &sel_runModalForDirectory_1file_1, "runModalForDirectory:file:" },
        { &sel_inverseForRelationshipKey_1, "inverseForRelationshipKey:" },
        { &sel_cancelLoadInBackground, "cancelLoadInBackground" },
        { &sel_setLeftMargin_1, "setLeftMargin:" },
        { &sel_tabStopType, "tabStopType" },
        { &sel_replaceCharactersInRange_1withRTF_1, "replaceCharactersInRange:withRTF:" },
        { &sel_drawInRect_1fromRect_1operation_1fraction_1, "drawInRect:fromRect:operation:fraction:" },
        { &sel_sound, "sound" },
        { &sel_localizedRecoverySuggestion, "localizedRecoverySuggestion" },
        { &sel_getInputStream_1outputStream_1, "getInputStream:outputStream:" },
        { &sel_defaultType, "defaultType" },
        { &sel_sharedFontPanel, "sharedFontPanel" },
        { &sel_fixParagraphStyleAttributeInRange_1, "fixParagraphStyleAttributeInRange:" },
        { &sel_textColor, "textColor" },
        { &sel_noteFileSystemChanged, "noteFileSystemChanged" },
        { &sel_setObject_1forKey_1, "setObject:forKey:" },
        { &sel_drawAtPoint_1, "drawAtPoint:" },
        { &sel_tableView_1shouldSelectTableColumn_1, "tableView:shouldSelectTableColumn:" },
        { &sel_deleteWordBackward_1, "deleteWordBackward:" },
        { &sel_pipe, "pipe" },
        { &sel_resetStandardUserDefaults, "resetStandardUserDefaults" },
        { &sel_orderFrontSpacingPanel_1, "orderFrontSpacingPanel:" },
        { &sel_setUsesFontPanel_1, "setUsesFontPanel:" },
        { &sel_saveToURL_1ofType_1forSaveOperation_1delegate_1didSaveSelector_1contextInfo_1, "saveToURL:ofType:forSaveOperation:delegate:didSaveSelector:contextInfo:" },
        { &sel_linkPath_1toPath_1handler_1, "linkPath:toPath:handler:" },
        { &sel_addTimeInterval_1, "addTimeInterval:" },
        { &sel_formattingDictionary, "formattingDictionary" },
        { &sel_ignoresMultiClick, "ignoresMultiClick" },
        { &sel_encodeValuesOfObjCTypes_1, "encodeValuesOfObjCTypes:" },
        { &sel_indexAtPosition_1, "indexAtPosition:" },
        { &sel_autoresizesSubviews, "autoresizesSubviews" },
        { &sel_takesTitleFromPreviousColumn, "takesTitleFromPreviousColumn" },
        { &sel_titlePosition, "titlePosition" },
        { &sel_currentAppleEvent, "currentAppleEvent" },
        { &sel_valueForDimension_1, "valueForDimension:" },
        { &sel_printDocumentWithSettings_1showPrintPanel_1delegate_1didPrintSelector_1contextInfo_1, "printDocumentWithSettings:showPrintPanel:delegate:didPrintSelector:contextInfo:" },
        { &sel_isZoomable, "isZoomable" },
        { &sel_setNeedsDisplay, "setNeedsDisplay" },
        { &sel_initWithColors_1, "initWithColors:" },
        { &sel_isSubclassOfClass_1, "isSubclassOfClass:" },
        { &sel_adobeRGB1998ColorSpace, "adobeRGB1998ColorSpace" },
        { &sel_textView_1willChangeSelectionFromCharacterRange_1toCharacterRange_1, "textView:willChangeSelectionFromCharacterRange:toCharacterRange:" },
        { &sel_useAllLigatures_1, "useAllLigatures:" },
        { &sel_setFrameUsingName_1force_1, "setFrameUsingName:force:" },
        { &sel_percentSymbol, "percentSymbol" },
        { &sel_addRepresentations_1, "addRepresentations:" },
        { &sel_writeEPSInsideRect_1toPasteboard_1, "writeEPSInsideRect:toPasteboard:" },
        { &sel_systemFontSize, "systemFontSize" },
        { &sel_canRemoveAllRows, "canRemoveAllRows" },
        { &sel_endLineWithGlyphRange_1, "endLineWithGlyphRange:" },
        { &sel_maxItemSize, "maxItemSize" },
        { &sel_setImageScaling_1forSegment_1, "setImageScaling:forSegment:" },
        { &sel_reloadDefaultFontFamilies, "reloadDefaultFontFamilies" },
        { &sel_removeRow_1, "removeRow:" },
        { &sel_contentSize, "contentSize" },
        { &sel_setValueTransformer_1forName_1, "setValueTransformer:forName:" },
        { &sel_defaultCStringEncoding, "defaultCStringEncoding" },
        { &sel_setMaxNumberOfRows_1, "setMaxNumberOfRows:" },
        { &sel_continueWithoutCredentialForAuthenticationChallenge_1, "continueWithoutCredentialForAuthenticationChallenge:" },
        { &sel_encodeArrayOfObjCType_1count_1at_1, "encodeArrayOfObjCType:count:at:" },
        { &sel_tabStops, "tabStops" },
        { &sel_altIncrementValue, "altIncrementValue" },
        { &sel_removeAttribute_1range_1, "removeAttribute:range:" },
        { &sel_rightExpressionAttributeType, "rightExpressionAttributeType" },
        { &sel_setAutoresizesAllColumnsToFit_1, "setAutoresizesAllColumnsToFit:" },
        { &sel_removeAllToolTips, "removeAllToolTips" },
        { &sel_setNotANumberSymbol_1, "setNotANumberSymbol:" },
        { &sel_setMinWidth_1, "setMinWidth:" },
        { &sel_setDefaultTimeZone_1, "setDefaultTimeZone:" },
        { &sel_setTabStops_1, "setTabStops:" },
        { &sel_textView_1draggedCell_1inRect_1event_1, "textView:draggedCell:inRect:event:" },
        { &sel_PDFOperationWithView_1insideRect_1toData_1, "PDFOperationWithView:insideRect:toData:" },
        { &sel_outlineView_1selectionIndexesForProposedSelection_1, "outlineView:selectionIndexesForProposedSelection:" },
        { &sel_initWithContentsOfURL_1, "initWithContentsOfURL:" },
        { &sel_setBidiProcessingEnabled_1, "setBidiProcessingEnabled:" },
        { &sel_selectToMark_1, "selectToMark:" },
        { &sel_newlineCharacterSet, "newlineCharacterSet" },
        { &sel_accessibilitySetOverrideValue_1forAttribute_1, "accessibilitySetOverrideValue:forAttribute:" },
        { &sel_setPostsFrameChangedNotifications_1, "setPostsFrameChangedNotifications:" },
        { &sel_cellPrototype, "cellPrototype" },
        { &sel_unmarkText, "unmarkText" },
        { &sel_displayValuesKeyPath, "displayValuesKeyPath" },
        { &sel_orderFrontStylesPanel_1, "orderFrontStylesPanel:" },
        { &sel_getBuffer_1length_1, "getBuffer:length:" },
        { &sel_calcDrawInfo_1, "calcDrawInfo:" },
        { &sel_initWithUTF8String_1, "initWithUTF8String:" },
        { &sel_deselectAllCells, "deselectAllCells" },
        { &sel_checkGrammarOfString_1startingAt_1language_1wrap_1inSpellDocumentWithTag_1details_1, "checkGrammarOfString:startingAt:language:wrap:inSpellDocumentWithTag:details:" },
        { &sel_poolCountHighWaterResolution, "poolCountHighWaterResolution" },
        { &sel_canInitWithData_1, "canInitWithData:" },
        { &sel_setHasVerticalScroller_1, "setHasVerticalScroller:" },
        { &sel_flushHostCache, "flushHostCache" },
        { &sel_toolbarDefaultItemIdentifiers_1, "toolbarDefaultItemIdentifiers:" },
        { &sel_setSearchButtonCell_1, "setSearchButtonCell:" },
        { &sel_defaultButtonCell, "defaultButtonCell" },
        { &sel_sizeLastColumnToFit, "sizeLastColumnToFit" },
        { &sel_addColumn, "addColumn" },
        { &sel_failureResponse, "failureResponse" },
        { &sel_insertTabIgnoringFieldEditor_1, "insertTabIgnoringFieldEditor:" },
        { &sel_locationForGlyphAtIndex_1, "locationForGlyphAtIndex:" },
        { &sel_insertContainerBreak_1, "insertContainerBreak:" },
        { &sel_setAutosizesCells_1, "setAutosizesCells:" },
        { &sel_isEditable, "isEditable" },
        { &sel_path, "path" },
        { &sel_setStringValue_1resolvingEntities_1, "setStringValue:resolvingEntities:" },
        { &sel_readFileContentsType_1toFile_1, "readFileContentsType:toFile:" },
        { &sel_fileExtensionHidden, "fileExtensionHidden" },
        { &sel_setTextureImageToPixelBuffer_1colorBuffer_1, "setTextureImageToPixelBuffer:colorBuffer:" },
        { &sel_setFilename_1, "setFilename:" },
        { &sel_callStackReturnAddresses, "callStackReturnAddresses" },
        { &sel_blocksOtherRecognizers, "blocksOtherRecognizers" },
        { &sel_pixelBuffer, "pixelBuffer" },
        { &sel_initWithStartingColor_1endingColor_1, "initWithStartingColor:endingColor:" },
        { &sel_indexOfObjectIdenticalTo_1inRange_1, "indexOfObjectIdenticalTo:inRange:" },
        { &sel_duration, "duration" },
        { &sel_matchForPredicate_1, "matchForPredicate:" },
        { &sel_windowDidMiniaturize_1, "windowDidMiniaturize:" },
        { &sel_drawWithFrame_1inView_1characterIndex_1layoutManager_1, "drawWithFrame:inView:characterIndex:layoutManager:" },
        { &sel_setTwoDigitStartDate_1, "setTwoDigitStartDate:" },
        { &sel_selectTextAtRow_1column_1, "selectTextAtRow:column:" },
        { &sel_splitView_1shouldHideDividerAtIndex_1, "splitView:shouldHideDividerAtIndex:" },
        { &sel_isExcludedFromWindowsMenu, "isExcludedFromWindowsMenu" },
        { &sel_earlierDate_1, "earlierDate:" },
        { &sel_initWithLeftExpressions_1rightExpressionAttributeType_1modifier_1operators_1options_1, "initWithLeftExpressions:rightExpressionAttributeType:modifier:operators:options:" },
        { &sel_minItemSize, "minItemSize" },
        { &sel_setSearchMenuTemplate_1, "setSearchMenuTemplate:" },
        { &sel_rightMouseUp_1, "rightMouseUp:" },
        { &sel_stopSpeaking_1, "stopSpeaking:" },
        { &sel_getObjectValue_1forString_1errorDescription_1, "getObjectValue:forString:errorDescription:" },
        { &sel_unarchiver_1didDecodeObject_1, "unarchiver:didDecodeObject:" },
        { &sel_endSpecifier, "endSpecifier" },
        { &sel_ascending, "ascending" },
        { &sel_sharedCoercionHandler, "sharedCoercionHandler" },
        { &sel_textAttributesForPositiveInfinity, "textAttributesForPositiveInfinity" },
        { &sel_isEqualToData_1, "isEqualToData:" },
        { &sel_setHighlightMode_1, "setHighlightMode:" },
        { &sel_valueWithNonretainedObject_1, "valueWithNonretainedObject:" },
        { &sel_textAttributesForNotANumber, "textAttributesForNotANumber" },
        { &sel_getCFRunLoop, "getCFRunLoop" },
        { &sel_invalidateGlyphsForCharacterRange_1changeInLength_1actualCharacterRange_1, "invalidateGlyphsForCharacterRange:changeInLength:actualCharacterRange:" },
        { &sel_cachedResponse, "cachedResponse" },
        { &sel_containerIsRangeContainerObject, "containerIsRangeContainerObject" },
        { &sel_setLanguage_1, "setLanguage:" },
        { &sel_loadNibFile_1externalNameTable_1withZone_1, "loadNibFile:externalNameTable:withZone:" },
        { &sel_offsetInFile, "offsetInFile" },
        { &sel_initWithRulerView_1markerLocation_1image_1imageOrigin_1, "initWithRulerView:markerLocation:image:imageOrigin:" },
        { &sel_commandDescriptionWithAppleEventClass_1andAppleEventCode_1, "commandDescriptionWithAppleEventClass:andAppleEventCode:" },
        { &sel_detachDrawingThread_1toTarget_1withObject_1, "detachDrawingThread:toTarget:withObject:" },
        { &sel_outlineView_1shouldShowCellExpansionForTableColumn_1item_1, "outlineView:shouldShowCellExpansionForTableColumn:item:" },
        { &sel_catalogNameComponent, "catalogNameComponent" },
        { &sel_monthSymbols, "monthSymbols" },
        { &sel_invalidateShadow, "invalidateShadow" },
        { &sel_waitUntilDate_1, "waitUntilDate:" },
        { &sel_languageLevel, "languageLevel" },
        { &sel_XMLData, "XMLData" },
        { &sel_textView_1shouldChangeTextInRanges_1replacementStrings_1, "textView:shouldChangeTextInRanges:replacementStrings:" },
        { &sel_initWithPointerFunctions_1, "initWithPointerFunctions:" },
        { &sel_initWithTextureTarget_1textureInternalFormat_1textureMaxMipMapLevel_1pixelsWide_1pixelsHigh_1, "initWithTextureTarget:textureInternalFormat:textureMaxMipMapLevel:pixelsWide:pixelsHigh:" },
        { &sel_classForClassName_1, "classForClassName:" },
        { &sel_decodeInt64ForKey_1, "decodeInt64ForKey:" },
        { &sel_stringWithSavedFrame, "stringWithSavedFrame" },
        { &sel_writeRTFDToFile_1atomically_1, "writeRTFDToFile:atomically:" },
        { &sel_initWithLocal_1connection_1, "initWithLocal:connection:" },
        { &sel_sendBeforeDate_1msgid_1components_1from_1reserved_1, "sendBeforeDate:msgid:components:from:reserved:" },
        { &sel_playsEveryFrame, "playsEveryFrame" },
        { &sel_prependTransform_1, "prependTransform:" },
        { &sel_setUsesWeakReadAndWriteBarriers_1, "setUsesWeakReadAndWriteBarriers:" },
        { &sel_isContinuous, "isContinuous" },
        { &sel_andPredicateWithSubpredicates_1, "andPredicateWithSubpredicates:" },
        { &sel_cookieWithProperties_1, "cookieWithProperties:" },
        { &sel_builtInPlugInsPath, "builtInPlugInsPath" },
        { &sel_performSelector_1onThread_1withObject_1waitUntilDone_1, "performSelector:onThread:withObject:waitUntilDone:" },
        { &sel_sharedDocumentController, "sharedDocumentController" },
        { &sel_setNeedsSizing_1, "setNeedsSizing:" },
        { &sel_selectorForCommand_1, "selectorForCommand:" },
        { &sel_displayIfNeededInRectIgnoringOpacity_1, "displayIfNeededInRectIgnoringOpacity:" },
        { &sel_draggingPasteboard, "draggingPasteboard" },
        { &sel_unscriptRange_1, "unscriptRange:" },
        { &sel_launchApplication_1, "launchApplication:" },
        { &sel_inputClientBecomeActive_1, "inputClientBecomeActive:" },
        { &sel_getFirstUnlaidCharacterIndex_1glyphIndex_1, "getFirstUnlaidCharacterIndex:glyphIndex:" },
        { &sel_initWithContentsOfURL_1options_1error_1, "initWithContentsOfURL:options:error:" },
        { &sel_createSymbolicLinkAtPath_1withDestinationPath_1error_1, "createSymbolicLinkAtPath:withDestinationPath:error:" },
        { &sel_accessibilityAttributeValue_1forParameter_1, "accessibilityAttributeValue:forParameter:" },
        { &sel_setPlaceholderAttributedString_1, "setPlaceholderAttributedString:" },
        { &sel_initWithIndex_1, "initWithIndex:" },
        { &sel_readFromURL_1ofType_1error_1, "readFromURL:ofType:error:" },
        { &sel_preferredFilename, "preferredFilename" },
        { &sel_smartInsertDeleteEnabled, "smartInsertDeleteEnabled" },
        { &sel_horizontalLineScroll, "horizontalLineScroll" },
        { &sel_doDoubleClick_1, "doDoubleClick:" },
        { &sel_fontDescriptorWithFace_1, "fontDescriptorWithFace:" },
        { &sel_pointerArrayWithPointerFunctions_1, "pointerArrayWithPointerFunctions:" },
        { &sel_defaultDate, "defaultDate" },
        { &sel_typesetterBehavior, "typesetterBehavior" },
        { &sel_setAllowsNonContiguousLayout_1, "setAllowsNonContiguousLayout:" },
        { &sel_control_1didFailToFormatString_1errorDescription_1, "control:didFailToFormatString:errorDescription:" },
        { &sel_isBaseFont, "isBaseFont" },
        { &sel_removeDescriptorWithKeyword_1, "removeDescriptorWithKeyword:" },
        { &sel_substringFromIndex_1, "substringFromIndex:" },
        { &sel_componentsFromLocaleIdentifier_1, "componentsFromLocaleIdentifier:" },
        { &sel_setUsesFeedbackWindow_1, "setUsesFeedbackWindow:" },
        { &sel_setAnimates_1, "setAnimates:" },
        { &sel_initWithDomain_1code_1userInfo_1, "initWithDomain:code:userInfo:" },
        { &sel_setContentView_1, "setContentView:" },
        { &sel_allowedFileTypes, "allowedFileTypes" },
        { &sel_leftExpressions, "leftExpressions" },
        { &sel_isStandalone, "isStandalone" },
        { &sel_floatForKey_1inTable_1, "floatForKey:inTable:" },
        { &sel_notANumber, "notANumber" },
        { &sel_updateFromPMPrintSettings, "updateFromPMPrintSettings" },
        { &sel_wantsToTrackMouse, "wantsToTrackMouse" },
        { &sel_initWithName_1reason_1userInfo_1, "initWithName:reason:userInfo:" },
        { &sel_prepareOpenGL, "prepareOpenGL" },
        { &sel_setAttributedStringForNil_1, "setAttributedStringForNil:" },
        { &sel_sizeToFit, "sizeToFit" },
        { &sel_setSortDescriptorPrototype_1, "setSortDescriptorPrototype:" },
        { &sel_canHide, "canHide" },
        { &sel_replacementObjectForArchiver_1, "replacementObjectForArchiver:" },
        { &sel_purpleColor, "purpleColor" },
        { &sel_setProperty_1forKey_1, "setProperty:forKey:" },
        { &sel_separatorItem, "separatorItem" },
        { &sel_loadedCellAtRow_1column_1, "loadedCellAtRow:column:" },
        { &sel_containerSpecifier, "containerSpecifier" },
        { &sel_draggingSourceOperationMaskForLocal_1, "draggingSourceOperationMaskForLocal:" },
        { &sel_willPresentError_1, "willPresentError:" },
        { &sel_strikethroughGlyphRange_1strikethroughType_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1, "strikethroughGlyphRange:strikethroughType:lineFragmentRect:lineFragmentGlyphRange:containerOrigin:" },
        { &sel_elementWithName_1stringValue_1, "elementWithName:stringValue:" },
        { &sel_unsignedCharValue, "unsignedCharValue" },
        { &sel_rangeOfComposedCharacterSequencesForRange_1, "rangeOfComposedCharacterSequencesForRange:" },
        { &sel_activate_1, "activate:" },
        { &sel_controlView, "controlView" },
        { &sel_cachePolicy, "cachePolicy" },
        { &sel_fontAttributesInRange_1, "fontAttributesInRange:" },
        { &sel_setPreservesSelection_1, "setPreservesSelection:" },
        { &sel_unscript_1, "unscript:" },
        { &sel_deltaZ, "deltaZ" },
        { &sel_connection_1handleRequest_1, "connection:handleRequest:" },
        { &sel_caseSensitive, "caseSensitive" },
        { &sel_tabViewItemAtPoint_1, "tabViewItemAtPoint:" },
        { &sel_setTextAttributesForNegativeValues_1, "setTextAttributesForNegativeValues:" },
        { &sel_underlineGlyphRange_1underlineType_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1, "underlineGlyphRange:underlineType:lineFragmentRect:lineFragmentGlyphRange:containerOrigin:" },
        { &sel_classForCoder, "classForCoder" },
        { &sel_setContent_1, "setContent:" },
        { &sel_getLineStart_1end_1contentsEnd_1forRange_1, "getLineStart:end:contentsEnd:forRange:" },
        { &sel_removeRowsAtIndexes_1includeSubrows_1, "removeRowsAtIndexes:includeSubrows:" },
        { &sel_tokenFieldCell_1styleForRepresentedObject_1, "tokenFieldCell:styleForRepresentedObject:" },
        { &sel_setToolTip_1, "setToolTip:" },
        { &sel_titleHeight, "titleHeight" },
        { &sel_setShowsStateBy_1, "setShowsStateBy:" },
        { &sel_URLWithString_1relativeToURL_1, "URLWithString:relativeToURL:" },
        { &sel_fileSystemRepresentationWithPath_1, "fileSystemRepresentationWithPath:" },
        { &sel_setRate_1, "setRate:" },
        { &sel_extraLineFragmentTextContainer, "extraLineFragmentTextContainer" },
        { &sel_insertObjects_1atArrangedObjectIndexes_1, "insertObjects:atArrangedObjectIndexes:" },
        { &sel_fontDescriptorWithSymbolicTraits_1, "fontDescriptorWithSymbolicTraits:" },
        { &sel_topMargin, "topMargin" },
        { &sel_tokenField_1representedObjectForEditingString_1, "tokenField:representedObjectForEditingString:" },
        { &sel_drawInsertionPointInRect_1color_1turnedOn_1, "drawInsertionPointInRect:color:turnedOn:" },
        { &sel_fontNamed_1hasTraits_1, "fontNamed:hasTraits:" },
        { &sel_revertToSavedFromFile_1ofType_1, "revertToSavedFromFile:ofType:" },
        { &sel_cString, "cString" },
        { &sel_markerForItemNumber_1, "markerForItemNumber:" },
        { &sel_mapTableWithWeakToStrongObjects, "mapTableWithWeakToStrongObjects" },
        { &sel_autosaveExpandedItems, "autosaveExpandedItems" },
        { &sel_setMiterLimit_1, "setMiterLimit:" },
        { &sel_indentationLevel, "indentationLevel" },
        { &sel_fileHandleForUpdatingAtPath_1, "fileHandleForUpdatingAtPath:" },
        { &sel_fontWithDescriptor_1textTransform_1, "fontWithDescriptor:textTransform:" },
        { &sel_selectLine_1, "selectLine:" },
        { &sel_deleteForward_1, "deleteForward:" },
        { &sel_getAdvancements_1forPackedGlyphs_1length_1, "getAdvancements:forPackedGlyphs:length:" },
        { &sel_usesRuler, "usesRuler" },
        { &sel_performClose_1, "performClose:" },
        { &sel_trackRect, "trackRect" },
        { &sel_setFont_1, "setFont:" },
        { &sel_conformsToProtocol_1, "conformsToProtocol:" },
        { &sel_appendBezierPathWithPoints_1count_1, "appendBezierPathWithPoints:count:" },
        { &sel_defaultLineHeightForFont_1, "defaultLineHeightForFont:" },
        { &sel_mouse_1inRect_1, "mouse:inRect:" },
        { &sel_portCoderWithReceivePort_1sendPort_1components_1, "portCoderWithReceivePort:sendPort:components:" },
        { &sel_inputClientDisabled_1, "inputClientDisabled:" },
        { &sel_widthForSegment_1, "widthForSegment:" },
        { &sel_performSelector_1, "performSelector:" },
        { &sel_recalculateKeyViewLoop, "recalculateKeyViewLoop" },
        { &sel_initWithDrawSelector_1delegate_1, "initWithDrawSelector:delegate:" },
        { &sel_breakUndoCoalescing, "breakUndoCoalescing" },
        { &sel_font, "font" },
        { &sel_fontDescriptorWithSize_1, "fontDescriptorWithSize:" },
        { &sel_insertItemWithTitle_1atIndex_1, "insertItemWithTitle:atIndex:" },
        { &sel_contentAspectRatio, "contentAspectRatio" },
        { &sel_currentHandler, "currentHandler" },
        { &sel_sharedAppleEventManager, "sharedAppleEventManager" },
        { &sel_pathForResource_1ofType_1, "pathForResource:ofType:" },
        { &sel_initWithRequest_1cachedResponse_1client_1, "initWithRequest:cachedResponse:client:" },
        { &sel_isTitled, "isTitled" },
        { &sel_drawerWillOpen_1, "drawerWillOpen:" },
        { &sel_screenFont, "screenFont" },
        { &sel_principalClass, "principalClass" },
        { &sel_pathControl_1willDisplayOpenPanel_1, "pathControl:willDisplayOpenPanel:" },
        { &sel_setGroupingSeparator_1, "setGroupingSeparator:" },
        { &sel_fontWithDescriptor_1size_1, "fontWithDescriptor:size:" },
        { &sel_glyphInfoWithCharacterIdentifier_1collection_1baseString_1, "glyphInfoWithCharacterIdentifier:collection:baseString:" },
        { &sel_movieUnfilteredFileTypes, "movieUnfilteredFileTypes" },
        { &sel_portList, "portList" },
        { &sel_tokenField_1readFromPasteboard_1, "tokenField:readFromPasteboard:" },
        { &sel_setEndSpecifier_1, "setEndSpecifier:" },
        { &sel_textView_1willDisplayToolTip_1forCharacterAtIndex_1, "textView:willDisplayToolTip:forCharacterAtIndex:" },
        { &sel_applicationIconImage, "applicationIconImage" },
        { &sel_target, "target" },
        { &sel_replaceGlyphAtIndex_1withGlyph_1, "replaceGlyphAtIndex:withGlyph:" },
        { &sel_borderColorForEdge_1, "borderColorForEdge:" },
        { &sel_timeIntervalSinceDate_1, "timeIntervalSinceDate:" },
        { &sel_pathsForResourcesOfType_1inDirectory_1forLocalization_1, "pathsForResourcesOfType:inDirectory:forLocalization:" },
        { &sel_bitmapData, "bitmapData" },
        { &sel_redComponent, "redComponent" },
        { &sel_numberOfVisibleItems, "numberOfVisibleItems" },
        { &sel_selectCell_1, "selectCell:" },
        { &sel_applicationWillHide_1, "applicationWillHide:" },
        { &sel_characterIsMember_1, "characterIsMember:" },
        { &sel_setArrowsPosition_1, "setArrowsPosition:" },
        { &sel_minusSign, "minusSign" },
        { &sel_canSpawnSeparateThread, "canSpawnSeparateThread" },
        { &sel_setContinuous_1, "setContinuous:" },
        { &sel_addSymbolicLinkWithDestination_1preferredFilename_1, "addSymbolicLinkWithDestination:preferredFilename:" },
        { &sel_destinationOfSymbolicLinkAtPath_1error_1, "destinationOfSymbolicLinkAtPath:error:" },
        { &sel_runUntilDate_1, "runUntilDate:" },
        { &sel_stringByAbbreviatingWithTildeInPath, "stringByAbbreviatingWithTildeInPath" },
        { &sel_drawerWillResizeContents_1toSize_1, "drawerWillResizeContents:toSize:" },
        { &sel_imageRectForBounds_1, "imageRectForBounds:" },
        { &sel_indexGreaterThanIndex_1, "indexGreaterThanIndex:" },
        { &sel_setSelectionFrom_1to_1anchor_1highlight_1, "setSelectionFrom:to:anchor:highlight:" },
        { &sel_unsignedIntegerValue, "unsignedIntegerValue" },
        { &sel_focusView, "focusView" },
        { &sel_longCharacterIsMember_1, "longCharacterIsMember:" },
        { &sel_groupingSeparator, "groupingSeparator" },
        { &sel_depthLimit, "depthLimit" },
        { &sel_attributesAtIndex_1longestEffectiveRange_1inRange_1, "attributesAtIndex:longestEffectiveRange:inRange:" },
        { &sel_setAcceptsArrowKeys_1, "setAcceptsArrowKeys:" },
        { &sel_isGreaterThanOrEqualTo_1, "isGreaterThanOrEqualTo:" },
        { &sel_maxContentSize, "maxContentSize" },
        { &sel_setParentWindow_1, "setParentWindow:" },
        { &sel_importsGraphics, "importsGraphics" },
        { &sel_setPaddingPosition_1, "setPaddingPosition:" },
        { &sel_yearOfCommonEra, "yearOfCommonEra" },
        { &sel_cells, "cells" },
        { &sel_cyanComponent, "cyanComponent" },
        { &sel_documentClassForType_1, "documentClassForType:" },
        { &sel_setSelectionHighlightStyle_1, "setSelectionHighlightStyle:" },
        { &sel_addWindowController_1, "addWindowController:" },
        { &sel_initWithXMLString_1error_1, "initWithXMLString:error:" },
        { &sel_authenticateComponents_1withData_1, "authenticateComponents:withData:" },
        { &sel_traitsOfFont_1, "traitsOfFont:" },
        { &sel_timeIntervalSinceReferenceDate, "timeIntervalSinceReferenceDate" },
        { &sel_orderFrontCharacterPalette_1, "orderFrontCharacterPalette:" },
        { &sel_setServicesProvider_1, "setServicesProvider:" },
        { &sel_setMessage_1, "setMessage:" },
        { &sel_msgid, "msgid" },
        { &sel_beginUndoGrouping, "beginUndoGrouping" },
        { &sel_RTFDFromRange_1documentAttributes_1, "RTFDFromRange:documentAttributes:" },
        { &sel_selectedItem, "selectedItem" },
        { &sel_addTabStop_1, "addTabStop:" },
        { &sel_scrollRect_1by_1, "scrollRect:by:" },
        { &sel_icon, "icon" },
        { &sel_setValue_1forUndefinedKey_1, "setValue:forUndefinedKey:" },
        { &sel_decodeFloatForKey_1, "decodeFloatForKey:" },
        { &sel_commentURL, "commentURL" },
        { &sel_shortStandaloneMonthSymbols, "shortStandaloneMonthSymbols" },
        { &sel_browser_1titleOfColumn_1, "browser:titleOfColumn:" },
        { &sel_exit, "exit" },
        { &sel_deselectAll_1, "deselectAll:" },
        { &sel_canRemove, "canRemove" },
        { &sel_proxyType, "proxyType" },
        { &sel_shouldCloseDocument, "shouldCloseDocument" },
        { &sel_setMinimumLineHeight_1, "setMinimumLineHeight:" },
        { &sel_grayColor, "grayColor" },
        { &sel_suspend, "suspend" },
        { &sel_printJobTitle, "printJobTitle" },
        { &sel_fileHandleWithStandardOutput, "fileHandleWithStandardOutput" },
        { &sel_objCType, "objCType" },
        { &sel_maximumIntegerDigits, "maximumIntegerDigits" },
        { &sel_initWithKey_1ascending_1, "initWithKey:ascending:" },
        { &sel_paramDescriptorForKeyword_1, "paramDescriptorForKeyword:" },
        { &sel_cookiesForURL_1, "cookiesForURL:" },
        { &sel_currentTextContainer, "currentTextContainer" },
        { &sel_removeAllCachedResponses, "removeAllCachedResponses" },
        { &sel_setAllHTTPHeaderFields_1, "setAllHTTPHeaderFields:" },
        { &sel_setShortQuarterSymbols_1, "setShortQuarterSymbols:" },
        { &sel_removeItemWithObjectValue_1, "removeItemWithObjectValue:" },
        { &sel_reloadColumn_1, "reloadColumn:" },
        { &sel_initWithData_1, "initWithData:" },
        { &sel_textDidEndEditing_1, "textDidEndEditing:" },
        { &sel_descriptorForKeyword_1, "descriptorForKeyword:" },
        { &sel_gState, "gState" },
        { &sel_setCellClass_1, "setCellClass:" },
        { &sel_requestUserAttention_1, "requestUserAttention:" },
        { &sel_disableUndoRegistration, "disableUndoRegistration" },
        { &sel_currencySymbol, "currencySymbol" },
        { &sel_defaultWritingDirectionForLanguage_1, "defaultWritingDirectionForLanguage:" },
        { &sel_selectedCellInColumn_1, "selectedCellInColumn:" },
        { &sel_spellServer_1didForgetWord_1inLanguage_1, "spellServer:didForgetWord:inLanguage:" },
        { &sel_initWithType_1error_1, "initWithType:error:" },
        { &sel_editedRow, "editedRow" },
        { &sel_expressionForUnionSet_1with_1, "expressionForUnionSet:with:" },
        { &sel_verticalMotionCanBeginDrag, "verticalMotionCanBeginDrag" },
        { &sel_selectNextKeyView_1, "selectNextKeyView:" },
        { &sel_lowercaseString, "lowercaseString" },
        { &sel_intercellSpacing, "intercellSpacing" },
        { &sel_selectedItemIdentifier, "selectedItemIdentifier" },
        { &sel_getIndexes_1, "getIndexes:" },
        { &sel_contentRect, "contentRect" },
        { &sel_addObjects_1, "addObjects:" },
        { &sel_selectedRowIndexes, "selectedRowIndexes" },
        { &sel_setSecond_1, "setSecond:" },
        { &sel_setIgnoresMultiClick_1, "setIgnoresMultiClick:" },
        { &sel_hasMemberInPlane_1, "hasMemberInPlane:" },
        { &sel_setClientView_1, "setClientView:" },
        { &sel_setInitialFirstResponder_1, "setInitialFirstResponder:" },
        { &sel_defaultAnimationForKey_1, "defaultAnimationForKey:" },
        { &sel_systemTimeZone, "systemTimeZone" },
        { &sel_pageSizeForPaper_1, "pageSizeForPaper:" },
        { &sel_windowBackgroundColor, "windowBackgroundColor" },
        { &sel_prepareGState, "prepareGState" },
        { &sel_willSetLineFragmentRect_1forGlyphRange_1usedRect_1baselineOffset_1, "willSetLineFragmentRect:forGlyphRange:usedRect:baselineOffset:" },
        { &sel_setScriptingProperties_1, "setScriptingProperties:" },
        { &sel_initWithScrollView_1orientation_1, "initWithScrollView:orientation:" },
        { &sel_canBecomeVisibleWithoutLogin, "canBecomeVisibleWithoutLogin" },
        { &sel_scrollLineDown_1, "scrollLineDown:" },
        { &sel_setServicesMenu_1, "setServicesMenu:" },
        { &sel_appleEventCode, "appleEventCode" },
        { &sel_replaceObjectsInRange_1withObjectsFromArray_1range_1, "replaceObjectsInRange:withObjectsFromArray:range:" },
        { &sel_autosizesCells, "autosizesCells" },
        { &sel_tableView_1toolTipForCell_1rect_1tableColumn_1row_1mouseLocation_1, "tableView:toolTipForCell:rect:tableColumn:row:mouseLocation:" },
        { &sel_dateWithYear_1month_1day_1hour_1minute_1second_1timeZone_1, "dateWithYear:month:day:hour:minute:second:timeZone:" },
        { &sel_windowWillResize_1toSize_1, "windowWillResize:toSize:" },
        { &sel_initWithUnsignedChar_1, "initWithUnsignedChar:" },
        { &sel_suiteForAppleEventCode_1, "suiteForAppleEventCode:" },
        { &sel_setTrailingOffset_1, "setTrailingOffset:" },
        { &sel_canBecomeKeyWindow, "canBecomeKeyWindow" },
        { &sel_setAnimationBlockingMode_1, "setAnimationBlockingMode:" },
        { &sel_formUnionWithCharacterSet_1, "formUnionWithCharacterSet:" },
        { &sel_typeForArgumentWithName_1, "typeForArgumentWithName:" },
        { &sel_setFileName_1, "setFileName:" },
        { &sel_createSymbolicLinkAtPath_1pathContent_1, "createSymbolicLinkAtPath:pathContent:" },
        { &sel_undoMenuTitleForUndoActionName_1, "undoMenuTitleForUndoActionName:" },
        { &sel_dateStyle, "dateStyle" },
        { &sel_currentContext, "currentContext" },
        { &sel_dequeueNotificationsMatching_1coalesceMask_1, "dequeueNotificationsMatching:coalesceMask:" },
        { &sel_thousandSeparator, "thousandSeparator" },
        { &sel_writeData_1, "writeData:" },
        { &sel_selectedTag, "selectedTag" },
        { &sel_drawWithRect_1options_1, "drawWithRect:options:" },
        { &sel_canonicalLocaleIdentifierFromString_1, "canonicalLocaleIdentifierFromString:" },
        { &sel_convertFontTraits_1, "convertFontTraits:" },
        { &sel_itemAdded_1, "itemAdded:" },
        { &sel_scriptErrorString, "scriptErrorString" },
        { &sel_submenuAction_1, "submenuAction:" },
        { &sel_initWithType_1subpredicates_1, "initWithType:subpredicates:" },
        { &sel_subpathsOfDirectoryAtPath_1error_1, "subpathsOfDirectoryAtPath:error:" },
        { &sel_becomesKeyOnlyIfNeeded, "becomesKeyOnlyIfNeeded" },
        { &sel_displayAllColumns, "displayAllColumns" },
        { &sel_indexOfItemWithSubmenu_1, "indexOfItemWithSubmenu:" },
        { &sel_runModalSavePanelForSaveOperation_1delegate_1didSaveSelector_1contextInfo_1, "runModalSavePanelForSaveOperation:delegate:didSaveSelector:contextInfo:" },
        { &sel_setCollectionBehavior_1, "setCollectionBehavior:" },
        { &sel_boundingRectWithSize_1options_1attributes_1, "boundingRectWithSize:options:attributes:" },
        { &sel_valueForAttribute_1, "valueForAttribute:" },
        { &sel_attributedStringForNotANumber, "attributedStringForNotANumber" },
        { &sel_indicesOfObjectsByEvaluatingObjectSpecifier_1, "indicesOfObjectsByEvaluatingObjectSpecifier:" },
        { &sel_initWithPath_1, "initWithPath:" },
        { &sel_doCommandBySelector_1, "doCommandBySelector:" },
        { &sel_numberWithChar_1, "numberWithChar:" },
        { &sel_setAllowsMixedState_1, "setAllowsMixedState:" },
        { &sel_abortEditing, "abortEditing" },
        { &sel_context, "context" },
        { &sel_drawerShouldClose_1, "drawerShouldClose:" },
        { &sel_tabViewDidChangeNumberOfTabViewItems_1, "tabViewDidChangeNumberOfTabViewItems:" },
        { &sel_focusRingType, "focusRingType" },
        { &sel_copyScriptingValue_1forKey_1withProperties_1, "copyScriptingValue:forKey:withProperties:" },
        { &sel_acceptsFirstMouse_1, "acceptsFirstMouse:" },
        { &sel_initWithPosition_1objectSpecifier_1, "initWithPosition:objectSpecifier:" },
        { &sel_selectionRangeForProposedRange_1granularity_1, "selectionRangeForProposedRange:granularity:" },
        { &sel_isNotEqualTo_1, "isNotEqualTo:" },
        { &sel_encodeRootObject_1, "encodeRootObject:" },
        { &sel_hasSuffix_1, "hasSuffix:" },
        { &sel_initWithFontAttributes_1, "initWithFontAttributes:" },
        { &sel_initWithRTFDFileWrapper_1documentAttributes_1, "initWithRTFDFileWrapper:documentAttributes:" },
        { &sel_miniwindowImage, "miniwindowImage" },
        { &sel_developmentLocalization, "developmentLocalization" },
        { &sel_localizedSummaryItems, "localizedSummaryItems" },
        { &sel_intValue, "intValue" },
        { &sel_setReturnValue_1, "setReturnValue:" },
        { &sel_selectedMenuItemColor, "selectedMenuItemColor" },
        { &sel_editColumn_1row_1withEvent_1select_1, "editColumn:row:withEvent:select:" },
        { &sel_descriptionWithCalendarFormat_1timeZone_1locale_1, "descriptionWithCalendarFormat:timeZone:locale:" },
        { &sel_itemHeight, "itemHeight" },
        { &sel_application_1openFiles_1, "application:openFiles:" },
        { &sel_window, "window" },
        { &sel_setShortStandaloneMonthSymbols_1, "setShortStandaloneMonthSymbols:" },
        { &sel_setTag_1, "setTag:" },
        { &sel_ignoredWordsInSpellDocumentWithTag_1, "ignoredWordsInSpellDocumentWithTag:" },
        { &sel_preferredLocalizationsFromArray_1, "preferredLocalizationsFromArray:" },
        { &sel_intersectsIndexesInRange_1, "intersectsIndexesInRange:" },
        { &sel_scanLongLong_1, "scanLongLong:" },
        { &sel_characterSetWithContentsOfFile_1, "characterSetWithContentsOfFile:" },
        { &sel_elementWithName_1children_1attributes_1, "elementWithName:children:attributes:" },
        { &sel_removeItem_1, "removeItem:" },
        { &sel_classForKeyedArchiver, "classForKeyedArchiver" },
        { &sel_initWithString_1locale_1, "initWithString:locale:" },
        { &sel_initWithData_1options_1error_1, "initWithData:options:error:" },
        { &sel_setIsPaneSplitter_1, "setIsPaneSplitter:" },
        { &sel_URLHandle_1resourceDataDidBecomeAvailable_1, "URLHandle:resourceDataDidBecomeAvailable:" },
        { &sel_systemDefaultPortNameServer, "systemDefaultPortNameServer" },
        { &sel_controlTextDidEndEditing_1, "controlTextDidEndEditing:" },
        { &sel_commandDescription, "commandDescription" },
        { &sel_collapseItem_1, "collapseItem:" },
        { &sel_setAutoresizesOutlineColumn_1, "setAutoresizesOutlineColumn:" },
        { &sel_isSubsetOfHashTable_1, "isSubsetOfHashTable:" },
        { &sel_discardEventsMatchingMask_1beforeEvent_1, "discardEventsMatchingMask:beforeEvent:" },
        { &sel_highlightSelectionInClipRect_1, "highlightSelectionInClipRect:" },
        { &sel_decodeSizeForKey_1, "decodeSizeForKey:" },
        { &sel_decimalNumberByRaisingToPower_1, "decimalNumberByRaisingToPower:" },
        { &sel_canBecomeMainWindow, "canBecomeMainWindow" },
        { &sel_setMenuItem_1, "setMenuItem:" },
        { &sel_contentRectForFrameRect_1styleMask_1, "contentRectForFrameRect:styleMask:" },
        { &sel_clearGLContext, "clearGLContext" },
        { &sel_setFileType_1, "setFileType:" },
        { &sel_expressionForIntersectSet_1with_1, "expressionForIntersectSet:with:" },
        { &sel_sharedHelpManager, "sharedHelpManager" },
        { &sel_setMiniwindowTitle_1, "setMiniwindowTitle:" },
        { &sel_fontDescriptorWithName_1size_1, "fontDescriptorWithName:size:" },
        { &sel_cookies, "cookies" },
        { &sel_detachNewThreadSelector_1toTarget_1withObject_1, "detachNewThreadSelector:toTarget:withObject:" },
        { &sel_needsPanelToBecomeKey, "needsPanelToBecomeKey" },
        { &sel_retainArguments, "retainArguments" },
        { &sel_textStorageWillProcessEditing_1, "textStorageWillProcessEditing:" },
        { &sel_location, "location" },
        { &sel_shouldChangeTextInRange_1replacementString_1, "shouldChangeTextInRange:replacementString:" },
        { &sel_textView_1doubleClickedOnCell_1inRect_1, "textView:doubleClickedOnCell:inRect:" },
        { &sel_validateVisibleItems, "validateVisibleItems" },
        { &sel_isOneway, "isOneway" },
        { &sel_zone, "zone" },
        { &sel_titleAlignment, "titleAlignment" },
        { &sel_localNameForName_1, "localNameForName:" },
        { &sel_loopMode, "loopMode" },
        { &sel_setFocusRingType_1, "setFocusRingType:" },
        { &sel_stringForKey_1, "stringForKey:" },
        { &sel_initWithDomain_1type_1name_1, "initWithDomain:type:name:" },
        { &sel_animationDidEnd_1, "animationDidEnd:" },
        { &sel_addSubview_1positioned_1relativeTo_1, "addSubview:positioned:relativeTo:" },
        { &sel_removeObjects_1, "removeObjects:" },
        { &sel_graphicsContextWithBitmapImageRep_1, "graphicsContextWithBitmapImageRep:" },
        { &sel_isDescendantOf_1, "isDescendantOf:" },
        { &sel_tableView_1nextTypeSelectMatchFromRow_1toRow_1forString_1, "tableView:nextTypeSelectMatchFromRow:toRow:forString:" },
        { &sel_initWithRequest_1delegate_1startImmediately_1, "initWithRequest:delegate:startImmediately:" },
        { &sel_reservedThicknessForMarkers, "reservedThicknessForMarkers" },
        { &sel_movieRect, "movieRect" },
        { &sel_portForName_1host_1, "portForName:host:" },
        { &sel_tabView_1willSelectTabViewItem_1, "tabView:willSelectTabViewItem:" },
        { &sel_isOneShot, "isOneShot" },
        { &sel_usesThreadedAnimation, "usesThreadedAnimation" },
        { &sel_shortStandaloneQuarterSymbols, "shortStandaloneQuarterSymbols" },
        { &sel_browser_1validateDrop_1proposedRow_1column_1dropOperation_1, "browser:validateDrop:proposedRow:column:dropOperation:" },
        { &sel_setLineSpacing_1, "setLineSpacing:" },
        { &sel_indexOfItemWithTitle_1, "indexOfItemWithTitle:" },
        { &sel_subrowsKeyPath, "subrowsKeyPath" },
        { &sel_showsResizeIndicator, "showsResizeIndicator" },
        { &sel_setState_1, "setState:" },
        { &sel_fileAttributesAtPath_1traverseLink_1, "fileAttributesAtPath:traverseLink:" },
        { &sel_setHorizontal_1, "setHorizontal:" },
        { &sel_windowDidExpose_1, "windowDidExpose:" },
        { &sel_systemID, "systemID" },
        { &sel_turnOffKerning_1, "turnOffKerning:" },
        { &sel_stringByReplacingPercentEscapesUsingEncoding_1, "stringByReplacingPercentEscapesUsingEncoding:" },
        { &sel_control_1textView_1completions_1forPartialWordRange_1indexOfSelectedItem_1, "control:textView:completions:forPartialWordRange:indexOfSelectedItem:" },
        { &sel_selectLastTabViewItem_1, "selectLastTabViewItem:" },
        { &sel_setKeyEquivalentFont_1, "setKeyEquivalentFont:" },
        { &sel_invalidateCursorRectsForView_1, "invalidateCursorRectsForView:" },
        { &sel_selectTextAtIndex_1, "selectTextAtIndex:" },
        { &sel_showPools, "showPools" },
        { &sel_setPlaysSelectionOnly_1, "setPlaysSelectionOnly:" },
        { &sel_note, "note" },
        { &sel_setDrawsCellBackground_1, "setDrawsCellBackground:" },
        { &sel_layoutCharactersInRange_1forLayoutManager_1maximumNumberOfLineFragments_1, "layoutCharactersInRange:forLayoutManager:maximumNumberOfLineFragments:" },
        { &sel_lengthOfBytesUsingEncoding_1, "lengthOfBytesUsingEncoding:" },
        { &sel_columnResizingType, "columnResizingType" },
        { &sel_paragraphSeparatorGlyphRange, "paragraphSeparatorGlyphRange" },
        { &sel_floatValue, "floatValue" },
        { &sel_setRoundingIncrement_1, "setRoundingIncrement:" },
        { &sel_dateFromString_1, "dateFromString:" },
        { &sel_panel_1shouldShowFilename_1, "panel:shouldShowFilename:" },
        { &sel_isEqualToDate_1, "isEqualToDate:" },
        { &sel_drawWithFrame_1inView_1characterIndex_1, "drawWithFrame:inView:characterIndex:" },
        { &sel_initWithInteger_1, "initWithInteger:" },
        { &sel_CGImage, "CGImage" },
        { &sel_endDocument, "endDocument" },
        { &sel_removeFile, "removeFile" },
        { &sel_splitView_1shouldCollapseSubview_1forDoubleClickOnDividerAtIndex_1, "splitView:shouldCollapseSubview:forDoubleClickOnDividerAtIndex:" },
        { &sel_setDefaultMiterLimit_1, "setDefaultMiterLimit:" },
        { &sel_keyCode, "keyCode" },
        { &sel_raise_1format_1, "raise:format:" },
        { &sel_cellSize, "cellSize" },
        { &sel_runModalForWindow_1, "runModalForWindow:" },
        { &sel_colorListNamed_1, "colorListNamed:" },
        { &sel_detachColorList_1, "detachColorList:" },
        { &sel_postEvent_1atStart_1, "postEvent:atStart:" },
        { &sel_setMaximumFractionDigits_1, "setMaximumFractionDigits:" },
        { &sel_setVolatileDomain_1forName_1, "setVolatileDomain:forName:" },
        { &sel_imageInterpolation, "imageInterpolation" },
        { &sel_setTitlePosition_1, "setTitlePosition:" },
        { &sel_leadingOffset, "leadingOffset" },
        { &sel_invokeWithTarget_1, "invokeWithTarget:" },
        { &sel_negativeFormat, "negativeFormat" },
        { &sel_windowController, "windowController" },
        { &sel_setVerticalPageScroll_1, "setVerticalPageScroll:" },
        { &sel_applicationDidUpdate_1, "applicationDidUpdate:" },
        { &sel_valueForProperty_1, "valueForProperty:" },
        { &sel_tokenField_1hasMenuForRepresentedObject_1, "tokenField:hasMenuForRepresentedObject:" },
        { &sel_resolveClassMethod_1, "resolveClassMethod:" },
        { &sel_setAutomaticQuoteSubstitutionEnabled_1, "setAutomaticQuoteSubstitutionEnabled:" },
        { &sel_ordinalityOfUnit_1inUnit_1forDate_1, "ordinalityOfUnit:inUnit:forDate:" },
        { &sel_initWithHost_1port_1protocol_1realm_1authenticationMethod_1, "initWithHost:port:protocol:realm:authenticationMethod:" },
        { &sel_timeIntervalSinceNow, "timeIntervalSinceNow" },
        { &sel_showFindIndicatorForRange_1, "showFindIndicatorForRange:" },
        { &sel_drawLabel_1inRect_1, "drawLabel:inRect:" },
        { &sel_startQuery, "startQuery" },
        { &sel_initWithNibNamed_1bundle_1, "initWithNibNamed:bundle:" },
        { &sel_firstResponder, "firstResponder" },
        { &sel_windowWillMove_1, "windowWillMove:" },
        { &sel_dictionaryForKey_1, "dictionaryForKey:" },
        { &sel_decodeValueOfObjCType_1at_1, "decodeValueOfObjCType:at:" },
        { &sel_activeApplication, "activeApplication" },
        { &sel_initWithUnsignedLongLong_1, "initWithUnsignedLongLong:" },
        { &sel_decimalNumberWithString_1, "decimalNumberWithString:" },
        { &sel_replaceTextStorage_1, "replaceTextStorage:" },
        { &sel_relativePosition, "relativePosition" },
        { &sel_objectValueOfSelectedItem, "objectValueOfSelectedItem" },
        { &sel_timeInterval, "timeInterval" },
        { &sel_getBytes_1range_1, "getBytes:range:" },
        { &sel_initWithViewAnimations_1, "initWithViewAnimations:" },
        { &sel_setHorizontalRulerView_1, "setHorizontalRulerView:" },
        { &sel_keyPathsForValuesAffectingPreview, "keyPathsForValuesAffectingPreview" },
        { &sel_setWithObjects_1count_1, "setWithObjects:count:" },
        { &sel_bitsPerSample, "bitsPerSample" },
        { &sel_dayOfYear, "dayOfYear" },
        { &sel_maximumFractionDigits, "maximumFractionDigits" },
        { &sel_isSelectionByRect, "isSelectionByRect" },
        { &sel_getRed_1green_1blue_1alpha_1, "getRed:green:blue:alpha:" },
        { &sel_glyphIsEncoded_1, "glyphIsEncoded:" },
        { &sel_setStartSubelementIdentifier_1, "setStartSubelementIdentifier:" },
        { &sel_connection_1didFailWithError_1, "connection:didFailWithError:" },
        { &sel_parser_1foundExternalEntityDeclarationWithName_1publicID_1systemID_1, "parser:foundExternalEntityDeclarationWithName:publicID:systemID:" },
        { &sel_outlineView_1shouldTypeSelectForEvent_1withCurrentSearchString_1, "outlineView:shouldTypeSelectForEvent:withCurrentSearchString:" },
        { &sel_lowerBaseline_1, "lowerBaseline:" },
        { &sel_outlineView_1willDisplayCell_1forTableColumn_1item_1, "outlineView:willDisplayCell:forTableColumn:item:" },
        { &sel_notificationWithName_1object_1userInfo_1, "notificationWithName:object:userInfo:" },
        { &sel_setMaxConcurrentOperationCount_1, "setMaxConcurrentOperationCount:" },
        { &sel_closeSpellDocumentWithTag_1, "closeSpellDocumentWithTag:" },
        { &sel_popUpStatusItemMenu_1, "popUpStatusItemMenu:" },
        { &sel_itemPrototype, "itemPrototype" },
        { &sel_commandName, "commandName" },
        { &sel_setTextAttributesForZero_1, "setTextAttributesForZero:" },
        { &sel_dateFromComponents_1, "dateFromComponents:" },
        { &sel_outlineViewColumnDidResize_1, "outlineViewColumnDidResize:" },
        { &sel_setTailIndent_1, "setTailIndent:" },
        { &sel_setRowTemplates_1, "setRowTemplates:" },
        { &sel_objectsForXQuery_1constants_1error_1, "objectsForXQuery:constants:error:" },
        { &sel_mutableCopyWithZone_1, "mutableCopyWithZone:" },
        { &sel_initWithItemIdentifier_1, "initWithItemIdentifier:" },
        { &sel_minuteOfHour, "minuteOfHour" },
        { &sel_setAutosavingDelay_1, "setAutosavingDelay:" },
        { &sel_nextKeyView, "nextKeyView" },
        { &sel_orderFront_1, "orderFront:" },
        { &sel_encodeValueOfObjCType_1at_1, "encodeValueOfObjCType:at:" },
        { &sel_mode, "mode" },
        { &sel_appleEventWithEventClass_1eventID_1targetDescriptor_1returnID_1transactionID_1, "appleEventWithEventClass:eventID:targetDescriptor:returnID:transactionID:" },
        { &sel_stringByDeletingPathExtension, "stringByDeletingPathExtension" },
        { &sel_standardOutput, "standardOutput" },
        { &sel_enumCodeValue, "enumCodeValue" },
        { &sel_setResourceData_1, "setResourceData:" },
        { &sel_convertRectFromBase_1, "convertRectFromBase:" },
        { &sel_initWithContentRect_1styleMask_1backing_1defer_1screen_1, "initWithContentRect:styleMask:backing:defer:screen:" },
        { &sel_autoenablesItems, "autoenablesItems" },
        { &sel_textContainerForGlyphAtIndex_1effectiveRange_1withoutAdditionalLayout_1, "textContainerForGlyphAtIndex:effectiveRange:withoutAdditionalLayout:" },
        { &sel_QTMovie, "QTMovie" },
        { &sel_addObserver_1selector_1name_1object_1suspensionBehavior_1, "addObserver:selector:name:object:suspensionBehavior:" },
        { &sel_getArgument_1atIndex_1, "getArgument:atIndex:" },
        { &sel_replaceChildAtIndex_1withNode_1, "replaceChildAtIndex:withNode:" },
        { &sel_beginForDirectory_1file_1types_1modelessDelegate_1didEndSelector_1contextInfo_1, "beginForDirectory:file:types:modelessDelegate:didEndSelector:contextInfo:" },
        { &sel_supportsMode_1, "supportsMode:" },
        { &sel_openFile_1, "openFile:" },
        { &sel_zero, "zero" },
        { &sel_compositingFilter, "compositingFilter" },
        { &sel_fileGroupOwnerAccountID, "fileGroupOwnerAccountID" },
        { &sel_tokenField_1writeRepresentedObjects_1toPasteboard_1, "tokenField:writeRepresentedObjects:toPasteboard:" },
        { &sel_tabViewType, "tabViewType" },
        { &sel_drawSortIndicatorWithFrame_1inView_1ascending_1priority_1, "drawSortIndicatorWithFrame:inView:ascending:priority:" },
        { &sel_spellCheckerDocumentTag, "spellCheckerDocumentTag" },
        { &sel_updateFromPMPageFormat, "updateFromPMPageFormat" },
        { &sel_colorSyncProfile, "colorSyncProfile" },
        { &sel_flushBufferedKeyEvents, "flushBufferedKeyEvents" },
        { &sel_removeAllObjects, "removeAllObjects" },
        { &sel_selectItemWithTitle_1, "selectItemWithTitle:" },
        { &sel_textContainers, "textContainers" },
        { &sel_isHorizontallyResizable, "isHorizontallyResizable" },
        { &sel_selectionIndexPaths, "selectionIndexPaths" },
        { &sel_setString_1forType_1, "setString:forType:" },
        { &sel_setWraps_1, "setWraps:" },
        { &sel_dataCell, "dataCell" },
        { &sel_addPointer_1, "addPointer:" },
        { &sel_invalidate, "invalidate" },
        { &sel_draggingImageForRowsWithIndexes_1inColumn_1withEvent_1offset_1, "draggingImageForRowsWithIndexes:inColumn:withEvent:offset:" },
        { &sel_horizontalEdgePadding, "horizontalEdgePadding" },
        { &sel_view, "view" },
        { &sel_showsPrintPanel, "showsPrintPanel" },
        { &sel_hyphenationFactor, "hyphenationFactor" },
        { &sel_setAcceptsGlyphInfo_1, "setAcceptsGlyphInfo:" },
        { &sel_formatWidth, "formatWidth" },
        { &sel_stringByAppendingFormat_1, "stringByAppendingFormat:" },
        { &sel_documentForFileName_1, "documentForFileName:" },
        { &sel_outlineView_1nextTypeSelectMatchFromItem_1toItem_1forString_1, "outlineView:nextTypeSelectMatchFromItem:toItem:forString:" },
        { &sel_isItemExpanded_1, "isItemExpanded:" },
        { &sel_playbackDeviceIdentifier, "playbackDeviceIdentifier" },
        { &sel_addButtonWithTitle_1, "addButtonWithTitle:" },
        { &sel_lowercaseLetterCharacterSet, "lowercaseLetterCharacterSet" },
        { &sel_netService_1didNotResolve_1, "netService:didNotResolve:" },
        { &sel_copiesOnScroll, "copiesOnScroll" },
        { &sel_unarchiver_1willReplaceObject_1withObject_1, "unarchiver:willReplaceObject:withObject:" },
        { &sel_setHasShadow_1, "setHasShadow:" },
        { &sel_addObserver_1selector_1name_1object_1, "addObserver:selector:name:object:" },
        { &sel_setDouble_1forKey_1, "setDouble:forKey:" },
        { &sel_positionOfGlyph_1struckOverRect_1metricsExist_1, "positionOfGlyph:struckOverRect:metricsExist:" },
        { &sel_sharedInstance, "sharedInstance" },
        { &sel_setPaperSize_1, "setPaperSize:" },
        { &sel_data1, "data1" },
        { &sel_applicationWillBecomeActive_1, "applicationWillBecomeActive:" },
        { &sel_URLProtocol_1cachedResponseIsValid_1, "URLProtocol:cachedResponseIsValid:" },
        { &sel_mouseDown_1, "mouseDown:" },
        { &sel_setVeryShortStandaloneWeekdaySymbols_1, "setVeryShortStandaloneWeekdaySymbols:" },
        { &sel_setUsesStrongWriteBarrier_1, "setUsesStrongWriteBarrier:" },
        { &sel_second, "second" },
        { &sel_predicateWithLeftExpression_1rightExpression_1modifier_1type_1options_1, "predicateWithLeftExpression:rightExpression:modifier:type:options:" },
        { &sel_setFloatingPanel_1, "setFloatingPanel:" },
        { &sel_parser_1didEndElement_1namespaceURI_1qualifiedName_1, "parser:didEndElement:namespaceURI:qualifiedName:" },
        { &sel_handlePortMessage_1, "handlePortMessage:" },
        { &sel_filteredSetUsingPredicate_1, "filteredSetUsingPredicate:" },
        { &sel_setLocalizedKeyDictionary_1, "setLocalizedKeyDictionary:" },
        { &sel_drawCellInside_1, "drawCellInside:" },
        { &sel_browserDidScroll_1, "browserDidScroll:" },
        { &sel_isDirectory, "isDirectory" },
        { &sel_setEnvironment_1, "setEnvironment:" },
        { &sel_persistence, "persistence" },
        { &sel_backingType, "backingType" },
        { &sel_orderedDocuments, "orderedDocuments" },
        { &sel_windowWillUseStandardFrame_1defaultFrame_1, "windowWillUseStandardFrame:defaultFrame:" },
        { &sel_toggleTraditionalCharacterShape_1, "toggleTraditionalCharacterShape:" },
        { &sel_fractionOfDistanceThroughGlyphForPoint_1, "fractionOfDistanceThroughGlyphForPoint:" },
        { &sel_netServiceWillPublish_1, "netServiceWillPublish:" },
        { &sel_drawInRect_1relativeCenterPosition_1, "drawInRect:relativeCenterPosition:" },
        { &sel_setShowsAlpha_1, "setShowsAlpha:" },
        { &sel_canDragRowsWithIndexes_1inColumn_1withEvent_1, "canDragRowsWithIndexes:inColumn:withEvent:" },
        { &sel_start, "start" },
        { &sel_imageRectInRuler, "imageRectInRuler" },
        { &sel_TXTRecordData, "TXTRecordData" },
        { &sel_groupingLevel, "groupingLevel" },
        { &sel_response, "response" },
        { &sel_insertionIndex, "insertionIndex" },
        { &sel_cancelPreviousPerformRequestsWithTarget_1selector_1object_1, "cancelPreviousPerformRequestsWithTarget:selector:object:" },
        { &sel_itemWithTitle_1, "itemWithTitle:" },
        { &sel_insertRow_1, "insertRow:" },
        { &sel_mutableChildNodes, "mutableChildNodes" },
        { &sel_removeAllPoints, "removeAllPoints" },
        { &sel_searchForRegistrationDomains, "searchForRegistrationDomains" },
        { &sel_replacementObjectForCoder_1, "replacementObjectForCoder:" },
        { &sel_tangentialPressure, "tangentialPressure" },
        { &sel_setMaxDate_1, "setMaxDate:" },
        { &sel_performMnemonic_1, "performMnemonic:" },
        { &sel_maximumRecentDocumentCount, "maximumRecentDocumentCount" },
        { &sel_stringsByAppendingPaths_1, "stringsByAppendingPaths:" },
        { &sel_localTimeZone, "localTimeZone" },
        { &sel_draggingLocation, "draggingLocation" },
        { &sel_searchForAllDomains, "searchForAllDomains" },
        { &sel_attributedStringWithAttachment_1, "attributedStringWithAttachment:" },
        { &sel_initWithContentsOfURL_1byReference_1, "initWithContentsOfURL:byReference:" },
        { &sel_exchangeObjectAtIndex_1withObjectAtIndex_1, "exchangeObjectAtIndex:withObjectAtIndex:" },
        { &sel_draw, "draw" },
        { &sel_fileIsImmutable, "fileIsImmutable" },
        { &sel_tokenField_1styleForRepresentedObject_1, "tokenField:styleForRepresentedObject:" },
        { &sel_setAutorecalculatesContentBorderThickness_1forEdge_1, "setAutorecalculatesContentBorderThickness:forEdge:" },
        { &sel_firstRectForCharacterRange_1actualRange_1, "firstRectForCharacterRange:actualRange:" },
        { &sel_targetForAction_1to_1from_1, "targetForAction:to:from:" },
        { &sel_setShouldCloseDocument_1, "setShouldCloseDocument:" },
        { &sel_originOffset, "originOffset" },
        { &sel_sharedSupportPath, "sharedSupportPath" },
        { &sel_disableScreenUpdatesUntilFlush, "disableScreenUpdatesUntilFlush" },
        { &sel_setShortStandaloneQuarterSymbols_1, "setShortStandaloneQuarterSymbols:" },
        { &sel_filenames, "filenames" },
        { &sel_numberOfItemsInComboBox_1, "numberOfItemsInComboBox:" },
        { &sel_hasBytesAvailable, "hasBytesAvailable" },
        { &sel_currentConversation, "currentConversation" },
        { &sel_setAllowsEditingTextAttributes_1, "setAllowsEditingTextAttributes:" },
        { &sel_initWithName_1stringValue_1, "initWithName:stringValue:" },
        { &sel_tableViewColumnDidResize_1, "tableViewColumnDidResize:" },
        { &sel_knowsPageRange_1, "knowsPageRange:" },
        { &sel_uppercaseLetterCharacterSet, "uppercaseLetterCharacterSet" },
        { &sel_capitalizedLetterCharacterSet, "capitalizedLetterCharacterSet" },
        { &sel_main, "main" },
        { &sel_genericRGBColorSpace, "genericRGBColorSpace" },
        { &sel_clearsFilterPredicateOnInsertion, "clearsFilterPredicateOnInsertion" },
        { &sel_paragraphs, "paragraphs" },
        { &sel_setJobDisposition_1, "setJobDisposition:" },
        { &sel_setContainerClassDescription_1, "setContainerClassDescription:" },
        { &sel_stringWithContentsOfURL_1, "stringWithContentsOfURL:" },
        { &sel_setTrackingMode_1, "setTrackingMode:" },
        { &sel_canCloseDocumentWithDelegate_1shouldCloseSelector_1contextInfo_1, "canCloseDocumentWithDelegate:shouldCloseSelector:contextInfo:" },
        { &sel_usesItemFromMenu, "usesItemFromMenu" },
        { &sel_shortValue, "shortValue" },
        { &sel_readDataOfLength_1, "readDataOfLength:" },
        { &sel_descriptorWithDescriptorType_1data_1, "descriptorWithDescriptorType:data:" },
        { &sel_setCanRemoveAllRows_1, "setCanRemoveAllRows:" },
        { &sel_defaultCenter, "defaultCenter" },
        { &sel_scriptingIsGreaterThan_1, "scriptingIsGreaterThan:" },
        { &sel_splitView_1constrainSplitPosition_1ofSubviewAt_1, "splitView:constrainSplitPosition:ofSubviewAt:" },
        { &sel_setTokenStyle_1, "setTokenStyle:" },
        { &sel_initWithContentRect_1styleMask_1backing_1defer_1, "initWithContentRect:styleMask:backing:defer:" },
        { &sel_insertTabViewItem_1atIndex_1, "insertTabViewItem:atIndex:" },
        { &sel_rowForDisplayValue_1, "rowForDisplayValue:" },
        { &sel_isDrawingToScreen, "isDrawingToScreen" },
        { &sel_encodeRect_1, "encodeRect:" },
        { &sel_controlDarkShadowColor, "controlDarkShadowColor" },
        { &sel_maxDate, "maxDate" },
        { &sel_lock, "lock" },
        { &sel_resetSystemTimeZone, "resetSystemTimeZone" },
        { &sel_coerceValue_1toClass_1, "coerceValue:toClass:" },
        { &sel_qdPort, "qdPort" },
        { &sel_resultAtIndex_1, "resultAtIndex:" },
        { &sel_descriptorWithBoolean_1, "descriptorWithBoolean:" },
        { &sel_markedRange, "markedRange" },
        { &sel_colorWithCalibratedHue_1saturation_1brightness_1alpha_1, "colorWithCalibratedHue:saturation:brightness:alpha:" },
        { &sel_setSharedPrintInfo_1, "setSharedPrintInfo:" },
        { &sel_setBorderColor_1, "setBorderColor:" },
        { &sel_parser_1foundCharacters_1, "parser:foundCharacters:" },
        { &sel_preferredPasteboardTypeFromArray_1restrictedToTypesFromArray_1, "preferredPasteboardTypeFromArray:restrictedToTypesFromArray:" },
        { &sel_resume, "resume" },
        { &sel_iconForFiles_1, "iconForFiles:" },
        { &sel_drawKeyEquivalentWithFrame_1inView_1, "drawKeyEquivalentWithFrame:inView:" },
        { &sel_boxType, "boxType" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1name_1, "initWithContainerClassDescription:containerSpecifier:key:name:" },
        { &sel_setFill, "setFill" },
        { &sel_setParagraphGlyphRange_1separatorGlyphRange_1, "setParagraphGlyphRange:separatorGlyphRange:" },
        { &sel_copyWithZone_1, "copyWithZone:" },
        { &sel_self, "self" },
        { &sel_reservedSpaceLength, "reservedSpaceLength" },
        { &sel_unsignedIntValue, "unsignedIntValue" },
        { &sel_URLHandleResourceDidFinishLoading_1, "URLHandleResourceDidFinishLoading:" },
        { &sel_menuWillOpen_1, "menuWillOpen:" },
        { &sel_menuWillClose_1, "menuWillClose:" },
        { &sel_pointerArrayWithWeakObjects, "pointerArrayWithWeakObjects" },
        { &sel_fetchPredicate, "fetchPredicate" },
        { &sel_pathToColumn_1, "pathToColumn:" },
        { &sel_columnWithIdentifier_1, "columnWithIdentifier:" },
        { &sel_setShouldCreateUI_1, "setShouldCreateUI:" },
        { &sel_getGlyphs_1range_1, "getGlyphs:range:" },
        { &sel_returnID, "returnID" },
        { &sel_miterLimit, "miterLimit" },
        { &sel_hidesEmptyCells, "hidesEmptyCells" },
        { &sel_userSpaceScaleFactor, "userSpaceScaleFactor" },
        { &sel_xHeight, "xHeight" },
        { &sel_decimalNumberByMultiplyingBy_1withBehavior_1, "decimalNumberByMultiplyingBy:withBehavior:" },
        { &sel_reloadData, "reloadData" },
        { &sel_setShortWeekdaySymbols_1, "setShortWeekdaySymbols:" },
        { &sel_containsIndexesInRange_1, "containsIndexesInRange:" },
        { &sel_colorWithDeviceRed_1green_1blue_1alpha_1, "colorWithDeviceRed:green:blue:alpha:" },
        { &sel_screenFontWithRenderingMode_1, "screenFontWithRenderingMode:" },
        { &sel_suggestedFilename, "suggestedFilename" },
        { &sel_fileNameExtensionForType_1saveOperation_1, "fileNameExtensionForType:saveOperation:" },
        { &sel_labelFontSize, "labelFontSize" },
        { &sel_setAlphaValue_1, "setAlphaValue:" },
        { &sel_openGLContext, "openGLContext" },
        { &sel_scriptingIsLessThan_1, "scriptingIsLessThan:" },
        { &sel_keysSortedByValueUsingSelector_1, "keysSortedByValueUsingSelector:" },
        { &sel_control_1didFailToValidatePartialString_1errorDescription_1, "control:didFailToValidatePartialString:errorDescription:" },
        { &sel_offStateImage, "offStateImage" },
        { &sel_bidiProcessingEnabled, "bidiProcessingEnabled" },
        { &sel_isKeyWindow, "isKeyWindow" },
        { &sel_initWithIconRef_1, "initWithIconRef:" },
        { &sel_changeCurrentDirectoryPath_1, "changeCurrentDirectoryPath:" },
        { &sel_textView, "textView" },
        { &sel_localizedStringForStatusCode_1, "localizedStringForStatusCode:" },
        { &sel_setWantsLayer_1, "setWantsLayer:" },
        { &sel_positivePrefix, "positivePrefix" },
        { &sel_setDefaultFlatness_1, "setDefaultFlatness:" },
        { &sel_addChild_1, "addChild:" },
        { &sel_parser_1foundAttributeDeclarationWithName_1forElement_1type_1defaultValue_1, "parser:foundAttributeDeclarationWithName:forElement:type:defaultValue:" },
        { &sel_scannerWithString_1, "scannerWithString:" },
        { &sel_removeFileWrapper_1, "removeFileWrapper:" },
        { &sel_setTitleWidth_1, "setTitleWidth:" },
        { &sel_setTabKeyTraversesCells_1, "setTabKeyTraversesCells:" },
        { &sel_glyphRangeForBoundingRect_1inTextContainer_1, "glyphRangeForBoundingRect:inTextContainer:" },
        { &sel_fileHandleForWritingAtPath_1, "fileHandleForWritingAtPath:" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1, "initWithContainerClassDescription:containerSpecifier:key:" },
        { &sel_fontAttributes, "fontAttributes" },
        { &sel_reviewUnsavedDocumentsWithAlertTitle_1cancellable_1delegate_1didReviewAllSelector_1contextInfo_1, "reviewUnsavedDocumentsWithAlertTitle:cancellable:delegate:didReviewAllSelector:contextInfo:" },
        { &sel_minWidth, "minWidth" },
        { &sel_getLineFragmentInsertionPointsForCharacterAtIndex_1alternatePositions_1inDisplayOrder_1positions_1characterIndexes_1, "getLineFragmentInsertionPointsForCharacterAtIndex:alternatePositions:inDisplayOrder:positions:characterIndexes:" },
        { &sel_finishDecoding, "finishDecoding" },
        { &sel_currentContextDrawingToScreen, "currentContextDrawingToScreen" },
        { &sel_setKeyEquivalent_1, "setKeyEquivalent:" },
        { &sel_smartInsertForString_1replacingRange_1beforeString_1afterString_1, "smartInsertForString:replacingRange:beforeString:afterString:" },
        { &sel_useStandardKerning_1, "useStandardKerning:" },
        { &sel_sharedSystemTypesetter, "sharedSystemTypesetter" },
        { &sel_setDatePickerMode_1, "setDatePickerMode:" },
        { &sel_encodePoint_1forKey_1, "encodePoint:forKey:" },
        { &sel_colorSpace, "colorSpace" },
        { &sel_pasteboardByFilteringTypesInPasteboard_1, "pasteboardByFilteringTypesInPasteboard:" },
        { &sel_sendDoubleAction, "sendDoubleAction" },
        { &sel_isColumnSelected_1, "isColumnSelected:" },
        { &sel_unarchiveObjectWithFile_1, "unarchiveObjectWithFile:" },
        { &sel_usesEPSOnResolutionMismatch, "usesEPSOnResolutionMismatch" },
        { &sel_encodeBycopyObject_1, "encodeBycopyObject:" },
        { &sel_removeAttributeForName_1, "removeAttributeForName:" },
        { &sel_keyCell, "keyCell" },
        { &sel_allocWithZone_1, "allocWithZone:" },
        { &sel_getCompression_1factor_1, "getCompression:factor:" },
        { &sel_insertValue_1inPropertyWithKey_1, "insertValue:inPropertyWithKey:" },
        { &sel_drawAtPoint_1withAttributes_1, "drawAtPoint:withAttributes:" },
        { &sel_isTrue, "isTrue" },
        { &sel_expectedContentLength, "expectedContentLength" },
        { &sel_setTitle_1, "setTitle:" },
        { &sel_connection_1didReceiveAuthenticationChallenge_1, "connection:didReceiveAuthenticationChallenge:" },
        { &sel_isEnabledForSegment_1, "isEnabledForSegment:" },
        { &sel_speechSynthesizer_1willSpeakPhoneme_1, "speechSynthesizer:willSpeakPhoneme:" },
        { &sel_setShowsStateColumn_1, "setShowsStateColumn:" },
        { &sel_requiredFileType, "requiredFileType" },
        { &sel_convertRect_1fromView_1, "convertRect:fromView:" },
        { &sel_visibleFrame, "visibleFrame" },
        { &sel_concludeDragOperation_1, "concludeDragOperation:" },
        { &sel_minimumFractionDigits, "minimumFractionDigits" },
        { &sel_reopenDocumentForURL_1withContentsOfURL_1error_1, "reopenDocumentForURL:withContentsOfURL:error:" },
        { &sel_roundingMode, "roundingMode" },
        { &sel_colorWithCatalogName_1colorName_1, "colorWithCatalogName:colorName:" },
        { &sel_setWithSet_1, "setWithSet:" },
        { &sel_fileManager_1willProcessPath_1, "fileManager:willProcessPath:" },
        { &sel_setSuspended_1, "setSuspended:" },
        { &sel_currentInputManager, "currentInputManager" },
        { &sel_operatingSystemVersionString, "operatingSystemVersionString" },
        { &sel_resetBytesInRange_1, "resetBytesInRange:" },
        { &sel_sizeForKey_1inTable_1, "sizeForKey:inTable:" },
        { &sel_setFloat_1forKey_1, "setFloat:forKey:" },
        { &sel_enableUndoRegistration, "enableUndoRegistration" },
        { &sel_initWithCGImage_1, "initWithCGImage:" },
        { &sel_initWithCIImage_1, "initWithCIImage:" },
        { &sel_addCharactersInRange_1, "addCharactersInRange:" },
        { &sel_initWithRect_1options_1owner_1userInfo_1, "initWithRect:options:owner:userInfo:" },
        { &sel_incrementalLoadFromData_1complete_1, "incrementalLoadFromData:complete:" },
        { &sel_tableView_1acceptDrop_1row_1dropOperation_1, "tableView:acceptDrop:row:dropOperation:" },
        { &sel_classNamed_1, "classNamed:" },
        { &sel_setIndeterminate_1, "setIndeterminate:" },
        { &sel_normalizeAdjacentTextNodesPreservingCDATA_1, "normalizeAdjacentTextNodesPreservingCDATA:" },
        { &sel_validateUserInterfaceItem_1, "validateUserInterfaceItem:" },
        { &sel_setPlaysEveryFrame_1, "setPlaysEveryFrame:" },
        { &sel_isCompiled, "isCompiled" },
        { &sel_tokenFieldCell_1editingStringForRepresentedObject_1, "tokenFieldCell:editingStringForRepresentedObject:" },
        { &sel_tableView_1isGroupRow_1, "tableView:isGroupRow:" },
        { &sel_orderFrontLinkPanel_1, "orderFrontLinkPanel:" },
        { &sel_alphaControlAddedOrRemoved_1, "alphaControlAddedOrRemoved:" },
        { &sel_setShadowColor_1, "setShadowColor:" },
        { &sel_canBecomeKeyView, "canBecomeKeyView" },
        { &sel_addTimer_1forMode_1, "addTimer:forMode:" },
        { &sel_clickedColumn, "clickedColumn" },
        { &sel_initWithName_1URI_1, "initWithName:URI:" },
        { &sel_saveDocument_1, "saveDocument:" },
        { &sel_observationInfo, "observationInfo" },
        { &sel_readFromURL_1options_1documentAttributes_1error_1, "readFromURL:options:documentAttributes:error:" },
        { &sel_addClient_1, "addClient:" },
        { &sel_appleEventForSuspensionID_1, "appleEventForSuspensionID:" },
        { &sel_setGeneratesCalendarDates_1, "setGeneratesCalendarDates:" },
        { &sel_tableView_1sortDescriptorsDidChange_1, "tableView:sortDescriptorsDidChange:" },
        { &sel_predicateFormat, "predicateFormat" },
        { &sel_windowShouldZoom_1toFrame_1, "windowShouldZoom:toFrame:" },
        { &sel_usesFontPanel, "usesFontPanel" },
        { &sel_encodeNXObject_1, "encodeNXObject:" },
        { &sel_colorAtX_1y_1, "colorAtX:y:" },
        { &sel_publishWithOptions_1, "publishWithOptions:" },
        { &sel_allHTTPHeaderFields, "allHTTPHeaderFields" },
        { &sel_registerPort_1name_1, "registerPort:name:" },
        { &sel_lineFragmentUsedRectForGlyphAtIndex_1effectiveRange_1withoutAdditionalLayout_1, "lineFragmentUsedRectForGlyphAtIndex:effectiveRange:withoutAdditionalLayout:" },
        { &sel_hour, "hour" },
        { &sel_setTextLists_1, "setTextLists:" },
        { &sel_maximumAdvancement, "maximumAdvancement" },
        { &sel_setHighlightedItemIndex_1, "setHighlightedItemIndex:" },
        { &sel_initWithMemoryCapacity_1diskCapacity_1diskPath_1, "initWithMemoryCapacity:diskCapacity:diskPath:" },
        { &sel_setDocumentContentKind_1, "setDocumentContentKind:" },
        { &sel_updateDragTypeRegistration, "updateDragTypeRegistration" },
        { &sel_deviceDescription, "deviceDescription" },
        { &sel_setMiniwindowImage_1, "setMiniwindowImage:" },
        { &sel_sharedTypesetter, "sharedTypesetter" },
        { &sel_deleteToEndOfLine_1, "deleteToEndOfLine:" },
        { &sel_setState_1atRow_1column_1, "setState:atRow:column:" },
        { &sel_validModesForFontPanel_1, "validModesForFontPanel:" },
        { &sel_currentCalendar, "currentCalendar" },
        { &sel_selectionIndexPath, "selectionIndexPath" },
        { &sel_setTextFont_1, "setTextFont:" },
        { &sel_password, "password" },
        { &sel_words, "words" },
        { &sel_status, "status" },
        { &sel_typingAttributes, "typingAttributes" },
        { &sel_handleTakeValue_1forUnboundKey_1, "handleTakeValue:forUnboundKey:" },
        { &sel_image_1didLoadRepresentation_1withStatus_1, "image:didLoadRepresentation:withStatus:" },
        { &sel_setBitsPerSample_1, "setBitsPerSample:" },
        { &sel_sortSubviewsUsingFunction_1context_1, "sortSubviewsUsingFunction:context:" },
        { &sel_initWithProtocolFamily_1socketType_1protocol_1socket_1, "initWithProtocolFamily:socketType:protocol:socket:" },
        { &sel_numberOfItemsInMenu_1, "numberOfItemsInMenu:" },
        { &sel_numberWithUnsignedShort_1, "numberWithUnsignedShort:" },
        { &sel_textView_1menu_1forEvent_1atIndex_1, "textView:menu:forEvent:atIndex:" },
        { &sel_arrowCursor, "arrowCursor" },
        { &sel_abbreviation, "abbreviation" },
        { &sel_moveDown_1, "moveDown:" },
        { &sel_activateContextHelpMode_1, "activateContextHelpMode:" },
        { &sel_properties, "properties" },
        { &sel_setObject_1forProperty_1error_1, "setObject:forProperty:error:" },
        { &sel_setAutodisplay_1, "setAutodisplay:" },
        { &sel_locationInWindow, "locationInWindow" },
        { &sel_layoutManager, "layoutManager" },
        { &sel_hyphenCharacterForGlyphAtIndex_1, "hyphenCharacterForGlyphAtIndex:" },
        { &sel_play, "play" },
        { &sel_compositeToPoint_1fromRect_1operation_1fraction_1, "compositeToPoint:fromRect:operation:fraction:" },
        { &sel_cellBackgroundColor, "cellBackgroundColor" },
        { &sel_shouldAntialias, "shouldAntialias" },
        { &sel_windowWillReturnFieldEditor_1toObject_1, "windowWillReturnFieldEditor:toObject:" },
        { &sel_setValuesForKeysWithDictionary_1, "setValuesForKeysWithDictionary:" },
        { &sel_drawsGrid, "drawsGrid" },
        { &sel_patternPhase, "patternPhase" },
        { &sel_setFrame_1, "setFrame:" },
        { &sel_roundingIncrement, "roundingIncrement" },
        { &sel_adjustScroll_1, "adjustScroll:" },
        { &sel_alertShowHelp_1, "alertShowHelp:" },
        { &sel_animate_1, "animate:" },
        { &sel_tabletID, "tabletID" },
        { &sel_selectedRowEnumerator, "selectedRowEnumerator" },
        { &sel_XMLString, "XMLString" },
        { &sel_setWarningValue_1, "setWarningValue:" },
        { &sel_tableView_1validateDrop_1proposedRow_1proposedDropOperation_1, "tableView:validateDrop:proposedRow:proposedDropOperation:" },
        { &sel_checkSpelling_1, "checkSpelling:" },
        { &sel_setFormattingStringsFilename_1, "setFormattingStringsFilename:" },
        { &sel_displayIfNeeded, "displayIfNeeded" },
        { &sel_localizedName, "localizedName" },
        { &sel_isEqualToSet_1, "isEqualToSet:" },
        { &sel_initWithBytesNoCopy_1length_1encoding_1freeWhenDone_1, "initWithBytesNoCopy:length:encoding:freeWhenDone:" },
        { &sel_reloadPredicate, "reloadPredicate" },
        { &sel_setNumberOfMajorTickMarks_1, "setNumberOfMajorTickMarks:" },
        { &sel_defaultPlaceholderForMarker_1withBinding_1, "defaultPlaceholderForMarker:withBinding:" },
        { &sel_encodeDataObject_1, "encodeDataObject:" },
        { &sel_writeToURL_1ofType_1, "writeToURL:ofType:" },
        { &sel_createContext, "createContext" },
        { &sel_verticalScroller, "verticalScroller" },
        { &sel_setShowsInvisibleCharacters_1, "setShowsInvisibleCharacters:" },
        { &sel_encodeConditionalObject_1forKey_1, "encodeConditionalObject:forKey:" },
        { &sel_isEqualTo_1, "isEqualTo:" },
        { &sel_translateXBy_1yBy_1, "translateXBy:yBy:" },
        { &sel_customizationPaletteIsRunning, "customizationPaletteIsRunning" },
        { &sel_dictionaryWithDictionary_1, "dictionaryWithDictionary:" },
        { &sel_drawMarkersInRect_1, "drawMarkersInRect:" },
        { &sel_centerSelectionInVisibleArea_1, "centerSelectionInVisibleArea:" },
        { &sel_stringByAppendingString_1, "stringByAppendingString:" },
        { &sel_flushWindowIfNeeded, "flushWindowIfNeeded" },
        { &sel_lockFocusOnRepresentation_1, "lockFocusOnRepresentation:" },
        { &sel_setNotShownAttribute_1forGlyphAtIndex_1, "setNotShownAttribute:forGlyphAtIndex:" },
        { &sel_currentReplyAppleEvent, "currentReplyAppleEvent" },
        { &sel_setTitleAlignment_1, "setTitleAlignment:" },
        { &sel_removeSuiteNamed_1, "removeSuiteNamed:" },
        { &sel_capitalizedString, "capitalizedString" },
        { &sel_typeFromFileExtension_1, "typeFromFileExtension:" },
        { &sel_allowsImageEditing, "allowsImageEditing" },
        { &sel_loosenKerning_1, "loosenKerning:" },
        { &sel_decomposableCharacterSet, "decomposableCharacterSet" },
        { &sel_subdataWithRange_1, "subdataWithRange:" },
        { &sel_attachPopUpWithFrame_1inView_1, "attachPopUpWithFrame:inView:" },
        { &sel_setColumnResizingType_1, "setColumnResizingType:" },
        { &sel_genericCMYKColorSpace, "genericCMYKColorSpace" },
        { &sel_actionForControlCharacterAtIndex_1, "actionForControlCharacterAtIndex:" },
        { &sel_documentRect, "documentRect" },
        { &sel_dataWithContentsOfFile_1, "dataWithContentsOfFile:" },
        { &sel_localizedDescriptionForType_1, "localizedDescriptionForType:" },
        { &sel_increment, "increment" },
        { &sel_deleteToEndOfParagraph_1, "deleteToEndOfParagraph:" },
        { &sel_exceptionWithName_1reason_1userInfo_1, "exceptionWithName:reason:userInfo:" },
        { &sel_postscriptName, "postscriptName" },
        { &sel_setPreferredFilename_1, "setPreferredFilename:" },
        { &sel_setPostsBoundsChangedNotifications_1, "setPostsBoundsChangedNotifications:" },
        { &sel_decimalNumberHandlerWithRoundingMode_1scale_1raiseOnExactness_1raiseOnOverflow_1raiseOnUnderflow_1raiseOnDivideByZero_1, "decimalNumberHandlerWithRoundingMode:scale:raiseOnExactness:raiseOnOverflow:raiseOnUnderflow:raiseOnDivideByZero:" },
        { &sel_openDocumentWithContentsOfFile_1display_1, "openDocumentWithContentsOfFile:display:" },
        { &sel_objectForInfoDictionaryKey_1, "objectForInfoDictionaryKey:" },
        { &sel_setFrameOrigin_1, "setFrameOrigin:" },
        { &sel_pathControl_1willPopUpMenu_1, "pathControl:willPopUpMenu:" },
        { &sel_lineWidth, "lineWidth" },
        { &sel_poseAsClass_1, "poseAsClass:" },
        { &sel_selectPreviousKeyView_1, "selectPreviousKeyView:" },
        { &sel_isKey_1inTable_1, "isKey:inTable:" },
        { &sel_isZoomed, "isZoomed" },
        { &sel_setCompletionDelay_1, "setCompletionDelay:" },
        { &sel_mainMenu, "mainMenu" },
        { &sel_scrollView, "scrollView" },
        { &sel_dividerColor, "dividerColor" },
        { &sel_requestModes, "requestModes" },
        { &sel_setShowsResizeIndicator_1, "setShowsResizeIndicator:" },
        { &sel_setScrollable_1, "setScrollable:" },
        { &sel_setLineScroll_1, "setLineScroll:" },
        { &sel_resolvePrefixForNamespaceURI_1, "resolvePrefixForNamespaceURI:" },
        { &sel_bind_1toObject_1withKeyPath_1options_1, "bind:toObject:withKeyPath:options:" },
        { &sel_alignCenter_1, "alignCenter:" },
        { &sel_addTemporaryAttribute_1value_1forCharacterRange_1, "addTemporaryAttribute:value:forCharacterRange:" },
        { &sel_expressionForConstantValue_1, "expressionForConstantValue:" },
        { &sel_initWithContentSize_1preferredEdge_1, "initWithContentSize:preferredEdge:" },
        { &sel_setAccessoryView_1, "setAccessoryView:" },
        { &sel_setContentWidth_1type_1, "setContentWidth:type:" },
        { &sel_searchMenuTemplate, "searchMenuTemplate" },
        { &sel_imageRepClassForType_1, "imageRepClassForType:" },
        { &sel_decimalValue, "decimalValue" },
        { &sel_protocolSpecificInformation, "protocolSpecificInformation" },
        { &sel_statusBar, "statusBar" },
        { &sel_setTimeZone_1, "setTimeZone:" },
        { &sel_setWidth_1forSegment_1, "setWidth:forSegment:" },
        { &sel_objectIsForcedForKey_1inDomain_1, "objectIsForcedForKey:inDomain:" },
        { &sel_evaluationErrorSpecifier, "evaluationErrorSpecifier" },
        { &sel_application_1openFile_1, "application:openFile:" },
        { &sel_changeDocumentBackgroundColor_1, "changeDocumentBackgroundColor:" },
        { &sel_volatileDomainNames, "volatileDomainNames" },
        { &sel_changeInLength, "changeInLength" },
        { &sel_autoresizingMask, "autoresizingMask" },
        { &sel_setRepresentedObject_1, "setRepresentedObject:" },
        { &sel_isUndoRegistrationEnabled, "isUndoRegistrationEnabled" },
        { &sel_alertWithError_1, "alertWithError:" },
        { &sel_saturationComponent, "saturationComponent" },
        { &sel_spellServer_1didLearnWord_1inLanguage_1, "spellServer:didLearnWord:inLanguage:" },
        { &sel_performActionWithHighlightingForItemAtIndex_1, "performActionWithHighlightingForItemAtIndex:" },
        { &sel_loadSuitesFromBundle_1, "loadSuitesFromBundle:" },
        { &sel_firstTextView, "firstTextView" },
        { &sel_targetForAction_1, "targetForAction:" },
        { &sel_enterExitEventWithType_1location_1modifierFlags_1timestamp_1windowNumber_1context_1eventNumber_1trackingNumber_1userData_1, "enterExitEventWithType:location:modifierFlags:timestamp:windowNumber:context:eventNumber:trackingNumber:userData:" },
        { &sel_setHelpAnchor_1, "setHelpAnchor:" },
        { &sel_printerWithName_1, "printerWithName:" },
        { &sel_boundingBoxForControlGlyphAtIndex_1forTextContainer_1proposedLineFragment_1glyphPosition_1characterIndex_1, "boundingBoxForControlGlyphAtIndex:forTextContainer:proposedLineFragment:glyphPosition:characterIndex:" },
        { &sel_initWithBytesNoCopy_1length_1freeWhenDone_1, "initWithBytesNoCopy:length:freeWhenDone:" },
        { &sel_getRow_1column_1ofCell_1, "getRow:column:ofCell:" },
        { &sel_smartDeleteRangeForProposedRange_1, "smartDeleteRangeForProposedRange:" },
        { &sel_getHue_1saturation_1brightness_1alpha_1, "getHue:saturation:brightness:alpha:" },
        { &sel_automaticallyNotifiesObserversForKey_1, "automaticallyNotifiesObserversForKey:" },
        { &sel_setAllowsImageEditing_1, "setAllowsImageEditing:" },
        { &sel_draggingUpdated_1, "draggingUpdated:" },
        { &sel_insertRowAtIndex_1withType_1asSubrowOfRow_1animate_1, "insertRowAtIndex:withType:asSubrowOfRow:animate:" },
        { &sel_getRectsExposedDuringLiveResize_1count_1, "getRectsExposedDuringLiveResize:count:" },
        { &sel_usesSignificantDigits, "usesSignificantDigits" },
        { &sel_numberOfVirtualScreens, "numberOfVirtualScreens" },
        { &sel_sendSynchronousRequest_1returningResponse_1error_1, "sendSynchronousRequest:returningResponse:error:" },
        { &sel_setBecomesKeyOnlyIfNeeded_1, "setBecomesKeyOnlyIfNeeded:" },
        { &sel_autorecalculatesKeyViewLoop, "autorecalculatesKeyViewLoop" },
        { &sel_decodeDataObject, "decodeDataObject" },
        { &sel_setOriginOffset_1, "setOriginOffset:" },
        { &sel_pointingDeviceSerialNumber, "pointingDeviceSerialNumber" },
        { &sel_drawSegment_1inFrame_1withView_1, "drawSegment:inFrame:withView:" },
        { &sel_close, "close" },
        { &sel_setAlignmentRect_1, "setAlignmentRect:" },
        { &sel_paragraphSeparatorCharacterRange, "paragraphSeparatorCharacterRange" },
        { &sel_measurementUnits, "measurementUnits" },
        { &sel_setUsesEPSOnResolutionMismatch_1, "setUsesEPSOnResolutionMismatch:" },
        { &sel_setLineFragmentPadding_1, "setLineFragmentPadding:" },
        { &sel_setLastComponentOfFileName_1, "setLastComponentOfFileName:" },
        { &sel_initWithSuiteName_1commandName_1dictionary_1, "initWithSuiteName:commandName:dictionary:" },
        { &sel_initWithContent_1, "initWithContent:" },
        { &sel_provideNewView_1, "provideNewView:" },
        { &sel_pathComponentCells, "pathComponentCells" },
        { &sel_instanceMethodForSelector_1, "instanceMethodForSelector:" },
        { &sel_layoutManagerDidInvalidateLayout_1, "layoutManagerDidInvalidateLayout:" },
        { &sel_helpAnchor, "helpAnchor" },
        { &sel_URLProtocol_1wasRedirectedToRequest_1redirectResponse_1, "URLProtocol:wasRedirectedToRequest:redirectResponse:" },
        { &sel_setIsVisible_1, "setIsVisible:" },
        { &sel_browser_1sizeToFitWidthOfColumn_1, "browser:sizeToFitWidthOfColumn:" },
        { &sel_handleFailureInMethod_1object_1file_1lineNumber_1description_1, "handleFailureInMethod:object:file:lineNumber:description:" },
        { &sel_serializedRepresentation, "serializedRepresentation" },
        { &sel_replaceTextContainer_1, "replaceTextContainer:" },
        { &sel_speechSynthesizer_1willSpeakWord_1ofString_1, "speechSynthesizer:willSpeakWord:ofString:" },
        { &sel_startSpeaking_1, "startSpeaking:" },
        { &sel_setHyphenationFactor_1, "setHyphenationFactor:" },
        { &sel_retain, "retain" },
        { &sel_insertItem_1atIndex_1, "insertItem:atIndex:" },
        { &sel_sortWithSortDescriptors_1recursively_1, "sortWithSortDescriptors:recursively:" },
        { &sel_selectTabViewItem_1, "selectTabViewItem:" },
        { &sel_clipRect_1, "clipRect:" },
        { &sel_close_1, "close:" },
        { &sel_didAddSubview_1, "didAddSubview:" },
        { &sel_markedTextSelectionChanged_1client_1, "markedTextSelectionChanged:client:" },
        { &sel_registerLanguage_1byVendor_1, "registerLanguage:byVendor:" },
        { &sel_removeClient_1, "removeClient:" },
        { &sel_setSendsWholeSearchString_1, "setSendsWholeSearchString:" },
        { &sel_localName, "localName" },
        { &sel_setSelectedSegment_1, "setSelectedSegment:" },
        { &sel_setLineHeightMultiple_1, "setLineHeightMultiple:" },
        { &sel_setCanCreateDirectories_1, "setCanCreateDirectories:" },
        { &sel_setCookieAcceptPolicy_1, "setCookieAcceptPolicy:" },
        { &sel_convertFont_1toHaveTrait_1, "convertFont:toHaveTrait:" },
        { &sel_headerCell, "headerCell" },
        { &sel_maximumDecimalNumber, "maximumDecimalNumber" },
        { &sel_browser_1isColumnValid_1, "browser:isColumnValid:" },
        { &sel_tableViewSelectionIsChanging_1, "tableViewSelectionIsChanging:" },
        { &sel_setNotificationBatchingInterval_1, "setNotificationBatchingInterval:" },
        { &sel_isLeaf, "isLeaf" },
        { &sel_valuesForAttributes_1, "valuesForAttributes:" },
        { &sel_removeTemporaryAttribute_1forCharacterRange_1, "removeTemporaryAttribute:forCharacterRange:" },
        { &sel_pixelsWide, "pixelsWide" },
        { &sel_orderFrontStandardAboutPanel_1, "orderFrontStandardAboutPanel:" },
        { &sel_beginSheetModalForWindow_1modalDelegate_1didEndSelector_1contextInfo_1, "beginSheetModalForWindow:modalDelegate:didEndSelector:contextInfo:" },
        { &sel_setToolTip_1forSegment_1, "setToolTip:forSegment:" },
        { &sel_canonicalXMLStringPreservingComments_1, "canonicalXMLStringPreservingComments:" },
        { &sel_orderFrontListPanel_1, "orderFrontListPanel:" },
        { &sel_setIsMiniaturized_1, "setIsMiniaturized:" },
        { &sel_download_1didReceiveDataOfLength_1, "download:didReceiveDataOfLength:" },
        { &sel_layoutManager_1didCompleteLayoutForTextContainer_1atEnd_1, "layoutManager:didCompleteLayoutForTextContainer:atEnd:" },
        { &sel_standardWindowButton_1forStyleMask_1, "standardWindowButton:forStyleMask:" },
        { &sel_writeToURL_1atomically_1, "writeToURL:atomically:" },
        { &sel_useStandardLigatures_1, "useStandardLigatures:" },
        { &sel_currentRunLoop, "currentRunLoop" },
        { &sel_setExtraLineFragmentRect_1usedRect_1textContainer_1, "setExtraLineFragmentRect:usedRect:textContainer:" },
        { &sel_rootElement, "rootElement" },
        { &sel_setContentViewMargins_1, "setContentViewMargins:" },
        { &sel_cancelPerformSelector_1target_1argument_1, "cancelPerformSelector:target:argument:" },
        { &sel_outputFormat, "outputFormat" },
        { &sel_arrayWithContentsOfFile_1, "arrayWithContentsOfFile:" },
        { &sel_applicationWillFinishLaunching_1, "applicationWillFinishLaunching:" },
        { &sel_prefixForName_1, "prefixForName:" },
        { &sel_decimalNumberByDividingBy_1, "decimalNumberByDividingBy:" },
        { &sel_mouseUpOnCharacterIndex_1atCoordinate_1withModifier_1client_1, "mouseUpOnCharacterIndex:atCoordinate:withModifier:client:" },
        { &sel_defaultVoice, "defaultVoice" },
        { &sel_operand, "operand" },
        { &sel_moveToEndOfLine_1, "moveToEndOfLine:" },
        { &sel_addEntry_1, "addEntry:" },
        { &sel_scaleBy_1, "scaleBy:" },
        { &sel_setMnemonicLocation_1, "setMnemonicLocation:" },
        { &sel_dateWithCalendarFormat_1timeZone_1, "dateWithCalendarFormat:timeZone:" },
        { &sel_setUsesFontLeading_1, "setUsesFontLeading:" },
        { &sel_CIContext, "CIContext" },
        { &sel_isDaylightSavingTime, "isDaylightSavingTime" },
        { &sel_setShowsBorderOnlyWhileMouseInside_1, "setShowsBorderOnlyWhileMouseInside:" },
        { &sel_isSetOnMouseEntered, "isSetOnMouseEntered" },
        { &sel_stringFromDate_1, "stringFromDate:" },
        { &sel_deselectColumn_1, "deselectColumn:" },
        { &sel_requestHeaderFieldsWithCookies_1, "requestHeaderFieldsWithCookies:" },
        { &sel_outlineViewColumnDidMove_1, "outlineViewColumnDidMove:" },
        { &sel_fileExtensionsFromType_1, "fileExtensionsFromType:" },
        { &sel_setUsesScreenFonts_1, "setUsesScreenFonts:" },
        { &sel_commandDescriptionsInSuite_1, "commandDescriptionsInSuite:" },
        { &sel_notShownAttributeForGlyphAtIndex_1, "notShownAttributeForGlyphAtIndex:" },
        { &sel_isRunning, "isRunning" },
        { &sel_sharedPrintInfo, "sharedPrintInfo" },
        { &sel_isValid, "isValid" },
        { &sel_handleFailureInFunction_1file_1lineNumber_1description_1, "handleFailureInFunction:file:lineNumber:description:" },
        { &sel_localizedRecoveryOptions, "localizedRecoveryOptions" },
        { &sel_establishConnection, "establishConnection" },
        { &sel_isMainWindow, "isMainWindow" },
        { &sel_setDrawsBackground_1, "setDrawsBackground:" },
        { &sel_intAttribute_1forGlyphAtIndex_1, "intAttribute:forGlyphAtIndex:" },
        { &sel_shadowColor, "shadowColor" },
        { &sel_keyEquivalentModifierMask, "keyEquivalentModifierMask" },
        { &sel_textStorageDidProcessEditing_1, "textStorageDidProcessEditing:" },
        { &sel_setType_1, "setType:" },
        { &sel_previousSibling, "previousSibling" },
        { &sel_dateByAddingYears_1months_1days_1hours_1minutes_1seconds_1, "dateByAddingYears:months:days:hours:minutes:seconds:" },
        { &sel_setMinimum_1, "setMinimum:" },
        { &sel_columnAutoresizingStyle, "columnAutoresizingStyle" },
        { &sel_convertPointFromBase_1, "convertPointFromBase:" },
        { &sel_layout, "layout" },
        { &sel_textStorage, "textStorage" },
        { &sel_values, "values" },
        { &sel_RTFFromRange_1documentAttributes_1, "RTFFromRange:documentAttributes:" },
        { &sel_isMiniaturizable, "isMiniaturizable" },
        { &sel_opaqueAncestor, "opaqueAncestor" },
        { &sel_notationName, "notationName" },
        { &sel_setBaseWritingDirection_1range_1, "setBaseWritingDirection:range:" },
        { &sel_setManagedObjectContext_1, "setManagedObjectContext:" },
        { &sel_patternImage, "patternImage" },
        { &sel_windowDidResize_1, "windowDidResize:" },
        { &sel_setFieldEditor_1, "setFieldEditor:" },
        { &sel_initWithContainerClassDescription_1containerSpecifier_1key_1relativePosition_1baseSpecifier_1, "initWithContainerClassDescription:containerSpecifier:key:relativePosition:baseSpecifier:" },
        { &sel_setMainMenu_1, "setMainMenu:" },
        { &sel_setObjectZone_1, "setObjectZone:" },
        { &sel_localizedDescription, "localizedDescription" },
        { &sel_setImageScaling_1, "setImageScaling:" },
        { &sel_moveToBeginningOfLine_1, "moveToBeginningOfLine:" },
        { &sel_transposeWords_1, "transposeWords:" },
        { &sel_protocol, "protocol" },
        { &sel_isHorizontallyCentered, "isHorizontallyCentered" },
        { &sel_invert, "invert" },
        { &sel_isEqualToValue_1, "isEqualToValue:" },
        { &sel_registerName_1withNameServer_1, "registerName:withNameServer:" },
        { &sel_writeToURL_1ofType_1error_1, "writeToURL:ofType:error:" },
        { &sel_rangeForUserTextChange, "rangeForUserTextChange" },
        { &sel_configurePersistentStoreCoordinatorForURL_1ofType_1error_1, "configurePersistentStoreCoordinatorForURL:ofType:error:" },
        { &sel_setShouldAntialias_1, "setShouldAntialias:" },
        { &sel_alignmentRect, "alignmentRect" },
        { &sel_zoom_1, "zoom:" },
        { &sel_rate, "rate" },
        { &sel_maxVisibleColumns, "maxVisibleColumns" },
        { &sel_splitViewDidResizeSubviews_1, "splitViewDidResizeSubviews:" },
        { &sel_maxWidth, "maxWidth" },
        { &sel_setData_1, "setData:" },
        { &sel_isVisible, "isVisible" },
        { &sel_isSelected, "isSelected" },
        { &sel_rulerView_1shouldRemoveMarker_1, "rulerView:shouldRemoveMarker:" },
        { &sel_setURL_1, "setURL:" },
        { &sel_drawTitle_1withFrame_1inView_1, "drawTitle:withFrame:inView:" },
        { &sel_usesWeakReadAndWriteBarriers, "usesWeakReadAndWriteBarriers" },
        { &sel_elementDeclarationForName_1, "elementDeclarationForName:" },
        { &sel_setOneShot_1, "setOneShot:" },
        { &sel_shouldProcessNamespaces, "shouldProcessNamespaces" },
        { &sel_isEqualToArray_1, "isEqualToArray:" },
        { &sel_XMLStringWithOptions_1, "XMLStringWithOptions:" },
        { &sel_initFileURLWithPath_1isDirectory_1, "initFileURLWithPath:isDirectory:" },
        { &sel_datePickerElements, "datePickerElements" },
        { &sel_willChange_1valuesAtIndexes_1forKey_1, "willChange:valuesAtIndexes:forKey:" },
        { &sel_setSelected_1forSegment_1, "setSelected:forSegment:" },
        { &sel_initWithFormat_1shareContext_1, "initWithFormat:shareContext:" },
        { &sel_browser_1shouldSizeColumn_1forUserResize_1toWidth_1, "browser:shouldSizeColumn:forUserResize:toWidth:" },
        { &sel_indexSetWithIndexesInRange_1, "indexSetWithIndexesInRange:" },
        { &sel_netServiceBrowser_1didFindService_1moreComing_1, "netServiceBrowser:didFindService:moreComing:" },
        { &sel_keyUp_1, "keyUp:" },
        { &sel_pageHeader, "pageHeader" },
        { &sel_isCancelled, "isCancelled" },
        { &sel_segmentStyle, "segmentStyle" },
        { &sel_imageRepWithContentsOfURL_1, "imageRepWithContentsOfURL:" },
        { &sel_initWithNibName_1bundle_1, "initWithNibName:bundle:" },
        { &sel_removeObserver_1fromObjectsAtIndexes_1forKeyPath_1, "removeObserver:fromObjectsAtIndexes:forKeyPath:" },
        { &sel_setFetchPredicate_1, "setFetchPredicate:" },
        { &sel_compare_1options_1range_1, "compare:options:range:" },
        { &sel_validateVisibleColumns, "validateVisibleColumns" },
        { &sel_initWithCGColorSpace_1, "initWithCGColorSpace:" },
        { &sel_mountNewRemovableMedia, "mountNewRemovableMedia" },
        { &sel_compare_1options_1range_1locale_1, "compare:options:range:locale:" },
        { &sel_setTopMargin_1, "setTopMargin:" },
        { &sel_maximumLengthOfBytesUsingEncoding_1, "maximumLengthOfBytesUsingEncoding:" },
        { &sel_colorWithAlphaComponent_1, "colorWithAlphaComponent:" },
        { &sel_appendBezierPathWithRoundedRect_1xRadius_1yRadius_1, "appendBezierPathWithRoundedRect:xRadius:yRadius:" },
        { &sel_autosavedContentsFileURL, "autosavedContentsFileURL" },
        { &sel_markedTextAttributes, "markedTextAttributes" },
        { &sel_predicateWithValue_1, "predicateWithValue:" },
        { &sel_makeFirstResponder_1, "makeFirstResponder:" },
        { &sel_alternateTitle, "alternateTitle" },
        { &sel_attribute, "attribute" },
        { &sel_decodeIntegerForKey_1, "decodeIntegerForKey:" },
        { &sel_setSeparatesColumns_1, "setSeparatesColumns:" },
        { &sel_imageRepsWithContentsOfURL_1, "imageRepsWithContentsOfURL:" },
        { &sel_isPlanar, "isPlanar" },
        { &sel_download_1didReceiveAuthenticationChallenge_1, "download:didReceiveAuthenticationChallenge:" },
        { &sel_startingRow, "startingRow" },
        { &sel_evaluateWithObject_1substitutionVariables_1, "evaluateWithObject:substitutionVariables:" },
        { &sel_initWithRTFD_1documentAttributes_1, "initWithRTFD:documentAttributes:" },
        { &sel_ensureLayoutForTextContainer_1, "ensureLayoutForTextContainer:" },
        { &sel_runModalForWindow_1relativeToWindow_1, "runModalForWindow:relativeToWindow:" },
        { &sel_isResizable, "isResizable" },
        { &sel_isSymbolicLink, "isSymbolicLink" },
        { &sel_containsIndexes_1, "containsIndexes:" },
        { &sel_splitView_1constrainMaxCoordinate_1ofSubviewAt_1, "splitView:constrainMaxCoordinate:ofSubviewAt:" },
        { &sel_setImportsGraphics_1, "setImportsGraphics:" },
        { &sel_action, "action" },
        { &sel_noteNumberOfItemsChanged, "noteNumberOfItemsChanged" },
        { &sel_drawBackgroundInClipRect_1, "drawBackgroundInClipRect:" },
        { &sel_printInfo, "printInfo" },
        { &sel_performSelector_1withObject_1afterDelay_1, "performSelector:withObject:afterDelay:" },
        { &sel_boundingRectForGlyphRange_1inTextContainer_1, "boundingRectForGlyphRange:inTextContainer:" },
        { &sel_currencyCode, "currencyCode" },
        { &sel_splitView_1canCollapseSubview_1, "splitView:canCollapseSubview:" },
        { &sel_hide, "hide" },
        { &sel_setMonth_1, "setMonth:" },
        { &sel_dataFromTXTRecordDictionary_1, "dataFromTXTRecordDictionary:" },
        { &sel_rulerView_1didAddMarker_1, "rulerView:didAddMarker:" },
        { &sel_deleteBackward_1, "deleteBackward:" },
        { &sel_setMaximumLineHeight_1, "setMaximumLineHeight:" },
        { &sel_orderedWindows, "orderedWindows" },
        { &sel_standaloneWeekdaySymbols, "standaloneWeekdaySymbols" },
        { &sel_isAttached, "isAttached" },
        { &sel_resizeLeftRightCursor, "resizeLeftRightCursor" },
        { &sel_methodSignature, "methodSignature" },
        { &sel_setDiskCapacity_1, "setDiskCapacity:" },
        { &sel_lineFragmentRectForGlyphAtIndex_1effectiveRange_1withoutAdditionalLayout_1, "lineFragmentRectForGlyphAtIndex:effectiveRange:withoutAdditionalLayout:" },
        { &sel_screen, "screen" },
        { &sel_windowNumber, "windowNumber" },
        { &sel_selectSegmentWithTag_1, "selectSegmentWithTag:" },
        { &sel_availableFontFamilies, "availableFontFamilies" },
        { &sel_superclass, "superclass" },
        { &sel_registeredImageRepClasses, "registeredImageRepClasses" },
        { &sel_needsSizing, "needsSizing" },
        { &sel_setUsesAlternatingRowBackgroundColors_1, "setUsesAlternatingRowBackgroundColors:" },
        { &sel_getBitmapDataPlanes_1, "getBitmapDataPlanes:" },
        { &sel_fontWithFamily_1traits_1weight_1size_1, "fontWithFamily:traits:weight:size:" },
        { &sel_borderColor, "borderColor" },
        { &sel_colorUsingColorSpace_1, "colorUsingColorSpace:" },
        { &sel_propertyForKey_1, "propertyForKey:" },
        { &sel_setPublicID_1, "setPublicID:" },
        { &sel_forwardInvocation_1, "forwardInvocation:" },
        { &sel_deleteToBeginningOfLine_1, "deleteToBeginningOfLine:" },
        { &sel_hasNonContiguousLayout, "hasNonContiguousLayout" },
        { &sel_getObjects_1, "getObjects:" },
        { &sel_clearRecentDocuments_1, "clearRecentDocuments:" },
        { &sel_paletteFontOfSize_1, "paletteFontOfSize:" },
        { &sel_rightMargin, "rightMargin" },
        { &sel_browser_1createRowsForColumn_1inMatrix_1, "browser:createRowsForColumn:inMatrix:" },
        { &sel_removeItemAtPath_1error_1, "removeItemAtPath:error:" },
        { &sel_getRectsBeingDrawn_1count_1, "getRectsBeingDrawn:count:" },
        { &sel_numberWithUnsignedInt_1, "numberWithUnsignedInt:" },
        { &sel_complete_1, "complete:" },
        { &sel_synchronizeTitleAndSelectedItem, "synchronizeTitleAndSelectedItem" },
        { &sel_archiverData, "archiverData" },
        { &sel_selectNextTabViewItem_1, "selectNextTabViewItem:" },
        { &sel_displayNameForType_1, "displayNameForType:" },
        { &sel_defaultNameServerPortNumber, "defaultNameServerPortNumber" },
        { &sel_setFireDate_1, "setFireDate:" },
        { &sel_selectFirstTabViewItem_1, "selectFirstTabViewItem:" },
        { &sel_setRightMargin_1, "setRightMargin:" },
        { &sel_menuView, "menuView" },
        { &sel_removeObjectsFromIndices_1numIndices_1, "removeObjectsFromIndices:numIndices:" },
        { &sel_tabKeyTraversesCells, "tabKeyTraversesCells" },
        { &sel_initToBuffer_1capacity_1, "initToBuffer:capacity:" },
        { &sel_endPage, "endPage" },
        { &sel_setTextAttributesForNotANumber_1, "setTextAttributesForNotANumber:" },
        { &sel_makeNextSegmentKey, "makeNextSegmentKey" },
        { &sel_addAttributes_1range_1, "addAttributes:range:" },
        { &sel_lineFragmentPadding, "lineFragmentPadding" },
        { &sel_showController_1adjustingSize_1, "showController:adjustingSize:" },
        { &sel_glyphInfoWithGlyphName_1forFont_1baseString_1, "glyphInfoWithGlyphName:forFont:baseString:" },
        { &sel_initWithCondition_1, "initWithCondition:" },
        { &sel_handleMachMessage_1, "handleMachMessage:" },
        { &sel_setFontMenu_1, "setFontMenu:" },
        { &sel_invocationWithMethodSignature_1, "invocationWithMethodSignature:" },
        { &sel_textAttributesForPositiveValues, "textAttributesForPositiveValues" },
        { &sel_decodePointForKey_1, "decodePointForKey:" },
        { &sel_doubleForKey_1, "doubleForKey:" },
        { &sel_application_1willPresentError_1, "application:willPresentError:" },
        { &sel_setFloatingPointFormat_1left_1right_1, "setFloatingPointFormat:left:right:" },
        { &sel_loadColumnZero, "loadColumnZero" },
        { &sel_availableFonts, "availableFonts" },
        { &sel_drawUnderlineForGlyphRange_1underlineType_1baselineOffset_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1, "drawUnderlineForGlyphRange:underlineType:baselineOffset:lineFragmentRect:lineFragmentGlyphRange:containerOrigin:" },
        { &sel_highlightedTableColumn, "highlightedTableColumn" },
        { &sel_removeObjectsInRange_1, "removeObjectsInRange:" },
        { &sel_rectForKey_1inTable_1, "rectForKey:inTable:" },
        { &sel_canStoreColor, "canStoreColor" },
        { &sel_windowWillMiniaturize_1, "windowWillMiniaturize:" },
        { &sel_documentForWindow_1, "documentForWindow:" },
        { &sel_setAttributedStringForNotANumber_1, "setAttributedStringForNotANumber:" },
        { &sel_rangeOfString_1options_1range_1, "rangeOfString:options:range:" },
        { &sel_pause, "pause" },
        { &sel_continueTracking_1at_1inView_1, "continueTracking:at:inView:" },
        { &sel_servicesProvider, "servicesProvider" },
        { &sel_setIgnoredWords_1inSpellDocumentWithTag_1, "setIgnoredWords:inSpellDocumentWithTag:" },
        { &sel_clear_1, "clear:" },
        { &sel_readFromData_1options_1documentAttributes_1error_1, "readFromData:options:documentAttributes:error:" },
        { &sel_columnNumber, "columnNumber" },
        { &sel_components, "components" },
        { &sel_image, "image" },
        { &sel_setDisplayMode_1, "setDisplayMode:" },
        { &sel_insertParagraphSeparator_1, "insertParagraphSeparator:" },
        { &sel_setPaperName_1, "setPaperName:" },
        { &sel_defaultFormatterBehavior, "defaultFormatterBehavior" },
        { &sel_timeZoneWithAbbreviation_1, "timeZoneWithAbbreviation:" },
        { &sel_setHighlighted_1, "setHighlighted:" },
        { &sel_addFileWithPath_1, "addFileWithPath:" },
        { &sel_allowsDocumentBackgroundColorChange, "allowsDocumentBackgroundColorChange" },
        { &sel_initWithURL_1documentAttributes_1, "initWithURL:documentAttributes:" },
        { &sel_allowsUndo, "allowsUndo" },
        { &sel_localeIdentifierFromComponents_1, "localeIdentifierFromComponents:" },
        { &sel_allowsNonContiguousLayout, "allowsNonContiguousLayout" },
        { &sel_arrayWithArray_1, "arrayWithArray:" },
        { &sel_setCompositingOperation_1, "setCompositingOperation:" },
        { &sel_netServiceBrowserDidStopSearch_1, "netServiceBrowserDidStopSearch:" },
        { &sel_setHorizontalEdgePadding_1, "setHorizontalEdgePadding:" },
        { &sel_accessibilityActionDescription_1, "accessibilityActionDescription:" },
        { &sel_localizedKeyDictionary, "localizedKeyDictionary" },
        { &sel_initWithColorSyncProfile_1, "initWithColorSyncProfile:" },
        { &sel_displayedCommandsTitle, "displayedCommandsTitle" },
        { &sel_flatness, "flatness" },
        { &sel_localizations, "localizations" },
        { &sel_mountedRemovableMedia, "mountedRemovableMedia" },
        { &sel_topAutoreleasePoolCount, "topAutoreleasePoolCount" },
        { &sel_postsFrameChangedNotifications, "postsFrameChangedNotifications" },
        { &sel_performZoom_1, "performZoom:" },
        { &sel_moveBackward_1, "moveBackward:" },
        { &sel_verticalPageScroll, "verticalPageScroll" },
        { &sel_setToolTip_1forCell_1, "setToolTip:forCell:" },
        { &sel_layoutManagerOwnsFirstResponderInWindow_1, "layoutManagerOwnsFirstResponderInWindow:" },
        { &sel_jobStyleHint, "jobStyleHint" },
        { &sel_selectionIndexes, "selectionIndexes" },
        { &sel_segmentCount, "segmentCount" },
        { &sel_accessibilityIsIgnored, "accessibilityIsIgnored" },
        { &sel_hasUnautosavedChanges, "hasUnautosavedChanges" },
        { &sel_deactivate, "deactivate" },
        { &sel_setSelectionIndexPaths_1, "setSelectionIndexPaths:" },
        { &sel_pathForSoundResource_1, "pathForSoundResource:" },
        { &sel_setUsesRuler_1, "setUsesRuler:" },
        { &sel_takeSelectedTabViewItemFromSender_1, "takeSelectedTabViewItemFromSender:" },
        { &sel_writeToFile_1ofType_1originalFile_1saveOperation_1, "writeToFile:ofType:originalFile:saveOperation:" },
        { &sel_numberWithLong_1, "numberWithLong:" },
        { &sel_interiorBackgroundStyle, "interiorBackgroundStyle" },
        { &sel_insertionPointColor, "insertionPointColor" },
        { &sel_prompt, "prompt" },
        { &sel_finishLaunching, "finishLaunching" },
        { &sel_addTextContainer_1, "addTextContainer:" },
        { &sel_setAutosavedContentsFileURL_1, "setAutosavedContentsFileURL:" },
        { &sel_initWithFrame_1textContainer_1, "initWithFrame:textContainer:" },
        { &sel_clearColor, "clearColor" },
        { &sel_insertText_1, "insertText:" },
        { &sel_sendAction, "sendAction" },
        { &sel_innerRect, "innerRect" },
        { &sel_pointerFunctions, "pointerFunctions" },
        { &sel_key, "key" },
        { &sel_comboBoxSelectionDidChange_1, "comboBoxSelectionDidChange:" },
        { &sel_hasMarkedText, "hasMarkedText" },
        { &sel_setDefaultLineCapStyle_1, "setDefaultLineCapStyle:" },
        { &sel_stringListForKey_1inTable_1, "stringListForKey:inTable:" },
        { &sel_defaultConnection, "defaultConnection" },
        { &sel_pathContentOfSymbolicLinkAtPath_1, "pathContentOfSymbolicLinkAtPath:" },
        { &sel_stringWithContentsOfFile_1encoding_1error_1, "stringWithContentsOfFile:encoding:error:" },
        { &sel_detachSubmenu, "detachSubmenu" },
        { &sel_isSecure, "isSecure" },
        { &sel_movie, "movie" },
        { &sel_outlineViewItemWillExpand_1, "outlineViewItemWillExpand:" },
        { &sel_sharedScriptSuiteRegistry, "sharedScriptSuiteRegistry" },
        { &sel_removeCharactersInString_1, "removeCharactersInString:" },
        { &sel_setLocation_1withAdvancements_1forStartOfGlyphRange_1, "setLocation:withAdvancements:forStartOfGlyphRange:" },
        { &sel_moveDownAndModifySelection_1, "moveDownAndModifySelection:" },
        { &sel_fileAttributesToWriteToURL_1ofType_1forSaveOperation_1originalContentsURL_1error_1, "fileAttributesToWriteToURL:ofType:forSaveOperation:originalContentsURL:error:" },
        { &sel_classDescriptionForKey_1, "classDescriptionForKey:" },
        { &sel_addRequestMode_1, "addRequestMode:" },
        { &sel_setPullsDown_1, "setPullsDown:" },
        { &sel_setItemHeight_1, "setItemHeight:" },
        { &sel_printerFont, "printerFont" },
        { &sel_linkTextAttributes, "linkTextAttributes" },
        { &sel_state, "state" },
        { &sel_shouldCloseWindowController_1delegate_1shouldCloseSelector_1contextInfo_1, "shouldCloseWindowController:delegate:shouldCloseSelector:contextInfo:" },
        { &sel_addIndex_1, "addIndex:" },
        { &sel_setChildSpecifier_1, "setChildSpecifier:" },
        { &sel_toolbarDidRemoveItem_1, "toolbarDidRemoveItem:" },
        { &sel_displayName, "displayName" },
        { &sel_setInsertionPointColor_1, "setInsertionPointColor:" },
        { &sel_bezierPathByReversingPath, "bezierPathByReversingPath" },
        { &sel_connection_1didReceiveData_1, "connection:didReceiveData:" },
        { &sel_eraSymbols, "eraSymbols" },
        { &sel_removeObjectsForKeys_1, "removeObjectsForKeys:" },
        { &sel_subrowIndexesForRow_1, "subrowIndexesForRow:" },
        { &sel_increaseLengthBy_1, "increaseLengthBy:" },
        { &sel_viewDidEndLiveResize, "viewDidEndLiveResize" },
        { &sel_encodeBool_1forKey_1, "encodeBool:forKey:" },
        { &sel_handleQueryWithUnboundKey_1, "handleQueryWithUnboundKey:" },
        { &sel_elementsForName_1, "elementsForName:" },
        { &sel_cascadeTopLeftFromPoint_1, "cascadeTopLeftFromPoint:" },
        { &sel_linkItemAtPath_1toPath_1error_1, "linkItemAtPath:toPath:error:" },
        { &sel_frameSizeForContentSize_1hasHorizontalScroller_1hasVerticalScroller_1borderType_1, "frameSizeForContentSize:hasHorizontalScroller:hasVerticalScroller:borderType:" },
        { &sel_initWithString_1attributes_1, "initWithString:attributes:" },
        { &sel_readFromData_1options_1documentAttributes_1, "readFromData:options:documentAttributes:" },
        { &sel_setAlpha_1, "setAlpha:" },
        { &sel_hash, "hash" },
        { &sel_rangeForUserParagraphAttributeChange, "rangeForUserParagraphAttributeChange" },
        { &sel_initWithData_1encoding_1, "initWithData:encoding:" },
        { &sel_newScriptingObjectOfClass_1forValueForKey_1withContentsValue_1properties_1, "newScriptingObjectOfClass:forValueForKey:withContentsValue:properties:" },
        { &sel_pageDown_1, "pageDown:" },
        { &sel_hasCloseBox, "hasCloseBox" },
        { &sel_standardizedURL, "standardizedURL" },
        { &sel_setAttributes_1range_1, "setAttributes:range:" },
        { &sel_setControlSize_1, "setControlSize:" },
        { &sel_revertToInitialValues_1, "revertToInitialValues:" },
        { &sel_setIntAttribute_1value_1forGlyphAtIndex_1, "setIntAttribute:value:forGlyphAtIndex:" },
        { &sel_stopTracking_1at_1inView_1mouseIsUp_1, "stopTracking:at:inView:mouseIsUp:" },
        { &sel_setParamDescriptor_1forKeyword_1, "setParamDescriptor:forKeyword:" },
        { &sel_textShouldBeginEditing_1, "textShouldBeginEditing:" },
        { &sel_applicationDidHide_1, "applicationDidHide:" },
        { &sel_beginSheetWithPrintInfo_1modalForWindow_1delegate_1didEndSelector_1contextInfo_1, "beginSheetWithPrintInfo:modalForWindow:delegate:didEndSelector:contextInfo:" },
        { &sel_shiftIndexesStartingAtIndex_1by_1, "shiftIndexesStartingAtIndex:by:" },
        { &sel_getStreamsToHost_1port_1inputStream_1outputStream_1, "getStreamsToHost:port:inputStream:outputStream:" },
        { &sel_attributesOfFileSystemForPath_1error_1, "attributesOfFileSystemForPath:error:" },
        { &sel_setTemporaryAttributes_1forCharacterRange_1, "setTemporaryAttributes:forCharacterRange:" },
        { &sel_checkSpellingOfString_1startingAt_1language_1wrap_1inSpellDocumentWithTag_1wordCount_1, "checkSpellingOfString:startingAt:language:wrap:inSpellDocumentWithTag:wordCount:" },
        { &sel_insertChild_1atIndex_1, "insertChild:atIndex:" },
        { &sel_defaultManager, "defaultManager" },
        { &sel_invocation, "invocation" },
        { &sel_setMinValue_1, "setMinValue:" },
        { &sel_decodeSize, "decodeSize" },
        { &sel_replaceObject_1withObject_1, "replaceObject:withObject:" },
        { &sel_descriptionWithLocale_1, "descriptionWithLocale:" },
        { &sel_setSharingType_1, "setSharingType:" },
        { &sel_isLenient, "isLenient" },
        { &sel_decimalNumberWithString_1locale_1, "decimalNumberWithString:locale:" },
        { &sel_allowedTypes, "allowedTypes" },
        { &sel_superscript_1, "superscript:" },
        { &sel_initWithContentsOfFile_1encoding_1error_1, "initWithContentsOfFile:encoding:error:" },
        { &sel_windowsMenu, "windowsMenu" },
        { &sel_performSelector_1target_1argument_1order_1modes_1, "performSelector:target:argument:order:modes:" },
        { &sel_unscheduleFromRunLoop_1forMode_1, "unscheduleFromRunLoop:forMode:" },
        { &sel_evaluatedArguments, "evaluatedArguments" },
        { &sel_encodeSize_1forKey_1, "encodeSize:forKey:" },
        { &sel_sendBeforeDate_1components_1from_1reserved_1, "sendBeforeDate:components:from:reserved:" },
        { &sel_containerSize, "containerSize" },
        { &sel_selectedTextColor, "selectedTextColor" },
        { &sel_getGlyphsInRange_1glyphs_1characterIndexes_1glyphInscriptions_1elasticBits_1, "getGlyphsInRange:glyphs:characterIndexes:glyphInscriptions:elasticBits:" },
        { &sel_curveToPoint_1controlPoint1_1controlPoint2_1, "curveToPoint:controlPoint1:controlPoint2:" },
        { &sel_mutableBytes, "mutableBytes" },
        { &sel_rangeOfUnit_1inUnit_1forDate_1, "rangeOfUnit:inUnit:forDate:" },
        { &sel_allowsNaturalLanguage, "allowsNaturalLanguage" },
        { &sel_mouseLocation, "mouseLocation" },
        { &sel_selectCellAtRow_1column_1, "selectCellAtRow:column:" },
        { &sel_toggleBaseWritingDirection_1, "toggleBaseWritingDirection:" },
        { &sel_maximum, "maximum" },
        { &sel_initWithFocusedViewRect_1, "initWithFocusedViewRect:" },
        { &sel_thickness, "thickness" },
        { &sel_setImageOrigin_1, "setImageOrigin:" },
        { &sel_color, "color" },
        { &sel_capitalizeWord_1, "capitalizeWord:" },
        { &sel_imageRepClassForData_1, "imageRepClassForData:" },
        { &sel_outlineTableColumn, "outlineTableColumn" },
        { &sel_runModalWithPrintInfo_1, "runModalWithPrintInfo:" },
        { &sel_flushCachedData, "flushCachedData" },
        { &sel_exitFullScreenModeWithOptions_1, "exitFullScreenModeWithOptions:" },
        { &sel_alertStyle, "alertStyle" },
        { &sel_runModalPageLayoutWithPrintInfo_1delegate_1didRunSelector_1contextInfo_1, "runModalPageLayoutWithPrintInfo:delegate:didRunSelector:contextInfo:" },
        { &sel_setDisplayedWhenStopped_1, "setDisplayedWhenStopped:" },
        { &sel_drawBackgroundWithFrame_1inView_1characterRange_1layoutManager_1, "drawBackgroundWithFrame:inView:characterRange:layoutManager:" },
        { &sel_addObject_1, "addObject:" },
        { &sel_dragPromisedFilesOfTypes_1fromRect_1source_1slideBack_1event_1, "dragPromisedFilesOfTypes:fromRect:source:slideBack:event:" },
        { &sel_samplesPerPixel, "samplesPerPixel" },
        { &sel_negativePrefix, "negativePrefix" },
        { &sel_initialKey, "initialKey" },
        { &sel_orderFrontColorPanel_1, "orderFrontColorPanel:" },
        { &sel_hasLearnedWord_1, "hasLearnedWord:" },
        { &sel_setLineFragmentRect_1forGlyphRange_1usedRect_1baselineOffset_1, "setLineFragmentRect:forGlyphRange:usedRect:baselineOffset:" },
        { &sel_setHidesOnDeactivate_1, "setHidesOnDeactivate:" },
        { &sel_setMsgid_1, "setMsgid:" },
        { &sel_elementCount, "elementCount" },
        { &sel_dateWithString_1, "dateWithString:" },
        { &sel_rangeOfTextBlock_1atIndex_1, "rangeOfTextBlock:atIndex:" },
        { &sel_setMenuItemCell_1forItemAtIndex_1, "setMenuItemCell:forItemAtIndex:" },
        { &sel_defaultTimeZone, "defaultTimeZone" },
        { &sel_gotoBeginning_1, "gotoBeginning:" },
        { &sel_setDrawsOutsideLineFragment_1forGlyphAtIndex_1, "setDrawsOutsideLineFragment:forGlyphAtIndex:" },
        { &sel_characterCollection, "characterCollection" },
        { &sel_getValues_1forParameter_1, "getValues:forParameter:" },
        { &sel_removeColumn_1, "removeColumn:" },
        { &sel_descender, "descender" },
        { &sel_fragment, "fragment" },
        { &sel_setSelectionByRect_1, "setSelectionByRect:" },
        { &sel_colorWithColorSpace_1components_1count_1, "colorWithColorSpace:components:count:" },
        { &sel_windingRule, "windingRule" },
        { &sel_insertColumn_1, "insertColumn:" },
        { &sel_resumeWithSuspensionID_1, "resumeWithSuspensionID:" },
        { &sel_seekToEndOfFile, "seekToEndOfFile" },
        { &sel_initWithTarget_1connection_1, "initWithTarget:connection:" },
        { &sel_symbolCharacterSet, "symbolCharacterSet" },
        { &sel_filterPredicate, "filterPredicate" },
        { &sel_setAutoenablesItems_1, "setAutoenablesItems:" },
        { &sel_printShowingPrintPanel_1, "printShowingPrintPanel:" },
        { &sel_pathForResource_1ofType_1inDirectory_1forLocalization_1, "pathForResource:ofType:inDirectory:forLocalization:" },
        { &sel_objectByApplyingXSLTAtURL_1arguments_1error_1, "objectByApplyingXSLTAtURL:arguments:error:" },
        { &sel_setHidesEmptyCells_1, "setHidesEmptyCells:" },
        { &sel_date, "date" },
        { &sel_writeToFile_1atomically_1, "writeToFile:atomically:" },
        { &sel_locale, "locale" },
        { &sel_localizedKeyTable, "localizedKeyTable" },
        { &sel_absoluteURL, "absoluteURL" },
        { &sel_bundleWithPath_1, "bundleWithPath:" },
        { &sel_setHeaderCell_1, "setHeaderCell:" },
        { &sel_setAutoresizesSubviews_1, "setAutoresizesSubviews:" },
        { &sel_URI, "URI" },
        { &sel_controlBackgroundColor, "controlBackgroundColor" },
        { &sel_displayNameAtPath_1, "displayNameAtPath:" },
        { &sel_decodePortObject, "decodePortObject" },
        { &sel_alpha, "alpha" },
        { &sel_initWithLeftExpression_1rightExpression_1customSelector_1, "initWithLeftExpression:rightExpression:customSelector:" },
        { &sel_secondaryGroupingSize, "secondaryGroupingSize" },
        { &sel_connectionDidFinishLoading_1, "connectionDidFinishLoading:" },
        { &sel_localObjects, "localObjects" },
        { &sel_enableKeyEquivalentForDefaultButtonCell, "enableKeyEquivalentForDefaultButtonCell" },
        { &sel_drawKnobSlotInRect_1highlight_1, "drawKnobSlotInRect:highlight:" },
        { &sel_dateWithString_1calendarFormat_1locale_1, "dateWithString:calendarFormat:locale:" },
        { &sel_stop, "stop" },
        { &sel_appendBezierPathWithOvalInRect_1, "appendBezierPathWithOvalInRect:" },
        { &sel_componentsSeparatedByCharactersInSet_1, "componentsSeparatedByCharactersInSet:" },
        { &sel_tightenKerning_1, "tightenKerning:" },
        { &sel_verticalRulerView, "verticalRulerView" },
        { &sel_setImageAlignment_1, "setImageAlignment:" },
        { &sel_removeFrameUsingName_1, "removeFrameUsingName:" },
        { &sel_insertColor_1key_1atIndex_1, "insertColor:key:atIndex:" },
        { &sel_terminate_1, "terminate:" },
        { &sel_textContainerChangedTextView_1, "textContainerChangedTextView:" },
        { &sel_removeFileAtPath_1handler_1, "removeFileAtPath:handler:" },
        { &sel_splitViewWillResizeSubviews_1, "splitViewWillResizeSubviews:" },
        { &sel_windowDidBecomeMain_1, "windowDidBecomeMain:" },
        { &sel_cellBaselineOffset, "cellBaselineOffset" },
        { &sel_addEntriesFromDictionary_1, "addEntriesFromDictionary:" },
        { &sel_setOnStateImage_1, "setOnStateImage:" },
        { &sel_colorWithCIColor_1, "colorWithCIColor:" },
        { &sel_getCyan_1magenta_1yellow_1black_1alpha_1, "getCyan:magenta:yellow:black:alpha:" },
        { &sel_symbolicTraits, "symbolicTraits" },
        { &sel_stringByAppendingPathExtension_1, "stringByAppendingPathExtension:" },
        { &sel_horizontalScroller, "horizontalScroller" },
        { &sel_setInitialValue_1, "setInitialValue:" },
        { &sel_sizeForPaperName_1, "sizeForPaperName:" },
        { &sel_CGLContextObj, "CGLContextObj" },
        { &sel_elementWithName_1, "elementWithName:" },
        { &sel_fileManager_1shouldMoveItemAtPath_1toPath_1, "fileManager:shouldMoveItemAtPath:toPath:" },
        { &sel_richTextSource, "richTextSource" },
        { &sel_unregisterDraggedTypes, "unregisterDraggedTypes" },
        { &sel_absoluteString, "absoluteString" },
        { &sel_spellingPanel, "spellingPanel" },
        { &sel_launchedApplications, "launchedApplications" },
        { &sel_initWithContentsOfFile_1byReference_1, "initWithContentsOfFile:byReference:" },
        { &sel_setLoaded_1, "setLoaded:" },
        { &sel_setWindowFrameAutosaveName_1, "setWindowFrameAutosaveName:" },
        { &sel_initOrTestWithTests_1, "initOrTestWithTests:" },
        { &sel_drawsBackground, "drawsBackground" },
        { &sel_numberWithDouble_1, "numberWithDouble:" },
        { &sel_textView_1writeCell_1atIndex_1toPasteboard_1type_1, "textView:writeCell:atIndex:toPasteboard:type:" },
        { &sel_defaultMiterLimit, "defaultMiterLimit" },
        { &sel_containsObject_1, "containsObject:" },
        { &sel_headerTextColor, "headerTextColor" },
        { &sel_textView_1doCommandBySelector_1, "textView:doCommandBySelector:" },
        { &sel_drawBorderAndBackgroundWithFrame_1inView_1, "drawBorderAndBackgroundWithFrame:inView:" },
        { &sel_quarterSymbols, "quarterSymbols" },
        { &sel_setContainerSize_1, "setContainerSize:" },
        { &sel_sortUsingSelector_1, "sortUsingSelector:" },
        { &sel_setKey_1, "setKey:" },
        { &sel_headerView, "headerView" },
        { &sel_isRegularFile, "isRegularFile" },
        { &sel_userData, "userData" },
        { &sel_documentCursor, "documentCursor" },
        { &sel_textEncodingName, "textEncodingName" },
        { &sel_performActionForItemAtIndex_1, "performActionForItemAtIndex:" },
        { &sel_isCaseInsensitiveLike_1, "isCaseInsensitiveLike:" },
        { &sel_isEditing, "isEditing" },
        { &sel_selectFile_1inFileViewerRootedAtPath_1, "selectFile:inFileViewerRootedAtPath:" },
        { &sel_messageFontOfSize_1, "messageFontOfSize:" },
        { &sel_independentConversationQueueing, "independentConversationQueueing" },
        { &sel_initWithCoder_1, "initWithCoder:" },
        { &sel_rangesForUserParagraphAttributeChange, "rangesForUserParagraphAttributeChange" },
        { &sel_removeTrackingArea_1, "removeTrackingArea:" },
        { &sel_glyphGenerator, "glyphGenerator" },
        { &sel_extraLineFragmentUsedRect, "extraLineFragmentUsedRect" },
        { &sel_isButtonBordered, "isButtonBordered" },
        { &sel_setDefaultFormatterBehavior_1, "setDefaultFormatterBehavior:" },
        { &sel_didChange_1valuesAtIndexes_1forKey_1, "didChange:valuesAtIndexes:forKey:" },
        { &sel_timeoutInterval, "timeoutInterval" },
        { &sel_initialValues, "initialValues" },
        { &sel_getRow_1column_1forPoint_1, "getRow:column:forPoint:" },
        { &sel_tabletPoint_1, "tabletPoint:" },
        { &sel_setAutorecalculatesKeyViewLoop_1, "setAutorecalculatesKeyViewLoop:" },
        { &sel_identifier, "identifier" },
        { &sel_scheduleInRunLoop_1forMode_1, "scheduleInRunLoop:forMode:" },
        { &sel_baseURL, "baseURL" },
        { &sel_initWithURL_1, "initWithURL:" },
        { &sel_setBackgroundColors_1, "setBackgroundColors:" },
        { &sel_addTableColumn_1, "addTableColumn:" },
        { &sel_fontDescriptorWithFontAttributes_1, "fontDescriptorWithFontAttributes:" },
        { &sel_dataCellForRow_1, "dataCellForRow:" },
        { &sel_speechSynthesizer_1didEncounterErrorAtIndex_1ofString_1message_1, "speechSynthesizer:didEncounterErrorAtIndex:ofString:message:" },
        { &sel_recoveryAttempter, "recoveryAttempter" },
        { &sel_alignJustified_1, "alignJustified:" },
        { &sel_setCompression_1factor_1, "setCompression:factor:" },
        { &sel_elementsForLocalName_1URI_1, "elementsForLocalName:URI:" },
        { &sel_deviceGrayColorSpace, "deviceGrayColorSpace" },
        { &sel_scheduledTimerWithTimeInterval_1target_1selector_1userInfo_1repeats_1, "scheduledTimerWithTimeInterval:target:selector:userInfo:repeats:" },
        { &sel_runModalSession_1, "runModalSession:" },
        { &sel_awakeFromNib, "awakeFromNib" },
        { &sel_connectionWithReceivePort_1sendPort_1, "connectionWithReceivePort:sendPort:" },
        { &sel_outlineView_1validateDrop_1proposedItem_1proposedChildIndex_1, "outlineView:validateDrop:proposedItem:proposedChildIndex:" },
        { &sel_remove_1, "remove:" },
        { &sel_setTimeInterval_1, "setTimeInterval:" },
        { &sel_splitView_1effectiveRect_1forDrawnRect_1ofDividerAtIndex_1, "splitView:effectiveRect:forDrawnRect:ofDividerAtIndex:" },
        { &sel_setUpGState, "setUpGState" },
        { &sel_initWithResponse_1data_1, "initWithResponse:data:" },
        { &sel_notificationCenter, "notificationCenter" },
        { &sel_setAlternateImage_1, "setAlternateImage:" },
        { &sel_mainWindow, "mainWindow" },
        { &sel_substringWithRange_1, "substringWithRange:" },
        { &sel_forgetWord_1, "forgetWord:" },
        { &sel_shouldCascadeWindows, "shouldCascadeWindows" },
        { &sel_updateScroller, "updateScroller" },
        { &sel_currentDirectoryPath, "currentDirectoryPath" },
        { &sel_isPartialStringValidationEnabled, "isPartialStringValidationEnabled" },
        { &sel_splitView_1constrainMinCoordinate_1ofSubviewAt_1, "splitView:constrainMinCoordinate:ofSubviewAt:" },
        { &sel_drawWithFrame_1inView_1, "drawWithFrame:inView:" },
        { &sel_encodingScheme, "encodingScheme" },
        { &sel_namespaceWithName_1stringValue_1, "namespaceWithName:stringValue:" },
        { &sel_initWithLongLong_1, "initWithLongLong:" },
        { &sel_processIdentifier, "processIdentifier" },
        { &sel_setSubmenu_1forItem_1, "setSubmenu:forItem:" },
        { &sel_textAttributesForNil, "textAttributesForNil" },
        { &sel_lockWithPath_1, "lockWithPath:" },
        { &sel_removeFromSuperviewWithoutNeedingDisplay, "removeFromSuperviewWithoutNeedingDisplay" },
        { &sel_cut_1, "cut:" },
        { &sel_nullDescriptor, "nullDescriptor" },
        { &sel_menuFormRepresentation, "menuFormRepresentation" },
        { &sel_removeObjectsAtIndexes_1, "removeObjectsAtIndexes:" },
        { &sel_initWithSource_1, "initWithSource:" },
        { &sel_acceptsGlyphInfo, "acceptsGlyphInfo" },
        { &sel_borderType, "borderType" },
        { &sel_initWithResumeData_1delegate_1path_1, "initWithResumeData:delegate:path:" },
        { &sel_attachedMenu, "attachedMenu" },
        { &sel_stopAnimation, "stopAnimation" },
        { &sel_setDoubleAction_1, "setDoubleAction:" },
        { &sel_returnType, "returnType" },
        { &sel_fontDescriptorsInCollection_1, "fontDescriptorsInCollection:" },
        { &sel_setMeasurementUnits_1, "setMeasurementUnits:" },
        { &sel_baseWritingDirection, "baseWritingDirection" },
        { &sel_currentPoint, "currentPoint" },
        { &sel_initRemoteWithTCPPort_1host_1, "initRemoteWithTCPPort:host:" },
        { &sel_entityDeclarationForName_1, "entityDeclarationForName:" },
        { &sel_evaluate, "evaluate" },
        { &sel_browser_1draggingImageForRowsWithIndexes_1inColumn_1withEvent_1offset_1, "browser:draggingImageForRowsWithIndexes:inColumn:withEvent:offset:" },
        { &sel_turnOffLigatures_1, "turnOffLigatures:" },
        { &sel_setTitleWithMnemonic_1, "setTitleWithMnemonic:" },
        { &sel_deepestScreen, "deepestScreen" },
        { &sel_connection_1shouldMakeNewConnection_1, "connection:shouldMakeNewConnection:" },
        { &sel_selectionShouldChangeInOutlineView_1, "selectionShouldChangeInOutlineView:" },
        { &sel_preservesSelection, "preservesSelection" },
        { &sel_preparePageLayout_1, "preparePageLayout:" },
        { &sel_setOpaque_1, "setOpaque:" },
        { &sel_insertObject_1atIndex_1, "insertObject:atIndex:" },
        { &sel_isActive, "isActive" },
        { &sel_drawStrikethroughForGlyphRange_1strikethroughType_1baselineOffset_1lineFragmentRect_1lineFragmentGlyphRange_1containerOrigin_1, "drawStrikethroughForGlyphRange:strikethroughType:baselineOffset:lineFragmentRect:lineFragmentGlyphRange:containerOrigin:" },
        { &sel_insertObject_1atArrangedObjectIndex_1, "insertObject:atArrangedObjectIndex:" },
        { &sel_initWithCStringNoCopy_1length_1freeWhenDone_1, "initWithCStringNoCopy:length:freeWhenDone:" },
        { &sel_previousKeyView, "previousKeyView" },
        { &sel_performMiniaturize_1, "performMiniaturize:" },
        { &sel_decimalNumberWithDecimal_1, "decimalNumberWithDecimal:" },
        { &sel_autosaveTableColumns, "autosaveTableColumns" },
        { &sel_baselineOffsetInLayoutManager_1glyphIndex_1, "baselineOffsetInLayoutManager:glyphIndex:" },
        { &sel_keyViewSelectionDirection, "keyViewSelectionDirection" },
        { &sel_encodeBytes_1length_1, "encodeBytes:length:" },
        { &sel_fileManager_1shouldProceedAfterError_1copyingItemAtPath_1toPath_1, "fileManager:shouldProceedAfterError:copyingItemAtPath:toPath:" },
        { &sel_menuNeedsUpdate_1, "menuNeedsUpdate:" },
        { &sel_paragraphSpacingAfterGlyphAtIndex_1withProposedLineFragmentRect_1, "paragraphSpacingAfterGlyphAtIndex:withProposedLineFragmentRect:" },
        { &sel_synchronize, "synchronize" },
        { &sel_lockFocus, "lockFocus" },
        { &sel_toggleSmartInsertDelete_1, "toggleSmartInsertDelete:" },
        { &sel_setMenu_1forSegment_1, "setMenu:forSegment:" },
        { &sel_removeParamDescriptorWithKeyword_1, "removeParamDescriptorWithKeyword:" },
        { &sel_applicationShouldOpenUntitledFile_1, "applicationShouldOpenUntitledFile:" },
        { &sel_DTD, "DTD" },
        { &sel_cancelTracking, "cancelTracking" },
        { &sel_fileSystemNumber, "fileSystemNumber" },
        { &sel_setLevel_1, "setLevel:" },
        { &sel_setRequiredFileType_1, "setRequiredFileType:" },
        { &sel_presentError_1, "presentError:" },
        { &sel_allowsUserCustomization, "allowsUserCustomization" },
        { &sel_childrenKeyPathForNode_1, "childrenKeyPathForNode:" },
        { &sel_setYear_1, "setYear:" },
        { &sel_movieController, "movieController" },
        { &sel_unsignedLongValue, "unsignedLongValue" },
        { &sel_hashTableWithOptions_1, "hashTableWithOptions:" },
        { &sel_setVerticalAlignment_1, "setVerticalAlignment:" },
        { &sel_cycleToNextInputServerInLanguage_1, "cycleToNextInputServerInLanguage:" },
        { &sel_sendAction_1to_1from_1, "sendAction:to:from:" },
        { &sel_numberFromString_1, "numberFromString:" },
        { &sel_setUndoManager_1, "setUndoManager:" },
        { &sel_imageDimsWhenDisabled, "imageDimsWhenDisabled" },
        { &sel_autosavingFileType, "autosavingFileType" },
        { &sel_unsignedLongLongValue, "unsignedLongLongValue" },
        { &sel_initImageCell_1, "initImageCell:" },
        { &sel_invalidateDisplayForCharacterRange_1, "invalidateDisplayForCharacterRange:" },
        { &sel_setMaxContentSize_1, "setMaxContentSize:" },
        { &sel_outlineView_1isItemExpandable_1, "outlineView:isItemExpandable:" },
        { &sel_initWithUser_1password_1persistence_1, "initWithUser:password:persistence:" },
        { &sel_setBackgroundFilters_1, "setBackgroundFilters:" },
        { &sel_setAllowsDocumentBackgroundColorChange_1, "setAllowsDocumentBackgroundColorChange:" },
        { &sel_decodeNXObject, "decodeNXObject" },
        { &sel_setMaximumSignificantDigits_1, "setMaximumSignificantDigits:" },
        { &sel_URLsFromRunningOpenPanel, "URLsFromRunningOpenPanel" },
        { &sel_removeChildWindow_1, "removeChildWindow:" },
        { &sel_removeObjectForKey_1, "removeObjectForKey:" },
        { &sel_setCellSize_1, "setCellSize:" },
        { &sel_getParagraphStart_1end_1contentsEnd_1forRange_1, "getParagraphStart:end:contentsEnd:forRange:" },
        { &sel_connectionWithRequest_1delegate_1, "connectionWithRequest:delegate:" },
        { &sel_setNotShownAttribute_1forGlyphRange_1, "setNotShownAttribute:forGlyphRange:" },
        { &sel_collapsesBorders, "collapsesBorders" },
        { &sel_setNegativeInfinitySymbol_1, "setNegativeInfinitySymbol:" },
        { &sel_initWithKind_1, "initWithKind:" },
        { &sel_appleEventCodeForArgumentWithName_1, "appleEventCodeForArgumentWithName:" },
        { &sel_moveUp_1, "moveUp:" },
        { &sel_initWithTextAlignment_1location_1options_1, "initWithTextAlignment:location:options:" },
        { &sel_systemVersion, "systemVersion" },
        { &sel_numberOfItemsInComboBoxCell_1, "numberOfItemsInComboBoxCell:" },
        { &sel_readableTypes, "readableTypes" },
        { &sel_setDraggingSourceOperationMask_1forLocal_1, "setDraggingSourceOperationMask:forLocal:" },
        { &sel_insertLineBreak_1, "insertLineBreak:" },
        { &sel_inLiveResize, "inLiveResize" },
        { &sel_setCanHide_1, "setCanHide:" },
        { &sel_nextResponder, "nextResponder" },
        { &sel_scrollClipView_1toPoint_1, "scrollClipView:toPoint:" },
        { &sel_positiveFormat, "positiveFormat" },
        { &sel_redoMenuItemTitle, "redoMenuItemTitle" },
        { &sel_addIndexesInRange_1, "addIndexesInRange:" },
        { &sel_lockBeforeDate_1, "lockBeforeDate:" },
        { &sel_unlockWithCondition_1, "unlockWithCondition:" },
        { &sel_nextWordFromIndex_1forward_1, "nextWordFromIndex:forward:" },
        { &sel_waitUntilAllOperationsAreFinished, "waitUntilAllOperationsAreFinished" },
        { &sel_drawRow_1clipRect_1, "drawRow:clipRect:" },
        { &sel_setPartialStringValidationEnabled_1, "setPartialStringValidationEnabled:" },
        { &sel_methodSignatureForSelector_1, "methodSignatureForSelector:" },
        { &sel_setSecondaryGroupingSize_1, "setSecondaryGroupingSize:" },
        { &sel_criteriaForRow_1, "criteriaForRow:" },
        { &sel_setShadowBlurRadius_1, "setShadowBlurRadius:" },
        { &sel_expressionForFunction_1selectorName_1arguments_1, "expressionForFunction:selectorName:arguments:" },
        { &sel_initWithWindowNibName_1, "initWithWindowNibName:" },
        { &sel_selectItemWithTag_1, "selectItemWithTag:" },
        { &sel_characterIndexForPoint_1, "characterIndexForPoint:" },
        { &sel_validate, "validate" },
        { &sel_setHorizontalPageScroll_1, "setHorizontalPageScroll:" },
        { &sel_localizedColorNameComponent, "localizedColorNameComponent" },
        { &sel_setVoice_1, "setVoice:" },
        { &sel_setCachedSeparately_1, "setCachedSeparately:" },
        { &sel_frameRectForContentRect_1, "frameRectForContentRect:" },
        { &sel_bezelStyle, "bezelStyle" },
        { &sel_setDecimalSeparator_1, "setDecimalSeparator:" },
        { &sel_conversationIdentifier, "conversationIdentifier" },
        { &sel_setPrompt_1, "setPrompt:" },
        { &sel_setShowsFirstResponder_1, "setShowsFirstResponder:" },
        { &sel_setRootObject_1, "setRootObject:" },
        { &sel_menuBarVisible, "menuBarVisible" },
        { &sel_netServiceBrowser_1didRemoveDomain_1moreComing_1, "netServiceBrowser:didRemoveDomain:moreComing:" },
        { &sel_threadPriority, "threadPriority" },
        { &sel_countKeyPath, "countKeyPath" },
        { &sel_runCustomizationPalette_1, "runCustomizationPalette:" },
        { &sel_fileHandleWithStandardError, "fileHandleWithStandardError" },
        { &sel_documentContentKind, "documentContentKind" },
        { &sel_view_1StringForToolTip_1point_1userData_1, "view:StringForToolTip:point:userData:" },
        { &sel_nameFieldLabel, "nameFieldLabel" },
        { &sel_miniaturizeAll_1, "miniaturizeAll:" },
        { &sel_initWithRepresentedObject_1, "initWithRepresentedObject:" },
        { &sel_runOperation, "runOperation" },
        { &sel_drawBackgroundForBlock_1withFrame_1inView_1characterRange_1layoutManager_1, "drawBackgroundForBlock:withFrame:inView:characterRange:layoutManager:" },
        { &sel_localizedInfoDictionary, "localizedInfoDictionary" },
        { &sel_scanFloat_1, "scanFloat:" },
        { &sel_scanHexDouble_1, "scanHexDouble:" },
        { &sel_continueSpeaking, "continueSpeaking" },
        { &sel_attachedMenuView, "attachedMenuView" },
        { &sel_wantsToHandleMouseEvents, "wantsToHandleMouseEvents" },
        { &sel_attemptRecoveryFromError_1optionIndex_1, "attemptRecoveryFromError:optionIndex:" },
        { &sel_window_1shouldDragDocumentWithEvent_1from_1withPasteboard_1, "window:shouldDragDocumentWithEvent:from:withPasteboard:" },
        { &sel_mouseEntered_1, "mouseEntered:" },
        { &sel_setNameFieldLabel_1, "setNameFieldLabel:" },
        { &sel_setIndentationPerLevel_1, "setIndentationPerLevel:" },
        { &sel_setMinColumnWidth_1, "setMinColumnWidth:" },
        { &sel_classNameForClass_1, "classNameForClass:" },
        { &sel_runLoopModes, "runLoopModes" },
        { &sel_pullsDown, "pullsDown" },
        { &sel_setOutlineTableColumn_1, "setOutlineTableColumn:" },
        { &sel_windowDidLoad, "windowDidLoad" },
        { &sel_read_1maxLength_1, "read:maxLength:" },
        { &sel_removeItemAtIndex_1, "removeItemAtIndex:" },
        { &sel_initWithColor_1, "initWithColor:" },
        { &sel_compare_1options_1, "compare:options:" },
        { &sel_removeTableColumn_1, "removeTableColumn:" },
        { &sel_isRedoing, "isRedoing" },
        { &sel_setTitleWithRepresentedFilename_1, "setTitleWithRepresentedFilename:" },
        { &sel_setDirectory_1, "setDirectory:" },
        { &sel_makeDocumentWithContentsOfURL_1ofType_1error_1, "makeDocumentWithContentsOfURL:ofType:error:" },
        { &sel_isSelectedForSegment_1, "isSelectedForSegment:" },
        { &sel_month, "month" },
        { &sel_addRow, "addRow" },
        { &sel_layoutOptions, "layoutOptions" },
        { &sel_maxNumberOfRows, "maxNumberOfRows" },
        { &sel_setUpPrintOperationDefaultValues, "setUpPrintOperationDefaultValues" },
        { &sel_initByReferencingURL_1, "initByReferencingURL:" },
        { &sel_class, "class" },
        { &sel_setFrameAutosaveName_1, "setFrameAutosaveName:" },
        { &sel_fileWrapperFromRange_1documentAttributes_1error_1, "fileWrapperFromRange:documentAttributes:error:" },
        { &sel_int32Value, "int32Value" },
        { &sel_setControlView_1, "setControlView:" },
        { &sel_setCharacterEncoding_1, "setCharacterEncoding:" },
        { &sel_disableFlushWindow, "disableFlushWindow" },
        { &sel_insertString_1atIndex_1, "insertString:atIndex:" },
        { &sel_childNodes, "childNodes" },
        { &sel_rangeContainerObject, "rangeContainerObject" },
        { &sel_kind, "kind" },
        { &sel_title, "title" },
        { &sel_bundleWithIdentifier_1, "bundleWithIdentifier:" },
        { &sel_initWithMovie_1, "initWithMovie:" },
        { &sel_unionHashTable_1, "unionHashTable:" },
        { &sel_setStartSpecifier_1, "setStartSpecifier:" },
        { &sel_browser_1nextTypeSelectMatchFromRow_1toRow_1inColumn_1forString_1, "browser:nextTypeSelectMatchFromRow:toRow:inColumn:forString:" },
        { &sel_tokenFieldCell_1representedObjectForEditingString_1, "tokenFieldCell:representedObjectForEditingString:" },
        { &sel_initWithContentsOfFile_1, "initWithContentsOfFile:" },
        { &sel_dataWithContentsOfURL_1, "dataWithContentsOfURL:" },
        { &sel_firstWeekday, "firstWeekday" },
        { &sel_setInitialValues_1, "setInitialValues:" },
        { &sel_setIntegerValue_1, "setIntegerValue:" },
        { &sel_calcSize, "calcSize" },
        { &sel_setTokenizingCharacterSet_1, "setTokenizingCharacterSet:" },
        { &sel_setRepresentedFilename_1, "setRepresentedFilename:" },
        { &sel_colorSpaceName, "colorSpaceName" },
        { &sel_setLineBreakMode_1, "setLineBreakMode:" },
        { &sel_appliesImmediately, "appliesImmediately" },
        { &sel_classDescriptionWithAppleEventCode_1, "classDescriptionWithAppleEventCode:" },
        { &sel_eventRef, "eventRef" },
        { &sel_textAttributesForZero, "textAttributesForZero" },
        { &sel_setAutosavesConfiguration_1, "setAutosavesConfiguration:" },
        { &sel_countOfIndexesInRange_1, "countOfIndexesInRange:" },
        { &sel_count, "count" },
        { &sel_initWithSuiteName_1className_1dictionary_1, "initWithSuiteName:className:dictionary:" },
        { &sel_isReleasedWhenClosed, "isReleasedWhenClosed" },
        { &sel_windowWithWindowNumber_1, "windowWithWindowNumber:" },
        { &sel_removeNamespaceForPrefix_1, "removeNamespaceForPrefix:" },
        { &sel_documentWithRootElement_1, "documentWithRootElement:" },
        { &sel_pageFooter, "pageFooter" },
        { &sel_initWithOptions_1capacity_1, "initWithOptions:capacity:" },
        { &sel_insertBacktab_1, "insertBacktab:" },
        { &sel_changeWindowsItem_1title_1filename_1, "changeWindowsItem:title:filename:" },
        { &sel_changeCount, "changeCount" },
        { &sel_paragraphCharacterRange, "paragraphCharacterRange" },
        { &sel_currentProgress, "currentProgress" },
        { &sel_parser_1didStartMappingPrefix_1toURI_1, "parser:didStartMappingPrefix:toURI:" },
        { &sel_setFormatWidth_1, "setFormatWidth:" },
        { &sel_cancelAllOperations, "cancelAllOperations" },
        { &sel_beginLoadInBackground, "beginLoadInBackground" },
        { &sel_draggedDistance, "draggedDistance" },
        { &sel_setIndex_1, "setIndex:" },
        { &sel_initWithScheme_1host_1path_1, "initWithScheme:host:path:" },
        { &sel_toolTipForCell_1, "toolTipForCell:" },
        { &sel_predicateForRow_1, "predicateForRow:" },
        { &sel_predefinedEntityDeclarationForName_1, "predefinedEntityDeclarationForName:" },
        { &sel_replacePointerAtIndex_1withPointer_1, "replacePointerAtIndex:withPointer:" },
        { &sel_fileURLWithPath_1, "fileURLWithPath:" },
        { &sel_currentDocument, "currentDocument" },
        { &sel_shouldDrawInsertionPoint, "shouldDrawInsertionPoint" },
        { &sel_saveAllDocuments_1, "saveAllDocuments:" },
        { &sel_windowControllerWillLoadNib_1, "windowControllerWillLoadNib:" },
        { &sel_closeAllDocumentsWithDelegate_1didCloseAllSelector_1contextInfo_1, "closeAllDocumentsWithDelegate:didCloseAllSelector:contextInfo:" },
        { &sel_tableView_1heightOfRow_1, "tableView:heightOfRow:" },
        { &sel_postNotificationName_1object_1userInfo_1options_1, "postNotificationName:object:userInfo:options:" },
        { &sel_imageTypes, "imageTypes" },
        { &sel_setPreferredBackingLocation_1, "setPreferredBackingLocation:" },
        { &sel_netServiceDidPublish_1, "netServiceDidPublish:" },
        { &sel_diskCapacity, "diskCapacity" },
        { &sel_initWithString_1calendarFormat_1locale_1, "initWithString:calendarFormat:locale:" },
        { &sel_preferredEdge, "preferredEdge" },
        { &sel_comboBoxCell_1indexOfItemWithStringValue_1, "comboBoxCell:indexOfItemWithStringValue:" },
        { &sel_replaceCharactersInRange_1withString_1, "replaceCharactersInRange:withString:" },
        { &sel_initWithTimeIntervalSinceReferenceDate_1, "initWithTimeIntervalSinceReferenceDate:" },
        { &sel_secondsFromGMT, "secondsFromGMT" },
        { &sel_hasOrderedToManyRelationshipForKey_1, "hasOrderedToManyRelationshipForKey:" },
        { &sel_resignFirstResponder, "resignFirstResponder" },
        { &sel_netServiceDidStop_1, "netServiceDidStop:" },
        { &sel_absoluteY, "absoluteY" },
        { &sel_beginModalSessionForWindow_1, "beginModalSessionForWindow:" },
        { &sel_alignment, "alignment" },
        { &sel_setCharactersToBeSkipped_1, "setCharactersToBeSkipped:" },
        { &sel_requestWithURL_1cachePolicy_1timeoutInterval_1, "requestWithURL:cachePolicy:timeoutInterval:" },
        { &sel_ruler, "ruler" },
        { &sel_isSetOnMouseExited, "isSetOnMouseExited" },
        { &sel_setRemovable_1, "setRemovable:" },
        { &sel_draggingSource, "draggingSource" },
        { &sel_textView_1clickedOnLink_1, "textView:clickedOnLink:" },
        { &sel_canBeVisibleOnAllSpaces, "canBeVisibleOnAllSpaces" },
        { &sel_setBadgeLabel_1, "setBadgeLabel:" },
        { &sel_parser_1foundUnparsedEntityDeclarationWithName_1publicID_1systemID_1notationName_1, "parser:foundUnparsedEntityDeclarationWithName:publicID:systemID:notationName:" },
        { &sel_operations, "operations" },
        { &sel_setInteger_1forKey_1, "setInteger:forKey:" },
        { &sel_otherMouseUp_1, "otherMouseUp:" },
        { &sel_drawImageWithFrame_1inView_1, "drawImageWithFrame:inView:" },
        { &sel_getPixel_1atX_1y_1, "getPixel:atX:y:" },
        { &sel_standardError, "standardError" },
        { &sel_setLabel_1, "setLabel:" },
        { &sel_initWithUnsignedInt_1, "initWithUnsignedInt:" },
        { &sel_isFinished, "isFinished" },
        { &sel_drawSwatchInRect_1, "drawSwatchInRect:" },
        { &sel_descriptorAtIndex_1, "descriptorAtIndex:" },
        { &sel_cachedHandleForURL_1, "cachedHandleForURL:" },
        { &sel_classCode, "classCode" },
        { &sel_resolvesAliases, "resolvesAliases" },
        { &sel_textTypes, "textTypes" },
        { &sel_invalidateTextContainerOrigin, "invalidateTextContainerOrigin" },
        { &sel_document, "document" },
        { &sel_interiorBackgroundStyleForSegment_1, "interiorBackgroundStyleForSegment:" },
        { &sel_transformedValue_1, "transformedValue:" },
        { &sel_substringToIndex_1, "substringToIndex:" },
        { &sel_addDocument_1, "addDocument:" },
        { &sel_numberWithInteger_1, "numberWithInteger:" },
        { &sel_setBoundsRotation_1, "setBoundsRotation:" },
        { &sel_convertFont_1toFace_1, "convertFont:toFace:" },
        { &sel_updateInsertionPointStateAndRestartTimer_1, "updateInsertionPointStateAndRestartTimer:" },
        { &sel_tryToPerform_1with_1, "tryToPerform:with:" },
        { &sel_defaultLineHeightForFont, "defaultLineHeightForFont" },
        { &sel_scriptingIsEqualTo_1, "scriptingIsEqualTo:" },
        { &sel_setDoubleValue_1, "setDoubleValue:" },
        { &sel_AMSymbol, "AMSymbol" },
        { &sel_valueWraps, "valueWraps" },
        { &sel_allCredentials, "allCredentials" },
        { &sel_editingDelegate, "editingDelegate" },
        { &sel_maintainsInactiveSelection, "maintainsInactiveSelection" },
        { &sel_policyDelegate, "policyDelegate" },
        { &sel_preferences, "preferences" },
        { &sel_registerViewClass_1representationClass_1forMIMEType_1, "registerViewClass:representationClass:forMIMEType:" },
        { &sel_setHostWindow_1, "setHostWindow:" },
        { &sel_hostWindow, "hostWindow" },
        { &sel_searchFor_1direction_1caseSensitive_1wrap_1, "searchFor:direction:caseSensitive:wrap:" },
        { &sel_initWithFrame_1frameName_1groupName_1, "initWithFrame:frameName:groupName:" },
        { &sel_canGoBack, "canGoBack" },
        { &sel_setFrameLoadDelegate_1, "setFrameLoadDelegate:" },
        { &sel_takeStringURLFrom_1, "takeStringURLFrom:" },
        { &sel_registerURLSchemeAsLocal_1, "registerURLSchemeAsLocal:" },
        { &sel_StringByEvaluatingJavaScriptFromString_1, "StringByEvaluatingJavaScriptFromString:" },
        { &sel_replaceSelectionWithMarkupString_1, "replaceSelectionWithMarkupString:" },
        { &sel_setPreferences_1, "setPreferences:" },
        { &sel_customUserAgent, "customUserAgent" },
        { &sel_mainFrame, "mainFrame" },
        { &sel_goToBackForwardItem_1, "goToBackForwardItem:" },
        { &sel_pasteboardTypesForElement_1, "pasteboardTypesForElement:" },
        { &sel_applyStyle_1, "applyStyle:" },
        { &sel_setResourceLoadDelegate_1, "setResourceLoadDelegate:" },
        { &sel_moveToBeginningOfSentenceAndModifySelection_1, "moveToBeginningOfSentenceAndModifySelection:" },
        { &sel_replaceSelectionWithArchive_1, "replaceSelectionWithArchive:" },
        { &sel_userAgentForURL_1, "userAgentForURL:" },
        { &sel_frameLoadDelegate, "frameLoadDelegate" },
        { &sel_windowScriptObject, "windowScriptObject" },
        { &sel_removeDragCaret, "removeDragCaret" },
        { &sel_editableDOMRangeForPoint_1, "editableDOMRangeForPoint:" },
        { &sel_moveToEndOfSentence_1, "moveToEndOfSentence:" },
        { &sel_preferencesIdentifier, "preferencesIdentifier" },
        { &sel_setPolicyDelegate_1, "setPolicyDelegate:" },
        { &sel_goBack, "goBack" },
        { &sel_downloadDelegate, "downloadDelegate" },
        { &sel_canShowMIMEType_1, "canShowMIMEType:" },
        { &sel_elementAtPoint_1, "elementAtPoint:" },
        { &sel_groupName, "groupName" },
        { &sel_selectedFrame, "selectedFrame" },
        { &sel_setMIMETypesShownAsHTML_1, "setMIMETypesShownAsHTML:" },
        { &sel_goForward, "goForward" },
        { &sel_makeTextStandardSize_1, "makeTextStandardSize:" },
        { &sel_setMainFrameURL_1, "setMainFrameURL:" },
        { &sel_pasteboardTypesForSelection, "pasteboardTypesForSelection" },
        { &sel_customTextEncodingName, "customTextEncodingName" },
        { &sel_MIMETypesShownAsHTML, "MIMETypesShownAsHTML" },
        { &sel_replaceSelectionWithText_1, "replaceSelectionWithText:" },
        { &sel_setTextSizeMultiplier_1, "setTextSizeMultiplier:" },
        { &sel_stopLoading_1, "stopLoading:" },
        { &sel_goBack_1, "goBack:" },
        { &sel_canMakeTextStandardSize, "canMakeTextStandardSize" },
        { &sel_setCustomUserAgent_1, "setCustomUserAgent:" },
        { &sel_moveDragCaretToPoint_1, "moveDragCaretToPoint:" },
        { &sel_makeTextSmaller_1, "makeTextSmaller:" },
        { &sel_moveToBeginningOfSentence_1, "moveToBeginningOfSentence:" },
        { &sel_reload_1, "reload:" },
        { &sel_typingStyle, "typingStyle" },
        { &sel_setShouldCloseWithWindow_1, "setShouldCloseWithWindow:" },
        { &sel_setMediaStyle_1, "setMediaStyle:" },
        { &sel_canMakeTextLarger, "canMakeTextLarger" },
        { &sel_textSizeMultiplier, "textSizeMultiplier" },
        { &sel_shouldCloseWithWindow, "shouldCloseWithWindow" },
        { &sel_setPreferencesIdentifier_1, "setPreferencesIdentifier:" },
        { &sel_setApplicationNameForUserAgent_1, "setApplicationNameForUserAgent:" },
        { &sel_mainFrameURL, "mainFrameURL" },
        { &sel_goForward_1, "goForward:" },
        { &sel_selectedDOMRange, "selectedDOMRange" },
        { &sel_setDownloadDelegate_1, "setDownloadDelegate:" },
        { &sel_setEditingDelegate_1, "setEditingDelegate:" },
        { &sel_setUIDelegate_1, "setUIDelegate:" },
        { &sel_mainFrameTitle, "mainFrameTitle" },
        { &sel_setSelectedDOMRange_1affinity_1, "setSelectedDOMRange:affinity:" },
        { &sel_setTypingStyle_1, "setTypingStyle:" },
        { &sel_backForwardList, "backForwardList" },
        { &sel_deleteSelection, "deleteSelection" },
        { &sel_canGoForward, "canGoForward" },
        { &sel_styleDeclarationWithText_1, "styleDeclarationWithText:" },
        { &sel_moveToEndOfSentenceAndModifySelection_1, "moveToEndOfSentenceAndModifySelection:" },
        { &sel_replaceSelectionWithNode_1, "replaceSelectionWithNode:" },
        { &sel_URLTitleFromPasteboard_1, "URLTitleFromPasteboard:" },
        { &sel_UIDelegate, "UIDelegate" },
        { &sel_setMaintainsBackForwardList_1, "setMaintainsBackForwardList:" },
        { &sel_mainFrameIcon, "mainFrameIcon" },
        { &sel_setGroupName_1, "setGroupName:" },
        { &sel_canMakeTextSmaller, "canMakeTextSmaller" },
        { &sel_applicationNameForUserAgent, "applicationNameForUserAgent" },
        { &sel_supportsTextEncoding, "supportsTextEncoding" },
        { &sel_canShowMIMETypeAsHTML_1, "canShowMIMETypeAsHTML:" },
        { &sel_mediaStyle, "mediaStyle" },
        { &sel_makeTextLarger_1, "makeTextLarger:" },
        { &sel_writeElement_1withPasteboardTypes_1toPasteboard_1, "writeElement:withPasteboardTypes:toPasteboard:" },
        { &sel_estimatedProgress, "estimatedProgress" },
        { &sel_setCustomTextEncodingName_1, "setCustomTextEncodingName:" },
        { &sel_mainFrameDocument, "mainFrameDocument" },
        { &sel_isLoading, "isLoading" },
        { &sel_selectSentence_1, "selectSentence:" },
        { &sel_computedStyleForElement_1pseudoElement_1, "computedStyleForElement:pseudoElement:" },
        { &sel_writeSelectionWithPasteboardTypes_1toPasteboard_1, "writeSelectionWithPasteboardTypes:toPasteboard:" },
        { &sel_resourceLoadDelegate, "resourceLoadDelegate" },
        { &sel_reload, "reload" },
        { &sel_loadAlternateHTMLString_1baseURL_1forUnreachableURL_1, "loadAlternateHTMLString:baseURL:forUnreachableURL:" },
        { &sel_loadHTMLString_1baseURL_1, "loadHTMLString:baseURL:" },
        { &sel_loadArchive_1, "loadArchive:" },
        { &sel_webView, "webView" },
        { &sel_provisionalDataSource, "provisionalDataSource" },
        { &sel_findFrameNamed_1, "findFrameNamed:" },
        { &sel_DOMDocument, "DOMDocument" },
        { &sel_frameView, "frameView" },
        { &sel_globalContext, "globalContext" },
        { &sel_windowObject, "windowObject" },
        { &sel_childFrames, "childFrames" },
        { &sel_loadData_1MIMEType_1textEncodingName_1baseURL_1, "loadData:MIMEType:textEncodingName:baseURL:" },
        { &sel_initWithName_1webFrameView_1webView_1, "initWithName:webFrameView:webView:" },
        { &sel_frameElement, "frameElement" },
        { &sel_loadRequest_1, "loadRequest:" },
        { &sel_parentFrame, "parentFrame" },
        { &sel_representation, "representation" },
        { &sel_documentSource, "documentSource" },
        { &sel_webView_1didChangeLocationWithinPageForFrame_1, "webView:didChangeLocationWithinPageForFrame:" },
        { &sel_webView_1didFailProvisionalLoadWithError_1forFrame_1, "webView:didFailProvisionalLoadWithError:forFrame:" },
        { &sel_webView_1didFinishLoadForFrame_1, "webView:didFinishLoadForFrame:" },
        { &sel_webView_1didReceiveTitle_1forFrame_1, "webView:didReceiveTitle:forFrame:" },
        { &sel_webView_1didStartProvisionalLoadForFrame_1, "webView:didStartProvisionalLoadForFrame:" },
        { &sel_webView_1didCommitLoadForFrame_1, "webView:didCommitLoadForFrame:" },
        { &sel_webView_1resource_1didFinishLoadingFromDataSource_1, "webView:resource:didFinishLoadingFromDataSource:" },
        { &sel_webView_1resource_1didFailLoadingWithError_1fromDataSource_1, "webView:resource:didFailLoadingWithError:fromDataSource:" },
        { &sel_webView_1identifierForInitialRequest_1fromDataSource_1, "webView:identifierForInitialRequest:fromDataSource:" },
        { &sel_webView_1resource_1willSendRequest_1redirectResponse_1fromDataSource_1, "webView:resource:willSendRequest:redirectResponse:fromDataSource:" },
        { &sel_webView_1createWebViewWithRequest_1, "webView:createWebViewWithRequest:" },
        { &sel_webViewShow_1, "webViewShow:" },
        { &sel_webView_1setFrame_1, "webView:setFrame:" },
        { &sel_webViewClose_1, "webViewClose:" },
        { &sel_webView_1contextMenuItemsForElement_1defaultMenuItems_1, "webView:contextMenuItemsForElement:defaultMenuItems:" },
        { &sel_webView_1setStatusBarVisible_1, "webView:setStatusBarVisible:" },
        { &sel_webView_1setResizable_1, "webView:setResizable:" },
        { &sel_webView_1setToolbarsVisible_1, "webView:setToolbarsVisible:" },
        { &sel_webView_1setStatusText_1, "webView:setStatusText:" },
        { &sel_webViewFocus_1, "webViewFocus:" },
        { &sel_webViewUnfocus_1, "webViewUnfocus:" },
        { &sel_webView_1runJavaScriptAlertPanelWithMessage_1, "webView:runJavaScriptAlertPanelWithMessage:" },
        { &sel_webView_1runJavaScriptConfirmPanelWithMessage_1, "webView:runJavaScriptConfirmPanelWithMessage:" },
        { &sel_webView_1runOpenPanelForFileButtonWithResultListener_1, "webView:runOpenPanelForFileButtonWithResultListener:" },
        { &sel_webView_1mouseDidMoveOverElement_1modifierFlags_1, "webView:mouseDidMoveOverElement:modifierFlags:" },
        { &sel_webView_1printFrameView_1, "webView:printFrameView:" },
        { &sel_webView_1decidePolicyForMIMEType_1request_1frame_1decisionListener_1, "webView:decidePolicyForMIMEType:request:frame:decisionListener:" },
        { &sel_webView_1decidePolicyForNewWindowAction_1request_1newFrameName_1decisionListener_1, "webView:decidePolicyForNewWindowAction:request:newFrameName:decisionListener:" },
        { &sel_webView_1unableToImplementPolicyWithError_1frame_1, "webView:unableToImplementPolicyWithError:frame:" },
        { &sel_webView_1decidePolicyForNavigationAction_1request_1frame_1decisionListener_1, "webView:decidePolicyForNavigationAction:request:frame:decisionListener::" },
        { &sel_standardPreferences, "standardPreferences" },
        { &sel_setJavaEnabled_1, "setJavaEnabled:" },
        { &sel_use, "use" },
        { &sel_download, "download" },
        { &sel_ignore, "ignore" },
        { &sel_pageTitle, "pageTitle" },
        { &sel_webFrame, "webFrame" },
        { &sel_chooseFilename_1, "chooseFilename:" },
        { &sel_addEventListener_1listener_1useCapture_1, "addEventListener:listener:useCapture:" },
        { &sel_handleEvent_1, "handleEvent:" },
        { &sel_cancelable, "cancelable" },
        { &sel_timeStamp, "timeStamp" },
        { &sel_initEvent_1_1_1, "initEvent:::" },
        { &sel_bubbles, "bubbles" },
        { &sel_stopPropagation, "stopPropagation" },
        { &sel_initEvent_1canBubbleArg_1cancelableArg_1, "initEvent:canBubbleArg:cancelableArg:" },
        { &sel_eventPhase, "eventPhase" },
        { &sel_currentTarget, "currentTarget" },
        { &sel_preventDefault, "preventDefault" },
        { &sel_screenX, "screenX" },
        { &sel_initMouseEvent_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1, "initMouseEvent:::::::::::::::" },
        { &sel_clientY, "clientY" },
        { &sel_charCode, "charCode" },
        { &sel_relatedTarget, "relatedTarget" },
        { &sel_button, "button" },
        { &sel_clientX, "clientX" },
        { &sel_initMouseEvent_1canBubble_1cancelable_1view_1detail_1screenX_1screenY_1clientX_1clientY_1ctrlKey_1altKey_1shiftKey_1metaKey_1button_1relatedTarget_1, "initMouseEvent:canBubble:cancelable:view:detail:screenX:screenY:clientX:clientY:ctrlKey:altKey:shiftKey:metaKey:button:relatedTarget:" },
        { &sel_shiftKey, "shiftKey" },
        { &sel_ctrlKey, "ctrlKey" },
        { &sel_metaKey, "metaKey" },
        { &sel_altKey, "altKey" },
        { &sel_keyLocation, "keyLocation" },
        { &sel_getModifierState_1, "getModifierState:" },
        { &sel_screenY, "screenY" },
        { &sel_detail, "detail" },
        { &sel_handleNotification_1, "handleNotification:" },
        { &sel_setAllowsScrolling_1, "setAllowsScrolling:" },
        { &sel_allowsScrolling, "allowsScrolling" },
        { &sel_printDocumentView, "printDocumentView" },
        { &sel_documentViewShouldHandlePrint, "documentViewShouldHandlePrint" },
        { &sel_printOperationWithPrintInfo_1, "printOperationWithPrintInfo:" },
        { &sel_canPrintHeadersAndFooters, "canPrintHeadersAndFooters" },
        { &sel_wheelDelta, "wheelDelta" },
    ];

    /** Constants */
    public static const int NSAWTEventType = 16;
    public static const int NSAboveBottom = 4;
    public static const int NSAboveTop = 1;
    public static const int NSAddTraitFontAction = 2;
    public static const int NSAdobeCNS1CharacterCollection = 1;
    public static const int NSAdobeGB1CharacterCollection = 2;
    public static const int NSAdobeJapan1CharacterCollection = 3;
    public static const int NSAdobeJapan2CharacterCollection = 4;
    public static const int NSAdobeKorea1CharacterCollection = 5;
    public static const int NSAlertAlternateReturn = 0;
    public static const int NSAlertDefaultReturn = 1;
    public static const int NSAlertErrorReturn = -2;
    public static const int NSAlertFirstButtonReturn = 1000;
    public static const int NSAlertOtherReturn = -1;
    public static const int NSAlertSecondButtonReturn = 1001;
    public static const int NSAlertThirdButtonReturn = 1002;
    public static const int NSAllScrollerParts = 2;
    public static const int NSAlphaFirstBitmapFormat = 1;
    public static const int NSAlphaNonpremultipliedBitmapFormat = 2;
    public static const int NSAlphaShiftKeyMask = 65536;
    public static const int NSAlternateKeyMask = 524288;
    public static const int NSAnimationBlocking = 0;
    public static const int NSAnimationEaseIn = 1;
    public static const int NSAnimationEaseInOut = 0;
    public static const int NSAnimationEaseOut = 2;
    public static const int NSAnimationEffectDisappearingItemDefault = 0;
    public static const int NSAnimationEffectPoof = 10;
    public static const int NSAnimationLinear = 3;
    public static const int NSAnimationNonblocking = 1;
    public static const int NSAnimationNonblockingThreaded = 2;
    public static const int NSAnyEventMask = -1;
    public static const int NSAnyType = 0;
    public static const int NSAppKitDefined = 13;
    public static const int NSAppKitDefinedMask = 8192;
    public static const int NSAppKitVersionNumber10_0 = 577;
    public static const int NSAppKitVersionNumber10_1 = 620;
    public static const int NSAppKitVersionNumber10_2 = 663;
    public static const double NSAppKitVersionNumber10_2_3 = 663.60000000000002;
    public static const int NSAppKitVersionNumber10_3 = 743;
    public static const double NSAppKitVersionNumber10_3_2 = 743.13999999999999;
    public static const double NSAppKitVersionNumber10_3_3 = 743.20000000000005;
    public static const double NSAppKitVersionNumber10_3_5 = 743.24000000000001;
    public static const double NSAppKitVersionNumber10_3_7 = 743.33000000000004;
    public static const double NSAppKitVersionNumber10_3_9 = 743.36000000000001;
    public static const int NSAppKitVersionNumber10_4 = 824;
    public static const double NSAppKitVersionNumberWithColumnResizingBrowser = 685.00000000000000;
    public static const double NSAppKitVersionNumberWithContinuousScrollingBrowser = 680.00000000000000;
    public static const double NSAppKitVersionNumberWithCursorSizeSupport = 682.00000000000000;
    public static const double NSAppKitVersionNumberWithCustomSheetPosition = 686.00000000000000;
    public static const double NSAppKitVersionNumberWithDirectionalTabs = 631.00000000000000;
    public static const double NSAppKitVersionNumberWithPatternColorLeakFix = 641.00000000000000;
    public static const int NSApplicationActivatedEventType = 1;
    public static const int NSApplicationDeactivatedEventType = 2;
    public static const int NSApplicationDefined = 15;
    public static const int NSApplicationDefinedMask = 32768;
    public static const int NSApplicationDelegateReplyCancel = 1;
    public static const int NSApplicationDelegateReplyFailure = 2;
    public static const int NSApplicationDelegateReplySuccess = 0;
    public static const int NSAscendingPageOrder = 1;
    public static const int NSAtBottom = 5;
    public static const int NSAtTop = 2;
    public static const int NSAttachmentCharacter = 65532;
    public static const int NSAutoPagination = 0;
    public static const int NSAutosaveOperation = 3;
    public static const int NSBMPFileType = 1;
    public static const int NSBackTabCharacter = 25;
    public static const int NSBackgroundStyleDark = 1;
    public static const int NSBackgroundStyleLight = 0;
    public static const int NSBackgroundStyleLowered = 3;
    public static const int NSBackgroundStyleRaised = 2;
    public static const int NSBackgroundTab = 1;
    public static const int NSBackingStoreBuffered = 2;
    public static const int NSBackingStoreNonretained = 1;
    public static const int NSBackingStoreRetained = 0;
    public static const int NSBackspaceCharacter = 8;
    public static const int NSBacktabTextMovement = 18;
    public static const int NSBeginFunctionKey = 63274;
    public static const int NSBelowBottom = 6;
    public static const int NSBelowTop = 3;
    public static const int NSBevelLineJoinStyle = 2;
    public static const int NSBezelBorder = 2;
    public static const int NSBlueControlTint = 1;
    public static const int NSBoldFontMask = 2;
    public static const int NSBorderlessWindowMask = 0;
    public static const int NSBottomTabsBezelBorder = 2;
    public static const int NSBoxCustom = 4;
    public static const int NSBoxOldStyle = 3;
    public static const int NSBoxPrimary = 0;
    public static const int NSBoxSecondary = 1;
    public static const int NSBoxSeparator = 2;
    public static const int NSBreakFunctionKey = 63282;
    public static const int NSBrowserAutoColumnResizing = 1;
    public static const int NSBrowserDropAbove = 1;
    public static const int NSBrowserDropOn = 0;
    public static const int NSBrowserNoColumnResizing = 0;
    public static const int NSBrowserUserColumnResizing = 2;
    public static const int NSButtLineCapStyle = 0;
    public static const int NSCMYKColorSpaceModel = 2;
    public static const int NSCMYKModeColorPanel = 2;
    public static const int NSCancelButton = 0;
    public static const int NSCancelTextMovement = 23;
    public static const int NSCarriageReturnCharacter = 13;
    public static const int NSCellAllowsMixedState = 16;
    public static const int NSCellChangesContents = 14;
    public static const int NSCellDisabled = 0;
    public static const int NSCellEditable = 3;
    public static const int NSCellHasImageHorizontal = 12;
    public static const int NSCellHasImageOnLeftOrBottom = 13;
    public static const int NSCellHasOverlappingImage = 11;
    public static const int NSCellHighlighted = 5;
    public static const int NSCellHitContentArea = 1;
    public static const int NSCellHitEditableTextArea = 2;
    public static const int NSCellHitNone = 0;
    public static const int NSCellHitTrackableArea = 4;
    public static const int NSCellIsBordered = 10;
    public static const int NSCellIsInsetButton = 15;
    public static const int NSCellLightsByBackground = 9;
    public static const int NSCellLightsByContents = 6;
    public static const int NSCellLightsByGray = 7;
    public static const int NSCellState = 1;
    public static const int NSCenterTabStopType = 2;
    public static const int NSCenterTextAlignment = 2;
    public static const int NSChangeAutosaved = 4;
    public static const int NSChangeBackgroundCell = 8;
    public static const int NSChangeBackgroundCellMask = 8;
    public static const int NSChangeCleared = 2;
    public static const int NSChangeDone = 0;
    public static const int NSChangeGrayCell = 4;
    public static const int NSChangeGrayCellMask = 4;
    public static const int NSChangeReadOtherContents = 3;
    public static const int NSChangeRedone = 5;
    public static const int NSChangeUndone = 1;
    public static const int NSCircularBezelStyle = 7;
    public static const int NSCircularSlider = 1;
    public static const int NSClearControlTint = 7;
    public static const int NSClearDisplayFunctionKey = 63290;
    public static const int NSClearLineFunctionKey = 63289;
    public static const int NSClipPagination = 2;
    public static const int NSClockAndCalendarDatePickerStyle = 1;
    public static const int NSClosableWindowMask = 2;
    public static const int NSClosePathBezierPathElement = 3;
    public static const int NSColorListModeColorPanel = 5;
    public static const int NSColorPanelAllModesMask = 65535;
    public static const int NSColorPanelCMYKModeMask = 4;
    public static const int NSColorPanelColorListModeMask = 32;
    public static const int NSColorPanelCrayonModeMask = 128;
    public static const int NSColorPanelCustomPaletteModeMask = 16;
    public static const int NSColorPanelGrayModeMask = 1;
    public static const int NSColorPanelHSBModeMask = 8;
    public static const int NSColorPanelRGBModeMask = 2;
    public static const int NSColorPanelWheelModeMask = 64;
    public static const int NSColorRenderingIntentAbsoluteColorimetric = 1;
    public static const int NSColorRenderingIntentDefault = 0;
    public static const int NSColorRenderingIntentPerceptual = 3;
    public static const int NSColorRenderingIntentRelativeColorimetric = 2;
    public static const int NSColorRenderingIntentSaturation = 4;
    public static const int NSCommandKeyMask = 1048576;
    public static const int NSCompositeClear = 0;
    public static const int NSCompositeCopy = 1;
    public static const int NSCompositeDestinationAtop = 9;
    public static const int NSCompositeDestinationIn = 7;
    public static const int NSCompositeDestinationOut = 8;
    public static const int NSCompositeDestinationOver = 6;
    public static const int NSCompositeHighlight = 12;
    public static const int NSCompositePlusDarker = 11;
    public static const int NSCompositePlusLighter = 13;
    public static const int NSCompositeSourceAtop = 5;
    public static const int NSCompositeSourceIn = 3;
    public static const int NSCompositeSourceOut = 4;
    public static const int NSCompositeSourceOver = 2;
    public static const int NSCompositeXOR = 10;
    public static const int NSCompressedFontMask = 512;
    public static const int NSCondensedFontMask = 64;
    public static const int NSContentsCellMask = 1;
    public static const int NSContinuousCapacityLevelIndicatorStyle = 1;
    public static const int NSControlGlyph = 16777215;
    public static const int NSControlKeyMask = 262144;
    public static const int NSCrayonModeColorPanel = 7;
    public static const int NSCriticalAlertStyle = 2;
    public static const int NSCriticalRequest = 0;
    public static const int NSCursorPointingDevice = 2;
    public static const int NSCursorUpdate = 17;
    public static const int NSCursorUpdateMask = 131072;
    public static const int NSCurveToBezierPathElement = 2;
    public static const int NSCustomPaletteModeColorPanel = 4;
    public static const int NSDecimalTabStopType = 3;
    public static const int NSDefaultControlTint = 0;
    public static const int NSDefaultTokenStyle = 0;
    public static const int NSDeleteCharFunctionKey = 63294;
    public static const int NSDeleteCharacter = 127;
    public static const int NSDeleteFunctionKey = 63272;
    public static const int NSDeleteLineFunctionKey = 63292;
    public static const int NSDescendingPageOrder = -1;
    public static const int NSDeviceIndependentModifierFlagsMask = -65536;
    public static const int NSDeviceNColorSpaceModel = 4;
    public static const int NSDirectSelection = 0;
    public static const int NSDisclosureBezelStyle = 5;
    public static const int NSDiscreteCapacityLevelIndicatorStyle = 2;
    public static const int NSDisplayWindowRunLoopOrdering = 600000;
    public static const int NSDocModalWindowMask = 64;
    public static const int NSDockWindowLevel = 20;
    public static const int NSDoubleType = 6;
    public static const int NSDownArrowFunctionKey = 63233;
    public static const int NSDownTextMovement = 22;
    public static const int NSDragOperationAll = 15;
    public static const int NSDragOperationAll_Obsolete = 15;
    public static const int NSDragOperationCopy = 1;
    public static const int NSDragOperationDelete = 32;
    public static const int NSDragOperationEvery = -1;
    public static const int NSDragOperationGeneric = 4;
    public static const int NSDragOperationLink = 2;
    public static const int NSDragOperationMove = 16;
    public static const int NSDragOperationNone = 0;
    public static const int NSDragOperationPrivate = 8;
    public static const int NSDrawerClosedState = 0;
    public static const int NSDrawerClosingState = 3;
    public static const int NSDrawerOpenState = 2;
    public static const int NSDrawerOpeningState = 1;
    public static const int NSEndFunctionKey = 63275;
    public static const int NSEnterCharacter = 3;
    public static const int NSEraDatePickerElementFlag = 256;
    public static const int NSEraserPointingDevice = 3;
    public static const int NSEvenOddWindingRule = 1;
    public static const int NSExclude10_4ElementsIconCreationOption = 4;
    public static const int NSExcludeQuickDrawElementsIconCreationOption = 2;
    public static const int NSExecuteFunctionKey = 63298;
    public static const int NSExpandedFontMask = 32;
    public static const int NSF10FunctionKey = 63245;
    public static const int NSF11FunctionKey = 63246;
    public static const int NSF12FunctionKey = 63247;
    public static const int NSF13FunctionKey = 63248;
    public static const int NSF14FunctionKey = 63249;
    public static const int NSF15FunctionKey = 63250;
    public static const int NSF16FunctionKey = 63251;
    public static const int NSF17FunctionKey = 63252;
    public static const int NSF18FunctionKey = 63253;
    public static const int NSF19FunctionKey = 63254;
    public static const int NSF1FunctionKey = 63236;
    public static const int NSF20FunctionKey = 63255;
    public static const int NSF21FunctionKey = 63256;
    public static const int NSF22FunctionKey = 63257;
    public static const int NSF23FunctionKey = 63258;
    public static const int NSF24FunctionKey = 63259;
    public static const int NSF25FunctionKey = 63260;
    public static const int NSF26FunctionKey = 63261;
    public static const int NSF27FunctionKey = 63262;
    public static const int NSF28FunctionKey = 63263;
    public static const int NSF29FunctionKey = 63264;
    public static const int NSF2FunctionKey = 63237;
    public static const int NSF30FunctionKey = 63265;
    public static const int NSF31FunctionKey = 63266;
    public static const int NSF32FunctionKey = 63267;
    public static const int NSF33FunctionKey = 63268;
    public static const int NSF34FunctionKey = 63269;
    public static const int NSF35FunctionKey = 63270;
    public static const int NSF3FunctionKey = 63238;
    public static const int NSF4FunctionKey = 63239;
    public static const int NSF5FunctionKey = 63240;
    public static const int NSF6FunctionKey = 63241;
    public static const int NSF7FunctionKey = 63242;
    public static const int NSF8FunctionKey = 63243;
    public static const int NSF9FunctionKey = 63244;
    public static const int NSFPCurrentField = 134;
    public static const int NSFPPreviewButton = 131;
    public static const int NSFPPreviewField = 128;
    public static const int NSFPRevertButton = 130;
    public static const int NSFPSetButton = 132;
    public static const int NSFPSizeField = 129;
    public static const int NSFPSizeTitle = 133;
    public static const int NSFileHandlingPanelCancelButton = 0;
    public static const int NSFileHandlingPanelOKButton = 1;
    public static const int NSFindFunctionKey = 63301;
    public static const int NSFindPanelActionNext = 2;
    public static const int NSFindPanelActionPrevious = 3;
    public static const int NSFindPanelActionReplace = 5;
    public static const int NSFindPanelActionReplaceAll = 4;
    public static const int NSFindPanelActionReplaceAllInSelection = 8;
    public static const int NSFindPanelActionReplaceAndFind = 6;
    public static const int NSFindPanelActionSelectAll = 9;
    public static const int NSFindPanelActionSelectAllInSelection = 10;
    public static const int NSFindPanelActionSetFindString = 7;
    public static const int NSFindPanelActionShowFindPanel = 1;
    public static const int NSFindPanelSubStringMatchTypeContains = 0;
    public static const int NSFindPanelSubStringMatchTypeEndsWith = 3;
    public static const int NSFindPanelSubStringMatchTypeFullWord = 2;
    public static const int NSFindPanelSubStringMatchTypeStartsWith = 1;
    public static const int NSFitPagination = 1;
    public static const int NSFixedPitchFontMask = 1024;
    public static const int NSFlagsChanged = 12;
    public static const int NSFlagsChangedMask = 4096;
    public static const int NSFloatType = 3;
    public static const int NSFloatingPointSamplesBitmapFormat = 4;
    public static const int NSFloatingWindowLevel = 3;
    public static const int NSFocusRingAbove = 2;
    public static const int NSFocusRingBelow = 1;
    public static const int NSFocusRingOnly = 0;
    public static const int NSFocusRingTypeDefault = 0;
    public static const int NSFocusRingTypeExterior = 2;
    public static const int NSFocusRingTypeNone = 1;
    public static const int NSFontAntialiasedIntegerAdvancementsRenderingMode = 3;
    public static const int NSFontAntialiasedRenderingMode = 1;
    public static const int NSFontBoldTrait = 2;
    public static const int NSFontClarendonSerifsClass = 1073741824;
    public static const int NSFontCollectionApplicationOnlyMask = 1;
    public static const int NSFontCondensedTrait = 64;
    public static const int NSFontDefaultRenderingMode = 0;
    public static const int NSFontExpandedTrait = 32;
    public static const int NSFontFamilyClassMask = -268435456;
    public static const int NSFontFreeformSerifsClass = 1879048192;
    public static const int NSFontIntegerAdvancementsRenderingMode = 2;
    public static const int NSFontItalicTrait = 1;
    public static const int NSFontModernSerifsClass = 805306368;
    public static const int NSFontMonoSpaceTrait = 1024;
    public static const int NSFontOldStyleSerifsClass = 268435456;
    public static const int NSFontOrnamentalsClass = -1879048192;
    public static const int NSFontPanelAllEffectsModeMask = 1048320;
    public static const int NSFontPanelAllModesMask = -1;
    public static const int NSFontPanelCollectionModeMask = 4;
    public static const int NSFontPanelDocumentColorEffectModeMask = 2048;
    public static const int NSFontPanelFaceModeMask = 1;
    public static const int NSFontPanelShadowEffectModeMask = 4096;
    public static const int NSFontPanelSizeModeMask = 2;
    public static const int NSFontPanelStandardModesMask = 65535;
    public static const int NSFontPanelStrikethroughEffectModeMask = 512;
    public static const int NSFontPanelTextColorEffectModeMask = 1024;
    public static const int NSFontPanelUnderlineEffectModeMask = 256;
    public static const int NSFontSansSerifClass = -2147483648;
    public static const int NSFontScriptsClass = -1610612736;
    public static const int NSFontSlabSerifsClass = 1342177280;
    public static const int NSFontSymbolicClass = -1073741824;
    public static const int NSFontTransitionalSerifsClass = 536870912;
    public static const int NSFontUIOptimizedTrait = 4096;
    public static const int NSFontUnknownClass = 0;
    public static const int NSFontVerticalTrait = 2048;
    public static const int NSFormFeedCharacter = 12;
    public static const int NSFunctionKeyMask = 8388608;
    public static const int NSGIFFileType = 2;
    public static const int NSGlyphAttributeBidiLevel = 2;
    public static const int NSGlyphAttributeElastic = 1;
    public static const int NSGlyphAttributeInscribe = 5;
    public static const int NSGlyphAttributeSoft = 0;
    public static const int NSGlyphInscribeAbove = 2;
    public static const int NSGlyphInscribeBase = 0;
    public static const int NSGlyphInscribeBelow = 1;
    public static const int NSGlyphInscribeOverBelow = 4;
    public static const int NSGlyphInscribeOverstrike = 3;
    public static const int NSGradientConcaveStrong = 2;
    public static const int NSGradientConcaveWeak = 1;
    public static const int NSGradientConvexStrong = 4;
    public static const int NSGradientConvexWeak = 3;
    public static const int NSGradientDrawsAfterEndingLocation = 2;
    public static const int NSGradientDrawsBeforeStartingLocation = 1;
    public static const int NSGradientNone = 0;
    public static const int NSGraphiteControlTint = 6;
    public static const int NSGrayColorSpaceModel = 0;
    public static const int NSGrayModeColorPanel = 0;
    public static const int NSGrooveBorder = 3;
    public static const int NSHSBModeColorPanel = 3;
    public static const int NSHUDWindowMask = 8192;
    public static const int NSHeavierFontAction = 5;
    public static const int NSHelpButtonBezelStyle = 9;
    public static const int NSHelpFunctionKey = 63302;
    public static const int NSHelpKeyMask = 4194304;
    public static const int NSHighlightModeMatrix = 1;
    public static const int NSHomeFunctionKey = 63273;
    public static const int NSHorizontalRuler = 0;
    public static const int NSHourMinuteDatePickerElementFlag = 12;
    public static const int NSHourMinuteSecondDatePickerElementFlag = 14;
    public static const int NSIdentityMappingCharacterCollection = 0;
    public static const int NSIllegalTextMovement = 0;
    public static const int NSImageAbove = 5;
    public static const int NSImageAlignBottom = 5;
    public static const int NSImageAlignBottomLeft = 6;
    public static const int NSImageAlignBottomRight = 7;
    public static const int NSImageAlignCenter = 0;
    public static const int NSImageAlignLeft = 4;
    public static const int NSImageAlignRight = 8;
    public static const int NSImageAlignTop = 1;
    public static const int NSImageAlignTopLeft = 2;
    public static const int NSImageAlignTopRight = 3;
    public static const int NSImageBelow = 4;
    public static const int NSImageCacheAlways = 1;
    public static const int NSImageCacheBySize = 2;
    public static const int NSImageCacheDefault = 0;
    public static const int NSImageCacheNever = 3;
    public static const int NSImageCellType = 2;
    public static const int NSImageFrameButton = 4;
    public static const int NSImageFrameGrayBezel = 2;
    public static const int NSImageFrameGroove = 3;
    public static const int NSImageFrameNone = 0;
    public static const int NSImageFramePhoto = 1;
    public static const int NSImageInterpolationDefault = 0;
    public static const int NSImageInterpolationHigh = 3;
    public static const int NSImageInterpolationLow = 2;
    public static const int NSImageInterpolationNone = 1;
    public static const int NSImageLeft = 2;
    public static const int NSImageLoadStatusCancelled = 1;
    public static const int NSImageLoadStatusCompleted = 0;
    public static const int NSImageLoadStatusInvalidData = 2;
    public static const int NSImageLoadStatusReadError = 4;
    public static const int NSImageLoadStatusUnexpectedEOF = 3;
    public static const int NSImageOnly = 1;
    public static const int NSImageOverlaps = 6;
    public static const int NSImageRepLoadStatusCompleted = -6;
    public static const int NSImageRepLoadStatusInvalidData = -4;
    public static const int NSImageRepLoadStatusReadingHeader = -2;
    public static const int NSImageRepLoadStatusUnexpectedEOF = -5;
    public static const int NSImageRepLoadStatusUnknownType = -1;
    public static const int NSImageRepLoadStatusWillNeedAllData = -3;
    public static const int NSImageRepMatchesDevice = 0;
    public static const int NSImageRight = 3;
    public static const int NSImageScaleAxesIndependently = 1;
    public static const int NSImageScaleNone = 2;
    public static const int NSImageScaleProportionallyDown = 0;
    public static const int NSImageScaleProportionallyUpOrDown = 3;
    public static const int NSIndexedColorSpaceModel = 5;
    public static const int NSInformationalAlertStyle = 1;
    public static const int NSInformationalRequest = 10;
    public static const int NSInsertCharFunctionKey = 63293;
    public static const int NSInsertFunctionKey = 63271;
    public static const int NSInsertLineFunctionKey = 63291;
    public static const int NSIntType = 1;
    public static const int NSItalicFontMask = 1;
    public static const int NSJPEG2000FileType = 5;
    public static const int NSJPEGFileType = 3;
    public static const int NSJustifiedTextAlignment = 3;
    public static const int NSKeyDown = 10;
    public static const int NSKeyDownMask = 1024;
    public static const int NSKeyUp = 11;
    public static const int NSKeyUpMask = 2048;
    public static const int NSLABColorSpaceModel = 3;
    public static const int NSLandscapeOrientation = 1;
    public static const int NSLeftArrowFunctionKey = 63234;
    public static const int NSLeftMouseDown = 1;
    public static const int NSLeftMouseDownMask = 2;
    public static const int NSLeftMouseDragged = 6;
    public static const int NSLeftMouseDraggedMask = 64;
    public static const int NSLeftMouseUp = 2;
    public static const int NSLeftMouseUpMask = 4;
    public static const int NSLeftTabStopType = 0;
    public static const int NSLeftTabsBezelBorder = 1;
    public static const int NSLeftTextAlignment = 0;
    public static const int NSLeftTextMovement = 19;
    public static const int NSLighterFontAction = 6;
    public static const int NSLineBorder = 1;
    public static const int NSLineBreakByCharWrapping = 1;
    public static const int NSLineBreakByClipping = 2;
    public static const int NSLineBreakByTruncatingHead = 3;
    public static const int NSLineBreakByTruncatingMiddle = 5;
    public static const int NSLineBreakByTruncatingTail = 4;
    public static const int NSLineBreakByWordWrapping = 0;
    public static const int NSLineDoesntMove = 0;
    public static const int NSLineMovesDown = 3;
    public static const int NSLineMovesLeft = 1;
    public static const int NSLineMovesRight = 2;
    public static const int NSLineMovesUp = 4;
    public static const int NSLineSeparatorCharacter = 8232;
    public static const int NSLineSweepDown = 2;
    public static const int NSLineSweepLeft = 0;
    public static const int NSLineSweepRight = 1;
    public static const int NSLineSweepUp = 3;
    public static const int NSLineToBezierPathElement = 1;
    public static const int NSLinearSlider = 0;
    public static const int NSListModeMatrix = 2;
    public static const int NSMacintoshInterfaceStyle = 3;
    public static const int NSMainMenuWindowLevel = 24;
    public static const int NSMenuFunctionKey = 63285;
    public static const int NSMiniControlSize = 2;
    public static const int NSMiniaturizableWindowMask = 4;
    public static const int NSMiterLineJoinStyle = 0;
    public static const int NSMixedState = -1;
    public static const int NSModalPanelWindowLevel = 8;
    public static const int NSModeSwitchFunctionKey = 63303;
    public static const int NSMomentaryChangeButton = 5;
    public static const int NSMomentaryLight = 7;
    public static const int NSMomentaryLightButton = 0;
    public static const int NSMomentaryPushButton = 0;
    public static const int NSMomentaryPushInButton = 7;
    public static const int NSMouseEntered = 8;
    public static const int NSMouseEnteredMask = 256;
    public static const int NSMouseEventSubtype = 0;
    public static const int NSMouseExited = 9;
    public static const int NSMouseExitedMask = 512;
    public static const int NSMouseMoved = 5;
    public static const int NSMouseMovedMask = 32;
    public static const int NSMoveToBezierPathElement = 0;
    public static const int NSNarrowFontMask = 16;
    public static const int NSNativeShortGlyphPacking = 5;
    public static const int NSNaturalTextAlignment = 4;
    public static const int NSNewlineCharacter = 10;
    public static const int NSNextFunctionKey = 63296;
    public static const int NSNextStepInterfaceStyle = 1;
    public static const int NSNoBorder = 0;
    public static const int NSNoCellMask = 0;
    public static const int NSNoFontChangeAction = 0;
    public static const int NSNoImage = 0;
    public static const int NSNoInterfaceStyle = 0;
    public static const int NSNoModeColorPanel = -1;
    public static const int NSNoScrollerParts = 0;
    public static const int NSNoTabsBezelBorder = 4;
    public static const int NSNoTabsLineBorder = 5;
    public static const int NSNoTabsNoBorder = 6;
    public static const int NSNoTitle = 0;
    public static const int NSNoUnderlineStyle = 0;
    public static const int NSNonStandardCharacterSetFontMask = 8;
    public static const int NSNonZeroWindingRule = 0;
    public static const int NSNonactivatingPanelMask = 128;
    public static const int NSNormalWindowLevel = 0;
    public static const int NSNullCellType = 0;
    public static const int NSNullGlyph = 0;
    public static const int NSNumericPadKeyMask = 2097152;
    public static const int NSOKButton = 1;
    public static const int NSOPENGL_CURRENT_VERSION = 1;
    public static const int NSOffState = 0;
    public static const int NSOnOffButton = 6;
    public static const int NSOnState = 1;
    public static const int NSOnlyScrollerArrows = 1;
    public static const int NSOpenGLCPRasterizationEnable = 221;
    public static const int NSOpenGLCPStateValidation = 301;
    public static const int NSOpenGLCPSurfaceOpacity = 236;
    public static const int NSOpenGLCPSurfaceOrder = 235;
    public static const int NSOpenGLCPSwapInterval = 222;
    public static const int NSOpenGLCPSwapRectangle = 200;
    public static const int NSOpenGLCPSwapRectangleEnable = 201;
    public static const int NSOpenGLGOClearFormatCache = 502;
    public static const int NSOpenGLGOFormatCacheSize = 501;
    public static const int NSOpenGLGOResetLibrary = 504;
    public static const int NSOpenGLGORetainRenderers = 503;
    public static const int NSOpenGLPFAAccelerated = 73;
    public static const int NSOpenGLPFAAccumSize = 14;
    public static const int NSOpenGLPFAAllRenderers = 1;
    public static const int NSOpenGLPFAAllowOfflineRenderers = 96;
    public static const int NSOpenGLPFAAlphaSize = 11;
    public static const int NSOpenGLPFAAuxBuffers = 7;
    public static const int NSOpenGLPFAAuxDepthStencil = 57;
    public static const int NSOpenGLPFABackingStore = 76;
    public static const int NSOpenGLPFAClosestPolicy = 74;
    public static const int NSOpenGLPFAColorFloat = 58;
    public static const int NSOpenGLPFAColorSize = 8;
    public static const int NSOpenGLPFACompliant = 83;
    public static const int NSOpenGLPFADepthSize = 12;
    public static const int NSOpenGLPFADoubleBuffer = 5;
    public static const int NSOpenGLPFAFullScreen = 54;
    public static const int NSOpenGLPFAMPSafe = 78;
    public static const int NSOpenGLPFAMaximumPolicy = 52;
    public static const int NSOpenGLPFAMinimumPolicy = 51;
    public static const int NSOpenGLPFAMultiScreen = 81;
    public static const int NSOpenGLPFAMultisample = 59;
    public static const int NSOpenGLPFANoRecovery = 72;
    public static const int NSOpenGLPFAOffScreen = 53;
    public static const int NSOpenGLPFAPixelBuffer = 90;
    public static const int NSOpenGLPFARendererID = 70;
    public static const int NSOpenGLPFARobust = 75;
    public static const int NSOpenGLPFASampleAlpha = 61;
    public static const int NSOpenGLPFASampleBuffers = 55;
    public static const int NSOpenGLPFASamples = 56;
    public static const int NSOpenGLPFAScreenMask = 84;
    public static const int NSOpenGLPFASingleRenderer = 71;
    public static const int NSOpenGLPFAStencilSize = 13;
    public static const int NSOpenGLPFAStereo = 6;
    public static const int NSOpenGLPFASupersample = 60;
    public static const int NSOpenGLPFAVirtualScreenCount = 128;
    public static const int NSOpenGLPFAWindow = 80;
    public static const int NSOtherMouseDown = 25;
    public static const int NSOtherMouseDownMask = 33554432;
    public static const int NSOtherMouseDragged = 27;
    public static const int NSOtherMouseDraggedMask = 134217728;
    public static const int NSOtherMouseUp = 26;
    public static const int NSOtherMouseUpMask = 67108864;
    public static const int NSOtherTextMovement = 0;
    public static const int NSOutlineViewDropOnItemIndex = -1;
    public static const int NSPNGFileType = 4;
    public static const int NSPageDownFunctionKey = 63277;
    public static const int NSPageUpFunctionKey = 63276;
    public static const int NSParagraphSeparatorCharacter = 8233;
    public static const int NSPathStyleNavigationBar = 1;
    public static const int NSPathStylePopUp = 2;
    public static const int NSPathStyleStandard = 0;
    public static const int NSPatternColorSpaceModel = 6;
    public static const int NSPauseFunctionKey = 63280;
    public static const int NSPenLowerSideMask = 2;
    public static const int NSPenPointingDevice = 1;
    public static const int NSPenTipMask = 1;
    public static const int NSPenUpperSideMask = 4;
    public static const int NSPeriodic = 16;
    public static const int NSPeriodicMask = 65536;
    public static const int NSPlainTextTokenStyle = 1;
    public static const int NSPopUpArrowAtBottom = 2;
    public static const int NSPopUpArrowAtCenter = 1;
    public static const int NSPopUpMenuWindowLevel = 101;
    public static const int NSPopUpNoArrow = 0;
    public static const int NSPortraitOrientation = 0;
    public static const int NSPositiveDoubleType = 7;
    public static const int NSPositiveFloatType = 4;
    public static const int NSPositiveIntType = 2;
    public static const int NSPosterFontMask = 256;
    public static const int NSPowerOffEventType = 1;
    public static const int NSPressedTab = 2;
    public static const int NSPrevFunctionKey = 63295;
    public static const int NSPrintFunctionKey = 63288;
    public static const int NSPrintPanelShowsCopies = 1;
    public static const int NSPrintPanelShowsOrientation = 8;
    public static const int NSPrintPanelShowsPageRange = 2;
    public static const int NSPrintPanelShowsPageSetupAccessory = 256;
    public static const int NSPrintPanelShowsPaperSize = 4;
    public static const int NSPrintPanelShowsPreview = 131072;
    public static const int NSPrintPanelShowsScaling = 16;
    public static const int NSPrintScreenFunctionKey = 63278;
    public static const int NSPrinterTableError = 2;
    public static const int NSPrinterTableNotFound = 1;
    public static const int NSPrinterTableOK = 0;
    public static const int NSPrintingCancelled = 0;
    public static const int NSPrintingFailure = 3;
    public static const int NSPrintingReplyLater = 2;
    public static const int NSPrintingSuccess = 1;
    public static const int NSProgressIndicatorBarStyle = 0;
    public static const int NSProgressIndicatorPreferredAquaThickness = 12;
    public static const int NSProgressIndicatorPreferredLargeThickness = 18;
    public static const int NSProgressIndicatorPreferredSmallThickness = 10;
    public static const int NSProgressIndicatorPreferredThickness = 14;
    public static const int NSProgressIndicatorSpinningStyle = 1;
    public static const int NSPushInCell = 2;
    public static const int NSPushInCellMask = 2;
    public static const int NSPushOnPushOffButton = 1;
    public static const int NSQTMovieLoopingBackAndForthPlayback = 2;
    public static const int NSQTMovieLoopingPlayback = 1;
    public static const int NSQTMovieNormalPlayback = 0;
    public static const int NSRGBColorSpaceModel = 1;
    public static const int NSRGBModeColorPanel = 1;
    public static const int NSRadioButton = 4;
    public static const int NSRadioModeMatrix = 0;
    public static const int NSRangeDateMode = 1;
    public static const int NSRatingLevelIndicatorStyle = 3;
    public static const int NSRecessedBezelStyle = 13;
    public static const int NSRedoFunctionKey = 63300;
    public static const int NSRegularControlSize = 0;
    public static const int NSRegularSquareBezelStyle = 2;
    public static const int NSRelevancyLevelIndicatorStyle = 0;
    public static const int NSRemoveTraitFontAction = 7;
    public static const int NSResetCursorRectsRunLoopOrdering = 700000;
    public static const int NSResetFunctionKey = 63283;
    public static const int NSResizableWindowMask = 8;
    public static const int NSReturnTextMovement = 16;
    public static const int NSRightArrowFunctionKey = 63235;
    public static const int NSRightMouseDown = 3;
    public static const int NSRightMouseDownMask = 8;
    public static const int NSRightMouseDragged = 7;
    public static const int NSRightMouseDraggedMask = 128;
    public static const int NSRightMouseUp = 4;
    public static const int NSRightMouseUpMask = 16;
    public static const int NSRightTabStopType = 1;
    public static const int NSRightTabsBezelBorder = 3;
    public static const int NSRightTextAlignment = 1;
    public static const int NSRightTextMovement = 20;
    public static const int NSRoundLineCapStyle = 1;
    public static const int NSRoundLineJoinStyle = 1;
    public static const int NSRoundRectBezelStyle = 12;
    public static const int NSRoundedBezelStyle = 1;
    public static const int NSRoundedDisclosureBezelStyle = 14;
    public static const int NSRoundedTokenStyle = 2;
    public static const int NSRuleEditorNestingModeCompound = 2;
    public static const int NSRuleEditorNestingModeList = 1;
    public static const int NSRuleEditorNestingModeSimple = 3;
    public static const int NSRuleEditorNestingModeSingle = 0;
    public static const int NSRuleEditorRowTypeCompound = 1;
    public static const int NSRuleEditorRowTypeSimple = 0;
    public static const int NSRunAbortedResponse = -1001;
    public static const int NSRunContinuesResponse = -1002;
    public static const int NSRunStoppedResponse = -1000;
    public static const int NSSaveAsOperation = 1;
    public static const int NSSaveOperation = 0;
    public static const int NSSaveToOperation = 2;
    public static const int NSScaleNone = 2;
    public static const int NSScaleProportionally = 0;
    public static const int NSScaleToFit = 1;
    public static const int NSScreenChangedEventType = 8;
    public static const int NSScreenSaverWindowLevel = 1000;
    public static const int NSScrollLockFunctionKey = 63279;
    public static const int NSScrollWheel = 22;
    public static const int NSScrollWheelMask = 4194304;
    public static const int NSScrollerArrowsDefaultSetting = 0;
    public static const int NSScrollerArrowsMaxEnd = 0;
    public static const int NSScrollerArrowsMinEnd = 1;
    public static const int NSScrollerArrowsNone = 2;
    public static const int NSScrollerDecrementArrow = 1;
    public static const int NSScrollerDecrementLine = 4;
    public static const int NSScrollerDecrementPage = 1;
    public static const int NSScrollerIncrementArrow = 0;
    public static const int NSScrollerIncrementLine = 5;
    public static const int NSScrollerIncrementPage = 3;
    public static const int NSScrollerKnob = 2;
    public static const int NSScrollerKnobSlot = 6;
    public static const int NSScrollerNoPart = 0;
    public static const int NSSearchFieldClearRecentsMenuItemTag = 1002;
    public static const int NSSearchFieldNoRecentsMenuItemTag = 1003;
    public static const int NSSearchFieldRecentsMenuItemTag = 1001;
    public static const int NSSearchFieldRecentsTitleMenuItemTag = 1000;
    public static const int NSSegmentStyleAutomatic = 0;
    public static const int NSSegmentStyleCapsule = 5;
    public static const int NSSegmentStyleRoundRect = 3;
    public static const int NSSegmentStyleRounded = 1;
    public static const int NSSegmentStyleSmallSquare = 6;
    public static const int NSSegmentStyleTexturedRounded = 2;
    public static const int NSSegmentStyleTexturedSquare = 4;
    public static const int NSSegmentSwitchTrackingMomentary = 2;
    public static const int NSSegmentSwitchTrackingSelectAny = 1;
    public static const int NSSegmentSwitchTrackingSelectOne = 0;
    public static const int NSSelectByCharacter = 0;
    public static const int NSSelectByParagraph = 2;
    public static const int NSSelectByWord = 1;
    public static const int NSSelectFunctionKey = 63297;
    public static const int NSSelectedTab = 0;
    public static const int NSSelectingNext = 1;
    public static const int NSSelectingPrevious = 2;
    public static const int NSSelectionAffinityDownstream = 1;
    public static const int NSSelectionAffinityUpstream = 0;
    public static const int NSServiceApplicationLaunchFailedError = 66561;
    public static const int NSServiceApplicationNotFoundError = 66560;
    public static const int NSServiceErrorMaximum = 66817;
    public static const int NSServiceErrorMinimum = 66560;
    public static const int NSServiceInvalidPasteboardDataError = 66563;
    public static const int NSServiceMalformedServiceDictionaryError = 66564;
    public static const int NSServiceMiscellaneousError = 66800;
    public static const int NSServiceRequestTimedOutError = 66562;
    public static const int NSShadowlessSquareBezelStyle = 6;
    public static const int NSShiftKeyMask = 131072;
    public static const int NSShowControlGlyphs = 1;
    public static const int NSShowInvisibleGlyphs = 2;
    public static const int NSSingleDateMode = 0;
    public static const int NSSingleUnderlineStyle = 1;
    public static const int NSSizeDownFontAction = 4;
    public static const int NSSizeUpFontAction = 3;
    public static const int NSSmallCapsFontMask = 128;
    public static const int NSSmallControlSize = 1;
    public static const int NSSmallIconButtonBezelStyle = 2;
    public static const int NSSmallSquareBezelStyle = 10;
    public static const int NSSpecialPageOrder = 0;
    public static const int NSSpeechImmediateBoundary = 0;
    public static const int NSSpeechSentenceBoundary = 2;
    public static const int NSSpeechWordBoundary = 1;
    public static const int NSSpellingStateGrammarFlag = 2;
    public static const int NSSpellingStateSpellingFlag = 1;
    public static const int NSSplitViewDividerStyleThick = 1;
    public static const int NSSplitViewDividerStyleThin = 2;
    public static const int NSSquareLineCapStyle = 2;
    public static const int NSSquareStatusItemLength = -2;
    public static const int NSStatusWindowLevel = 25;
    public static const int NSStopFunctionKey = 63284;
    public static const int NSStringDrawingDisableScreenFontSubstitution = 4;
    public static const int NSStringDrawingOneShot = 16;
    public static const int NSStringDrawingTruncatesLastVisibleLine = 32;
    public static const int NSStringDrawingUsesDeviceMetrics = 8;
    public static const int NSStringDrawingUsesFontLeading = 2;
    public static const int NSStringDrawingUsesLineFragmentOrigin = 1;
    public static const int NSSubmenuWindowLevel = 3;
    public static const int NSSwitchButton = 3;
    public static const int NSSysReqFunctionKey = 63281;
    public static const int NSSystemDefined = 14;
    public static const int NSSystemDefinedMask = 16384;
    public static const int NSSystemFunctionKey = 63287;
    public static const int NSTIFFCompressionCCITTFAX3 = 3;
    public static const int NSTIFFCompressionCCITTFAX4 = 4;
    public static const int NSTIFFCompressionJPEG = 6;
    public static const int NSTIFFCompressionLZW = 5;
    public static const int NSTIFFCompressionNEXT = 32766;
    public static const int NSTIFFCompressionNone = 1;
    public static const int NSTIFFCompressionOldJPEG = 32865;
    public static const int NSTIFFCompressionPackBits = 32773;
    public static const int NSTIFFFileType = 0;
    public static const int NSTabCharacter = 9;
    public static const int NSTabTextMovement = 17;
    public static const int NSTableColumnAutoresizingMask = 1;
    public static const int NSTableColumnNoResizing = 0;
    public static const int NSTableColumnUserResizingMask = 2;
    public static const int NSTableViewDropAbove = 1;
    public static const int NSTableViewDropOn = 0;
    public static const int NSTableViewFirstColumnOnlyAutoresizingStyle = 5;
    public static const int NSTableViewGridNone = 0;
    public static const int NSTableViewLastColumnOnlyAutoresizingStyle = 4;
    public static const int NSTableViewNoColumnAutoresizing = 0;
    public static const int NSTableViewReverseSequentialColumnAutoresizingStyle = 3;
    public static const int NSTableViewSelectionHighlightStyleRegular = 0;
    public static const int NSTableViewSelectionHighlightStyleSourceList = 1;
    public static const int NSTableViewSequentialColumnAutoresizingStyle = 2;
    public static const int NSTableViewSolidHorizontalGridLineMask = 2;
    public static const int NSTableViewSolidVerticalGridLineMask = 1;
    public static const int NSTableViewUniformColumnAutoresizingStyle = 1;
    public static const int NSTabletPoint = 23;
    public static const int NSTabletPointEventSubtype = 1;
    public static const int NSTabletPointMask = 8388608;
    public static const int NSTabletProximity = 24;
    public static const int NSTabletProximityEventSubtype = 2;
    public static const int NSTabletProximityMask = 16777216;
    public static const int NSTerminateCancel = 0;
    public static const int NSTerminateLater = 2;
    public static const int NSTerminateNow = 1;
    public static const int NSTextBlockAbsoluteValueType = 0;
    public static const int NSTextBlockBaselineAlignment = 3;
    public static const int NSTextBlockBorder = 0;
    public static const int NSTextBlockBottomAlignment = 2;
    public static const int NSTextBlockHeight = 4;
    public static const int NSTextBlockMargin = 1;
    public static const int NSTextBlockMaximumHeight = 6;
    public static const int NSTextBlockMaximumWidth = 2;
    public static const int NSTextBlockMiddleAlignment = 1;
    public static const int NSTextBlockMinimumHeight = 5;
    public static const int NSTextBlockMinimumWidth = 1;
    public static const int NSTextBlockPadding = -1;
    public static const int NSTextBlockPercentageValueType = 1;
    public static const int NSTextBlockTopAlignment = 0;
    public static const int NSTextBlockWidth = 0;
    public static const int NSTextCellType = 1;
    public static const int NSTextFieldAndStepperDatePickerStyle = 0;
    public static const int NSTextFieldDatePickerStyle = 2;
    public static const int NSTextFieldRoundedBezel = 1;
    public static const int NSTextFieldSquareBezel = 0;
    public static const int NSTextListPrependEnclosingMarker = 1;
    public static const int NSTextReadInapplicableDocumentTypeError = 65806;
    public static const int NSTextReadWriteErrorMaximum = 66303;
    public static const int NSTextReadWriteErrorMinimum = 65792;
    public static const int NSTextStorageEditedAttributes = 1;
    public static const int NSTextStorageEditedCharacters = 2;
    public static const int NSTextTableAutomaticLayoutAlgorithm = 0;
    public static const int NSTextTableFixedLayoutAlgorithm = 1;
    public static const int NSTextWriteInapplicableDocumentTypeError = 66062;
    public static const int NSTexturedBackgroundWindowMask = 256;
    public static const int NSTexturedRoundedBezelStyle = 11;
    public static const int NSTexturedSquareBezelStyle = 8;
    public static const int NSThickSquareBezelStyle = 3;
    public static const int NSThickerSquareBezelStyle = 4;
    public static const int NSTickMarkAbove = 1;
    public static const int NSTickMarkBelow = 0;
    public static const int NSTickMarkLeft = 1;
    public static const int NSTickMarkRight = 0;
    public static const int NSTimeZoneDatePickerElementFlag = 16;
    public static const int NSTitledWindowMask = 1;
    public static const int NSToggleButton = 2;
    public static const int NSToolbarDisplayModeDefault = 0;
    public static const int NSToolbarDisplayModeIconAndLabel = 1;
    public static const int NSToolbarDisplayModeIconOnly = 2;
    public static const int NSToolbarDisplayModeLabelOnly = 3;
    public static const int NSToolbarItemVisibilityPriorityHigh = 1000;
    public static const int NSToolbarItemVisibilityPriorityLow = -1000;
    public static const int NSToolbarItemVisibilityPriorityStandard = 0;
    public static const int NSToolbarItemVisibilityPriorityUser = 2000;
    public static const int NSToolbarSizeModeDefault = 0;
    public static const int NSToolbarSizeModeRegular = 1;
    public static const int NSToolbarSizeModeSmall = 2;
    public static const int NSTopTabsBezelBorder = 0;
    public static const int NSTornOffMenuWindowLevel = 3;
    public static const int NSTrackModeMatrix = 3;
    public static const int NSTrackingActiveAlways = 128;
    public static const int NSTrackingActiveInActiveApp = 64;
    public static const int NSTrackingActiveInKeyWindow = 32;
    public static const int NSTrackingActiveWhenFirstResponder = 16;
    public static const int NSTrackingAssumeInside = 256;
    public static const int NSTrackingCursorUpdate = 4;
    public static const int NSTrackingEnabledDuringMouseDrag = 1024;
    public static const int NSTrackingInVisibleRect = 512;
    public static const int NSTrackingMouseEnteredAndExited = 1;
    public static const int NSTrackingMouseMoved = 2;
    public static const int NSTypesetterBehavior_10_2 = 2;
    public static const int NSTypesetterBehavior_10_2_WithCompatibility = 1;
    public static const int NSTypesetterBehavior_10_3 = 3;
    public static const int NSTypesetterBehavior_10_4 = 4;
    public static const int NSTypesetterContainerBreakAction = 32;
    public static const int NSTypesetterHorizontalTabAction = 4;
    public static const int NSTypesetterLatestBehavior = -1;
    public static const int NSTypesetterLineBreakAction = 8;
    public static const int NSTypesetterOriginalBehavior = 0;
    public static const int NSTypesetterParagraphBreakAction = 16;
    public static const int NSTypesetterWhitespaceAction = 2;
    public static const int NSTypesetterZeroAdvancementAction = 1;
    public static const int NSUnboldFontMask = 4;
    public static const int NSUnderlinePatternDash = 512;
    public static const int NSUnderlinePatternDashDot = 768;
    public static const int NSUnderlinePatternDashDotDot = 1024;
    public static const int NSUnderlinePatternDot = 256;
    public static const int NSUnderlinePatternSolid = 0;
    public static const int NSUnderlineStyleDouble = 9;
    public static const int NSUnderlineStyleNone = 0;
    public static const int NSUnderlineStyleSingle = 1;
    public static const int NSUnderlineStyleThick = 2;
    public static const int NSUndoFunctionKey = 63299;
    public static const int NSUnifiedTitleAndToolbarWindowMask = 4096;
    public static const int NSUnitalicFontMask = 16777216;
    public static const int NSUnknownColorSpaceModel = -1;
    public static const int NSUnknownPageOrder = 2;
    public static const int NSUnknownPointingDevice = 0;
    public static const int NSUnscaledWindowMask = 2048;
    public static const int NSUpArrowFunctionKey = 63232;
    public static const int NSUpTextMovement = 21;
    public static const int NSUpdateWindowsRunLoopOrdering = 500000;
    public static const int NSUserFunctionKey = 63286;
    public static const int NSUtilityWindowMask = 16;
    public static const int NSVariableStatusItemLength = -1;
    public static const int NSVerticalRuler = 1;
    public static const int NSViaPanelFontAction = 1;
    public static const int NSViewHeightSizable = 16;
    public static const int NSViewMaxXMargin = 4;
    public static const int NSViewMaxYMargin = 32;
    public static const int NSViewMinXMargin = 1;
    public static const int NSViewMinYMargin = 8;
    public static const int NSViewNotSizable = 0;
    public static const int NSViewWidthSizable = 2;
    public static const int NSWantsBidiLevels = 4;
    public static const int NSWarningAlertStyle = 0;
    public static const int NSWheelModeColorPanel = 6;
    public static const int NSWindowAbove = 1;
    public static const int NSWindowBackingLocationDefault = 0;
    public static const int NSWindowBackingLocationMainMemory = 2;
    public static const int NSWindowBackingLocationVideoMemory = 1;
    public static const int NSWindowBelow = -1;
    public static const int NSWindowCloseButton = 0;
    public static const int NSWindowCollectionBehaviorCanJoinAllSpaces = 1;
    public static const int NSWindowCollectionBehaviorDefault = 0;
    public static const int NSWindowCollectionBehaviorMoveToActiveSpace = 2;
    public static const int NSWindowDocumentIconButton = 4;
    public static const int NSWindowExposedEventType = 0;
    public static const int NSWindowMiniaturizeButton = 1;
    public static const int NSWindowMovedEventType = 4;
    public static const int NSWindowOut = 0;
    public static const int NSWindowSharingNone = 0;
    public static const int NSWindowSharingReadOnly = 1;
    public static const int NSWindowSharingReadWrite = 2;
    public static const int NSWindowToolbarButton = 3;
    public static const int NSWindowZoomButton = 2;
    public static const int NSWindows95InterfaceStyle = 2;
    public static const int NSWorkspaceLaunchAllowingClassicStartup = 131072;
    public static const int NSWorkspaceLaunchAndHide = 1048576;
    public static const int NSWorkspaceLaunchAndHideOthers = 2097152;
    public static const int NSWorkspaceLaunchAndPrint = 2;
    public static const int NSWorkspaceLaunchAsync = 65536;
    public static const int NSWorkspaceLaunchDefault = 196608;
    public static const int NSWorkspaceLaunchInhibitingBackgroundOnly = 128;
    public static const int NSWorkspaceLaunchNewInstance = 524288;
    public static const int NSWorkspaceLaunchPreferringClassic = 262144;
    public static const int NSWorkspaceLaunchWithoutActivation = 512;
    public static const int NSWorkspaceLaunchWithoutAddingToRecents = 256;
    public static const int NSWritingDirectionLeftToRight = 0;
    public static const int NSWritingDirectionNatural = -1;
    public static const int NSWritingDirectionRightToLeft = 1;
    public static const int NSYearMonthDatePickerElementFlag = 192;
    public static const int NSYearMonthDayDatePickerElementFlag = 224;
    public static const int NSASCIIStringEncoding = 1;
    public static const int NSAdminApplicationDirectory = 4;
    public static const int NSAggregateExpressionType = 14;
    public static const int NSAllApplicationsDirectory = 100;
    public static const int NSAllDomainsMask = 65535;
    public static const int NSAllLibrariesDirectory = 101;
    public static const int NSAllPredicateModifier = 1;
    public static const int NSAnchoredSearch = 8;
    public static const int NSAndPredicateType = 1;
    public static const int NSAnyPredicateModifier = 2;
    public static const int NSApplicationDirectory = 1;
    public static const int NSApplicationSupportDirectory = 14;
    public static const int NSArgumentEvaluationScriptError = 3;
    public static const int NSArgumentsWrongScriptError = 6;
    public static const int NSAtomicWrite = 1;
    public static const int NSBackwardsSearch = 4;
    public static const int NSBeginsWithComparison = 5;
    public static const int NSBeginsWithPredicateOperatorType = 8;
    public static const int NSBetweenPredicateOperatorType = 100;
    public static const int NSBundleExecutableArchitectureI386 = 7;
    public static const int NSBundleExecutableArchitecturePPC = 18;
    public static const int NSBundleExecutableArchitecturePPC64 = 16777234;
    public static const int NSBundleExecutableArchitectureX86_64 = 16777223;
    public static const int NSCachesDirectory = 13;
    public static const int NSCalculationDivideByZero = 4;
    public static const int NSCalculationLossOfPrecision = 1;
    public static const int NSCalculationNoError = 0;
    public static const int NSCalculationOverflow = 3;
    public static const int NSCalculationUnderflow = 2;
    public static const int NSCannotCreateScriptCommandError = 10;
    public static const int NSCaseInsensitivePredicateOption = 1;
    public static const int NSCaseInsensitiveSearch = 1;
    public static const int NSCollectorDisabledOption = 2;
    public static const int NSConstantValueExpressionType = 0;
    public static const int NSContainerSpecifierError = 2;
    public static const int NSContainsComparison = 7;
    public static const int NSContainsPredicateOperatorType = 99;
    public static const int NSCoreServiceDirectory = 10;
    public static const int NSCustomSelectorPredicateOperatorType = 11;
    public static const int NSDateFormatterBehavior10_0 = 1000;
    public static const int NSDateFormatterBehavior10_4 = 1040;
    public static const int NSDateFormatterBehaviorDefault = 0;
    public static const int NSDateFormatterFullStyle = 4;
    public static const int NSDateFormatterLongStyle = 3;
    public static const int NSDateFormatterMediumStyle = 2;
    public static const int NSDateFormatterNoStyle = 0;
    public static const int NSDateFormatterShortStyle = 1;
    public static const int NSDayCalendarUnit = 16;
    public static const int NSDecimalMaxSize = 8;
    public static const int NSDecimalNoScale = 32767;
    public static const int NSDemoApplicationDirectory = 2;
    public static const int NSDesktopDirectory = 12;
    public static const int NSDeveloperApplicationDirectory = 3;
    public static const int NSDeveloperDirectory = 6;
    public static const int NSDiacriticInsensitivePredicateOption = 2;
    public static const int NSDiacriticInsensitiveSearch = 128;
    public static const int NSDirectPredicateModifier = 0;
    public static const int NSDocumentDirectory = 9;
    public static const int NSDocumentationDirectory = 8;
    public static const int NSDownloadsDirectory = 15;
    public static const int NSEndsWithComparison = 6;
    public static const int NSEndsWithPredicateOperatorType = 9;
    public static const int NSEqualToComparison = 0;
    public static const int NSEqualToPredicateOperatorType = 4;
    public static const int NSEraCalendarUnit = 2;
    public static const int NSEvaluatedObjectExpressionType = 1;
    public static const int NSEverySubelement = 1;
    public static const int NSExecutableArchitectureMismatchError = 3585;
    public static const int NSExecutableErrorMaximum = 3839;
    public static const int NSExecutableErrorMinimum = 3584;
    public static const int NSExecutableLinkError = 3588;
    public static const int NSExecutableLoadError = 3587;
    public static const int NSExecutableNotLoadableError = 3584;
    public static const int NSExecutableRuntimeMismatchError = 3586;
    public static const int NSFileErrorMaximum = 1023;
    public static const int NSFileErrorMinimum = 0;
    public static const int NSFileLockingError = 255;
    public static const int NSFileNoSuchFileError = 4;
    public static const int NSFileReadCorruptFileError = 259;
    public static const int NSFileReadInapplicableStringEncodingError = 261;
    public static const int NSFileReadInvalidFileNameError = 258;
    public static const int NSFileReadNoPermissionError = 257;
    public static const int NSFileReadNoSuchFileError = 260;
    public static const int NSFileReadTooLargeError = 263;
    public static const int NSFileReadUnknownError = 256;
    public static const int NSFileReadUnknownStringEncodingError = 264;
    public static const int NSFileReadUnsupportedSchemeError = 262;
    public static const int NSFileWriteInapplicableStringEncodingError = 517;
    public static const int NSFileWriteInvalidFileNameError = 514;
    public static const int NSFileWriteNoPermissionError = 513;
    public static const int NSFileWriteOutOfSpaceError = 640;
    public static const int NSFileWriteUnknownError = 512;
    public static const int NSFileWriteUnsupportedSchemeError = 518;
    public static const int NSForcedOrderingSearch = 512;
    public static const int NSFormattingError = 2048;
    public static const int NSFormattingErrorMaximum = 2559;
    public static const int NSFormattingErrorMinimum = 2048;
    public static const double NSFoundationVersionNumber10_0 = 397.39999999999998;
    public static const double NSFoundationVersionNumber10_1 = 425.00000000000000;
    public static const double NSFoundationVersionNumber10_1_1 = 425.00000000000000;
    public static const double NSFoundationVersionNumber10_1_2 = 425.00000000000000;
    public static const double NSFoundationVersionNumber10_1_3 = 425.00000000000000;
    public static const double NSFoundationVersionNumber10_1_4 = 425.00000000000000;
    public static const double NSFoundationVersionNumber10_2 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_1 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_2 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_3 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_4 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_5 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_6 = 462.00000000000000;
    public static const double NSFoundationVersionNumber10_2_7 = 462.69999999999999;
    public static const double NSFoundationVersionNumber10_2_8 = 462.69999999999999;
    public static const double NSFoundationVersionNumber10_3 = 500.00000000000000;
    public static const double NSFoundationVersionNumber10_3_1 = 500.00000000000000;
    public static const double NSFoundationVersionNumber10_3_2 = 500.30000000000001;
    public static const double NSFoundationVersionNumber10_3_3 = 500.54000000000002;
    public static const double NSFoundationVersionNumber10_3_4 = 500.56000000000000;
    public static const double NSFoundationVersionNumber10_3_5 = 500.56000000000000;
    public static const double NSFoundationVersionNumber10_3_6 = 500.56000000000000;
    public static const double NSFoundationVersionNumber10_3_7 = 500.56000000000000;
    public static const double NSFoundationVersionNumber10_3_8 = 500.56000000000000;
    public static const double NSFoundationVersionNumber10_3_9 = 500.57999999999998;
    public static const double NSFoundationVersionNumber10_4 = 567.00000000000000;
    public static const double NSFoundationVersionNumber10_4_1 = 567.00000000000000;
    public static const double NSFoundationVersionNumber10_4_10 = 567.28999999999996;
    public static const double NSFoundationVersionNumber10_4_11 = 567.36000000000001;
    public static const double NSFoundationVersionNumber10_4_2 = 567.12000000000000;
    public static const double NSFoundationVersionNumber10_4_3 = 567.21000000000004;
    public static const double NSFoundationVersionNumber10_4_4_Intel = 567.23000000000002;
    public static const double NSFoundationVersionNumber10_4_4_PowerPC = 567.21000000000004;
    public static const double NSFoundationVersionNumber10_4_5 = 567.25000000000000;
    public static const double NSFoundationVersionNumber10_4_6 = 567.25999999999999;
    public static const double NSFoundationVersionNumber10_4_7 = 567.26999999999998;
    public static const double NSFoundationVersionNumber10_4_8 = 567.27999999999997;
    public static const double NSFoundationVersionNumber10_4_9 = 567.28999999999996;
    public static const int NSFoundationVersionWithFileManagerResourceForkSupport = 412;
    public static const int NSFunctionExpressionType = 4;
    public static const int NSGreaterThanComparison = 4;
    public static const int NSGreaterThanOrEqualToComparison = 3;
    public static const int NSGreaterThanOrEqualToPredicateOperatorType = 3;
    public static const int NSGreaterThanPredicateOperatorType = 2;
    public static const int NSHPUXOperatingSystem = 4;
    public static const int NSHTTPCookieAcceptPolicyAlways = 0;
    public static const int NSHTTPCookieAcceptPolicyNever = 1;
    public static const int NSHTTPCookieAcceptPolicyOnlyFromMainDocumentDomain = 2;
    public static const int NSHashTableCopyIn = 65536;
    public static const int NSHashTableObjectPointerPersonality = 512;
    public static const int NSHashTableStrongMemory = 0;
    public static const int NSHashTableZeroingWeakMemory = 1;
    public static const int NSHourCalendarUnit = 32;
    public static const int NSINTEGER_DEFINED = 1;
    public static const int NSISO2022JPStringEncoding = 21;
    public static const int NSISOLatin1StringEncoding = 5;
    public static const int NSISOLatin2StringEncoding = 9;
    public static const int NSInPredicateOperatorType = 10;
    public static const int NSIndexSubelement = 0;
    public static const int NSIntegerMax = 2147483647;
    public static const int NSIntegerMin = -2147483648;
    public static const int NSInternalScriptError = 8;
    public static const int NSInternalSpecifierError = 5;
    public static const int NSIntersectSetExpressionType = 6;
    public static const int NSInvalidIndexSpecifierError = 4;
    public static const int NSJapaneseEUCStringEncoding = 3;
    public static const int NSKeyPathExpressionType = 3;
    public static const int NSKeySpecifierEvaluationScriptError = 2;
    public static const int NSKeyValueChangeInsertion = 2;
    public static const int NSKeyValueChangeRemoval = 3;
    public static const int NSKeyValueChangeReplacement = 4;
    public static const int NSKeyValueChangeSetting = 1;
    public static const int NSKeyValueIntersectSetMutation = 3;
    public static const int NSKeyValueMinusSetMutation = 2;
    public static const int NSKeyValueObservingOptionInitial = 4;
    public static const int NSKeyValueObservingOptionNew = 1;
    public static const int NSKeyValueObservingOptionOld = 2;
    public static const int NSKeyValueObservingOptionPrior = 8;
    public static const int NSKeyValueSetSetMutation = 4;
    public static const int NSKeyValueUnionSetMutation = 1;
    public static const int NSKeyValueValidationError = 1024;
    public static const int NSLessThanComparison = 2;
    public static const int NSLessThanOrEqualToComparison = 1;
    public static const int NSLessThanOrEqualToPredicateOperatorType = 1;
    public static const int NSLessThanPredicateOperatorType = 0;
    public static const int NSLibraryDirectory = 5;
    public static const int NSLikePredicateOperatorType = 7;
    public static const int NSLiteralSearch = 2;
    public static const int NSLocalDomainMask = 2;
    public static const int NSMACHOperatingSystem = 5;
    public static const int NSMacOSRomanStringEncoding = 30;
    public static const int NSMachPortDeallocateNone = 0;
    public static const int NSMachPortDeallocateReceiveRight = 2;
    public static const int NSMachPortDeallocateSendRight = 1;
    public static const int NSMapTableCopyIn = 65536;
    public static const int NSMapTableObjectPointerPersonality = 512;
    public static const int NSMapTableStrongMemory = 0;
    public static const int NSMapTableZeroingWeakMemory = 1;
    public static const int NSMappedRead = 1;
    public static const int NSMatchesPredicateOperatorType = 6;
    public static const int NSMaxXEdge = 2;
    public static const int NSMaxYEdge = 3;
    public static const int NSMiddleSubelement = 2;
    public static const int NSMinXEdge = 0;
    public static const int NSMinYEdge = 1;
    public static const int NSMinusSetExpressionType = 7;
    public static const int NSMinuteCalendarUnit = 64;
    public static const int NSMonthCalendarUnit = 8;
    public static const int NSNEXTSTEPStringEncoding = 2;
    public static const int NSNetServiceNoAutoRename = 1;
    public static const int NSNetServicesActivityInProgress = -72003;
    public static const int NSNetServicesBadArgumentError = -72004;
    public static const int NSNetServicesCancelledError = -72005;
    public static const int NSNetServicesCollisionError = -72001;
    public static const int NSNetServicesInvalidError = -72006;
    public static const int NSNetServicesNotFoundError = -72002;
    public static const int NSNetServicesTimeoutError = -72007;
    public static const int NSNetServicesUnknownError = -72000;
    public static const int NSNetworkDomainMask = 4;
    public static const int NSNoScriptError = 0;
    public static const int NSNoSpecifierError = 0;
    public static const int NSNoSubelement = 4;
    public static const int NSNoTopLevelContainersSpecifierError = 1;
    public static const int NSNonLossyASCIIStringEncoding = 7;
    public static const int NSNotEqualToPredicateOperatorType = 5;
    public static const int NSNotFound = 2147483647;
    public static const int NSNotPredicateType = 0;
    public static const int NSNotificationCoalescingOnName = 1;
    public static const int NSNotificationCoalescingOnSender = 2;
    public static const int NSNotificationDeliverImmediately = 1;
    public static const int NSNotificationNoCoalescing = 0;
    public static const int NSNotificationPostToAllSessions = 2;
    public static const int NSNotificationSuspensionBehaviorCoalesce = 2;
    public static const int NSNotificationSuspensionBehaviorDeliverImmediately = 4;
    public static const int NSNotificationSuspensionBehaviorDrop = 1;
    public static const int NSNotificationSuspensionBehaviorHold = 3;
    public static const int NSNumberFormatterBehavior10_0 = 1000;
    public static const int NSNumberFormatterBehavior10_4 = 1040;
    public static const int NSNumberFormatterBehaviorDefault = 0;
    public static const int NSNumberFormatterCurrencyStyle = 2;
    public static const int NSNumberFormatterDecimalStyle = 1;
    public static const int NSNumberFormatterNoStyle = 0;
    public static const int NSNumberFormatterPadAfterPrefix = 1;
    public static const int NSNumberFormatterPadAfterSuffix = 3;
    public static const int NSNumberFormatterPadBeforePrefix = 0;
    public static const int NSNumberFormatterPadBeforeSuffix = 2;
    public static const int NSNumberFormatterPercentStyle = 3;
    public static const int NSNumberFormatterRoundCeiling = 0;
    public static const int NSNumberFormatterRoundDown = 2;
    public static const int NSNumberFormatterRoundFloor = 1;
    public static const int NSNumberFormatterRoundHalfDown = 5;
    public static const int NSNumberFormatterRoundHalfEven = 4;
    public static const int NSNumberFormatterRoundHalfUp = 6;
    public static const int NSNumberFormatterRoundUp = 3;
    public static const int NSNumberFormatterScientificStyle = 4;
    public static const int NSNumberFormatterSpellOutStyle = 5;
    public static const int NSNumericSearch = 64;
    public static const int NSOSF1OperatingSystem = 7;
    public static const int NSObjCArrayType = 91;
    public static const int NSObjCBitfield = 98;
    public static const int NSObjCBoolType = 66;
    public static const int NSObjCCharType = 99;
    public static const int NSObjCDoubleType = 100;
    public static const int NSObjCFloatType = 102;
    public static const int NSObjCLongType = 108;
    public static const int NSObjCLonglongType = 113;
    public static const int NSObjCNoType = 0;
    public static const int NSObjCObjectType = 64;
    public static const int NSObjCPointerType = 94;
    public static const int NSObjCSelectorType = 58;
    public static const int NSObjCShortType = 115;
    public static const int NSObjCStringType = 42;
    public static const int NSObjCStructType = 123;
    public static const int NSObjCUnionType = 40;
    public static const int NSObjCVoidType = 118;
    public static const int NSObjectAutoreleasedEvent = 3;
    public static const int NSObjectExtraRefDecrementedEvent = 5;
    public static const int NSObjectExtraRefIncrementedEvent = 4;
    public static const int NSObjectInternalRefDecrementedEvent = 7;
    public static const int NSObjectInternalRefIncrementedEvent = 6;
    public static const int NSOpenStepUnicodeReservedBase = 62464;
    public static const int NSOperationNotSupportedForKeyScriptError = 9;
    public static const int NSOperationNotSupportedForKeySpecifierError = 6;
    public static const int NSOperationQueueDefaultMaxConcurrentOperationCount = -1;
    public static const int NSOperationQueuePriorityHigh = 4;
    public static const int NSOperationQueuePriorityLow = -4;
    public static const int NSOperationQueuePriorityNormal = 0;
    public static const int NSOperationQueuePriorityVeryHigh = 8;
    public static const int NSOperationQueuePriorityVeryLow = -8;
    public static const int NSOrPredicateType = 2;
    public static const int NSOrderedAscending = -1;
    public static const int NSOrderedDescending = 1;
    public static const int NSOrderedSame = 0;
    public static const int NSPointerFunctionsCStringPersonality = 768;
    public static const int NSPointerFunctionsCopyIn = 65536;
    public static const int NSPointerFunctionsIntegerPersonality = 1280;
    public static const int NSPointerFunctionsMachVirtualMemory = 4;
    public static const int NSPointerFunctionsMallocMemory = 3;
    public static const int NSPointerFunctionsObjectPersonality = 0;
    public static const int NSPointerFunctionsObjectPointerPersonality = 512;
    public static const int NSPointerFunctionsOpaqueMemory = 2;
    public static const int NSPointerFunctionsOpaquePersonality = 256;
    public static const int NSPointerFunctionsStrongMemory = 0;
    public static const int NSPointerFunctionsStructPersonality = 1024;
    public static const int NSPointerFunctionsZeroingWeakMemory = 1;
    public static const int NSPositionAfter = 0;
    public static const int NSPositionBefore = 1;
    public static const int NSPositionBeginning = 2;
    public static const int NSPositionEnd = 3;
    public static const int NSPositionReplace = 4;
    public static const int NSPostASAP = 2;
    public static const int NSPostNow = 3;
    public static const int NSPostWhenIdle = 1;
    public static const int NSPropertyListBinaryFormat_v1_0 = 200;
    public static const int NSPropertyListImmutable = 0;
    public static const int NSPropertyListMutableContainers = 1;
    public static const int NSPropertyListMutableContainersAndLeaves = 2;
    public static const int NSPropertyListOpenStepFormat = 1;
    public static const int NSPropertyListXMLFormat_v1_0 = 100;
    public static const int NSRandomSubelement = 3;
    public static const int NSReceiverEvaluationScriptError = 1;
    public static const int NSReceiversCantHandleCommandScriptError = 4;
    public static const int NSRelativeAfter = 0;
    public static const int NSRelativeBefore = 1;
    public static const int NSRequiredArgumentsMissingScriptError = 5;
    public static const int NSRoundBankers = 3;
    public static const int NSRoundDown = 1;
    public static const int NSRoundPlain = 0;
    public static const int NSRoundUp = 2;
    public static const int NSSaveOptionsAsk = 2;
    public static const int NSSaveOptionsNo = 1;
    public static const int NSSaveOptionsYes = 0;
    public static const int NSScannedOption = 1;
    public static const int NSSecondCalendarUnit = 128;
    public static const int NSShiftJISStringEncoding = 8;
    public static const int NSSolarisOperatingSystem = 3;
    public static const int NSStreamEventEndEncountered = 16;
    public static const int NSStreamEventErrorOccurred = 8;
    public static const int NSStreamEventHasBytesAvailable = 2;
    public static const int NSStreamEventHasSpaceAvailable = 4;
    public static const int NSStreamEventNone = 0;
    public static const int NSStreamEventOpenCompleted = 1;
    public static const int NSStreamStatusAtEnd = 5;
    public static const int NSStreamStatusClosed = 6;
    public static const int NSStreamStatusError = 7;
    public static const int NSStreamStatusNotOpen = 0;
    public static const int NSStreamStatusOpen = 2;
    public static const int NSStreamStatusOpening = 1;
    public static const int NSStreamStatusReading = 3;
    public static const int NSStreamStatusWriting = 4;
    public static const int NSStringEncodingConversionAllowLossy = 1;
    public static const int NSStringEncodingConversionExternalRepresentation = 2;
    public static const int NSSubqueryExpressionType = 13;
    public static const int NSSunOSOperatingSystem = 6;
    public static const int NSSymbolStringEncoding = 6;
    public static const int NSSystemDomainMask = 8;
    public static const double NSTimeIntervalSince1970 = 978307200.00000000;
    public static const int NSTimeZoneNameStyleDaylightSaving = 2;
    public static const int NSTimeZoneNameStyleShortDaylightSaving = 3;
    public static const int NSTimeZoneNameStyleShortStandard = 1;
    public static const int NSTimeZoneNameStyleStandard = 0;
    public static const long NSUIntegerMax = 4294967295L;
    public static const int NSURLCacheStorageAllowed = 0;
    public static const int NSURLCacheStorageAllowedInMemoryOnly = 1;
    public static const int NSURLCacheStorageNotAllowed = 2;
    public static const int NSURLCredentialPersistenceForSession = 1;
    public static const int NSURLCredentialPersistenceNone = 0;
    public static const int NSURLCredentialPersistencePermanent = 2;
    public static const int NSURLErrorBadServerResponse = -1011;
    public static const int NSURLErrorBadURL = -1000;
    public static const int NSURLErrorCancelled = -999;
    public static const int NSURLErrorCannotCloseFile = -3002;
    public static const int NSURLErrorCannotConnectToHost = -1004;
    public static const int NSURLErrorCannotCreateFile = -3000;
    public static const int NSURLErrorCannotDecodeContentData = -1016;
    public static const int NSURLErrorCannotDecodeRawData = -1015;
    public static const int NSURLErrorCannotFindHost = -1003;
    public static const int NSURLErrorCannotLoadFromNetwork = -2000;
    public static const int NSURLErrorCannotMoveFile = -3005;
    public static const int NSURLErrorCannotOpenFile = -3001;
    public static const int NSURLErrorCannotParseResponse = -1017;
    public static const int NSURLErrorCannotRemoveFile = -3004;
    public static const int NSURLErrorCannotWriteToFile = -3003;
    public static const int NSURLErrorClientCertificateRejected = -1205;
    public static const int NSURLErrorDNSLookupFailed = -1006;
    public static const int NSURLErrorDataLengthExceedsMaximum = -1103;
    public static const int NSURLErrorDownloadDecodingFailedMidStream = -3006;
    public static const int NSURLErrorDownloadDecodingFailedToComplete = -3007;
    public static const int NSURLErrorFileDoesNotExist = -1100;
    public static const int NSURLErrorFileIsDirectory = -1101;
    public static const int NSURLErrorHTTPTooManyRedirects = -1007;
    public static const int NSURLErrorNetworkConnectionLost = -1005;
    public static const int NSURLErrorNoPermissionsToReadFile = -1102;
    public static const int NSURLErrorNotConnectedToInternet = -1009;
    public static const int NSURLErrorRedirectToNonExistentLocation = -1010;
    public static const int NSURLErrorResourceUnavailable = -1008;
    public static const int NSURLErrorSecureConnectionFailed = -1200;
    public static const int NSURLErrorServerCertificateHasBadDate = -1201;
    public static const int NSURLErrorServerCertificateHasUnknownRoot = -1203;
    public static const int NSURLErrorServerCertificateNotYetValid = -1204;
    public static const int NSURLErrorServerCertificateUntrusted = -1202;
    public static const int NSURLErrorTimedOut = -1001;
    public static const int NSURLErrorUnknown = -1;
    public static const int NSURLErrorUnsupportedURL = -1002;
    public static const int NSURLErrorUserAuthenticationRequired = -1013;
    public static const int NSURLErrorUserCancelledAuthentication = -1012;
    public static const int NSURLErrorZeroByteResource = -1014;
    public static const int NSURLHandleLoadFailed = 3;
    public static const int NSURLHandleLoadInProgress = 2;
    public static const int NSURLHandleLoadSucceeded = 1;
    public static const int NSURLHandleNotLoaded = 0;
    public static const int NSURLRequestReloadIgnoringCacheData = 1;
    public static const int NSURLRequestReloadIgnoringLocalAndRemoteCacheData = 4;
    public static const int NSURLRequestReloadIgnoringLocalCacheData = 1;
    public static const int NSURLRequestReloadRevalidatingCacheData = 5;
    public static const int NSURLRequestReturnCacheDataDontLoad = 3;
    public static const int NSURLRequestReturnCacheDataElseLoad = 2;
    public static const int NSURLRequestUseProtocolCachePolicy = 0;
    public static const int NSUTF16BigEndianStringEncoding = -1879047936;
    public static const int NSUTF16LittleEndianStringEncoding = -1811939072;
    public static const int NSUTF16StringEncoding = 10;
    public static const int NSUTF32BigEndianStringEncoding = -1744830208;
    public static const int NSUTF32LittleEndianStringEncoding = -1677721344;
    public static const int NSUTF32StringEncoding = -1946156800;
    public static const int NSUTF8StringEncoding = 4;
    public static const int NSUncachedRead = 2;
    public static const int NSUndefinedDateComponent = 2147483647;
    public static const int NSUndoCloseGroupingRunLoopOrdering = 350000;
    public static const int NSUnicodeStringEncoding = 10;
    public static const int NSUnionSetExpressionType = 5;
    public static const int NSUnknownKeyScriptError = 7;
    public static const int NSUnknownKeySpecifierError = 3;
    public static const int NSUserCancelledError = 3072;
    public static const int NSUserDirectory = 7;
    public static const int NSUserDomainMask = 1;
    public static const int NSValidationErrorMaximum = 2047;
    public static const int NSValidationErrorMinimum = 1024;
    public static const int NSVariableExpressionType = 2;
    public static const int NSWeekCalendarUnit = 256;
    public static const int NSWeekdayCalendarUnit = 512;
    public static const int NSWeekdayOrdinalCalendarUnit = 1024;
    public static const int NSWidthInsensitiveSearch = 256;
    public static const int NSWindows95OperatingSystem = 2;
    public static const int NSWindowsCP1250StringEncoding = 15;
    public static const int NSWindowsCP1251StringEncoding = 11;
    public static const int NSWindowsCP1252StringEncoding = 12;
    public static const int NSWindowsCP1253StringEncoding = 13;
    public static const int NSWindowsCP1254StringEncoding = 14;
    public static const int NSWindowsNTOperatingSystem = 1;
    public static const int NSWrapCalendarComponents = 1;
    public static const int NSXMLAttributeCDATAKind = 6;
    public static const int NSXMLAttributeDeclarationKind = 10;
    public static const int NSXMLAttributeEntitiesKind = 11;
    public static const int NSXMLAttributeEntityKind = 10;
    public static const int NSXMLAttributeEnumerationKind = 14;
    public static const int NSXMLAttributeIDKind = 7;
    public static const int NSXMLAttributeIDRefKind = 8;
    public static const int NSXMLAttributeIDRefsKind = 9;
    public static const int NSXMLAttributeKind = 3;
    public static const int NSXMLAttributeNMTokenKind = 12;
    public static const int NSXMLAttributeNMTokensKind = 13;
    public static const int NSXMLAttributeNotationKind = 15;
    public static const int NSXMLCommentKind = 6;
    public static const int NSXMLDTDKind = 8;
    public static const int NSXMLDocumentHTMLKind = 2;
    public static const int NSXMLDocumentIncludeContentTypeDeclaration = 262144;
    public static const int NSXMLDocumentKind = 1;
    public static const int NSXMLDocumentTextKind = 3;
    public static const int NSXMLDocumentTidyHTML = 512;
    public static const int NSXMLDocumentTidyXML = 1024;
    public static const int NSXMLDocumentValidate = 8192;
    public static const int NSXMLDocumentXHTMLKind = 1;
    public static const int NSXMLDocumentXInclude = 65536;
    public static const int NSXMLDocumentXMLKind = 0;
    public static const int NSXMLElementDeclarationAnyKind = 18;
    public static const int NSXMLElementDeclarationElementKind = 20;
    public static const int NSXMLElementDeclarationEmptyKind = 17;
    public static const int NSXMLElementDeclarationKind = 11;
    public static const int NSXMLElementDeclarationMixedKind = 19;
    public static const int NSXMLElementDeclarationUndefinedKind = 16;
    public static const int NSXMLElementKind = 2;
    public static const int NSXMLEntityDeclarationKind = 9;
    public static const int NSXMLEntityGeneralKind = 1;
    public static const int NSXMLEntityParameterKind = 4;
    public static const int NSXMLEntityParsedKind = 2;
    public static const int NSXMLEntityPredefined = 5;
    public static const int NSXMLEntityUnparsedKind = 3;
    public static const int NSXMLInvalidKind = 0;
    public static const int NSXMLNamespaceKind = 4;
    public static const int NSXMLNodeCompactEmptyElement = 4;
    public static const int NSXMLNodeExpandEmptyElement = 2;
    public static const int NSXMLNodeIsCDATA = 1;
    public static const int NSXMLNodeOptionsNone = 0;
    public static const int NSXMLNodePreserveAll = -1048546;
    public static const int NSXMLNodePreserveAttributeOrder = 2097152;
    public static const int NSXMLNodePreserveCDATA = 16777216;
    public static const int NSXMLNodePreserveCharacterReferences = 134217728;
    public static const int NSXMLNodePreserveDTD = 67108864;
    public static const int NSXMLNodePreserveEmptyElements = 6;
    public static const int NSXMLNodePreserveEntities = 4194304;
    public static const int NSXMLNodePreserveNamespaceOrder = 1048576;
    public static const int NSXMLNodePreservePrefixes = 8388608;
    public static const int NSXMLNodePreserveQuotes = 24;
    public static const int NSXMLNodePreserveWhitespace = 33554432;
    public static const int NSXMLNodePrettyPrint = 131072;
    public static const int NSXMLNodeUseDoubleQuotes = 16;
    public static const int NSXMLNodeUseSingleQuotes = 8;
    public static const int NSXMLNotationDeclarationKind = 12;
    public static const int NSXMLParserAttributeHasNoValueError = 41;
    public static const int NSXMLParserAttributeListNotFinishedError = 51;
    public static const int NSXMLParserAttributeListNotStartedError = 50;
    public static const int NSXMLParserAttributeNotFinishedError = 40;
    public static const int NSXMLParserAttributeNotStartedError = 39;
    public static const int NSXMLParserAttributeRedefinedError = 42;
    public static const int NSXMLParserCDATANotFinishedError = 63;
    public static const int NSXMLParserCharacterRefAtEOFError = 10;
    public static const int NSXMLParserCharacterRefInDTDError = 13;
    public static const int NSXMLParserCharacterRefInEpilogError = 12;
    public static const int NSXMLParserCharacterRefInPrologError = 11;
    public static const int NSXMLParserCommentContainsDoubleHyphenError = 80;
    public static const int NSXMLParserCommentNotFinishedError = 45;
    public static const int NSXMLParserConditionalSectionNotFinishedError = 59;
    public static const int NSXMLParserConditionalSectionNotStartedError = 58;
    public static const int NSXMLParserDOCTYPEDeclNotFinishedError = 61;
    public static const int NSXMLParserDelegateAbortedParseError = 512;
    public static const int NSXMLParserDocumentStartError = 3;
    public static const int NSXMLParserElementContentDeclNotFinishedError = 55;
    public static const int NSXMLParserElementContentDeclNotStartedError = 54;
    public static const int NSXMLParserEmptyDocumentError = 4;
    public static const int NSXMLParserEncodingNotSupportedError = 32;
    public static const int NSXMLParserEntityBoundaryError = 90;
    public static const int NSXMLParserEntityIsExternalError = 29;
    public static const int NSXMLParserEntityIsParameterError = 30;
    public static const int NSXMLParserEntityNotFinishedError = 37;
    public static const int NSXMLParserEntityNotStartedError = 36;
    public static const int NSXMLParserEntityRefAtEOFError = 14;
    public static const int NSXMLParserEntityRefInDTDError = 17;
    public static const int NSXMLParserEntityRefInEpilogError = 16;
    public static const int NSXMLParserEntityRefInPrologError = 15;
    public static const int NSXMLParserEntityRefLoopError = 89;
    public static const int NSXMLParserEntityReferenceMissingSemiError = 23;
    public static const int NSXMLParserEntityReferenceWithoutNameError = 22;
    public static const int NSXMLParserEntityValueRequiredError = 84;
    public static const int NSXMLParserEqualExpectedError = 75;
    public static const int NSXMLParserExternalStandaloneEntityError = 82;
    public static const int NSXMLParserExternalSubsetNotFinishedError = 60;
    public static const int NSXMLParserExtraContentError = 86;
    public static const int NSXMLParserGTRequiredError = 73;
    public static const int NSXMLParserInternalError = 1;
    public static const int NSXMLParserInvalidCharacterError = 9;
    public static const int NSXMLParserInvalidCharacterInEntityError = 87;
    public static const int NSXMLParserInvalidCharacterRefError = 8;
    public static const int NSXMLParserInvalidConditionalSectionError = 83;
    public static const int NSXMLParserInvalidDecimalCharacterRefError = 7;
    public static const int NSXMLParserInvalidEncodingError = 81;
    public static const int NSXMLParserInvalidEncodingNameError = 79;
    public static const int NSXMLParserInvalidHexCharacterRefError = 6;
    public static const int NSXMLParserInvalidURIError = 91;
    public static const int NSXMLParserLTRequiredError = 72;
    public static const int NSXMLParserLTSlashRequiredError = 74;
    public static const int NSXMLParserLessThanSymbolInAttributeError = 38;
    public static const int NSXMLParserLiteralNotFinishedError = 44;
    public static const int NSXMLParserLiteralNotStartedError = 43;
    public static const int NSXMLParserMisplacedCDATAEndStringError = 62;
    public static const int NSXMLParserMisplacedXMLDeclarationError = 64;
    public static const int NSXMLParserMixedContentDeclNotFinishedError = 53;
    public static const int NSXMLParserMixedContentDeclNotStartedError = 52;
    public static const int NSXMLParserNAMERequiredError = 68;
    public static const int NSXMLParserNMTOKENRequiredError = 67;
    public static const int NSXMLParserNamespaceDeclarationError = 35;
    public static const int NSXMLParserNoDTDError = 94;
    public static const int NSXMLParserNotWellBalancedError = 85;
    public static const int NSXMLParserNotationNotFinishedError = 49;
    public static const int NSXMLParserNotationNotStartedError = 48;
    public static const int NSXMLParserOutOfMemoryError = 2;
    public static const int NSXMLParserPCDATARequiredError = 69;
    public static const int NSXMLParserParsedEntityRefAtEOFError = 18;
    public static const int NSXMLParserParsedEntityRefInEpilogError = 20;
    public static const int NSXMLParserParsedEntityRefInInternalError = 88;
    public static const int NSXMLParserParsedEntityRefInInternalSubsetError = 21;
    public static const int NSXMLParserParsedEntityRefInPrologError = 19;
    public static const int NSXMLParserParsedEntityRefMissingSemiError = 25;
    public static const int NSXMLParserParsedEntityRefNoNameError = 24;
    public static const int NSXMLParserPrematureDocumentEndError = 5;
    public static const int NSXMLParserProcessingInstructionNotFinishedError = 47;
    public static const int NSXMLParserProcessingInstructionNotStartedError = 46;
    public static const int NSXMLParserPublicIdentifierRequiredError = 71;
    public static const int NSXMLParserSeparatorRequiredError = 66;
    public static const int NSXMLParserSpaceRequiredError = 65;
    public static const int NSXMLParserStandaloneValueError = 78;
    public static const int NSXMLParserStringNotClosedError = 34;
    public static const int NSXMLParserStringNotStartedError = 33;
    public static const int NSXMLParserTagNameMismatchError = 76;
    public static const int NSXMLParserURIFragmentError = 92;
    public static const int NSXMLParserURIRequiredError = 70;
    public static const int NSXMLParserUndeclaredEntityError = 26;
    public static const int NSXMLParserUnfinishedTagError = 77;
    public static const int NSXMLParserUnknownEncodingError = 31;
    public static const int NSXMLParserUnparsedEntityError = 28;
    public static const int NSXMLParserXMLDeclNotFinishedError = 57;
    public static const int NSXMLParserXMLDeclNotStartedError = 56;
    public static const int NSXMLProcessingInstructionKind = 5;
    public static const int NSXMLTextKind = 7;
    public static const int NSYearCalendarUnit = 4;
    public static const int NS_BigEndian = 2;
    public static const int NS_LittleEndian = 1;
    public static const int NS_UNICHAR_IS_EIGHT_BIT = 0;
    public static const int NS_UnknownByteOrder = 0;
    public static const int DOM_ADDITION = 2;
    public static const int DOM_ANY_TYPE = 0;
    public static const int DOM_ANY_UNORDERED_NODE_TYPE = 8;
    public static const int DOM_ATTRIBUTE_NODE = 2;
    public static const int DOM_AT_TARGET = 2;
    public static const int DOM_BAD_BOUNDARYPOINTS_ERR = 1;
    public static const int DOM_BOOLEAN_TYPE = 3;
    public static const int DOM_BOTH = 2;
    public static const int DOM_BUBBLING_PHASE = 3;
    public static const int DOM_CAPTURING_PHASE = 1;
    public static const int DOM_CDATA_SECTION_NODE = 4;
    public static const int DOM_CHARSET_RULE = 2;
    public static const int DOM_COMMENT_NODE = 8;
    public static const int DOM_CSS_ATTR = 22;
    public static const int DOM_CSS_CM = 6;
    public static const int DOM_CSS_COUNTER = 23;
    public static const int DOM_CSS_CUSTOM = 3;
    public static const int DOM_CSS_DEG = 11;
    public static const int DOM_CSS_DIMENSION = 18;
    public static const int DOM_CSS_EMS = 3;
    public static const int DOM_CSS_EXS = 4;
    public static const int DOM_CSS_GRAD = 13;
    public static const int DOM_CSS_HZ = 16;
    public static const int DOM_CSS_IDENT = 21;
    public static const int DOM_CSS_IN = 8;
    public static const int DOM_CSS_INHERIT = 0;
    public static const int DOM_CSS_KHZ = 17;
    public static const int DOM_CSS_MM = 7;
    public static const int DOM_CSS_MS = 14;
    public static const int DOM_CSS_NUMBER = 1;
    public static const int DOM_CSS_PC = 10;
    public static const int DOM_CSS_PERCENTAGE = 2;
    public static const int DOM_CSS_PRIMITIVE_VALUE = 1;
    public static const int DOM_CSS_PT = 9;
    public static const int DOM_CSS_PX = 5;
    public static const int DOM_CSS_RAD = 12;
    public static const int DOM_CSS_RECT = 24;
    public static const int DOM_CSS_RGBCOLOR = 25;
    public static const int DOM_CSS_S = 15;
    public static const int DOM_CSS_STRING = 19;
    public static const int DOM_CSS_UNKNOWN = 0;
    public static const int DOM_CSS_URI = 20;
    public static const int DOM_CSS_VALUE_LIST = 2;
    public static const int DOM_DOCUMENT_FRAGMENT_NODE = 11;
    public static const int DOM_DOCUMENT_NODE = 9;
    public static const int DOM_DOCUMENT_TYPE_NODE = 10;
    public static const int DOM_DOMSTRING_SIZE_ERR = 2;
    public static const int DOM_ELEMENT_NODE = 1;
    public static const int DOM_END_TO_END = 2;
    public static const int DOM_END_TO_START = 3;
    public static const int DOM_ENTITY_NODE = 6;
    public static const int DOM_ENTITY_REFERENCE_NODE = 5;
    public static const int DOM_FILTER_ACCEPT = 1;
    public static const int DOM_FILTER_REJECT = 2;
    public static const int DOM_FILTER_SKIP = 3;
    public static const int DOM_FIRST_ORDERED_NODE_TYPE = 9;
    public static const int DOM_FONT_FACE_RULE = 5;
    public static const int DOM_HIERARCHY_REQUEST_ERR = 3;
    public static const int DOM_HORIZONTAL = 0;
    public static const int DOM_IMPORT_RULE = 3;
    public static const int DOM_INDEX_SIZE_ERR = 1;
    public static const int DOM_INUSE_ATTRIBUTE_ERR = 10;
    public static const int DOM_INVALID_ACCESS_ERR = 15;
    public static const int DOM_INVALID_CHARACTER_ERR = 5;
    public static const int DOM_INVALID_EXPRESSION_ERR = 51;
    public static const int DOM_INVALID_MODIFICATION_ERR = 13;
    public static const int DOM_INVALID_NODE_TYPE_ERR = 2;
    public static const int DOM_INVALID_STATE_ERR = 11;
    public static const int DOM_KEY_LOCATION_LEFT = 1;
    public static const int DOM_KEY_LOCATION_NUMPAD = 3;
    public static const int DOM_KEY_LOCATION_RIGHT = 2;
    public static const int DOM_KEY_LOCATION_STANDARD = 0;
    public static const int DOM_MEDIA_RULE = 4;
    public static const int DOM_MODIFICATION = 1;
    public static const int DOM_NAMESPACE_ERR = 14;
    public static const int DOM_NODE_AFTER = 1;
    public static const int DOM_NODE_BEFORE = 0;
    public static const int DOM_NODE_BEFORE_AND_AFTER = 2;
    public static const int DOM_NODE_INSIDE = 3;
    public static const int DOM_NOTATION_NODE = 12;
    public static const int DOM_NOT_FOUND_ERR = 8;
    public static const int DOM_NOT_SUPPORTED_ERR = 9;
    public static const int DOM_NO_DATA_ALLOWED_ERR = 6;
    public static const int DOM_NO_MODIFICATION_ALLOWED_ERR = 7;
    public static const int DOM_NUMBER_TYPE = 1;
    public static const int DOM_ORDERED_NODE_ITERATOR_TYPE = 5;
    public static const int DOM_ORDERED_NODE_SNAPSHOT_TYPE = 7;
    public static const int DOM_PAGE_RULE = 6;
    public static const int DOM_PROCESSING_INSTRUCTION_NODE = 7;
    public static const int DOM_REMOVAL = 3;
    public static const int DOM_SHOW_ALL = -1;
    public static const int DOM_SHOW_ATTRIBUTE = 2;
    public static const int DOM_SHOW_CDATA_SECTION = 8;
    public static const int DOM_SHOW_COMMENT = 128;
    public static const int DOM_SHOW_DOCUMENT = 256;
    public static const int DOM_SHOW_DOCUMENT_FRAGMENT = 1024;
    public static const int DOM_SHOW_DOCUMENT_TYPE = 512;
    public static const int DOM_SHOW_ELEMENT = 1;
    public static const int DOM_SHOW_ENTITY = 32;
    public static const int DOM_SHOW_ENTITY_REFERENCE = 16;
    public static const int DOM_SHOW_NOTATION = 2048;
    public static const int DOM_SHOW_PROCESSING_INSTRUCTION = 64;
    public static const int DOM_SHOW_TEXT = 4;
    public static const int DOM_START_TO_END = 1;
    public static const int DOM_START_TO_START = 0;
    public static const int DOM_STRING_TYPE = 2;
    public static const int DOM_STYLE_RULE = 1;
    public static const int DOM_SYNTAX_ERR = 12;
    public static const int DOM_TEXT_NODE = 3;
    public static const int DOM_TYPE_ERR = 52;
    public static const int DOM_UNKNOWN_RULE = 0;
    public static const int DOM_UNORDERED_NODE_ITERATOR_TYPE = 4;
    public static const int DOM_UNORDERED_NODE_SNAPSHOT_TYPE = 6;
    public static const int DOM_UNSPECIFIED_EVENT_TYPE_ERR = 0;
    public static const int DOM_VERTICAL = 1;
    public static const int DOM_WRONG_DOCUMENT_ERR = 4;
    public static const int WebCacheModelDocumentBrowser = 1;
    public static const int WebCacheModelDocumentViewer = 0;
    public static const int WebCacheModelPrimaryWebBrowser = 2;
    public static const int WebDragDestinationActionAny = -1;
    public static const int WebDragDestinationActionDHTML = 1;
    public static const int WebDragDestinationActionEdit = 2;
    public static const int WebDragDestinationActionLoad = 4;
    public static const int WebDragDestinationActionNone = 0;
    public static const int WebDragSourceActionAny = -1;
    public static const int WebDragSourceActionDHTML = 1;
    public static const int WebDragSourceActionImage = 2;
    public static const int WebDragSourceActionLink = 4;
    public static const int WebDragSourceActionNone = 0;
    public static const int WebDragSourceActionSelection = 8;
    public static const int WebJNIReturnTypeBoolean = 3;
    public static const int WebJNIReturnTypeByte = 4;
    public static const int WebJNIReturnTypeChar = 5;
    public static const int WebJNIReturnTypeDouble = 10;
    public static const int WebJNIReturnTypeFloat = 9;
    public static const int WebJNIReturnTypeInt = 7;
    public static const int WebJNIReturnTypeInvalid = 0;
    public static const int WebJNIReturnTypeLong = 8;
    public static const int WebJNIReturnTypeObject = 2;
    public static const int WebJNIReturnTypeShort = 6;
    public static const int WebJNIReturnTypeVoid = 1;
    public static const int WebKitErrorCannotFindPlugIn = 200;
    public static const int WebKitErrorCannotLoadPlugIn = 201;
    public static const int WebKitErrorCannotShowMIMEType = 100;
    public static const int WebKitErrorCannotShowURL = 101;
    public static const int WebKitErrorFrameLoadInterruptedByPolicyChange = 102;
    public static const int WebKitErrorJavaUnavailable = 202;
    public static const int WebMenuItemPDFActualSize = 24;
    public static const int WebMenuItemPDFAutoSize = 27;
    public static const int WebMenuItemPDFContinuous = 30;
    public static const int WebMenuItemPDFFacingPages = 29;
    public static const int WebMenuItemPDFNextPage = 31;
    public static const int WebMenuItemPDFPreviousPage = 32;
    public static const int WebMenuItemPDFSinglePage = 28;
    public static const int WebMenuItemPDFZoomIn = 25;
    public static const int WebMenuItemPDFZoomOut = 26;
    public static const int WebMenuItemTagCopy = 8;
    public static const int WebMenuItemTagCopyImageToClipboard = 6;
    public static const int WebMenuItemTagCopyLinkToClipboard = 3;
    public static const int WebMenuItemTagCut = 13;
    public static const int WebMenuItemTagDownloadImageToDisk = 5;
    public static const int WebMenuItemTagDownloadLinkToDisk = 2;
    public static const int WebMenuItemTagGoBack = 9;
    public static const int WebMenuItemTagGoForward = 10;
    public static const int WebMenuItemTagIgnoreSpelling = 17;
    public static const int WebMenuItemTagLearnSpelling = 18;
    public static const int WebMenuItemTagLookUpInDictionary = 22;
    public static const int WebMenuItemTagNoGuessesFound = 16;
    public static const int WebMenuItemTagOpenFrameInNewWindow = 7;
    public static const int WebMenuItemTagOpenImageInNewWindow = 4;
    public static const int WebMenuItemTagOpenLinkInNewWindow = 1;
    public static const int WebMenuItemTagOpenWithDefaultApplication = 23;
    public static const int WebMenuItemTagOther = 19;
    public static const int WebMenuItemTagPaste = 14;
    public static const int WebMenuItemTagReload = 12;
    public static const int WebMenuItemTagSearchInSpotlight = 20;
    public static const int WebMenuItemTagSearchWeb = 21;
    public static const int WebMenuItemTagSpellingGuess = 15;
    public static const int WebMenuItemTagStop = 11;
    public static const int WebNavigationTypeBackForward = 2;
    public static const int WebNavigationTypeFormResubmitted = 4;
    public static const int WebNavigationTypeFormSubmitted = 1;
    public static const int WebNavigationTypeLinkClicked = 0;
    public static const int WebNavigationTypeOther = 5;
    public static const int WebNavigationTypeReload = 3;
    public static const int WebViewInsertActionDropped = 2;
    public static const int WebViewInsertActionPasted = 1;
    public static const int WebViewInsertActionTyped = 0;


    /** Globals */
//  public static const native int NSAbortModalException();
//  public static const native int NSAbortPrintingException();
//  public static const native int NSAccessibilityAllowedValuesAttribute();
//  public static const native int NSAccessibilityApplicationActivatedNotification();
//  public static const native int NSAccessibilityApplicationDeactivatedNotification();
//  public static const native int NSAccessibilityApplicationHiddenNotification();
//  public static const native int NSAccessibilityApplicationRole();
//  public static const native int NSAccessibilityApplicationShownNotification();
//  public static const native int NSAccessibilityAscendingSortDirectionValue();
//  public static const native int NSAccessibilityAttachmentTextAttribute();
//  public static const native int NSAccessibilityAttributedStringForRangeParameterizedAttribute();
//  public static const native int NSAccessibilityBackgroundColorTextAttribute();
//  public static const native int NSAccessibilityBoundsForRangeParameterizedAttribute();
//  public static const native int NSAccessibilityBrowserRole();
//  public static const native int NSAccessibilityBusyIndicatorRole();
//  public static const native int NSAccessibilityButtonRole();
//  public static const native int NSAccessibilityCancelAction();
//  public static const native int NSAccessibilityCancelButtonAttribute();
//  public static const native int NSAccessibilityCenterTabStopMarkerTypeValue();
//  public static const native int NSAccessibilityCentimetersUnitValue();
//  public static const native int NSAccessibilityCheckBoxRole();
//  public static const native int NSAccessibilityChildrenAttribute();
//  public static const native int NSAccessibilityClearButtonAttribute();
//  public static const native int NSAccessibilityCloseButtonAttribute();
//  public static const native int NSAccessibilityCloseButtonSubrole();
//  public static const native int NSAccessibilityColorWellRole();
//  public static const native int NSAccessibilityColumnCountAttribute();
//  public static const native int NSAccessibilityColumnRole();
//  public static const native int NSAccessibilityColumnTitlesAttribute();
//  public static const native int NSAccessibilityColumnsAttribute();
//  public static const native int NSAccessibilityComboBoxRole();
//  public static const native int NSAccessibilityConfirmAction();
//  public static const native int NSAccessibilityContentsAttribute();
//  public static const native int NSAccessibilityCreatedNotification();
//  public static const native int NSAccessibilityDecimalTabStopMarkerTypeValue();
//  public static const native int NSAccessibilityDecrementAction();
//  public static const native int NSAccessibilityDecrementArrowSubrole();
//  public static const native int NSAccessibilityDecrementButtonAttribute();
//  public static const native int NSAccessibilityDecrementPageSubrole();
//  public static const native int NSAccessibilityDefaultButtonAttribute();
//  public static const native int NSAccessibilityDeleteAction();
//  public static const native int NSAccessibilityDescendingSortDirectionValue();
//  public static const native int NSAccessibilityDescriptionAttribute();
//  public static const native int NSAccessibilityDialogSubrole();
//  public static const native int NSAccessibilityDisclosedByRowAttribute();
//  public static const native int NSAccessibilityDisclosedRowsAttribute();
//  public static const native int NSAccessibilityDisclosingAttribute();
//  public static const native int NSAccessibilityDisclosureLevelAttribute();
//  public static const native int NSAccessibilityDisclosureTriangleRole();
//  public static const native int NSAccessibilityDocumentAttribute();
//  public static const native int NSAccessibilityDrawerCreatedNotification();
//  public static const native int NSAccessibilityDrawerRole();
//  public static const native int NSAccessibilityEditedAttribute();
//  public static const native int NSAccessibilityEnabledAttribute();
//  public static const native int NSAccessibilityErrorCodeExceptionInfo();
//  public static const native int NSAccessibilityException();
//  public static const native int NSAccessibilityExpandedAttribute();
//  public static const native int NSAccessibilityFilenameAttribute();
//  public static const native int NSAccessibilityFirstLineIndentMarkerTypeValue();
//  public static const native int NSAccessibilityFloatingWindowSubrole();
//  public static const native int NSAccessibilityFocusedAttribute();
//  public static const native int NSAccessibilityFocusedUIElementAttribute();
//  public static const native int NSAccessibilityFocusedUIElementChangedNotification();
//  public static const native int NSAccessibilityFocusedWindowAttribute();
//  public static const native int NSAccessibilityFocusedWindowChangedNotification();
//  public static const native int NSAccessibilityFontFamilyKey();
//  public static const native int NSAccessibilityFontNameKey();
//  public static const native int NSAccessibilityFontSizeKey();
//  public static const native int NSAccessibilityFontTextAttribute();
//  public static const native int NSAccessibilityForegroundColorTextAttribute();
//  public static const native int NSAccessibilityFrontmostAttribute();
//  public static const native int NSAccessibilityGridRole();
//  public static const native int NSAccessibilityGroupRole();
//  public static const native int NSAccessibilityGrowAreaAttribute();
//  public static const native int NSAccessibilityGrowAreaRole();
//  public static const native int NSAccessibilityHeadIndentMarkerTypeValue();
//  public static const native int NSAccessibilityHeaderAttribute();
//  public static const native int NSAccessibilityHelpAttribute();
//  public static const native int NSAccessibilityHelpTagCreatedNotification();
//  public static const native int NSAccessibilityHelpTagRole();
//  public static const native int NSAccessibilityHiddenAttribute();
//  public static const native int NSAccessibilityHorizontalOrientationValue();
//  public static const native int NSAccessibilityHorizontalScrollBarAttribute();
//  public static const native int NSAccessibilityImageRole();
//  public static const native int NSAccessibilityInchesUnitValue();
//  public static const native int NSAccessibilityIncrementAction();
//  public static const native int NSAccessibilityIncrementArrowSubrole();
//  public static const native int NSAccessibilityIncrementButtonAttribute();
//  public static const native int NSAccessibilityIncrementPageSubrole();
//  public static const native int NSAccessibilityIncrementorRole();
//  public static const native int NSAccessibilityIndexAttribute();
//  public static const native int NSAccessibilityInsertionPointLineNumberAttribute();
//  public static const native int NSAccessibilityLabelUIElementsAttribute();
//  public static const native int NSAccessibilityLabelValueAttribute();
//  public static const native int NSAccessibilityLeftTabStopMarkerTypeValue();
//  public static const native int NSAccessibilityLineForIndexParameterizedAttribute();
//  public static const native int NSAccessibilityLinkRole();
//  public static const native int NSAccessibilityLinkTextAttribute();
//  public static const native int NSAccessibilityLinkedUIElementsAttribute();
//  public static const native int NSAccessibilityListRole();
//  public static const native int NSAccessibilityMainAttribute();
//  public static const native int NSAccessibilityMainWindowAttribute();
//  public static const native int NSAccessibilityMainWindowChangedNotification();
//  public static const native int NSAccessibilityMarkerGroupUIElementAttribute();
//  public static const native int NSAccessibilityMarkerTypeAttribute();
//  public static const native int NSAccessibilityMarkerTypeDescriptionAttribute();
//  public static const native int NSAccessibilityMarkerUIElementsAttribute();
//  public static const native int NSAccessibilityMarkerValuesAttribute();
//  public static const native int NSAccessibilityMatteContentUIElementAttribute();
//  public static const native int NSAccessibilityMatteHoleAttribute();
//  public static const native int NSAccessibilityMatteRole();
//  public static const native int NSAccessibilityMaxValueAttribute();
//  public static const native int NSAccessibilityMenuBarAttribute();
//  public static const native int NSAccessibilityMenuBarRole();
//  public static const native int NSAccessibilityMenuButtonRole();
//  public static const native int NSAccessibilityMenuItemRole();
//  public static const native int NSAccessibilityMenuRole();
//  public static const native int NSAccessibilityMinValueAttribute();
//  public static const native int NSAccessibilityMinimizeButtonAttribute();
//  public static const native int NSAccessibilityMinimizeButtonSubrole();
//  public static const native int NSAccessibilityMinimizedAttribute();
//  public static const native int NSAccessibilityMisspelledTextAttribute();
//  public static const native int NSAccessibilityModalAttribute();
//  public static const native int NSAccessibilityMovedNotification();
//  public static const native int NSAccessibilityNextContentsAttribute();
//  public static const native int NSAccessibilityNumberOfCharactersAttribute();
//  public static const native int NSAccessibilityOrderedByRowAttribute();
//  public static const native int NSAccessibilityOrientationAttribute();
//  public static const native int NSAccessibilityOutlineRole();
//  public static const native int NSAccessibilityOutlineRowSubrole();
//  public static const native int NSAccessibilityOverflowButtonAttribute();
//  public static const native int NSAccessibilityParentAttribute();
//  public static const native int NSAccessibilityPicasUnitValue();
//  public static const native int NSAccessibilityPickAction();
//  public static const native int NSAccessibilityPointsUnitValue();
//  public static const native int NSAccessibilityPopUpButtonRole();
    alias NSAccessibility.NSAccessibilityPositionAttribute NSAccessibilityPositionAttribute;
//  public static const native int NSAccessibilityPressAction();
//  public static const native int NSAccessibilityPreviousContentsAttribute();
//  public static const native int NSAccessibilityProgressIndicatorRole();
//  public static const native int NSAccessibilityProxyAttribute();
//  public static const native int NSAccessibilityRTFForRangeParameterizedAttribute();
//  public static const native int NSAccessibilityRadioButtonRole();
//  public static const native int NSAccessibilityRadioGroupRole();
//  public static const native int NSAccessibilityRaiseAction();
//  public static const native int NSAccessibilityRangeForIndexParameterizedAttribute();
//  public static const native int NSAccessibilityRangeForLineParameterizedAttribute();
//  public static const native int NSAccessibilityRangeForPositionParameterizedAttribute();
//  public static const native int NSAccessibilityResizedNotification();
//  public static const native int NSAccessibilityRightTabStopMarkerTypeValue();
//  public static const native int NSAccessibilityRoleAttribute();
//  public static const native int NSAccessibilityRoleDescriptionAttribute();
//  public static const native int NSAccessibilityRowCountAttribute();
//  public static const native int NSAccessibilityRowCountChangedNotification();
//  public static const native int NSAccessibilityRowRole();
//  public static const native int NSAccessibilityRowsAttribute();
//  public static const native int NSAccessibilityRulerMarkerRole();
//  public static const native int NSAccessibilityRulerRole();
//  public static const native int NSAccessibilityScrollAreaRole();
//  public static const native int NSAccessibilityScrollBarRole();
//  public static const native int NSAccessibilitySearchButtonAttribute();
//  public static const native int NSAccessibilitySearchFieldSubrole();
//  public static const native int NSAccessibilitySearchMenuAttribute();
//  public static const native int NSAccessibilitySecureTextFieldSubrole();
//  public static const native int NSAccessibilitySelectedAttribute();
//  public static const native int NSAccessibilitySelectedChildrenAttribute();
//  public static const native int NSAccessibilitySelectedChildrenChangedNotification();
//  public static const native int NSAccessibilitySelectedColumnsAttribute();
//  public static const native int NSAccessibilitySelectedColumnsChangedNotification();
//  public static const native int NSAccessibilitySelectedRowsAttribute();
//  public static const native int NSAccessibilitySelectedRowsChangedNotification();
//  public static const native int NSAccessibilitySelectedTextAttribute();
//  public static const native int NSAccessibilitySelectedTextChangedNotification();
//  public static const native int NSAccessibilitySelectedTextRangeAttribute();
//  public static const native int NSAccessibilitySelectedTextRangesAttribute();
//  public static const native int NSAccessibilityServesAsTitleForUIElementsAttribute();
//  public static const native int NSAccessibilityShadowTextAttribute();
//  public static const native int NSAccessibilitySharedCharacterRangeAttribute();
//  public static const native int NSAccessibilitySharedTextUIElementsAttribute();
//  public static const native int NSAccessibilitySheetCreatedNotification();
//  public static const native int NSAccessibilitySheetRole();
//  public static const native int NSAccessibilityShowMenuAction();
//  public static const native int NSAccessibilityShownMenuAttribute();
    alias NSAccessibility.NSAccessibilitySizeAttribute NSAccessibilitySizeAttribute;
//  public static const native int NSAccessibilitySliderRole();
//  public static const native int NSAccessibilitySortButtonRole();
//  public static const native int NSAccessibilitySortDirectionAttribute();
//  public static const native int NSAccessibilitySplitGroupRole();
//  public static const native int NSAccessibilitySplitterRole();
//  public static const native int NSAccessibilitySplittersAttribute();
//  public static const native int NSAccessibilityStandardWindowSubrole();
//  public static const native int NSAccessibilityStaticTextRole();
//  public static const native int NSAccessibilityStrikethroughColorTextAttribute();
//  public static const native int NSAccessibilityStrikethroughTextAttribute();
//  public static const native int NSAccessibilityStringForRangeParameterizedAttribute();
//  public static const native int NSAccessibilityStyleRangeForIndexParameterizedAttribute();
//  public static const native int NSAccessibilitySubroleAttribute();
//  public static const native int NSAccessibilitySuperscriptTextAttribute();
//  public static const native int NSAccessibilitySystemDialogSubrole();
//  public static const native int NSAccessibilitySystemFloatingWindowSubrole();
//  public static const native int NSAccessibilitySystemWideRole();
//  public static const native int NSAccessibilityTabGroupRole();
//  public static const native int NSAccessibilityTableRole();
//  public static const native int NSAccessibilityTableRowSubrole();
//  public static const native int NSAccessibilityTabsAttribute();
//  public static const native int NSAccessibilityTailIndentMarkerTypeValue();
//  public static const native int NSAccessibilityTextAreaRole();
//  public static const native int NSAccessibilityTextAttachmentSubrole();
//  public static const native int NSAccessibilityTextFieldRole();
//  public static const native int NSAccessibilityTextLinkSubrole();
//  public static const native int NSAccessibilityTimelineSubrole();
//  public static const native int NSAccessibilityTitleAttribute();
//  public static const native int NSAccessibilityTitleChangedNotification();
//  public static const native int NSAccessibilityTitleUIElementAttribute();
//  public static const native int NSAccessibilityToolbarButtonAttribute();
//  public static const native int NSAccessibilityToolbarButtonSubrole();
//  public static const native int NSAccessibilityToolbarRole();
//  public static const native int NSAccessibilityTopLevelUIElementAttribute();
//  public static const native int NSAccessibilityUIElementDestroyedNotification();
//  public static const native int NSAccessibilityURLAttribute();
//  public static const native int NSAccessibilityUnderlineColorTextAttribute();
//  public static const native int NSAccessibilityUnderlineTextAttribute();
//  public static const native int NSAccessibilityUnitDescriptionAttribute();
//  public static const native int NSAccessibilityUnitsAttribute();
//  public static const native int NSAccessibilityUnknownMarkerTypeValue();
//  public static const native int NSAccessibilityUnknownRole();
//  public static const native int NSAccessibilityUnknownSortDirectionValue();
//  public static const native int NSAccessibilityUnknownSubrole();
//  public static const native int NSAccessibilityUnknownUnitValue();
//  public static const native int NSAccessibilityValueAttribute();
//  public static const native int NSAccessibilityValueChangedNotification();
//  public static const native int NSAccessibilityValueDescriptionAttribute();
//  public static const native int NSAccessibilityValueIndicatorRole();
//  public static const native int NSAccessibilityVerticalOrientationValue();
//  public static const native int NSAccessibilityVerticalScrollBarAttribute();
//  public static const native int NSAccessibilityVisibleCharacterRangeAttribute();
//  public static const native int NSAccessibilityVisibleChildrenAttribute();
//  public static const native int NSAccessibilityVisibleColumnsAttribute();
//  public static const native int NSAccessibilityVisibleNameKey();
//  public static const native int NSAccessibilityVisibleRowsAttribute();
//  public static const native int NSAccessibilityWindowAttribute();
//  public static const native int NSAccessibilityWindowCreatedNotification();
//  public static const native int NSAccessibilityWindowDeminiaturizedNotification();
//  public static const native int NSAccessibilityWindowMiniaturizedNotification();
//  public static const native int NSAccessibilityWindowMovedNotification();
//  public static const native int NSAccessibilityWindowResizedNotification();
//  public static const native int NSAccessibilityWindowRole();
//  public static const native int NSAccessibilityWindowsAttribute();
//  public static const native int NSAccessibilityZoomButtonAttribute();
//  public static const native int NSAccessibilityZoomButtonSubrole();
//  public static const native int NSAlignmentBinding();
//  public static const native int NSAllRomanInputSourcesLocaleIdentifier();
//  public static const native int NSAllowsEditingMultipleValuesSelectionBindingOption();
//  public static const native int NSAllowsNullArgumentBindingOption();
//  public static const native int NSAlternateImageBinding();
//  public static const native int NSAlternateTitleBinding();
//  public static const native int NSAlwaysPresentsApplicationModalAlertsBindingOption();
//  public static const native int NSAnimateBinding();
//  public static const native int NSAnimationDelayBinding();
//  public static const native int NSAnimationProgressMark();
//  public static const native int NSAnimationProgressMarkNotification();
//  public static const native int NSAnimationTriggerOrderIn();
//  public static const native int NSAnimationTriggerOrderOut();
//  public static const native int NSAntialiasThresholdChangedNotification();
//  public static const native int NSApp();
//  public static const native int NSAppKitIgnoredException();
//  public static const native int NSAppKitVersionNumber();
//  public static const native int NSAppKitVirtualMemoryException();
//  public static const native int NSApplicationDidBecomeActiveNotification();
//  public static const native int NSApplicationDidChangeScreenParametersNotification();
//  public static const native int NSApplicationDidFinishLaunchingNotification();
//  public static const native int NSApplicationDidHideNotification();
//  public static const native int NSApplicationDidResignActiveNotification();
//  public static const native int NSApplicationDidUnhideNotification();
//  public static const native int NSApplicationDidUpdateNotification();
//  public static const native int NSApplicationFileType();
//  public static const native int NSApplicationWillBecomeActiveNotification();
//  public static const native int NSApplicationWillFinishLaunchingNotification();
//  public static const native int NSApplicationWillHideNotification();
//  public static const native int NSApplicationWillResignActiveNotification();
//  public static const native int NSApplicationWillTerminateNotification();
//  public static const native int NSApplicationWillUnhideNotification();
//  public static const native int NSApplicationWillUpdateNotification();
//  public static const native int NSArgumentBinding();
//  public static const native int NSAttachmentAttributeName();
//  public static const native int NSAttributedStringBinding();
//  public static const native int NSAuthorDocumentAttribute();
    alias NSAttributedString.NSBackgroundColorAttributeName NSBackgroundColorAttributeName;
//  public static const native int NSBackgroundColorDocumentAttribute();
//  public static const native int NSBadBitmapParametersException();
//  public static const native int NSBadComparisonException();
//  public static const native int NSBadRTFColorTableException();
//  public static const native int NSBadRTFDirectiveException();
//  public static const native int NSBadRTFFontTableException();
//  public static const native int NSBadRTFStyleSheetException();
//  public static const native int NSBaseURLDocumentOption();
    alias NSAttributedString.NSBaselineOffsetAttributeName NSBaselineOffsetAttributeName;
//  public static const native int NSBlack();
//  public static const native int NSBottomMarginDocumentAttribute();
//  public static const native int NSBrowserColumnConfigurationDidChangeNotification();
//  public static const native int NSBrowserIllegalDelegateException();
//  public static const native int NSCalibratedBlackColorSpace();
//  public static const native int NSCalibratedRGBColorSpace();
//  public static const native int NSCalibratedWhiteColorSpace();
//  public static const native int NSCharacterEncodingDocumentAttribute();
//  public static const native int NSCharacterEncodingDocumentOption();
//  public static const native int NSCharacterShapeAttributeName();
//  public static const native int NSCocoaVersionDocumentAttribute();
//  public static const native int NSColorListDidChangeNotification();
//  public static const native int NSColorListIOException();
//  public static const native int NSColorListNotEditableException();
//  public static const native int NSColorPanelColorDidChangeNotification();
//  public static const native int NSColorPboardType();
//  public static const native int NSComboBoxSelectionDidChangeNotification();
//  public static const native int NSComboBoxSelectionIsChangingNotification();
//  public static const native int NSComboBoxWillDismissNotification();
//  public static const native int NSComboBoxWillPopUpNotification();
//  public static const native int NSCommentDocumentAttribute();
//  public static const native int NSCompanyDocumentAttribute();
//  public static const native int NSConditionallySetsEditableBindingOption();
//  public static const native int NSConditionallySetsEnabledBindingOption();
//  public static const native int NSConditionallySetsHiddenBindingOption();
//  public static const native int NSContentArrayBinding();
//  public static const native int NSContentArrayForMultipleSelectionBinding();
//  public static const native int NSContentBinding();
//  public static const native int NSContentDictionaryBinding();
//  public static const native int NSContentHeightBinding();
//  public static const native int NSContentObjectBinding();
//  public static const native int NSContentObjectsBinding();
//  public static const native int NSContentPlacementTagBindingOption();
//  public static const native int NSContentSetBinding();
//  public static const native int NSContentValuesBinding();
//  public static const native int NSContentWidthBinding();
//  public static const native int NSContextHelpModeDidActivateNotification();
//  public static const native int NSContextHelpModeDidDeactivateNotification();
//  public static const native int NSContinuouslyUpdatesValueBindingOption();
//  public static const native int NSControlTextDidBeginEditingNotification();
//  public static const native int NSControlTextDidChangeNotification();
//  public static const native int NSControlTextDidEndEditingNotification();
//  public static const native int NSControlTintDidChangeNotification();
//  public static const native int NSConvertedDocumentAttribute();
//  public static const native int NSCopyrightDocumentAttribute();
//  public static const native int NSCreatesSortDescriptorBindingOption();
//  public static const native int NSCreationTimeDocumentAttribute();
//  public static const native int NSCriticalValueBinding();
//  public static const native int NSCursorAttributeName();
//  public static const native int NSCustomColorSpace();
//  public static const native int NSDarkGray();
//  public static const native int NSDataBinding();
//  public static const native int NSDefaultAttributesDocumentOption();
//  public static const native int NSDefaultTabIntervalDocumentAttribute();
//  public static const native int NSDeletesObjectsOnRemoveBindingsOption();
//  public static const native int NSDeviceBitsPerSample();
//  public static const native int NSDeviceBlackColorSpace();
//  public static const native int NSDeviceCMYKColorSpace();
//  public static const native int NSDeviceColorSpaceName();
//  public static const native int NSDeviceIsPrinter();
//  public static const native int NSDeviceIsScreen();
    alias NSGraphics.NSDeviceRGBColorSpace NSDeviceRGBColorSpace;
    alias NSScreen.NSDeviceResolution NSDeviceResolution;
//  public static const native int NSDeviceSize();
//  public static const native int NSDeviceWhiteColorSpace();
//  public static const native int NSDirectoryFileType();
//  public static const native int NSDisplayNameBindingOption();
//  public static const native int NSDisplayPatternBindingOption();
//  public static const native int NSDisplayPatternTitleBinding();
//  public static const native int NSDisplayPatternValueBinding();
//  public static const native int NSDocFormatTextDocumentType();
//  public static const native int NSDocumentEditedBinding();
//  public static const native int NSDocumentTypeDocumentAttribute();
//  public static const native int NSDocumentTypeDocumentOption();
//  public static const native int NSDoubleClickArgumentBinding();
//  public static const native int NSDoubleClickTargetBinding();
//  public static const native int NSDragPboard();
//  public static const native int NSDraggingException();
//  public static const native int NSDrawerDidCloseNotification();
//  public static const native int NSDrawerDidOpenNotification();
//  public static const native int NSDrawerWillCloseNotification();
//  public static const native int NSDrawerWillOpenNotification();
//  public static const native int NSEditableBinding();
//  public static const native int NSEditorDocumentAttribute();
//  public static const native int NSEnabledBinding();
//  public static const native int NSEventTrackingRunLoopMode();
//  public static const native int NSExcludedElementsDocumentAttribute();
//  public static const native int NSExcludedKeysBinding();
//  public static const native int NSExpansionAttributeName();
//  public static const native int NSFileContentsPboardType();
//  public static const native int NSFilenamesPboardType();
//  public static const native int NSFilesPromisePboardType();
//  public static const native int NSFilesystemFileType();
//  public static const native int NSFilterPredicateBinding();
//  public static const native int NSFindPanelCaseInsensitiveSearch();
//  public static const native int NSFindPanelSearchOptionsPboardType();
//  public static const native int NSFindPanelSubStringMatch();
//  public static const native int NSFindPboard();
    alias NSAttributedString.NSFontAttributeName NSFontAttributeName;
//  public static const native int NSFontBinding();
//  public static const native int NSFontBoldBinding();
//  public static const native int NSFontCascadeListAttribute();
//  public static const native int NSFontCharacterSetAttribute();
//  public static const native int NSFontFaceAttribute();
//  public static const native int NSFontFamilyAttribute();
//  public static const native int NSFontFamilyNameBinding();
//  public static const native int NSFontFeatureSelectorIdentifierKey();
//  public static const native int NSFontFeatureSettingsAttribute();
//  public static const native int NSFontFeatureTypeIdentifierKey();
//  public static const native int NSFontFixedAdvanceAttribute();
//  public static const native int NSFontIdentityMatrix();
//  public static const native int NSFontItalicBinding();
//  public static const native int NSFontMatrixAttribute();
//  public static const native int NSFontNameAttribute();
//  public static const native int NSFontNameBinding();
//  public static const native int NSFontPboard();
//  public static const native int NSFontPboardType();
//  public static const native int NSFontSetChangedNotification();
//  public static const native int NSFontSizeAttribute();
//  public static const native int NSFontSizeBinding();
//  public static const native int NSFontSlantTrait();
//  public static const native int NSFontSymbolicTrait();
//  public static const native int NSFontTraitsAttribute();
//  public static const native int NSFontUnavailableException();
//  public static const native int NSFontVariationAttribute();
//  public static const native int NSFontVariationAxisDefaultValueKey();
//  public static const native int NSFontVariationAxisIdentifierKey();
//  public static const native int NSFontVariationAxisMaximumValueKey();
//  public static const native int NSFontVariationAxisMinimumValueKey();
//  public static const native int NSFontVariationAxisNameKey();
//  public static const native int NSFontVisibleNameAttribute();
//  public static const native int NSFontWeightTrait();
//  public static const native int NSFontWidthTrait();
    alias NSAttributedString.NSForegroundColorAttributeName NSForegroundColorAttributeName;
//  public static const native int NSFullScreenModeAllScreens();
//  public static const native int NSFullScreenModeSetting();
//  public static const native int NSFullScreenModeWindowLevel();
//  public static const native int NSGeneralPboard();
//  public static const native int NSGlyphInfoAttributeName();
//  public static const native int NSGraphicsContextDestinationAttributeName();
//  public static const native int NSGraphicsContextPDFFormat();
//  public static const native int NSGraphicsContextPSFormat();
//  public static const native int NSGraphicsContextRepresentationFormatAttributeName();
//  public static const native int NSHTMLPboardType();
//  public static const native int NSHTMLTextDocumentType();
//  public static const native int NSHandlesContentAsCompoundValueBindingOption();
//  public static const native int NSHeaderTitleBinding();
//  public static const native int NSHiddenBinding();
//  public static const native int NSHyphenationFactorDocumentAttribute();
//  public static const native int NSIllegalSelectorException();
//  public static const native int NSImageBinding();
//  public static const native int NSImageCacheException();
//  public static const native int NSImageColorSyncProfileData();
//  public static const native int NSImageCompressionFactor();
//  public static const native int NSImageCompressionMethod();
//  public static const native int NSImageCurrentFrame();
//  public static const native int NSImageCurrentFrameDuration();
//  public static const native int NSImageDitherTransparency();
//  public static const native int NSImageEXIFData();
//  public static const native int NSImageFallbackBackgroundColor();
//  public static const native int NSImageFrameCount();
//  public static const native int NSImageGamma();
//  public static const native int NSImageInterlaced();
//  public static const native int NSImageLoopCount();
//  public static const native int NSImageNameActionTemplate();
//  public static const native int NSImageNameAddTemplate();
//  public static const native int NSImageNameAdvanced();
//  public static const native int NSImageNameBluetoothTemplate();
//  public static const native int NSImageNameBonjour();
//  public static const native int NSImageNameColorPanel();
//  public static const native int NSImageNameColumnViewTemplate();
//  public static const native int NSImageNameComputer();
//  public static const native int NSImageNameDotMac();
//  public static const native int NSImageNameEnterFullScreenTemplate();
//  public static const native int NSImageNameEveryone();
//  public static const native int NSImageNameExitFullScreenTemplate();
//  public static const native int NSImageNameFlowViewTemplate();
//  public static const native int NSImageNameFolderBurnable();
//  public static const native int NSImageNameFolderSmart();
//  public static const native int NSImageNameFollowLinkFreestandingTemplate();
//  public static const native int NSImageNameFontPanel();
//  public static const native int NSImageNameGoLeftTemplate();
//  public static const native int NSImageNameGoRightTemplate();
//  public static const native int NSImageNameIChatTheaterTemplate();
//  public static const native int NSImageNameIconViewTemplate();
//  public static const native int NSImageNameInfo();
//  public static const native int NSImageNameInvalidDataFreestandingTemplate();
//  public static const native int NSImageNameLeftFacingTriangleTemplate();
//  public static const native int NSImageNameListViewTemplate();
//  public static const native int NSImageNameLockLockedTemplate();
//  public static const native int NSImageNameLockUnlockedTemplate();
//  public static const native int NSImageNameMultipleDocuments();
//  public static const native int NSImageNameNetwork();
//  public static const native int NSImageNamePathTemplate();
//  public static const native int NSImageNamePreferencesGeneral();
//  public static const native int NSImageNameQuickLookTemplate();
//  public static const native int NSImageNameRefreshFreestandingTemplate();
//  public static const native int NSImageNameRefreshTemplate();
//  public static const native int NSImageNameRemoveTemplate();
//  public static const native int NSImageNameRevealFreestandingTemplate();
//  public static const native int NSImageNameRightFacingTriangleTemplate();
//  public static const native int NSImageNameSlideshowTemplate();
//  public static const native int NSImageNameSmartBadgeTemplate();
//  public static const native int NSImageNameStopProgressFreestandingTemplate();
//  public static const native int NSImageNameStopProgressTemplate();
//  public static const native int NSImageNameUser();
//  public static const native int NSImageNameUserAccounts();
//  public static const native int NSImageNameUserGroup();
//  public static const native int NSImageProgressive();
//  public static const native int NSImageRGBColorTable();
//  public static const native int NSImageRepRegistryDidChangeNotification();
//  public static const native int NSIncludedKeysBinding();
//  public static const native int NSInitialKeyBinding();
//  public static const native int NSInitialValueBinding();
//  public static const native int NSInkTextPboardType();
//  public static const native int NSInsertsNullPlaceholderBindingOption();
//  public static const native int NSInterfaceStyleDefault();
//  public static const native int NSInvokesSeparatelyWithArrayObjectsBindingOption();
//  public static const native int NSIsIndeterminateBinding();
//  public static const native int NSKernAttributeName();
//  public static const native int NSKeywordsDocumentAttribute();
//  public static const native int NSLabelBinding();
//  public static const native int NSLeftMarginDocumentAttribute();
//  public static const native int NSLigatureAttributeName();
//  public static const native int NSLightGray();
    alias NSAttributedString.NSLinkAttributeName NSLinkAttributeName;
//  public static const native int NSLocalizedKeyDictionaryBinding();
//  public static const native int NSMacSimpleTextDocumentType();
//  public static const native int NSManagedObjectContextBinding();
//  public static const native int NSMarkedClauseSegmentAttributeName();
//  public static const native int NSMaxValueBinding();
//  public static const native int NSMaxWidthBinding();
//  public static const native int NSMaximumRecentsBinding();
//  public static const native int NSMenuDidAddItemNotification();
//  public static const native int NSMenuDidBeginTrackingNotification();
//  public static const native int NSMenuDidChangeItemNotification();
//  public static const native int NSMenuDidEndTrackingNotification();
//  public static const native int NSMenuDidRemoveItemNotification();
//  public static const native int NSMenuDidSendActionNotification();
//  public static const native int NSMenuWillSendActionNotification();
//  public static const native int NSMinValueBinding();
//  public static const native int NSMinWidthBinding();
//  public static const native int NSMixedStateImageBinding();
//  public static const native int NSModalPanelRunLoopMode();
//  public static const native int NSModificationTimeDocumentAttribute();
//  public static const native int NSMultipleTextSelectionPboardType();
//  public static const native int NSMultipleValuesMarker();
//  public static const native int NSMultipleValuesPlaceholderBindingOption();
//  public static const native int NSNamedColorSpace();
//  public static const native int NSNibLoadingException();
//  public static const native int NSNibOwner();
//  public static const native int NSNibTopLevelObjects();
//  public static const native int NSNoSelectionMarker();
//  public static const native int NSNoSelectionPlaceholderBindingOption();
//  public static const native int NSNotApplicableMarker();
//  public static const native int NSNotApplicablePlaceholderBindingOption();
//  public static const native int NSNullPlaceholderBindingOption();
//  public static const native int NSObliquenessAttributeName();
//  public static const native int NSObservedKeyPathKey();
//  public static const native int NSObservedObjectKey();
//  public static const native int NSOffStateImageBinding();
//  public static const native int NSOfficeOpenXMLTextDocumentType();
//  public static const native int NSOnStateImageBinding();
//  public static const native int NSOpenDocumentTextDocumentType();
//  public static const native int NSOptionsKey();
//  public static const native int NSOutlineViewColumnDidMoveNotification();
//  public static const native int NSOutlineViewColumnDidResizeNotification();
//  public static const native int NSOutlineViewItemDidCollapseNotification();
//  public static const native int NSOutlineViewItemDidExpandNotification();
//  public static const native int NSOutlineViewItemWillCollapseNotification();
//  public static const native int NSOutlineViewItemWillExpandNotification();
//  public static const native int NSOutlineViewSelectionDidChangeNotification();
//  public static const native int NSOutlineViewSelectionIsChangingNotification();
//  public static const native int NSPDFPboardType();
//  public static const native int NSPICTPboardType();
//  public static const native int NSPPDIncludeNotFoundException();
//  public static const native int NSPPDIncludeStackOverflowException();
//  public static const native int NSPPDIncludeStackUnderflowException();
//  public static const native int NSPPDParseException();
//  public static const native int NSPaperSizeDocumentAttribute();
    alias NSAttributedString.NSParagraphStyleAttributeName NSParagraphStyleAttributeName;
//  public static const native int NSPasteboardCommunicationException();
//  public static const native int NSPatternColorSpace();
//  public static const native int NSPlainFileType();
//  public static const native int NSPlainTextDocumentType();
//  public static const native int NSPopUpButtonCellWillPopUpNotification();
//  public static const native int NSPopUpButtonWillPopUpNotification();
//  public static const native int NSPostScriptPboardType();
//  public static const native int NSPredicateBinding();
//  public static const native int NSPredicateFormatBindingOption();
//  public static const native int NSPrefixSpacesDocumentAttribute();
//  public static const native int NSPrintAllPages();
//  public static const native int NSPrintBottomMargin();
//  public static const native int NSPrintCancelJob();
//  public static const native int NSPrintCopies();
//  public static const native int NSPrintDetailedErrorReporting();
//  public static const native int NSPrintFaxCoverSheetName();
//  public static const native int NSPrintFaxHighResolution();
//  public static const native int NSPrintFaxJob();
//  public static const native int NSPrintFaxModem();
//  public static const native int NSPrintFaxNumber();
//  public static const native int NSPrintFaxReceiverNames();
//  public static const native int NSPrintFaxReceiverNumbers();
//  public static const native int NSPrintFaxReturnReceipt();
//  public static const native int NSPrintFaxSendTime();
//  public static const native int NSPrintFaxTrimPageEnds();
//  public static const native int NSPrintFaxUseCoverSheet();
//  public static const native int NSPrintFirstPage();
//  public static const native int NSPrintFormName();
//  public static const native int NSPrintHeaderAndFooter();
//  public static const native int NSPrintHorizontalPagination();
//  public static const native int NSPrintHorizontallyCentered();
//  public static const native int NSPrintJobDisposition();
//  public static const native int NSPrintJobFeatures();
//  public static const native int NSPrintLastPage();
//  public static const native int NSPrintLeftMargin();
//  public static const native int NSPrintManualFeed();
//  public static const native int NSPrintMustCollate();
//  public static const native int NSPrintOperationExistsException();
//  public static const native int NSPrintOrientation();
//  public static const native int NSPrintPackageException();
//  public static const native int NSPrintPagesAcross();
//  public static const native int NSPrintPagesDown();
//  public static const native int NSPrintPagesPerSheet();
//  public static const native int NSPrintPanelAccessorySummaryItemDescriptionKey();
//  public static const native int NSPrintPanelAccessorySummaryItemNameKey();
//  public static const native int NSPrintPaperFeed();
//  public static const native int NSPrintPaperName();
//  public static const native int NSPrintPaperSize();
//  public static const native int NSPrintPhotoJobStyleHint();
//  public static const native int NSPrintPreviewJob();
//  public static const native int NSPrintPrinter();
//  public static const native int NSPrintPrinterName();
//  public static const native int NSPrintReversePageOrder();
//  public static const native int NSPrintRightMargin();
//  public static const native int NSPrintSaveJob();
//  public static const native int NSPrintSavePath();
//  public static const native int NSPrintScalingFactor();
//  public static const native int NSPrintSpoolJob();
//  public static const native int NSPrintTime();
//  public static const native int NSPrintTopMargin();
//  public static const native int NSPrintVerticalPagination();
//  public static const native int NSPrintVerticallyCentered();
//  public static const native int NSPrintingCommunicationException();
//  public static const native int NSRTFDPboardType();
//  public static const native int NSRTFDTextDocumentType();
//  public static const native int NSRTFPboardType();
//  public static const native int NSRTFPropertyStackOverflowException();
//  public static const native int NSRTFTextDocumentType();
//  public static const native int NSRaisesForNotApplicableKeysBindingOption();
//  public static const native int NSReadOnlyDocumentAttribute();
//  public static const native int NSRecentSearchesBinding();
//  public static const native int NSRepresentedFilenameBinding();
//  public static const native int NSRightMarginDocumentAttribute();
//  public static const native int NSRowHeightBinding();
//  public static const native int NSRuleEditorPredicateComparisonModifier();
//  public static const native int NSRuleEditorPredicateCompoundType();
//  public static const native int NSRuleEditorPredicateCustomSelector();
//  public static const native int NSRuleEditorPredicateLeftExpression();
//  public static const native int NSRuleEditorPredicateOperatorType();
//  public static const native int NSRuleEditorPredicateOptions();
//  public static const native int NSRuleEditorPredicateRightExpression();
//  public static const native int NSRuleEditorRowsDidChangeNotification();
//  public static const native int NSRulerPboard();
//  public static const native int NSRulerPboardType();
//  public static const native int NSSelectedIdentifierBinding();
//  public static const native int NSSelectedIndexBinding();
//  public static const native int NSSelectedLabelBinding();
//  public static const native int NSSelectedObjectBinding();
//  public static const native int NSSelectedObjectsBinding();
//  public static const native int NSSelectedTagBinding();
//  public static const native int NSSelectedValueBinding();
//  public static const native int NSSelectedValuesBinding();
//  public static const native int NSSelectionIndexPathsBinding();
//  public static const native int NSSelectionIndexesBinding();
//  public static const native int NSSelectorNameBindingOption();
//  public static const native int NSSelectsAllWhenSettingContentBindingOption();
//  public static const native int NSShadowAttributeName();
//  public static const native int NSShellCommandFileType();
//  public static const native int NSSortDescriptorsBinding();
//  public static const native int NSSoundPboardType();
//  public static const native int NSSpeechCharacterModeProperty();
//  public static const native int NSSpeechCommandDelimiterProperty();
//  public static const native int NSSpeechCommandPrefix();
//  public static const native int NSSpeechCommandSuffix();
//  public static const native int NSSpeechCurrentVoiceProperty();
//  public static const native int NSSpeechDictionaryAbbreviations();
//  public static const native int NSSpeechDictionaryEntryPhonemes();
//  public static const native int NSSpeechDictionaryEntrySpelling();
//  public static const native int NSSpeechDictionaryLocaleIdentifier();
//  public static const native int NSSpeechDictionaryModificationDate();
//  public static const native int NSSpeechDictionaryPronunciations();
//  public static const native int NSSpeechErrorCount();
//  public static const native int NSSpeechErrorNewestCharacterOffset();
//  public static const native int NSSpeechErrorNewestCode();
//  public static const native int NSSpeechErrorOldestCharacterOffset();
//  public static const native int NSSpeechErrorOldestCode();
//  public static const native int NSSpeechErrorsProperty();
//  public static const native int NSSpeechInputModeProperty();
//  public static const native int NSSpeechModeLiteral();
//  public static const native int NSSpeechModeNormal();
//  public static const native int NSSpeechModePhoneme();
//  public static const native int NSSpeechModeText();
//  public static const native int NSSpeechNumberModeProperty();
//  public static const native int NSSpeechOutputToFileURLProperty();
//  public static const native int NSSpeechPhonemeInfoExample();
//  public static const native int NSSpeechPhonemeInfoHiliteEnd();
//  public static const native int NSSpeechPhonemeInfoHiliteStart();
//  public static const native int NSSpeechPhonemeInfoOpcode();
//  public static const native int NSSpeechPhonemeInfoSymbol();
//  public static const native int NSSpeechPhonemeSymbolsProperty();
//  public static const native int NSSpeechPitchBaseProperty();
//  public static const native int NSSpeechPitchModProperty();
//  public static const native int NSSpeechRateProperty();
//  public static const native int NSSpeechRecentSyncProperty();
//  public static const native int NSSpeechResetProperty();
//  public static const native int NSSpeechStatusNumberOfCharactersLeft();
//  public static const native int NSSpeechStatusOutputBusy();
//  public static const native int NSSpeechStatusOutputPaused();
//  public static const native int NSSpeechStatusPhonemeCode();
//  public static const native int NSSpeechStatusProperty();
//  public static const native int NSSpeechSynthesizerInfoIdentifier();
//  public static const native int NSSpeechSynthesizerInfoProperty();
//  public static const native int NSSpeechSynthesizerInfoVersion();
//  public static const native int NSSpeechVolumeProperty();
//  public static const native int NSSpellingStateAttributeName();
//  public static const native int NSSplitViewDidResizeSubviewsNotification();
//  public static const native int NSSplitViewWillResizeSubviewsNotification();
    alias NSAttributedString.NSStrikethroughColorAttributeName NSStrikethroughColorAttributeName;
    alias NSAttributedString.NSStrikethroughStyleAttributeName NSStrikethroughStyleAttributeName;
//  public static const native int NSStringPboardType();
//  public static const native int NSStrokeColorAttributeName();
//  public static const native int NSStrokeWidthAttributeName();
//  public static const native int NSSubjectDocumentAttribute();
//  public static const native int NSSuperscriptAttributeName();
//  public static const native int NSSystemColorsDidChangeNotification();
//  public static const native int NSTIFFException();
//  public static const native int NSTIFFPboardType();
//  public static const native int NSTabColumnTerminatorsAttributeName();
//  public static const native int NSTableViewColumnDidMoveNotification();
//  public static const native int NSTableViewColumnDidResizeNotification();
//  public static const native int NSTableViewSelectionDidChangeNotification();
//  public static const native int NSTableViewSelectionIsChangingNotification();
//  public static const native int NSTabularTextPboardType();
//  public static const native int NSTargetBinding();
//  public static const native int NSTextColorBinding();
//  public static const native int NSTextDidBeginEditingNotification();
//  public static const native int NSTextDidChangeNotification();
//  public static const native int NSTextDidEndEditingNotification();
//  public static const native int NSTextEncodingNameDocumentAttribute();
//  public static const native int NSTextEncodingNameDocumentOption();
//  public static const native int NSTextLineTooLongException();
//  public static const native int NSTextNoSelectionException();
//  public static const native int NSTextReadException();
//  public static const native int NSTextSizeMultiplierDocumentOption();
//  public static const native int NSTextStorageDidProcessEditingNotification();
//  public static const native int NSTextStorageWillProcessEditingNotification();
//  public static const native int NSTextViewDidChangeSelectionNotification();
//  public static const native int NSTextViewDidChangeTypingAttributesNotification();
//  public static const native int NSTextViewWillChangeNotifyingTextViewNotification();
//  public static const native int NSTextWriteException();
//  public static const native int NSTimeoutDocumentOption();
//  public static const native int NSTitleBinding();
//  public static const native int NSTitleDocumentAttribute();
//  public static const native int NSToolTipAttributeName();
//  public static const native int NSToolTipBinding();
//  public static const native int NSToolbarCustomizeToolbarItemIdentifier();
//  public static const native int NSToolbarDidRemoveItemNotification();
//  public static const native int NSToolbarFlexibleSpaceItemIdentifier();
//  public static const native int NSToolbarPrintItemIdentifier();
//  public static const native int NSToolbarSeparatorItemIdentifier();
//  public static const native int NSToolbarShowColorsItemIdentifier();
//  public static const native int NSToolbarShowFontsItemIdentifier();
//  public static const native int NSToolbarSpaceItemIdentifier();
//  public static const native int NSToolbarWillAddItemNotification();
//  public static const native int NSTopMarginDocumentAttribute();
//  public static const native int NSTransparentBinding();
//  public static const native int NSTypedStreamVersionException();
//  public static const native int NSURLPboardType();
//  public static const native int NSUnderlineByWordMask();
    alias NSAttributedString.NSUnderlineColorAttributeName NSUnderlineColorAttributeName;
//  public static const native int NSUnderlineStrikethroughMask();
    alias NSAttributedString.NSUnderlineStyleAttributeName NSUnderlineStyleAttributeName;
//  public static const native int NSVCardPboardType();
//  public static const native int NSValidatesImmediatelyBindingOption();
//  public static const native int NSValueBinding();
//  public static const native int NSValuePathBinding();
//  public static const native int NSValueTransformerBindingOption();
//  public static const native int NSValueTransformerNameBindingOption();
//  public static const native int NSValueURLBinding();
//  public static const native int NSViewAnimationEffectKey();
//  public static const native int NSViewAnimationEndFrameKey();
//  public static const native int NSViewAnimationFadeInEffect();
//  public static const native int NSViewAnimationFadeOutEffect();
//  public static const native int NSViewAnimationStartFrameKey();
//  public static const native int NSViewAnimationTargetKey();
//  public static const native int NSViewBoundsDidChangeNotification();
//  public static const native int NSViewDidUpdateTrackingAreasNotification();
//  public static const native int NSViewFocusDidChangeNotification();
//  public static const native int NSViewFrameDidChangeNotification();
//  public static const native int NSViewGlobalFrameDidChangeNotification();
//  public static const native int NSViewModeDocumentAttribute();
//  public static const native int NSViewSizeDocumentAttribute();
//  public static const native int NSViewZoomDocumentAttribute();
//  public static const native int NSVisibleBinding();
//  public static const native int NSVoiceAge();
//  public static const native int NSVoiceDemoText();
//  public static const native int NSVoiceGender();
//  public static const native int NSVoiceGenderFemale();
//  public static const native int NSVoiceGenderMale();
//  public static const native int NSVoiceGenderNeuter();
//  public static const native int NSVoiceIdentifier();
//  public static const native int NSVoiceIndividuallySpokenCharacters();
//  public static const native int NSVoiceLocaleIdentifier();
//  public static const native int NSVoiceName();
//  public static const native int NSVoiceSupportedCharacters();
//  public static const native int NSWarningValueBinding();
//  public static const native int NSWebArchiveTextDocumentType();
//  public static const native int NSWebPreferencesDocumentOption();
//  public static const native int NSWebResourceLoadDelegateDocumentOption();
//  public static const native int NSWhite();
//  public static const native int NSWidthBinding();
//  public static const native int NSWindowDidBecomeKeyNotification();
//  public static const native int NSWindowDidBecomeMainNotification();
//  public static const native int NSWindowDidChangeScreenNotification();
//  public static const native int NSWindowDidChangeScreenProfileNotification();
//  public static const native int NSWindowDidDeminiaturizeNotification();
//  public static const native int NSWindowDidEndSheetNotification();
//  public static const native int NSWindowDidExposeNotification();
//  public static const native int NSWindowDidMiniaturizeNotification();
//  public static const native int NSWindowDidMoveNotification();
//  public static const native int NSWindowDidResignKeyNotification();
//  public static const native int NSWindowDidResignMainNotification();
//  public static const native int NSWindowDidResizeNotification();
//  public static const native int NSWindowDidUpdateNotification();
//  public static const native int NSWindowServerCommunicationException();
//  public static const native int NSWindowWillBeginSheetNotification();
//  public static const native int NSWindowWillCloseNotification();
//  public static const native int NSWindowWillMiniaturizeNotification();
//  public static const native int NSWindowWillMoveNotification();
//  public static const native int NSWordMLTextDocumentType();
//  public static const native int NSWordTablesReadException();
//  public static const native int NSWordTablesWriteException();
//  public static const native int NSWorkspaceCompressOperation();
//  public static const native int NSWorkspaceCopyOperation();
//  public static const native int NSWorkspaceDecompressOperation();
//  public static const native int NSWorkspaceDecryptOperation();
//  public static const native int NSWorkspaceDestroyOperation();
//  public static const native int NSWorkspaceDidLaunchApplicationNotification();
//  public static const native int NSWorkspaceDidMountNotification();
//  public static const native int NSWorkspaceDidPerformFileOperationNotification();
//  public static const native int NSWorkspaceDidTerminateApplicationNotification();
//  public static const native int NSWorkspaceDidUnmountNotification();
//  public static const native int NSWorkspaceDidWakeNotification();
//  public static const native int NSWorkspaceDuplicateOperation();
//  public static const native int NSWorkspaceEncryptOperation();
//  public static const native int NSWorkspaceLinkOperation();
//  public static const native int NSWorkspaceMoveOperation();
//  public static const native int NSWorkspaceRecycleOperation();
//  public static const native int NSWorkspaceSessionDidBecomeActiveNotification();
//  public static const native int NSWorkspaceSessionDidResignActiveNotification();
//  public static const native int NSWorkspaceWillLaunchApplicationNotification();
//  public static const native int NSWorkspaceWillPowerOffNotification();
//  public static const native int NSWorkspaceWillSleepNotification();
//  public static const native int NSWorkspaceWillUnmountNotification();
//  public static const native int NSAppleEventManagerWillProcessFirstEventNotification();
//  public static const native int NSAppleEventTimeOutDefault();
//  public static const native int NSAppleEventTimeOutNone();
//  public static const native int NSAppleScriptErrorAppName();
//  public static const native int NSAppleScriptErrorBriefMessage();
//  public static const native int NSAppleScriptErrorMessage();
//  public static const native int NSAppleScriptErrorNumber();
//  public static const native int NSAppleScriptErrorRange();
//  public static const native int NSArgumentDomain();
//  public static const native int NSAverageKeyValueOperator();
//  public static const native int NSBuddhistCalendar();
//  public static const native int NSBundleDidLoadNotification();
//  public static const native int NSCharacterConversionException();
//  public static const native int NSChineseCalendar();
//  public static const native int NSClassDescriptionNeededForClassNotification();
//  public static const native int NSCocoaErrorDomain();
//  public static const native int NSConnectionDidDieNotification();
//  public static const native int NSConnectionDidInitializeNotification();
//  public static const native int NSConnectionReplyMode();
//  public static const native int NSCountKeyValueOperator();
//  public static const native int NSCurrentLocaleDidChangeNotification();
//  public static const native int NSDeallocateZombies();
//  public static const native int NSDebugEnabled();
//  public static const native int NSDecimalNumberDivideByZeroException();
//  public static const native int NSDecimalNumberExactnessException();
//  public static const native int NSDecimalNumberOverflowException();
//  public static const native int NSDecimalNumberUnderflowException();
    alias NSRunLoop.NSDefaultRunLoopMode NSDefaultRunLoopMode;
//  public static const native int NSDestinationInvalidException();
//  public static const native int NSDidBecomeSingleThreadedNotification();
//  public static const native int NSDistinctUnionOfArraysKeyValueOperator();
//  public static const native int NSDistinctUnionOfObjectsKeyValueOperator();
//  public static const native int NSDistinctUnionOfSetsKeyValueOperator();
//  public static const native int NSErrorFailingURLStringKey();
//  public static const native int NSFailedAuthenticationException();
//  public static const native int NSFileAppendOnly();
//  public static const native int NSFileBusy();
//  public static const native int NSFileCreationDate();
//  public static const native int NSFileDeviceIdentifier();
//  public static const native int NSFileExtensionHidden();
//  public static const native int NSFileGroupOwnerAccountID();
//  public static const native int NSFileGroupOwnerAccountName();
//  public static const native int NSFileHFSCreatorCode();
//  public static const native int NSFileHFSTypeCode();
//  public static const native int NSFileHandleConnectionAcceptedNotification();
//  public static const native int NSFileHandleDataAvailableNotification();
//  public static const native int NSFileHandleNotificationDataItem();
//  public static const native int NSFileHandleNotificationFileHandleItem();
//  public static const native int NSFileHandleNotificationMonitorModes();
//  public static const native int NSFileHandleOperationException();
//  public static const native int NSFileHandleReadCompletionNotification();
//  public static const native int NSFileHandleReadToEndOfFileCompletionNotification();
//  public static const native int NSFileImmutable();
//  public static const native int NSFileModificationDate();
//  public static const native int NSFileOwnerAccountID();
//  public static const native int NSFileOwnerAccountName();
//  public static const native int NSFilePathErrorKey();
//  public static const native int NSFilePosixPermissions();
//  public static const native int NSFileReferenceCount();
//  public static const native int NSFileSize();
//  public static const native int NSFileSystemFileNumber();
//  public static const native int NSFileSystemFreeNodes();
//  public static const native int NSFileSystemFreeSize();
//  public static const native int NSFileSystemNodes();
//  public static const native int NSFileSystemNumber();
//  public static const native int NSFileSystemSize();
//  public static const native int NSFileType();
//  public static const native int NSFileTypeBlockSpecial();
//  public static const native int NSFileTypeCharacterSpecial();
//  public static const native int NSFileTypeDirectory();
//  public static const native int NSFileTypeRegular();
//  public static const native int NSFileTypeSocket();
//  public static const native int NSFileTypeSymbolicLink();
//  public static const native int NSFileTypeUnknown();
//  public static const native int NSFoundationVersionNumber();
//  public static const native int NSGenericException();
//  public static const native int NSGlobalDomain();
//  public static const native int NSGrammarCorrections();
//  public static const native int NSGrammarRange();
//  public static const native int NSGrammarUserDescription();
//  public static const native int NSGregorianCalendar();
//  public static const native int NSHTTPCookieComment();
//  public static const native int NSHTTPCookieCommentURL();
//  public static const native int NSHTTPCookieDiscard();
//  public static const native int NSHTTPCookieDomain();
//  public static const native int NSHTTPCookieExpires();
//  public static const native int NSHTTPCookieManagerAcceptPolicyChangedNotification();
//  public static const native int NSHTTPCookieManagerCookiesChangedNotification();
//  public static const native int NSHTTPCookieMaximumAge();
//  public static const native int NSHTTPCookieName();
//  public static const native int NSHTTPCookieOriginURL();
//  public static const native int NSHTTPCookiePath();
//  public static const native int NSHTTPCookiePort();
//  public static const native int NSHTTPCookieSecure();
//  public static const native int NSHTTPCookieValue();
//  public static const native int NSHTTPCookieVersion();
//  public static const native int NSHangOnUncaughtException();
//  public static const native int NSHebrewCalendar();
//  public static const native int NSInconsistentArchiveException();
//  public static const native int NSIntegerHashCallBacks();
//  public static const native int NSIntegerMapKeyCallBacks();
//  public static const native int NSIntegerMapValueCallBacks();
//  public static const native int NSInternalInconsistencyException();
//  public static const native int NSInvalidArchiveOperationException();
//  public static const native int NSInvalidArgumentException();
//  public static const native int NSInvalidReceivePortException();
//  public static const native int NSInvalidSendPortException();
//  public static const native int NSInvalidUnarchiveOperationException();
//  public static const native int NSInvocationOperationCancelledException();
//  public static const native int NSInvocationOperationVoidResultException();
//  public static const native int NSIsNilTransformerName();
//  public static const native int NSIsNotNilTransformerName();
//  public static const native int NSIslamicCalendar();
//  public static const native int NSIslamicCivilCalendar();
//  public static const native int NSJapaneseCalendar();
//  public static const native int NSKeepAllocationStatistics();
//  public static const native int NSKeyValueChangeIndexesKey();
//  public static const native int NSKeyValueChangeKindKey();
//  public static const native int NSKeyValueChangeNewKey();
//  public static const native int NSKeyValueChangeNotificationIsPriorKey();
//  public static const native int NSKeyValueChangeOldKey();
//  public static const native int NSKeyedUnarchiveFromDataTransformerName();
//  public static const native int NSLoadedClasses();
//  public static const native int NSLocalNotificationCenterType();
//  public static const native int NSLocaleCalendar();
//  public static const native int NSLocaleCollationIdentifier();
//  public static const native int NSLocaleCountryCode();
//  public static const native int NSLocaleCurrencyCode();
//  public static const native int NSLocaleCurrencySymbol();
//  public static const native int NSLocaleDecimalSeparator();
//  public static const native int NSLocaleExemplarCharacterSet();
//  public static const native int NSLocaleGroupingSeparator();
//  public static const native int NSLocaleIdentifier();
//  public static const native int NSLocaleLanguageCode();
//  public static const native int NSLocaleMeasurementSystem();
//  public static const native int NSLocaleScriptCode();
//  public static const native int NSLocaleUsesMetricSystem();
//  public static const native int NSLocaleVariantCode();
//  public static const native int NSLocalizedDescriptionKey();
//  public static const native int NSLocalizedFailureReasonErrorKey();
//  public static const native int NSLocalizedRecoveryOptionsErrorKey();
//  public static const native int NSLocalizedRecoverySuggestionErrorKey();
//  public static const native int NSMachErrorDomain();
//  public static const native int NSMallocException();
//  public static const native int NSMaximumKeyValueOperator();
//  public static const native int NSMetadataQueryDidFinishGatheringNotification();
//  public static const native int NSMetadataQueryDidStartGatheringNotification();
//  public static const native int NSMetadataQueryDidUpdateNotification();
//  public static const native int NSMetadataQueryGatheringProgressNotification();
//  public static const native int NSMetadataQueryLocalComputerScope();
//  public static const native int NSMetadataQueryNetworkScope();
//  public static const native int NSMetadataQueryResultContentRelevanceAttribute();
//  public static const native int NSMetadataQueryUserHomeScope();
//  public static const native int NSMinimumKeyValueOperator();
//  public static const native int NSNegateBooleanTransformerName();
//  public static const native int NSNetServicesErrorCode();
//  public static const native int NSNetServicesErrorDomain();
//  public static const native int NSNonOwnedPointerHashCallBacks();
//  public static const native int NSNonOwnedPointerMapKeyCallBacks();
//  public static const native int NSNonOwnedPointerMapValueCallBacks();
//  public static const native int NSNonOwnedPointerOrNullMapKeyCallBacks();
//  public static const native int NSNonRetainedObjectHashCallBacks();
//  public static const native int NSNonRetainedObjectMapKeyCallBacks();
//  public static const native int NSNonRetainedObjectMapValueCallBacks();
//  public static const native int NSOSStatusErrorDomain();
//  public static const native int NSObjectHashCallBacks();
//  public static const native int NSObjectInaccessibleException();
//  public static const native int NSObjectMapKeyCallBacks();
//  public static const native int NSObjectMapValueCallBacks();
//  public static const native int NSObjectNotAvailableException();
//  public static const native int NSOldStyleException();
//  public static const native int NSOperationNotSupportedForKeyException();
//  public static const native int NSOwnedObjectIdentityHashCallBacks();
//  public static const native int NSOwnedPointerHashCallBacks();
//  public static const native int NSOwnedPointerMapKeyCallBacks();
//  public static const native int NSOwnedPointerMapValueCallBacks();
//  public static const native int NSPOSIXErrorDomain();
//  public static const native int NSParseErrorException();
//  public static const native int NSPointerToStructHashCallBacks();
//  public static const native int NSPortDidBecomeInvalidNotification();
//  public static const native int NSPortReceiveException();
//  public static const native int NSPortSendException();
//  public static const native int NSPortTimeoutException();
//  public static const native int NSRangeException();
//  public static const native int NSRecoveryAttempterErrorKey();
//  public static const native int NSRegistrationDomain();
//  public static const native int NSRunLoopCommonModes();
//  public static const native int NSStreamDataWrittenToMemoryStreamKey();
//  public static const native int NSStreamFileCurrentOffsetKey();
//  public static const native int NSStreamSOCKSErrorDomain();
//  public static const native int NSStreamSOCKSProxyConfigurationKey();
//  public static const native int NSStreamSOCKSProxyHostKey();
//  public static const native int NSStreamSOCKSProxyPasswordKey();
//  public static const native int NSStreamSOCKSProxyPortKey();
//  public static const native int NSStreamSOCKSProxyUserKey();
//  public static const native int NSStreamSOCKSProxyVersion4();
//  public static const native int NSStreamSOCKSProxyVersion5();
//  public static const native int NSStreamSOCKSProxyVersionKey();
//  public static const native int NSStreamSocketSSLErrorDomain();
//  public static const native int NSStreamSocketSecurityLevelKey();
//  public static const native int NSStreamSocketSecurityLevelNegotiatedSSL();
//  public static const native int NSStreamSocketSecurityLevelNone();
//  public static const native int NSStreamSocketSecurityLevelSSLv2();
//  public static const native int NSStreamSocketSecurityLevelSSLv3();
//  public static const native int NSStreamSocketSecurityLevelTLSv1();
//  public static const native int NSStringEncodingErrorKey();
//  public static const native int NSSumKeyValueOperator();
//  public static const native int NSSystemTimeZoneDidChangeNotification();
//  public static const native int NSTaskDidTerminateNotification();
//  public static const native int NSThreadWillExitNotification();
//  public static const native int NSURLAuthenticationMethodDefault();
//  public static const native int NSURLAuthenticationMethodHTMLForm();
//  public static const native int NSURLAuthenticationMethodHTTPBasic();
//  public static const native int NSURLAuthenticationMethodHTTPDigest();
//  public static const native int NSURLCredentialStorageChangedNotification();
//  public static const native int NSURLErrorDomain();
//  public static const native int NSURLErrorKey();
//  public static const native int NSURLFileScheme();
//  public static const native int NSURLProtectionSpaceFTPProxy();
//  public static const native int NSURLProtectionSpaceHTTPProxy();
//  public static const native int NSURLProtectionSpaceHTTPSProxy();
//  public static const native int NSURLProtectionSpaceSOCKSProxy();
//  public static const native int NSUnarchiveFromDataTransformerName();
//  public static const native int NSUndefinedKeyException();
//  public static const native int NSUnderlyingErrorKey();
//  public static const native int NSUndoManagerCheckpointNotification();
//  public static const native int NSUndoManagerDidOpenUndoGroupNotification();
//  public static const native int NSUndoManagerDidRedoChangeNotification();
//  public static const native int NSUndoManagerDidUndoChangeNotification();
//  public static const native int NSUndoManagerWillCloseUndoGroupNotification();
//  public static const native int NSUndoManagerWillRedoChangeNotification();
//  public static const native int NSUndoManagerWillUndoChangeNotification();
//  public static const native int NSUnionOfArraysKeyValueOperator();
//  public static const native int NSUnionOfObjectsKeyValueOperator();
//  public static const native int NSUnionOfSetsKeyValueOperator();
//  public static const native int NSUserDefaultsDidChangeNotification();
//  public static const native int NSWillBecomeMultiThreadedNotification();
//  public static const native int NSXMLParserErrorDomain();
//  public static const native int NSZeroPoint();
//  public static const native int NSZeroRect();
//  public static const native int NSZeroSize();
//  public static const native int NSZombieEnabled();
//  public static const native int DOMEventException();
//  public static const native int DOMException();
//  public static const native int DOMRangeException();
//  public static const native int DOMXPathException();
//  public static const native int WebActionButtonKey();
//  public static const native int WebActionElementKey();
//  public static const native int WebActionModifierFlagsKey();
//  public static const native int WebActionNavigationTypeKey();
//  public static const native int WebActionOriginalURLKey();
//  public static const native int WebArchivePboardType();
//  public static const native int WebElementDOMNodeKey();
//  public static const native int WebElementFrameKey();
//  public static const native int WebElementImageAltStringKey();
//  public static const native int WebElementImageKey();
//  public static const native int WebElementImageRectKey();
//  public static const native int WebElementImageURLKey();
//  public static const native int WebElementIsSelectedKey();
//  public static const native int WebElementLinkLabelKey();
//  public static const native int WebElementLinkTargetFrameKey();
//  public static const native int WebElementLinkTitleKey();
//  public static const native int WebElementLinkURLKey();
//  public static const native int WebHistoryAllItemsRemovedNotification();
//  public static const native int WebHistoryItemChangedNotification();
//  public static const native int WebHistoryItemsAddedNotification();
//  public static const native int WebHistoryItemsKey();
//  public static const native int WebHistoryItemsRemovedNotification();
//  public static const native int WebHistoryLoadedNotification();
//  public static const native int WebHistorySavedNotification();
//  public static const native int WebKitErrorDomain();
//  public static const native int WebKitErrorMIMETypeKey();
//  public static const native int WebKitErrorPlugInNameKey();
//  public static const native int WebKitErrorPlugInPageURLStringKey();
//  public static const native int WebPlugInAttributesKey();
//  public static const native int WebPlugInBaseURLKey();
//  public static const native int WebPlugInContainerKey();
//  public static const native int WebPlugInContainingElementKey();
//  public static const native int WebPreferencesChangedNotification();
//  public static const native int WebViewDidBeginEditingNotification();
//  public static const native int WebViewDidChangeNotification();
//  public static const native int WebViewDidChangeSelectionNotification();
//  public static const native int WebViewDidChangeTypingStyleNotification();
//  public static const native int WebViewDidEndEditingNotification();
//  public static const native int WebViewProgressEstimateChangedNotification();
//  public static const native int WebViewProgressFinishedNotification();
//  public static const native int WebViewProgressStartedNotification();

    /** Functions */
//  public static const native int NSAccessibilityActionDescription(int action);
//  public static const native void NSAccessibilityPostNotification(int element, int notification);
//  public static const native void NSAccessibilityRaiseBadArgumentException(int element, int attribute, int value);
//  public static const native int NSAccessibilityRoleDescription(int role, int subrole);
//  public static const native int NSAccessibilityRoleDescriptionForUIElement(int element);
//  public static const native int NSAccessibilityUnignoredAncestor(int element);
//  public static const native int NSAccessibilityUnignoredChildren(int originalChildren);
//  public static const native int NSAccessibilityUnignoredChildrenForOnlyChild(int originalChild);
//  public static const native int NSAccessibilityUnignoredDescendant(int element);
//  public static const native bool NSApplicationLoad();
//  public static const native int NSApplicationMain(int argc, int argv);
//  public static const native int NSAvailableWindowDepths();
//  public static const native void NSBeep();
//  public static const native void NSBeginAlertSheet(int title, int defaultButton, int alternateButton, int otherButton, int docWindow, int modalDelegate, int didEndSelector, int didDismissSelector, int contextInfo, int msgFormat);
//  public static const native void NSBeginCriticalAlertSheet(int title, int defaultButton, int alternateButton, int otherButton, int docWindow, int modalDelegate, int didEndSelector, int didDismissSelector, int contextInfo, int msgFormat);
//  public static const native void NSBeginInformationalAlertSheet(int title, int defaultButton, int alternateButton, int otherButton, int docWindow, int modalDelegate, int didEndSelector, int didDismissSelector, int contextInfo, int msgFormat);
//  public static const native int NSBestDepth(int colorSpace, int bps, int bpp, bool planar, int exactMatch);
    alias NSGraphics.NSBitsPerPixelFromDepth NSBitsPerPixelFromDepth;
//  public static const native int NSBitsPerSampleFromDepth(int depth);
//  public static const native int NSColorSpaceFromDepth(int depth);
//  public static const native int NSConvertGlyphsToPackedGlyphs(int glBuf, int count, int packing, int packedGlyphs);
//  public static const native void NSCopyBits(int srcGState, NSRect srcRect, NSPoint destPoint);
//  public static const native void NSCountWindows(int count);
//  public static const native void NSCountWindowsForContext(int context, int count);
//  public static const native int NSCreateFileContentsPboardType(int fileType);
//  public static const native int NSCreateFilenamePboardType(int fileType);
//  public static const native void NSDisableScreenUpdates();
//  public static const native void NSDottedFrameRect(NSRect aRect);
//  public static const native void NSDrawBitmap(NSRect rect, int width, int height, int bps, int spp, int bpp, int bpr, bool isPlanar, bool hasAlpha, int colorSpaceName, int data);
//  public static const native void NSDrawButton(NSRect aRect, NSRect clipRect);
////    public static const native NSRect NSDrawColorTiledRects(NSRect boundsRect, NSRect clipRect, int sides, int colors, int count);
//  public static const native void NSDrawDarkBezel(NSRect aRect, NSRect clipRect);
//  public static const native void NSDrawGrayBezel(NSRect aRect, NSRect clipRect);
//  public static const native void NSDrawGroove(NSRect aRect, NSRect clipRect);
//  public static const native void NSDrawLightBezel(NSRect aRect, NSRect clipRect);
//  public static const native void NSDrawNinePartImage(NSRect frame, int topLeftCorner, int topEdgeFill, int topRightCorner, int leftEdgeFill, int centerFill, int rightEdgeFill, int bottomLeftCorner, int bottomEdgeFill, int bottomRightCorner, int op, float alphaFraction, bool flipped);
//  public static const native void NSDrawThreePartImage(NSRect frame, int startCap, int centerFill, int endCap, bool vertical, int op, float alphaFraction, bool flipped);
////    public static const native NSRect NSDrawTiledRects(NSRect boundsRect, NSRect clipRect, int sides, int grays, int count);
//  public static const native void NSDrawWhiteBezel(NSRect aRect, NSRect clipRect);
//  public static const native void NSDrawWindowBackground(NSRect aRect);
//  public static const native void NSEnableScreenUpdates();
//  public static const native void NSEraseRect(NSRect aRect);
//  public static const native int NSEventMaskFromType(int type);
//  public static const native void NSFrameRect(NSRect aRect);
//  public static const native void NSFrameRectWithWidth(NSRect aRect, float frameWidth);
//  public static const native void NSFrameRectWithWidthUsingOperation(NSRect aRect, float frameWidth, int op);
//  public static const native int NSGetAlertPanel(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton);
//  public static const native int NSGetCriticalAlertPanel(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton);
//  public static const native int NSGetFileType(int pboardType);
//  public static const native int NSGetFileTypes(int pboardTypes);
//  public static const native int NSGetInformationalAlertPanel(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton);
//  public static const native int NSGetWindowServerMemory(int context, int virtualMemory, int windowBackingMemory, int windowDumpString);
//  public static const native void NSHighlightRect(NSRect aRect);
//  public static const native int NSInterfaceStyleForKey(int key, int responder);
//  public static const native bool NSIsControllerMarker(int object);
//  public static const native int NSNumberOfColorComponents(int colorSpaceName);
//  public static const native void NSOpenGLGetOption(int pname, int param);
//  public static const native void NSOpenGLGetVersion(int major, int minor);
//  public static const native void NSOpenGLSetOption(int pname, int param);
//  public static const native bool NSPerformService(int itemName, int pboard);
//  public static const native bool NSPlanarFromDepth(int depth);
//  public static const native int NSReadPixel(NSPoint passedPoint);
//  public static const native void NSRectClip(NSRect aRect);
//  public static const native void NSRectClipList(int rects, int count);
//  public static const native void NSRectFill(NSRect aRect);
//  public static const native void NSRectFillList(int rects, int count);
//  public static const native void NSRectFillListUsingOperation(int rects, int count, int op);
//  public static const native void NSRectFillListWithColors(int rects, int colors, int num);
//  public static const native void NSRectFillListWithColorsUsingOperation(int rects, int colors, int num, int op);
//  public static const native void NSRectFillListWithGrays(int rects, int grays, int num);
//  public static const native void NSRectFillUsingOperation(NSRect aRect, int op);
//  public static const native void NSRegisterServicesProvider(int provider, int name);
//  public static const native void NSReleaseAlertPanel(int panel);
//  public static const native int NSRunAlertPanel(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton);
//  public static const native int NSRunAlertPanelRelativeToWindow(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton, int docWindow);
//  public static const native int NSRunCriticalAlertPanel(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton);
//  public static const native int NSRunCriticalAlertPanelRelativeToWindow(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton, int docWindow);
//  public static const native int NSRunInformationalAlertPanel(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton);
//  public static const native int NSRunInformationalAlertPanelRelativeToWindow(int title, int msgFormat, int defaultButton, int alternateButton, int otherButton, int docWindow);
//  public static const native void NSSetFocusRingStyle(int placement);
//  public static const native int NSSetShowsServicesMenuItem(int itemName, bool enabled);
////    public static const native void NSShowAnimationEffect(int animationEffect, NSPoint centerLocation, NSSize size, int animationDelegate, int didEndSelector, int contextInfo);
//  public static const native bool NSShowsServicesMenuItem(int itemName);
//  public static const native void NSUnregisterServicesProvider(int name);
//  public static const native void NSUpdateDynamicServices();
//  public static const native void NSWindowList(int size, int list);
//  public static const native void NSWindowListForContext(int context, int size, int list);
//  public static const native int NSAllHashTableObjects(int table);
//  public static const native int NSAllMapTableKeys(int table);
//  public static const native int NSAllMapTableValues(int table);
//  public static const native int NSAllocateCollectable(int size, int options);
//  public static const native int NSAllocateMemoryPages(int bytes);
//  public static const native int NSAllocateObject(int aClass, int extraBytes, int zone);
//  public static const native int NSClassFromString(int aClassName);
//  public static const native bool NSCompareHashTables(int table1, int table2);
//  public static const native bool NSCompareMapTables(int table1, int table2);
//  public static const native bool NSContainsRect(NSRect aRect, NSRect bRect);
////    public static const native NSSwappedDouble NSConvertHostDoubleToSwapped(double x);
////    public static const native NSSwappedFloat NSConvertHostFloatToSwapped(float x);
//  public static const native double NSConvertSwappedDoubleToHost(NSSwappedDouble x);
//  public static const native float NSConvertSwappedFloatToHost(NSSwappedFloat x);
//  public static const native int NSCopyHashTableWithZone(int table, int zone);
//  public static const native int NSCopyMapTableWithZone(int table, int zone);
//  public static const native void NSCopyMemoryPages(int source, int dest, int bytes);
//  public static const native int NSCopyObject(int object, int extraBytes, int zone);
//  public static const native int NSCountFrames();
//  public static const native int NSCountHashTable(int table);
//  public static const native int NSCountMapTable(int table);
//  public static const native int NSCreateHashTable(NSHashTableCallBacks callBacks, int capacity);
//  public static const native int NSCreateHashTableWithZone(NSHashTableCallBacks callBacks, int capacity, int zone);
//  public static const native int NSCreateMapTable(NSMapTableKeyCallBacks keyCallBacks, NSMapTableValueCallBacks valueCallBacks, int capacity);
//  public static const native int NSCreateMapTableWithZone(NSMapTableKeyCallBacks keyCallBacks, NSMapTableValueCallBacks valueCallBacks, int capacity, int zone);
//  public static const native int NSCreateZone(int startSize, int granularity, bool canFree);
//  public static const native void NSDeallocateMemoryPages(int ptr, int bytes);
//  public static const native void NSDeallocateObject(int object);
//  public static const native int NSDecimalAdd(int result, int leftOperand, int rightOperand, int roundingMode);
//  public static const native void NSDecimalCompact(int number);
//  public static const native int NSDecimalCompare(int leftOperand, int rightOperand);
//  public static const native void NSDecimalCopy(int destination, int source);
//  public static const native int NSDecimalDivide(int result, int leftOperand, int rightOperand, int roundingMode);
//  public static const native bool NSDecimalIsNotANumber(int dcm);
//  public static const native int NSDecimalMultiply(int result, int leftOperand, int rightOperand, int roundingMode);
//  public static const native int NSDecimalMultiplyByPowerOf10(int result, int number, short power, int roundingMode);
//  public static const native int NSDecimalNormalize(int number1, int number2, int roundingMode);
//  public static const native int NSDecimalPower(int result, int number, int power, int roundingMode);
//  public static const native void NSDecimalRound(int result, int number, int scale, int roundingMode);
//  public static const native int NSDecimalString(int dcm, int locale);
//  public static const native int NSDecimalSubtract(int result, int leftOperand, int rightOperand, int roundingMode);
//  public static const native bool NSDecrementExtraRefCountWasZero(int object);
//  public static const native int NSDefaultMallocZone();
//  public static const native void NSDivideRect(NSRect inRect, int slice, int rem, float amount, int edge);
//  public static const native void NSEndHashTableEnumeration(int enumerator);
//  public static const native void NSEndMapTableEnumeration(int enumerator);
////    public static const native NSHashEnumerator NSEnumerateHashTable(int table);
////    public static const native NSMapEnumerator NSEnumerateMapTable(int table);
//  public static const native bool NSEqualPoints(NSPoint aPoint, NSPoint bPoint);
//  public static const native bool NSEqualRanges(NSRange range1, NSRange range2);
//  public static const native bool NSEqualRects(NSRect aRect, NSRect bRect);
//  public static const native bool NSEqualSizes(NSSize aSize, NSSize bSize);
//  public static const native int NSExtraRefCount(int object);
    alias NSHFSFileTypes.NSFileTypeForHFSTypeCode NSFileTypeForHFSTypeCode;
//  public static const native int NSFrameAddress(int frame);
//  public static const native void NSFreeHashTable(int table);
//  public static const native void NSFreeMapTable(int table);
//  public static const native int NSFullUserName();
//  public static const native int NSGetSizeAndAlignment(int typePtr, int sizep, int alignp);
//  public static const native int NSGetUncaughtExceptionHandler();
//  public static const native int NSHFSTypeCodeFromFileType(int fileTypeString);
//  public static const native int NSHFSTypeOfFile(int fullFilePath);
//  public static const native int NSHashGet(int table, int pointer);
//  public static const native void NSHashInsert(int table, int pointer);
//  public static const native int NSHashInsertIfAbsent(int table, int pointer);
//  public static const native void NSHashInsertKnownAbsent(int table, int pointer);
//  public static const native void NSHashRemove(int table, int pointer);
//  public static const native float NSHeight(NSRect aRect);
//  public static const native int NSHomeDirectory();
//  public static const native int NSHomeDirectoryForUser(int userName);
//  public static const native int NSHostByteOrder();
//  public static const native void NSIncrementExtraRefCount(int object);
////    public static const native NSRect NSInsetRect(NSRect aRect, float dX, float dY);
////    public static const native NSRect NSIntegralRect(NSRect aRect);
////    public static const native NSRange NSIntersectionRange(NSRange range1, NSRange range2);
////    public static const native NSRect NSIntersectionRect(NSRect aRect, NSRect bRect);
//  public static const native bool NSIntersectsRect(NSRect aRect, NSRect bRect);
//  public static const native bool NSIsEmptyRect(NSRect aRect);
//  public static const native bool NSIsFreedObject(int anObject);
//  public static const native bool NSLocationInRange(int loc, NSRange range);
//  public static const native void NSLog(int format);
//  public static const native int NSLogPageSize();
//  public static const native void NSLogv(int format, int args);
//  public static const native int NSMakeCollectable(int cf);
////    public static const native NSPoint NSMakePoint(float x, float y);
////    public static const native NSRange NSMakeRange(int loc, int len);
////    public static const native NSRect NSMakeRect(float x, float y, float w, float h);
////    public static const native NSSize NSMakeSize(float w, float h);
//  public static const native int NSMapGet(int table, int key);
//  public static const native void NSMapInsert(int table, int key, int value);
//  public static const native int NSMapInsertIfAbsent(int table, int key, int value);
//  public static const native void NSMapInsertKnownAbsent(int table, int key, int value);
//  public static const native bool NSMapMember(int table, int key, int originalKey, int value);
//  public static const native void NSMapRemove(int table, int key);
//  public static const native int NSMaxRange(NSRange range);
//  public static const native float NSMaxX(NSRect aRect);
//  public static const native float NSMaxY(NSRect aRect);
//  public static const native float NSMidX(NSRect aRect);
//  public static const native float NSMidY(NSRect aRect);
//  public static const native float NSMinX(NSRect aRect);
//  public static const native float NSMinY(NSRect aRect);
//  public static const native bool NSMouseInRect(NSPoint aPoint, NSRect aRect, bool flipped);
//  public static const native int NSNextHashEnumeratorItem(int enumerator);
//  public static const native bool NSNextMapEnumeratorPair(int enumerator, int key, int value);
////    public static const native NSRect NSOffsetRect(NSRect aRect, float dX, float dY);
//  public static const native int NSOpenStepRootDirectory();
//  public static const native int NSPageSize();
////    public static const native NSPoint NSPointFromCGPoint(CGPoint cgpoint);
////    public static const native NSPoint NSPointFromString(int aString);
//  public static const native bool NSPointInRect(NSPoint aPoint, NSRect aRect);
////    public static const native CGPoint NSPointToCGPoint(NSPoint nspoint);
//  public static const native int NSProtocolFromString(int namestr);
////    public static const native NSRange NSRangeFromString(int aString);
//  public static const native int NSRealMemoryAvailable();
//  public static const native int NSReallocateCollectable(int ptr, int size, int options);
//  public static const native void NSRecordAllocationEvent(int eventType, int object);
////    public static const native NSRect NSRectFromCGRect(CGRect cgrect);
////    public static const native NSRect NSRectFromString(int aString);
////    public static const native CGRect NSRectToCGRect(NSRect nsrect);
//  public static const native void NSRecycleZone(int zone);
//  public static const native void NSResetHashTable(int table);
//  public static const native void NSResetMapTable(int table);
//  public static const native int NSReturnAddress(int frame);
//  public static const native int NSRoundDownToMultipleOfPageSize(int bytes);
//  public static const native int NSRoundUpToMultipleOfPageSize(int bytes);
//  public static const native int NSSearchPathForDirectoriesInDomains(int directory, int domainMask, bool expandTilde);
//  public static const native int NSSelectorFromString(int aSelectorName);
//  public static const native void NSSetUncaughtExceptionHandler(int dummy);
//  public static const native void NSSetZoneName(int zone, int name);
//  public static const native bool NSShouldRetainWithZone(int anObject, int requestedZone);
////    public static const native NSSize NSSizeFromCGSize(CGSize cgsize);
////    public static const native NSSize NSSizeFromString(int aString);
////    public static const native CGSize NSSizeToCGSize(NSSize nssize);
//  public static const native int NSStringFromClass(int aClass);
//  public static const native int NSStringFromHashTable(int table);
//  public static const native int NSStringFromMapTable(int table);
//  public static const native int NSStringFromPoint(NSPoint aPoint);
//  public static const native int NSStringFromProtocol(int proto);
//  public static const native int NSStringFromRange(NSRange range);
//  public static const native int NSStringFromRect(NSRect aRect);
//  public static const native int NSStringFromSelector(int aSelector);
//  public static const native int NSStringFromSize(NSSize aSize);
//  public static const native double NSSwapBigDoubleToHost(NSSwappedDouble x);
//  public static const native float NSSwapBigFloatToHost(NSSwappedFloat x);
//  public static const native int NSSwapBigIntToHost(int x);
//  public static const native long NSSwapBigLongLongToHost(long x);
//  public static const native int NSSwapBigLongToHost(int x);
//  public static const native short NSSwapBigShortToHost(short x);
////    public static const native NSSwappedDouble NSSwapDouble(NSSwappedDouble x);
////    public static const native NSSwappedFloat NSSwapFloat(NSSwappedFloat x);
////    public static const native NSSwappedDouble NSSwapHostDoubleToBig(double x);
////    public static const native NSSwappedDouble NSSwapHostDoubleToLittle(double x);
////    public static const native NSSwappedFloat NSSwapHostFloatToBig(float x);
////    public static const native NSSwappedFloat NSSwapHostFloatToLittle(float x);
//  public static const native int NSSwapHostIntToBig(int x);
//  public static const native int NSSwapHostIntToLittle(int x);
//  public static const native long NSSwapHostLongLongToBig(long x);
//  public static const native long NSSwapHostLongLongToLittle(long x);
//  public static const native int NSSwapHostLongToBig(int x);
//  public static const native int NSSwapHostLongToLittle(int x);
//  public static const native short NSSwapHostShortToBig(short x);
//  public static const native short NSSwapHostShortToLittle(short x);
//  public static const native int NSSwapInt(int inv);
//  public static const native double NSSwapLittleDoubleToHost(NSSwappedDouble x);
//  public static const native float NSSwapLittleFloatToHost(NSSwappedFloat x);
//  public static const native int NSSwapLittleIntToHost(int x);
//  public static const native long NSSwapLittleLongLongToHost(long x);
//  public static const native int NSSwapLittleLongToHost(int x);
//  public static const native short NSSwapLittleShortToHost(short x);
//  public static const native int NSSwapLong(int inv);
//  public static const native long NSSwapLongLong(long inv);
//  public static const native short NSSwapShort(short inv);
//  public static const native int NSTemporaryDirectory();
//  public static const native NSRange NSUnionRange(NSRange range1, NSRange range2);
//  public static const native NSRect NSUnionRect(NSRect aRect, NSRect bRect);
//  public static const native int NSUserName();
//  public static const native float NSWidth(NSRect aRect);
//  public static const native int NSZoneCalloc(int zone, int numElems, int byteSize);
//  public static const native void NSZoneFree(int zone, int ptr);
//  public static const native int NSZoneFromPointer(int ptr);
//  public static const native int NSZoneMalloc(int zone, int size);
//  public static const native int NSZoneName(int zone);
//  public static const native int NSZoneRealloc(int zone, int ptr, int size);
//  public static const native int NXReadNSObjectFromCoder(int decoder);

}
